***
*** Inequality measures for Cte d'Ivoire (2002)
***
*** The code calculates each of the inequality measures in Table 3.2, 
*** with and without weights.
*** Borrowed from A. Deaton
***
cd "C:\Documents and settings\wb235844.WB\Desktop\Other surveys\Donnes\STATA"
do CIVexp

version 4.0
#delimit ;
drop _all;
cap log close;
log using CIVineq.log, replace;

/* defining program to calculate gini without weights */
use hhexp1, clear;
g weight=hhsize*pond;
g pce=hhexp/hhsize;
tempvar hhs;
g hhs=hhsize;

cap program drop giniu;
program define giniu;
gsort - pce;
gen hrnk=sum(hhs);
gen hhrnk=hrnk[_n-1]+1;
replace hhrnk=1 in 1;
qui summ hhs;
local bign=_result(1)*_result(3);
qui summ pce [aweight=hhs];
local mn=_result(3);
gen rnkx=pce*(hhrnk+0.5*(hhs-1));
qui summ rnkx [aweight=hhs];
local g=(`bign'+1)-(2/`mn')*_result(3);
local g=`g'/(`bign'-1);
local yr=2002;
dis("Gini coefficient `yr' =`g'");
end; 

/* defining program to calculate gini with weights */
cap program drop giniw;
program define giniw;
gsort - pce;
replace hhs=hhs*pond;
cap drop hrnk;
gen hrnk=sum(hhs);
cap drop hhrnk;
gen hhrnk=hrnk[_n-1]+1;
replace hhrnk=1 in 1;
qui summ hhs;
local bign=_result(1)*_result(3);
qui summ pce [aweight=hhs];
local mn=_result(3);
cap drop rnkx;
gen rnkx=pce*(hhrnk+0.5*(hhs-1));
qui summ rnkx [aweight=hhs];
local g=(`bign'+1)-(2/`mn')*_result(3);
local g=`g'/(`bign'-1);
local yr=2002;
dis("Gini coefficient `yr' =`g'"); 
end;

**Unweighted ginis;
giniu;
**Weighted ginis;
giniw; 


/* program for Atkinson measures */
/* argument `1' is the inequality aversion */
cap program drop aba;
program def aba;
replace hhs=hhs*pond;
qui summ pce [aweight=hhs];
local mn=_result(3);
cap drop pcerat;
gen pcerat=pce/`mn';
if `1' ==1 {;
cap drop tm;
gen tm=ln(pce/`mn');
qui summ tm [aweight=hhs];
local ineq=1-exp(_result(3));};
else {;
cap drop tm;
gen tm=(pce/`mn')^`1';
qui summ tm [aweight=hhs];
local ineq=1-(_result(3))^(1/(1-`1'));};
local yr=2002;
dis("`yr' Atkinson coefficient, eps=`1' =`ineq'");
end; 
aba 0.5;
aba 1;
aba 2; 


/* program for standard deviation of logs */
cap program drop sdlogs;
program define sdlogs;
replace hhs=hhs*pond;
cap drop lnpce;
gen lnpce=ln(pce);
qui summ lnpce [aweight=hhs];
local sdln=sqrt(_result(4));
local yr=2002;
dis("`yr' s.d. of lnpce, = `sdln'");
end; 
sdlogs; 


/* program for coefficient of variation */
cap program drop coefvar;
program define coefvar;
replace hhs=hhs*pond;
qui summ pce [aweight=hhs];
local cv=sqrt(_result(4))/_result(3);
local yr=2002;
dis("`yr' c.o.v. of pce, = `cv'"); 
end; 
coefvar; 

log close; 
