***
*** Poverty measures for Cte d'Ivoire (2002)
***
*** The code calculates the four poverty measures, together with 
*** their bootstrapped standard errors.
*** Borrowed from A. Deaton
***

cd "C:\Documents and settings\wb235844.WB\Desktop\Other surveys\Donnes\STATA"
do CIVexp

version 4.0
#delimit ;
drop _all;
cap log close;
log using povmeasures.log,replace;
use hhexp1;
/* setting the poverty line */
global pline=povline;
g weight=hhsize*pond;
g pce=hhexp/hhsize;
tempvar hhs;
g hhs=hhsize;
 
/* program for various poverty measures */

cap program drop peas;
program def peas;
gen wt=hhs*pond;
gen pind=pce <= $pline;
qui summ pind [aweight=wt];
local p0=_result(3);
gen df=(1-pce/$pline)*pind;
qui summ df [aweight=wt];
local p1=_result(3);
gen dfa=(1-pce/$pline)^2*pind;
qui summ dfa [aweight=wt];
local p2=_result(3);
drop if pce > $pline;
giniw;
local psen=`p0'*$g+`p1'*(1-$g);
dis("P0=`p0',P1=`p1',P2=`p2',Psen=`psen'");
drop _all;
end; 


/* we need this for the gini among the poor */
cap program drop giniw;
program def giniw;
gsort - pce;
qui {;
cap drop hrnk;
gen hrnk=sum(wt);
cap drop hhrnk;
gen hhrnk=hrnk[_n-1]+1;
replace hhrnk=1 in 1;};
qui summ wt;
local bign=_result(1)*_result(3);
qui summ pce [aweight=wt];
local mn=_result(3);
cap drop rnkx;
gen rnkx=pce*(hhrnk+0.5*(wt-1));
qui summ rnkx [aweight=wt];
global g=(`bign'+1)-(2/`mn')*_result(3);
global g=$g/(`bign'-1);
end; 
peas;


/* bootstrapping the measures*/ 
drop _all;
set more 1;
cap log close;
log using povboost.log, replace; 

/* program for creating clustered bootstrap sample */
/* and calculating poverty measures */

cap program drop bootit;
program def bootit;
use tempclus;
bsample _N;
sort grap;
qui {;
by grap: gen nreps=_N;
by grap: keep if _n==1;
merge grap using tempall;
keep if _merge==3;
expand nreps;
drop nreps;};
weepeas;
drop _all;
end; 


/* control program */ 
cap program drop runit;
cap program def runit;
local yr=2002;
use hhexp1, clear;
g weight=hhsize*pond;
g pce=hhexp/hhsize;
tempvar hhs;
g hhs=hhsize;

gen wt=hhs*pond;
keep grap hid pce wt;
sort grap;
save tempall, replace;
keep grap;
qui by grap: keep if _n==1;
save tempclus, replace;
drop _all;
local mcrep=1;
while `mcrep' <= 100 {;
dis ("Year `yr', Replication `mcrep'");
bootit;
drop _all;
qui set obs 1;
gen year=`yr';
gen p0=$p0;
gen p1=$p1;
gen p2=$p2;
gen psen=$psen;
qui save t33boot, replace;
drop _all;
end; 


/* calculates the various measures */
cap program drop weepeas;
program def weepeas;
global pline= 183.450;
qui {; 
gen pind=pce <= $pline;
qui summ pind [aweight=wt];
global p0=_result(3);
gen df=(1-pce/$pline)*pind;
qui summ df [aweight=wt];
global p1=_result(3);
gen dfa=(1-pce/$pline)^2*pind;
qui summ dfa [aweight=wt];
global p2=_result(3);
drop if pce > $pline;
giniw;
global psen=$p0*$g+$p1*(1-$g);
drop _all;
};
end; 
runit;
drop _all;
use t33boot;
sort strate;  /*Instead of year in the code*/
by strate: summ;
log close;

