clear _all
set mem 800m
set matsize 300
set more 1
set seed 123456789
set rmsg on
*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.

cd "C:\Documents and Settings\Bachir\Desktop\Bachir\World Bank\Wodon\CIV\Cote d'Ivoire Consumption\STATA"


cap log close
log using HealthEducExpenditures.log, replace

use temp, replace
count
keep if (agey>5 & agey<18)
count



*************
*************
**EDUCATION**
*************
*************



* Generating the total expenses for education
bysort indid: g type_enseign = s1q37      /*Type d'enseignement*/
bysort indid: g statut = s1q47            /*Statut de l'eleve*/
bysort indid: g exist_cantine = cond(s1q40==1, 1, 0)
bysort indid: g abonne_cantine = cond(s1q41==1, 1, 0)
bysort indid: g cantine = s1q44           /*Impact de la cantine sur le resultat scolaire*/
bysort indid: g cantine_charge = s1q43    /*Impact de la cantine sur les charges du chef de menage */
bysort indid: g manger_midi = s1q45       /*Lieu du repas a midi */


ta rich type_enseign [aw=weig], m
ta sex  type_enseign [aw=weig], m
ta region type_enseign [aw=weig], m
ta milieu type_enseign [aw=weig], m

ta rich statut [aw=weig], m
ta sex  statut [aw=weig], m
ta region statut [aw=weig], m
ta milieu statut [aw=weig], m

ta rich exist_cantine [aw=weig], m
ta sex  exist_cantine [aw=weig], m
ta region exist_cantine [aw=weig], m
ta milieu exist_cantine [aw=weig], m

ta rich abonne_cantine [aw=weig], m
ta sex  abonne_cantine [aw=weig], m
ta region abonne_cantine [aw=weig], m
ta milieu abonne_cantine [aw=weig], m

ta rich cantine [aw=weig], m
ta sex  cantine [aw=weig], m
ta region cantine [aw=weig], m
ta milieu cantine [aw=weig], m

ta rich cantine_charge [aw=weig], m
ta sex  cantine_charge [aw=weig], m
ta region cantine_charge [aw=weig], m
ta milieu cantine_charge [aw=weig], m

ta rich manger_midi [aw=weig], m
ta sex  manger_midi [aw=weig], m
ta region manger_midi [aw=weig], m
ta milieu manger_midi [aw=weig], m


bysort indid: g class_eleves = cond(s1q48>=0 & s1q48<40, 1, 0)
bys hid: egen seleves = sum(class_eleves)
bys hid: egen eleves = max(seleves)                           /*Total number of students children in the HH */
bysort indid: g class_prescho = cond(s1q48==0, 1, 0)               
bysort hid: egen sprescho = sum(class_prescho)
bysort hid: egen prescho = max(sprescho)                     /*Number of preschools children in the HH */
bysort indid: g class_prim = cond(s1q48>0 & s1q48 <7, 1, 0)
bysort hid: egen sprim = sum(class_prim)                    /*Number of primary children in the HH */
bysort hid: egen prim = max(sprim)
bysort indid: g class_sec = cond(s1q48>6 & s1q48 < 14, 1, 0)
bysort hid: egen ssec = sum(class_sec)
bysort hid: egen sec = max(ssec)                  /*Number of secondary children in the HH */
bysort indid: g class_postsec = cond(s1q48 >13 & s1q48 <16, 1, 0)
bysort hid: egen spostsec = sum(class_postsec)
bysort hid: egen postsec = max(spostsec)                  /*Number of postsecondary children in the HH */
bysort indid: g class_sup = cond(s1q48>15 & s1q48 < 24, 1, 0)
bysort hid: egen ssup = sum(class_sup)
bysort hid: egen sup = max(ssup)                  /*Number of tertiary children in the HH */
bysort indid: g class_techprof = cond(s1q48>23 & s1q48<40, 1, 0)
bysort hid: egen stechprof = sum(class_techprof)
bysort hid: egen techprof = max(stechprof)                  /*Number of technical/professionals children in the HH */




*Total number of students in HH



su prescho prim sec postsec sup techprof eleves [aw=weig]

ta rich class_eleves [aw=weig], m
ta milieu class_eleves [aw=weig], m
ta region class_eleves [aw=weig], m
ta sex class_eleves [aw=weig], m

ta rich class_prescho [aw=weig], m
ta milieu class_prescho [aw=weig], m
ta region class_prescho [aw=weig], m
ta sex class_prescho [aw=weig], m

ta rich class_prim [aw=weig], m
ta milieu class_prim [aw=weig], m
ta region class_prim [aw=weig], m
ta sex class_prim [aw=weig], m

ta rich class_sec [aw=weig], m
ta milieu class_sec [aw=weig], m
ta region class_sec [aw=weig], m
ta sex class_sec [aw=weig], m

ta rich class_postsec [aw=weig], m
ta milieu class_postsec [aw=weig], m
ta region class_postsec [aw=weig], m
ta sex class_postsec [aw=weig], m

ta rich class_sup [aw=weig], m
ta milieu class_sup [aw=weig], m
ta region class_sup [aw=weig], m
ta sex class_sup [aw=weig], m

ta rich class_techprof [aw=weig], m
ta milieu class_techprof [aw=weig], m
ta region class_techprof [aw=weig], m
ta sex class_techprof [aw=weig], m


*Cout cantine
preserve
sort hid
egen cout_cantine = rsum(s1q42)
bys hid: egen cout_cantines = max(cout_cantine)
drop cout_cantine
ren cout_cantines cout_cantine
su cout_cantine
replace cout_cantine = 0 if abonne_cantine==0 | cout_cantine==.
bys hid: g cout_cantine_prescho = cout_cantine/prescho
bys hid: replace cout_cantine_prescho = 0 if abonne_cantine==0 | cout_cantine_prescho==.
bys hid: g cout_cantine_prim = cout_cantine/prim 
bys hid: replace cout_cantine_prim = 0 if abonne_cantine==0 | cout_cantine_prim==.
bys hid: g cout_cantine_sec = cout_cantine/sec 
bys hid: replace cout_cantine_sec = 0 if abonne_cantine==0 | cout_cantine_sec==.
bys hid: g cout_cantine_postsec = cout_cantine/postsec 
bys hid: replace cout_cantine_postsec = 0 if abonne_cantine==0 | cout_cantine_postsec==.
bys hid: g cout_cantine_sup = cout_cantine/sup 
bys hid: replace cout_cantine_sup = 0 if abonne_cantine==0 | cout_cantine_sup==.
bys hid: g cout_cantine_techprof = cout_cantine/techprof 
bys hid: replace cout_cantine_techprof = 0 if abonne_cantine==0 | cout_cantine_techprof==.
bys hid: g cout_cantine_eleves = cout_cantine/eleves
bys hid: replace cout_cantine_eleves = 0 if abonne_cantine==0 | cout_cantine_eleves==.


collapse (sum) cout_cantine (max) cout_cantine_prescho ///
cout_cantine_prim cout_cantine_sec cout_cantine_postsec ///
cout_cantine_eleves cout_cantine_sup cout_cantine_techprof, by(hid)
sort hid
save cout_cantine, replace
restore



preserve
*Depenses a midi pour manger
sort hid
egen exp_midi = rsum(s1q46)
su exp_midi
count if exp_midi==.
bysort hid: replace exp_midi = 0 if s1q45==1 | exp_midi==.
bys hid: egen sexp_midi = max(exp_midi)
drop exp_midi
ren sexp_midi exp_midi

bys hid: g exp_midi_prescho = exp_midi/prescho
bys hid: replace exp_midi_prescho = 0 if exp_midi_prescho == .
bys hid: g exp_midi_prim = exp_midi/prim 
bys hid: replace exp_midi_prim = 0 if exp_midi_prim == .
bys hid: g exp_midi_sec = exp_midi/sec 
bys hid: replace exp_midi_sec = 0 if exp_midi_sec == .
bys hid: g exp_midi_postsec = exp_midi/postsec 
bys hid: replace exp_midi_postsec = 0 if exp_midi_postsec == .
bys hid: g exp_midi_sup = exp_midi/sup 
bys hid: replace exp_midi_sup = 0 if exp_midi_sup == .
bys hid: g exp_midi_techprof = exp_midi/techprof 
bys hid: replace exp_midi_techprof = 0 if exp_midi_techprof == .
bys hid: g exp_midi_eleves = exp_midi/eleves 
bys hid: replace exp_midi_eleves = 0 if exp_midi_eleves == .

collapse (sum) exp_midi (max) exp_midi_prescho ///
exp_midi_prim exp_midi_sec exp_midi_postsec ///
exp_midi_sup exp_midi_techprof exp_midi_eleves, by(hid)
sort hid
save exp_midi, replace
restore


bysort indid: g prise_charge = cond(s1q50==1, 1, 0)
bysort indid: g qui_prise_charge = s1q51
recode qui_prise_charge 1=1 2/7=2 8/max=3
cap lab drop qui_prise_charge 
lab def qui_prise_charge 1"Etat" 2"Autre Organisme" 3"Famille ou autre"
lab val qui_prise_charge qui_prise_charge
bysort indid: g lastyear_enroll = cond(s1q52==1, 1, 0)


ta rich prise_charge [aw=weig], m
ta sex  prise_charge [aw=weig], m
ta region prise_charge [aw=weig], m
ta milieu prise_charge [aw=weig], m

ta rich qui_prise_charge [aw=weig], m
ta sex  qui_prise_charge [aw=weig], m
ta region qui_prise_charge [aw=weig], m
ta milieu qui_prise_charge [aw=weig], m

ta rich lastyear_enroll [aw=weig], m
ta sex  lastyear_enroll [aw=weig], m
ta region lastyear_enroll [aw=weig], m
ta milieu lastyear_enroll [aw=weig], m




*Generating education expenses
*preserve
sort hid
egen inscription = rsum(s1q63 s1q64)
bys hid: replace inscription = 0 if inscription == .
bys hid: egen inscriptions = sum(inscription)
bys hid: egen sinscription = max(inscriptions)



drop inscription inscriptions
ren sinscription inscription
egen scolarite = rsum(s1q65)
bys hid: replace scolarite = 0 if scolarite == .
bys hid: egen scolarites = sum(scolarite)
bys hid: egen sscolarite = max(scolarites)
drop scolarite scolarites
ren sscolarite scolarite
egen fournitures = rsum(s1q66 s1q67) 
bys hid: replace fournitures = 0 if fournitures == .
bys hid: egen fournituress = sum(fournitures)
bys hid: egen sfournitures = max(fournituress)
drop fournitures fournituress
ren sfournitures fournitures 
egen uniformes = rsum(s1q68)
bys hid: replace uniformes = 0 if uniformes == .
bys hid: egen uniformess = sum(uniformes)
bys hid: egen suniformes = max(uniformess)
drop uniformes uniformess
ren suniformes uniformes 
egen transport = rsum(s1q69)
bys hid: replace transport = 0 if transport == .
bys hid: egen transports = sum(transport)
bys hid: egen stransport = max(transports)
drop transport transports
ren stransport transport 
egen autres_educ_dep = rsum(s1q70 s1q71 s1q72 s1q73 s1q74)
bys hid: replace autres_educ_dep = 0 if autres_educ_dep == .
bys hid: egen autres_educ_deps = sum(autres_educ_dep)
bys hid: egen sautres_educ_dep = max(autres_educ_deps)
drop autres_educ_dep autres_educ_deps
ren sautres_educ_dep autres_educ_dep
egen bourses = rsum(s1q76)
bys hid: replace bourses = 0 if bourses == .
bys hid: egen boursess = sum(bourses)
bys hid: egen sbourses = max(boursess)
drop bourses boursess
ren sbourses bourses
bysort indid: g toteduc1 = inscription + scolarite + fournitures + uniformes + transport + autres_educ_dep
bysort indid: g toteduc2 = toteduc1 + bourses 
bys hid: replace toteduc1 = 0 if toteduc1 == .
bys hid: egen toteduc1s = sum(toteduc1)
bys hid: egen stoteduc1 = max(toteduc1s)
drop toteduc1 toteduc1s
ren stoteduc1 toteduc1
bys hid: replace toteduc2 = 0 if toteduc2 == .
bys hid: egen toteduc2s = sum(toteduc2)
bys hid: egen stoteduc2 = max(toteduc2s)
drop toteduc2 toteduc2s
ren stoteduc2 toteduc2


table rich [aw=weig], col row c(mean inscription ) f(%9.0g)
table sex [aw=weig], col row c(mean inscription ) f(%9.0g)
table milieu [aw=weig], col row c(mean inscription ) f(%9.0g)
table region [aw=weig], col row c(mean inscription ) f(%9.0g)

table rich [aw=weig], col row c(mean scolarite ) f(%9.0g)
table sex [aw=weig], col row c(mean scolarite ) f(%9.0g)
table milieu [aw=weig], col row c(mean scolarite ) f(%9.0g)
table region [aw=weig], col row c(mean scolarite ) f(%9.0g)

table rich [aw=weig], col row c(mean fournitures ) f(%9.0g)
table sex [aw=weig], col row c(mean fournitures ) f(%9.0g)
table milieu [aw=weig], col row c(mean fournitures ) f(%9.0g)
table region [aw=weig], col row c(mean fournitures ) f(%9.0g)

table rich [aw=weig], col row c(mean uniformes ) f(%9.0g)
table sex [aw=weig], col row c(mean uniformes ) f(%9.0g)
table milieu [aw=weig], col row c(mean uniformes ) f(%9.0g)
table region [aw=weig], col row c(mean uniformes ) f(%9.0g)

table rich [aw=weig], col row c(mean transport ) f(%9.0g)
table sex [aw=weig], col row c(mean transport ) f(%9.0g)
table milieu [aw=weig], col row c(mean transport ) f(%9.0g)
table region [aw=weig], col row c(mean transport ) f(%9.0g)


table rich [aw=weig], col row c(mean autres_educ_dep ) f(%9.0g)
table sex [aw=weig], col row c(mean autres_educ_dep ) f(%9.0g)
table milieu [aw=weig], col row c(mean autres_educ_dep ) f(%9.0g)
table region [aw=weig], col row c(mean autres_educ_dep ) f(%9.0g)



table rich [aw=weig], col row c(mean bourses ) f(%9.0g)
table sex [aw=weig], col row c(mean bourses ) f(%9.0g)
table milieu [aw=weig], col row c(mean bourses ) f(%9.0g)
table region [aw=weig], col row c(mean bourses ) f(%9.0g)


table rich [aw=weig], col row c(mean toteduc1 ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc1 ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc1 ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc1 ) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc2 ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc2 ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc2 ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc2 ) f(%9.0g)

*Per capita education expenditures

bys hid: g inscription_eleves = inscription/eleves
bys hid: g inscription_prescho = inscription/prescho
bys hid: g inscription_prim = inscription /prim 
bys hid: g inscription_sec = inscription/sec 
bys hid: g inscription_postsec = inscription/postsec 
bys hid: g inscription_sup = inscription/sup 
bys hid: g inscription_techprof = inscription/techprof 

bys hid: g scolarite_eleves = scolarite/eleves
bys hid: g scolarite_prescho = scolarite/prescho
bys hid: g scolarite_prim = scolarite/prim 
bys hid: g scolarite_sec = scolarite/sec 
bys hid: g scolarite_postsec = scolarite/postsec 
bys hid: g scolarite_sup = scolarite/sup 
bys hid: g scolarite_techprof = scolarite/techprof 

bys hid: g fournitures_eleves = fournitures/eleves
bys hid: g fournitures_prescho = fournitures/prescho
bys hid: g fournitures_prim = fournitures/prim 
bys hid: g fournitures_sec = fournitures/sec 
bys hid: g fournitures_postsec = fournitures/postsec 
bys hid: g fournitures_sup = fournitures/sup 
bys hid: g fournitures_techprof = fournitures/techprof

bys hid: g uniformes_eleves = uniformes/eleves
bys hid: g uniformes_prescho = uniformes/prescho
bys hid: g uniformes_prim = uniformes/prim 
bys hid: g uniformes_sec = uniformes/sec 
bys hid: g uniformes_postsec = uniformes/postsec 
bys hid: g uniformes_sup = uniformes/sup 
bys hid: g uniformes_techprof = uniformes/techprof 

bys hid: g transport_eleves = transport/eleves
bys hid: g transport_prescho = transport/prescho
bys hid: g transport_prim = transport/prim 
bys hid: g transport_sec = transport/sec 
bys hid: g transport_postsec = transport/postsec 
bys hid: g transport_sup = transport/sup 
bys hid: g transport_techprof = transport/techprof 

bys hid: g autres_educ_dep_eleves = autres_educ_dep/eleves
bys hid: g autres_educ_dep_prescho = autres_educ_dep/prescho
bys hid: g autres_educ_dep_prim = autres_educ_dep/prim 
bys hid: g autres_educ_dep_sec = autres_educ_dep/sec 
bys hid: g autres_educ_dep_postsec = autres_educ_dep/postsec 
bys hid: g autres_educ_dep_sup = autres_educ_dep/sup 
bys hid: g autres_educ_dep_techprof = autres_educ_dep/techprof 

bys hid: g bourses_eleves = bourses/eleves
bys hid: g bourses_prescho = bourses/prescho
bys hid: g bourses_prim = bourses/prim 
bys hid: g bourses_sec = bourses/sec 
bys hid: g bourses_postsec = bourses/postsec 
bys hid: g bourses_sup = bourses/sup 
bys hid: g bourses_techprof = bourses/techprof 

bys hid: g toteduc1_eleves = toteduc1/eleves
bys hid: g toteduc1_prescho = toteduc1/prescho
bys hid: g toteduc1_prim = toteduc1/prim 
bys hid: g toteduc1_sec = toteduc1/sec 
bys hid: g toteduc1_postsec = toteduc1/postsec 
bys hid: g toteduc1_sup = toteduc1/sup 
bys hid: g toteduc1_techprof = toteduc1/techprof 

bys hid: g toteduc2_eleves = toteduc2/eleves
bys hid: g toteduc2_prescho = toteduc2/prescho
bys hid: g toteduc2_prim = toteduc2/prim 
bys hid: g toteduc2_sec = toteduc2/sec 
bys hid: g toteduc2_postsec = toteduc2/postsec 
bys hid: g toteduc2_sup = toteduc2/sup 
bys hid: g toteduc2_techprof = toteduc2/techprof 


su  inscription* scolarite* fournitures* uniformes* transport* autres_educ_dep* bourses* toteduc1* toteduc2* [aw=weig]


table rich [aw=weig], col row c(mean inscription_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean inscription_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean inscription_eleves) f(%9.0g)
table region [aw=weig], col row c(mean inscription_eleves) f(%9.0g)

table rich [aw=weig], col row c(mean inscription_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean inscription_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean inscription_prescho) f(%9.0g)
table region [aw=weig], col row c(mean inscription_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean inscription_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean inscription_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean inscription_prim ) f(%9.0g)
table region [aw=weig], col row c(mean inscription_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean inscription_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean inscription_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean inscription_sec ) f(%9.0g)
table region [aw=weig], col row c(mean inscription_sec ) f(%9.0g)

table rich [aw=weig], col row c(mean inscription_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean inscription_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean inscription_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean inscription_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean inscription_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean inscription_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean inscription_sup ) f(%9.0g)
table region [aw=weig], col row c(mean inscription_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean inscription_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean inscription_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean inscription_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean inscription_techprof ) f(%9.0g)



table rich [aw=weig], col row c(mean scolarite_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean scolarite_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean scolarite_eleves) f(%9.0g)
table region [aw=weig], col row c(mean scolarite_eleves) f(%9.0g)

table rich [aw=weig], col row c(mean scolarite_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean scolarite_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean scolarite_prescho) f(%9.0g)
table region [aw=weig], col row c(mean scolarite_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean scolarite_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean scolarite_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean scolarite_prim ) f(%9.0g)
table region [aw=weig], col row c(mean scolarite_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean scolarite_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean scolarite_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean scolarite_sec ) f(%9.0g)
table region [aw=weig], col row c(mean scolarite_sec ) f(%9.0g)

table rich [aw=weig], col row c(mean scolarite_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean scolarite_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean scolarite_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean scolarite_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean scolarite_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean scolarite_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean scolarite_sup ) f(%9.0g)
table region [aw=weig], col row c(mean scolarite_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean scolarite_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean scolarite_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean scolarite_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean scolarite_techprof ) f(%9.0g)


table rich [aw=weig], col row c(mean fournitures_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean fournitures_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean fournitures_eleves) f(%9.0g)
table region [aw=weig], col row c(mean fournitures_eleves) f(%9.0g)

table rich [aw=weig], col row c(mean fournitures_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean fournitures_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean fournitures_prescho) f(%9.0g)
table region [aw=weig], col row c(mean fournitures_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean fournitures_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean fournitures_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean fournitures_prim ) f(%9.0g)
table region [aw=weig], col row c(mean fournitures_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean fournitures_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean fournitures_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean fournitures_sec ) f(%9.0g)
table region [aw=weig], col row c(mean fournitures_sec ) f(%9.0g)

table rich [aw=weig], col row c(mean fournitures_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean fournitures_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean fournitures_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean fournitures_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean fournitures_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean fournitures_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean fournitures_sup ) f(%9.0g)
table region [aw=weig], col row c(mean fournitures_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean fournitures_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean fournitures_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean fournitures_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean fournitures_techprof ) f(%9.0g)


table rich [aw=weig], col row c(mean uniformes_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean uniformes_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean uniformes_eleves) f(%9.0g)
table region [aw=weig], col row c(mean uniformes_eleves) f(%9.0g)

table rich [aw=weig], col row c(mean uniformes_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean uniformes_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean uniformes_prescho) f(%9.0g)
table region [aw=weig], col row c(mean uniformes_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean uniformes_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean uniformes_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean uniformes_prim ) f(%9.0g)
table region [aw=weig], col row c(mean uniformes_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean uniformes_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean uniformes_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean uniformes_sec ) f(%9.0g)
table region [aw=weig], col row c(mean uniformes_sec ) f(%9.0g)

table rich [aw=weig], col row c(mean uniformes_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean uniformes_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean uniformes_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean uniformes_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean uniformes_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean uniformes_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean uniformes_sup ) f(%9.0g)
table region [aw=weig], col row c(mean uniformes_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean uniformes_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean uniformes_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean uniformes_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean uniformes_techprof ) f(%9.0g)


table rich [aw=weig], col row c(mean transport_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean transport_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean transport_eleves) f(%9.0g)
table region [aw=weig], col row c(mean transport_eleves) f(%9.0g)


table rich [aw=weig], col row c(mean transport_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean transport_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean transport_prescho) f(%9.0g)
table region [aw=weig], col row c(mean transport_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean transport_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean transport_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean transport_prim ) f(%9.0g)
table region [aw=weig], col row c(mean transport_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean transport_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean transport_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean transport_sec ) f(%9.0g)
table region [aw=weig], col row c(mean transport_sec) f(%9.0g)

table rich [aw=weig], col row c(mean transport_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean transport_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean transport_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean transport_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean transport_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean transport_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean transport_sup ) f(%9.0g)
table region [aw=weig], col row c(mean transport_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean transport_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean transport_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean transport_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean transport_techprof ) f(%9.0g)


table rich [aw=weig], col row c(mean autres_educ_dep_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean autres_educ_dep_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean autres_educ_dep_eleves) f(%9.0g)
table region [aw=weig], col row c(mean autres_educ_dep_eleves) f(%9.0g)

table rich [aw=weig], col row c(mean autres_educ_dep_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean autres_educ_dep_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean autres_educ_dep_prescho) f(%9.0g)
table region [aw=weig], col row c(mean autres_educ_dep_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean autres_educ_dep_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean autres_educ_dep_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean autres_educ_dep_prim ) f(%9.0g)
table region [aw=weig], col row c(mean autres_educ_dep_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean autres_educ_dep_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean autres_educ_dep_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean autres_educ_dep_sec ) f(%9.0g)
table region [aw=weig], col row c(mean autres_educ_dep_sec ) f(%9.0g)

table rich [aw=weig], col row c(mean autres_educ_dep_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean autres_educ_dep_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean autres_educ_dep_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean autres_educ_dep_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean autres_educ_dep_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean autres_educ_dep_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean autres_educ_dep_sup ) f(%9.0g)
table region [aw=weig], col row c(mean autres_educ_dep_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean autres_educ_dep_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean autres_educ_dep_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean autres_educ_dep_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean autres_educ_dep_techprof ) f(%9.0g)


table rich [aw=weig], col row c(mean bourses_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean bourses_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean bourses_eleves) f(%9.0g)
table region [aw=weig], col row c(mean bourses_eleves) f(%9.0g)

table rich [aw=weig], col row c(mean bourses_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean bourses_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean bourses_prescho) f(%9.0g)
table region [aw=weig], col row c(mean bourses_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean bourses_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean bourses_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean bourses_prim ) f(%9.0g)
table region [aw=weig], col row c(mean bourses_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean bourses_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean bourses_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean bourses_sec ) f(%9.0g)
table region [aw=weig], col row c(mean bourses_sec ) f(%9.0g)

table rich [aw=weig], col row c(mean bourses_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean bourses_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean bourses_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean bourses_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean bourses_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean bourses_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean bourses_sup ) f(%9.0g)
table region [aw=weig], col row c(mean bourses_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean bourses_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean bourses_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean bourses_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean bourses_techprof ) f(%9.0g)


table rich [aw=weig], col row c(mean toteduc1_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc1_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc1_eleves) f(%9.0g)
table region [aw=weig], col row c(mean toteduc1_eleves) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc1_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc1_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc1_prescho) f(%9.0g)
table region [aw=weig], col row c(mean toteduc1_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc1_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc1_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc1_prim ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc1_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc1_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc1_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc1_sec ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc1_sec ) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc1_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc1_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc1_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc1_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc1_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc1_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc1_sup ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc1_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc1_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc1_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc1_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc1_techprof ) f(%9.0g)


table rich [aw=weig], col row c(mean toteduc2_eleves) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc2_eleves) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc2_eleves) f(%9.0g)
table region [aw=weig], col row c(mean toteduc2_eleves) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc2_prescho) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc2_prescho) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc2_prescho) f(%9.0g)
table region [aw=weig], col row c(mean toteduc2_prescho) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc2_prim ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc2_prim ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc2_prim ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc2_prim ) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc2_sec ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc2_sec ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc2_sec ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc2_sec ) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc2_postsec ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc2_postsec ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc2_postsec ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc2_postsec) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc2_sup ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc2_sup ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc2_sup ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc2_sup ) f(%9.0g)

table rich [aw=weig], col row c(mean toteduc2_techprof ) f(%9.0g)
table sex [aw=weig], col row c(mean toteduc2_techprof ) f(%9.0g)
table milieu [aw=weig], col row c(mean toteduc2_techprof ) f(%9.0g)
table region [aw=weig], col row c(mean toteduc2_techprof ) f(%9.0g)





table rich milieu [aw=weight], col row c(mean inscription_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean inscription_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean inscription_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean inscription_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean inscription_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean inscription_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean inscription_techprof ) f(%9.0g)

table rich milieu [aw=weight], col row c(mean scolarite_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean scolarite_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean scolarite_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean scolarite_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean scolarite_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean scolarite_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean scolarite_techprof ) f(%9.0g)

table rich milieu [aw=weight], col row c(mean fournitures_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean fournitures_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean fournitures_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean fournitures_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean fournitures_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean fournitures_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean fournitures_techprof ) f(%9.0g)

table rich milieu [aw=weight], col row c(mean uniformes_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean uniformes_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean uniformes_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean uniformes_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean uniformes_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean uniformes_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean uniformes_techprof ) f(%9.0g)

table rich milieu [aw=weight], col row c(mean transport_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean transport_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean transport_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean transport_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean transport_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean transport_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean transport_techprof ) f(%9.0g)

table rich milieu [aw=weight], col row c(mean autres_educ_dep_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean autres_educ_dep_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean autres_educ_dep_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean autres_educ_dep_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean autres_educ_dep_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean autres_educ_dep_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean autres_educ_dep_techprof ) f(%9.0g)

table rich milieu [aw=weight], col row c(mean bourses_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean bourses_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean bourses_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean bourses_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean bourses_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean bourses_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean bourses_techprof ) f(%9.0g)


table rich milieu [aw=weight], col row c(mean toteduc1_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc1_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc1_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc1_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc1_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc1_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc1_techprof ) f(%9.0g)

table rich milieu [aw=weight], col row c(mean toteduc2_eleves) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc2_prescho) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc2_prim ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc2_sec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc2_postsec ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc2_sup ) f(%9.0g)
table rich milieu [aw=weight], col row c(mean toteduc2_techprof ) f(%9.0g)









table rich sex [aw=weight], col row c(mean inscription_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean inscription_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean inscription_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean inscription_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean inscription_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean inscription_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean inscription_techprof ) f(%9.0g)

table rich sex [aw=weight], col row c(mean scolarite_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean scolarite_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean scolarite_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean scolarite_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean scolarite_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean scolarite_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean scolarite_techprof ) f(%9.0g)

table rich sex [aw=weight], col row c(mean fournitures_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean fournitures_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean fournitures_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean fournitures_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean fournitures_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean fournitures_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean fournitures_techprof ) f(%9.0g)

table rich sex [aw=weight], col row c(mean uniformes_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean uniformes_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean uniformes_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean uniformes_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean uniformes_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean uniformes_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean uniformes_techprof ) f(%9.0g)

table rich sex [aw=weight], col row c(mean transport_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean transport_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean transport_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean transport_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean transport_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean transport_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean transport_techprof ) f(%9.0g)

table rich sex [aw=weight], col row c(mean autres_educ_dep_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean autres_educ_dep_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean autres_educ_dep_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean autres_educ_dep_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean autres_educ_dep_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean autres_educ_dep_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean autres_educ_dep_techprof ) f(%9.0g)

table rich sex [aw=weight], col row c(mean bourses_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean bourses_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean bourses_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean bourses_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean bourses_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean bourses_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean bourses_techprof ) f(%9.0g)

table rich sex [aw=weight], col row c(mean toteduc1_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc1_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc1_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc1_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc1_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc1_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc1_techprof ) f(%9.0g)

table rich sex [aw=weight], col row c(mean toteduc2_eleves) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc2_prescho) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc2_prim ) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc2_sec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc2_postsec ) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc2_sup ) f(%9.0g)
table rich sex [aw=weight], col row c(mean toteduc2_techprof ) f(%9.0g)







table sex milieu [aw=weight], col row c(mean inscription_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean inscription_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean inscription_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean inscription_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean inscription_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean inscription_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean inscription_techprof ) f(%9.0g)

table sex milieu [aw=weight], col row c(mean scolarite_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean scolarite_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean scolarite_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean scolarite_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean scolarite_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean scolarite_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean scolarite_techprof ) f(%9.0g)

table sex milieu [aw=weight], col row c(mean fournitures_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean fournitures_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean fournitures_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean fournitures_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean fournitures_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean fournitures_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean fournitures_techprof ) f(%9.0g)

table sex milieu [aw=weight], col row c(mean uniformes_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean uniformes_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean uniformes_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean uniformes_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean uniformes_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean uniformes_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean uniformes_techprof ) f(%9.0g)

table sex milieu [aw=weight], col row c(mean transport_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean transport_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean transport_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean transport_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean transport_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean transport_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean transport_techprof ) f(%9.0g)


table sex milieu [aw=weight], col row c(mean autres_educ_dep_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean autres_educ_dep_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean autres_educ_dep_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean autres_educ_dep_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean autres_educ_dep_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean autres_educ_dep_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean autres_educ_dep_techprof ) f(%9.0g)


table sex milieu [aw=weight], col row c(mean bourses_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean bourses_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean bourses_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean bourses_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean bourses_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean bourses_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean bourses_techprof ) f(%9.0g)


table sex milieu [aw=weight], col row c(mean toteduc1_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc1_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc1_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc1_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc1_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc1_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc1_techprof ) f(%9.0g)

table sex milieu [aw=weight], col row c(mean toteduc2_eleves) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc2_prescho) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc2_prim ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc2_sec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc2_postsec ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc2_sup ) f(%9.0g)
table sex milieu [aw=weight], col row c(mean toteduc2_techprof ) f(%9.0g)





table rich milieu [aw=weight] if sex==1, col row c(mean inscription_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean inscription_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean inscription_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean inscription_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean inscription_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean inscription_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean inscription_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==1, col row c(mean scolarite_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean scolarite_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean scolarite_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean scolarite_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean scolarite_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean scolarite_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean scolarite_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==1, col row c(mean fournitures_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean fournitures_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean fournitures_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean fournitures_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean fournitures_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean fournitures_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean fournitures_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==1, col row c(mean uniformes_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean uniformes_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean uniformes_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean uniformes_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean uniformes_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean uniformes_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean uniformes_techprof ) f(%9.0g)


table rich milieu [aw=weight] if sex==1, col row c(mean transport_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean transport_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean transport_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean transport_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean transport_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean transport_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean transport_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==1, col row c(mean autres_educ_dep_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean autres_educ_dep_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean autres_educ_dep_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean autres_educ_dep_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean autres_educ_dep_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean autres_educ_dep_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean autres_educ_dep_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==1, col row c(mean bourses_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean bourses_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean bourses_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean bourses_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean bourses_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean bourses_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean bourses_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==1, col row c(mean toteduc1_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc1_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc1_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc1_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc1_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc1_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc1_techprof ) f(%9.0g)


table rich milieu [aw=weight] if sex==1, col row c(mean toteduc2_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc2_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc2_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc2_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc2_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc2_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==1, col row c(mean toteduc2_techprof ) f(%9.0g)



table rich milieu [aw=weight] if sex==2, col row c(mean inscription_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean inscription_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean inscription_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean inscription_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean inscription_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean inscription_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean inscription_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean inscription_techprof ) f(%9.0g)


table rich milieu [aw=weight] if sex==2, col row c(mean scolarite_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean scolarite_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean scolarite_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean scolarite_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean scolarite_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean scolarite_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean scolarite_techprof ) f(%9.0g)


table rich milieu [aw=weight] if sex==2, col row c(mean fournitures_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean fournitures_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean fournitures_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean fournitures_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean fournitures_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean fournitures_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean fournitures_techprof ) f(%9.0g)


table rich milieu [aw=weight] if sex==2, col row c(mean uniformes_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean uniformes_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean uniformes_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean uniformes_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean uniformes_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean uniformes_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean uniformes_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==2, col row c(mean transport_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean transport_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean transport_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean transport_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean transport_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean transport_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean transport_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==2, col row c(mean autres_educ_dep_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean autres_educ_dep_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean autres_educ_dep_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean autres_educ_dep_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean autres_educ_dep_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean autres_educ_dep_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean autres_educ_dep_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==2, col row c(mean bourses_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean bourses_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean bourses_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean bourses_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean bourses_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean bourses_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean bourses_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==2, col row c(mean toteduc1_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc1_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc1_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc1_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc1_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc1_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc1_techprof ) f(%9.0g)

table rich milieu [aw=weight] if sex==2, col row c(mean toteduc2_eleves) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc2_prescho) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc2_prim ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc2_sec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc2_postsec ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc2_sup ) f(%9.0g)
table rich milieu [aw=weight] if sex==2, col row c(mean toteduc2_techprof ) f(%9.0g)





/*
tab rich inscription_prescho [aw=weight],  col row  nofreq
tab milieu inscription_prescho [aw=weight],  col row  nofreq
tab region inscription_prescho [aw=weight],  col row  nofreq
tab rich inscription_prim [aw=weight],  col row  nofreq
tab milieu inscription_prim [aw=weight],  col row  nofreq
tab region inscription_prim [aw=weight],  col row  nofreq
tab rich inscription_sec [aw=weight],  col row  nofreq
tab milieu inscription_sec [aw=weight],  col row  nofreq
tab region inscription_sec [aw=weight],  col row  nofreq
tab rich inscription_postsec [aw=weight],  col row  nofreq
tab milieu inscription_postsec [aw=weight],  col row  nofreq
tab region inscription_postsec [aw=weight],  col row  nofreq
tab rich inscription_sup [aw=weight],  col row  nofreq
tab milieu inscription_sup [aw=weight],  col row  nofreq
tab region inscription_sup [aw=weight],  col row  nofreq
tab rich inscription_techprof [aw=weight],  col row  nofreq
tab milieu inscription_techprof [aw=weight],  col row  nofreq
tab region inscription_techprof [aw=weight],  col row  nofreq


tab rich scolarite_prescho [aw=weight],  col row  nofreq
tab milieu scolarite_prescho [aw=weight],  col row  nofreq
tab region scolarite_prescho [aw=weight],  col row  nofreq
tab rich scolarite_prim [aw=weight],  col row  nofreq
tab milieu scolarite_prim [aw=weight],  col row  nofreq
tab region scolarite_prim [aw=weight],  col row  nofreq
tab rich scolarite_sec [aw=weight],  col row  nofreq
tab milieu scolarite_sec [aw=weight],  col row  nofreq
tab region scolarite_sec [aw=weight],  col row  nofreq
tab rich scolarite_postsec [aw=weight],  col row  nofreq
tab milieu scolarite_postsec [aw=weight],  col row  nofreq
tab region scolarite_postsec [aw=weight],  col row  nofreq
tab rich scolarite_sup [aw=weight],  col row  nofreq
tab milieu scolarite_sup [aw=weight],  col row  nofreq
tab region scolarite_sup [aw=weight],  col row  nofreq
tab rich scolarite_techprof [aw=weight],  col row  nofreq
tab milieu scolarite_techprof [aw=weight],  col row  nofreq
tab region scolarite_techprof [aw=weight],  col row  nofreq


tab rich fournitures_prescho [aw=weight],  col row  nofreq
tab milieu fournitures_prescho [aw=weight],  col row  nofreq
tab region fournitures_prescho [aw=weight],  col row  nofreq
tab rich fournitures_prim [aw=weight],  col row  nofreq
tab milieu fournitures_prim [aw=weight],  col row  nofreq
tab region fournitures_prim [aw=weight],  col row  nofreq
tab rich fournitures_sec [aw=weight],  col row  nofreq
tab milieu fournitures_sec [aw=weight],  col row  nofreq
tab region fournitures_sec [aw=weight],  col row  nofreq
tab rich fournitures_postsec [aw=weight],  col row  nofreq
tab milieu fournitures_postsec [aw=weight],  col row  nofreq
tab region fournitures_postsec [aw=weight],  col row  nofreq
tab rich fournitures_sup [aw=weight],  col row  nofreq
tab milieu fournitures_sup [aw=weight],  col row  nofreq
tab region fournitures_sup [aw=weight],  col row  nofreq
tab rich fournitures_techprof [aw=weight],  col row  nofreq
tab milieu fournitures_techprof [aw=weight],  col row  nofreq
tab region fournitures_techprof [aw=weight],  col row  nofreq


tab rich uniformes_prescho [aw=weight],  col row  nofreq
tab milieu uniformes_prescho [aw=weight],  col row  nofreq
tab region uniformes_prescho [aw=weight],  col row  nofreq
tab rich uniformes_prim [aw=weight],  col row  nofreq
tab milieu uniformes_prim [aw=weight],  col row  nofreq
tab region uniformes_prim [aw=weight],  col row  nofreq
tab rich uniformes_sec [aw=weight],  col row  nofreq
tab milieu uniformes_sec [aw=weight],  col row  nofreq
tab region uniformes_sec [aw=weight],  col row  nofreq
tab rich uniformes_postsec [aw=weight],  col row  nofreq
tab milieu uniformes_postsec [aw=weight],  col row  nofreq
tab region uniformes_postsec [aw=weight],  col row  nofreq
tab rich uniformes_sup [aw=weight],  col row  nofreq
tab milieu uniformes_sup [aw=weight],  col row  nofreq
tab region uniformes_sup [aw=weight],  col row  nofreq
tab rich uniformes_techprof [aw=weight],  col row  nofreq
tab milieu uniformes_techprof [aw=weight],  col row  nofreq
tab region uniformes_techprof [aw=weight],  col row  nofreq


tab rich transport_prescho [aw=weight],  col row  nofreq
tab milieu transport_prescho [aw=weight],  col row  nofreq
tab region transport_prescho [aw=weight],  col row  nofreq
tab rich transport_prim [aw=weight],  col row  nofreq
tab milieu transport_prim [aw=weight],  col row  nofreq
tab region transport_prim [aw=weight],  col row  nofreq
tab rich transport_sec [aw=weight],  col row  nofreq
tab milieu transport_sec [aw=weight],  col row  nofreq
tab region transport_sec [aw=weight],  col row  nofreq
tab rich transport_postsec [aw=weight],  col row  nofreq
tab milieu transport_postsec [aw=weight],  col row  nofreq
tab region transport_postsec [aw=weight],  col row  nofreq
tab rich transport_sup [aw=weight],  col row  nofreq
tab milieu transport_sup [aw=weight],  col row  nofreq
tab region transport_sup [aw=weight],  col row  nofreq
tab rich transport_techprof [aw=weight],  col row  nofreq
tab milieu transport_techprof [aw=weight],  col row  nofreq
tab region transport_techprof [aw=weight],  col row  nofreq


tab rich autres_educ_dep_prescho [aw=weight],  col row  nofreq
tab milieu autres_educ_dep_prescho [aw=weight],  col row  nofreq
tab region autres_educ_dep_prescho [aw=weight],  col row  nofreq
tab rich autres_educ_dep_prim [aw=weight],  col row  nofreq
tab milieu autres_educ_dep_prim [aw=weight],  col row  nofreq
tab region autres_educ_dep_prim [aw=weight],  col row  nofreq
tab rich autres_educ_dep_sec [aw=weight],  col row  nofreq
tab milieu autres_educ_dep_sec [aw=weight],  col row  nofreq
tab region autres_educ_dep_sec [aw=weight],  col row  nofreq
tab rich autres_educ_dep_postsec [aw=weight],  col row  nofreq
tab milieu autres_educ_dep_postsec [aw=weight],  col row  nofreq
tab region autres_educ_dep_postsec [aw=weight],  col row  nofreq
tab rich autres_educ_dep_sup [aw=weight],  col row  nofreq
tab milieu autres_educ_dep_sup [aw=weight],  col row  nofreq
tab region autres_educ_dep_sup [aw=weight],  col row  nofreq
tab rich autres_educ_dep_techprof [aw=weight],  col row  nofreq
tab milieu autres_educ_dep_techprof [aw=weight],  col row  nofreq
tab region autres_educ_dep_techprof [aw=weight],  col row  nofreq


tab rich bourses_prescho [aw=weight],  col row  nofreq
tab milieu bourses_prescho [aw=weight],  col row  nofreq
tab region bourses_prescho [aw=weight],  col row  nofreq
tab rich bourses_prim [aw=weight],  col row  nofreq
tab milieu bourses_prim [aw=weight],  col row  nofreq
tab region bourses_prim [aw=weight],  col row  nofreq
tab rich bourses_sec [aw=weight],  col row  nofreq
tab milieu bourses_sec [aw=weight],  col row  nofreq
tab region bourses_sec [aw=weight],  col row  nofreq
tab rich bourses_postsec [aw=weight],  col row  nofreq
tab milieu bourses_postsec [aw=weight],  col row  nofreq
tab region bourses_postsec [aw=weight],  col row  nofreq
tab rich bourses_sup [aw=weight],  col row  nofreq
tab milieu bourses_sup [aw=weight],  col row  nofreq
tab region bourses_sup [aw=weight],  col row  nofreq
tab rich bourses_techprof [aw=weight],  col row  nofreq
tab milieu bourses_techprof [aw=weight],  col row  nofreq
tab region bourses_techprof [aw=weight],  col row  nofreq


tab rich toteduc1_prescho [aw=weight],  col row  nofreq
tab milieu toteduc1_prescho [aw=weight],  col row  nofreq
tab region toteduc1_prescho [aw=weight],  col row  nofreq
tab rich toteduc1_prim [aw=weight],  col row  nofreq
tab milieu toteduc1_prim [aw=weight],  col row  nofreq
tab region toteduc1_prim [aw=weight],  col row  nofreq
tab rich toteduc1_sec [aw=weight],  col row  nofreq
tab milieu toteduc1_sec [aw=weight],  col row  nofreq
tab region toteduc1_sec [aw=weight],  col row  nofreq
tab rich toteduc1_postsec [aw=weight],  col row  nofreq
tab milieu toteduc1_postsec [aw=weight],  col row  nofreq
tab region toteduc1_postsec [aw=weight],  col row  nofreq
tab rich toteduc1_sup [aw=weight],  col row  nofreq
tab milieu toteduc1_sup [aw=weight],  col row  nofreq
tab region toteduc1_sup [aw=weight],  col row  nofreq
tab rich toteduc1_techprof [aw=weight],  col row  nofreq
tab milieu toteduc1_techprof [aw=weight],  col row  nofreq
tab region toteduc1_techprof [aw=weight],  col row  nofreq


tab rich toteduc2_prescho [aw=weight],  col row  nofreq
tab milieu toteduc2_prescho [aw=weight],  col row  nofreq
tab region toteduc2_prescho [aw=weight],  col row  nofreq
tab rich toteduc2_prim [aw=weight],  col row  nofreq
tab milieu toteduc2_prim [aw=weight],  col row  nofreq
tab region toteduc2_prim [aw=weight],  col row  nofreq
tab rich toteduc2_sec [aw=weight],  col row  nofreq
tab milieu toteduc2_sec [aw=weight],  col row  nofreq
tab region toteduc2_sec [aw=weight],  col row  nofreq
tab rich toteduc2_postsec [aw=weight],  col row  nofreq
tab milieu toteduc2_postsec [aw=weight],  col row  nofreq
tab region toteduc2_postsec [aw=weight],  col row  nofreq
tab rich toteduc2_sup [aw=weight],  col row  nofreq
tab milieu toteduc2_sup [aw=weight],  col row  nofreq
tab region toteduc2_sup [aw=weight],  col row  nofreq
tab rich toteduc2_techprof [aw=weight],  col row  nofreq
tab milieu toteduc2_techprof [aw=weight],  col row  nofreq
tab region toteduc2_techprof [aw=weight],  col row  nofreq

*/

collapse (sum) inscription scolarite fournitures uniformes transport autres_educ_dep bourses toteduc1 toteduc2 ///
(max) inscription_eleves inscription_prescho inscription_prim inscription_sec inscription_postsec inscription_sup inscription_techprof ///
scolarite_eleves scolarite_prescho scolarite_prim scolarite_sec scolarite_postsec scolarite_sup scolarite_techprof ///
fournitures_eleves fournitures_prescho fournitures_prim fournitures_sec fournitures_postsec fournitures_sup fournitures_techprof ///
uniformes_eleves uniformes_prescho uniformes_prim uniformes_sec uniformes_postsec uniformes_sup uniformes_techprof ///
transport_eleves transport_prescho transport_prim transport_sec transport_postsec transport_sup transport_techprof ///
autres_educ_dep_eleves autres_educ_dep_prescho autres_educ_dep_prim autres_educ_dep_sec autres_educ_dep_postsec autres_educ_dep_sup autres_educ_dep_techprof ///
bourses_eleves bourses_prescho bourses_prim bourses_sec bourses_postsec bourses_sup bourses_techprof ///
toteduc1_eleves toteduc1_prescho toteduc1_prim toteduc1_sec toteduc1_postsec toteduc1_sup toteduc1_techprof ///
toteduc2_eleves toteduc2_prescho toteduc2_prim toteduc2_sec toteduc2_postsec toteduc2_sup toteduc2_techprof ///
(mean) rich [pw=pond], by(hid)
sort hid
save educ_exp, replace
restore
bysort indid: g qui_assure = s1q75
recode qui_assure 1=1 2=2 3/10=3 11/max=4
ta qui_assure, m







**********
**********
**HEALTH**
**********
**********


use temp, clear
count

bys indid: g healthexp = s1q18
bys indid: replace healthexp = 0 if s1q11==2 | s1q13==2 | healthexp==.
bys hid: egen stothealthexp = sum(healthexp)
bys hid: egen tothealthexp = max(healthexp)

bys indid: g malade = cond(morbid==1, 1, 0)
bys hid: egen nmalade = sum(malade)
bys hid: egen malades = max(nmalade)

bys hid: g meanhealthexp = tothealthexp / malades

table rich [aw=weig], col row c(mean tothealthexp ) f(%9.0g)
table sex [aw=weig], col row c(mean tothealthexp ) f(%9.0g)
table milieu [aw=weig], col row c(mean tothealthexp ) f(%9.0g)
table region [aw=weig], col row c(mean tothealthexp ) f(%9.0g)

table rich [aw=weig], col row c(mean meanhealthexp ) f(%9.0g)
table sex [aw=weig], col row c(mean meanhealthexp ) f(%9.0g)
table milieu [aw=weig], col row c(mean meanhealthexp ) f(%9.0g)
table region [aw=weig], col row c(mean meanhealthexp ) f(%9.0g)




cap log close
set rmsg off
set more on
exit