clear
set mem 100m
set matsize 300
set more 1
set seed 123456789
set rmsg on

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of consumption and poverty****
*******************************************************************

 


cd "C:\Documents and Settings\Bachir\Desktop\Bachir\World Bank\Wodon\CIV\Cote d'Ivoire Consumption\STATA"

cap log close
log using "LastEssay.log", replace

*Education variables

use pauvre
*Actual region of residence
sort grappe
cap drop grappen
encode grappe, gen(grappen)
su grappe grappen
cap drop region
g region=.
replace region=1 if (grappen<141)
replace region=2 if (grappen>=341 & grappen<=374)
replace region=3 if (grappen>=256 & grappen<=280)
replace region=4 if (grappen>=519 & grappen<=524)
replace region=5 if (grappen>=187 & grappen<=217)
replace region=6 if (grappen>=218 & grappen<=255)
replace region=7 if (grappen>=431 & grappen<=449)
replace region=8 if (grappen>=281 & grappen<=323)
replace region=9 if (grappen>=423 & grappen<=430)
replace region=10 if (grappen>=537 & grappen<=540)
replace region=11 if (grappen>=530 & grappen<=536)
replace region=12 if (grappen>=141 & grappen<=186)
replace region=13 if (grappen>=375 & grappen<=422)
replace region=14 if (grappen>=525 & grappen<=529)
replace region=15 if (grappen>=450 & grappen<=463)
replace region=16 if (grappen>=324 & grappen<=340)
replace region=17 if (grappen>=488 & grappen<=502)
replace region=18 if (grappen>=503 & grappen<=518)
replace region=19 if (grappen>=464 & grappen<=487)

#delimit;
lab def region 
1"LAGUNES" 
2"ZANZAN" 
3"MOYEN COMOE" 
4"AGNEBY" 
5"SAVANES" 
6"VALLEE DU BANDAMA"
7"N'ZI COMOE"
8"MONTAGNES"
9"DENGUELE"
10"BAFING"
11"MOYEN CAVALLY"
12"HAUT SASSANDRA"
13"BAS SASSANDRA"
14"FROMAGER"
15"MARAHOUE"
16"LACS"
17"WORODOUGOU"
18"SUD BANDAMA"
19"SUD COMOE"
;
#delimit cr
lab values region region 
ta region, m
sort hid
save temp, replace

use civ_inc, replace
sort hid
save, replace
use temp, replace
merge hid using civ_inc
ta _merg
keep if _merg==3
drop _merg
sort hid
save temp, replace








                                                     *********************************************************
                                                     *GENERAL VARIABLES FOR INDIVIDUALS: HEALTH AND EDUCATION*               
                                                     *********************************************************                                                                   
                                                                                                                            
                                                                                                                         
use sect01, clear

sort hid 
save, replace

use temp, replace
merge hid using sect01
ta _merg
drop _merg
sort hid
save temp, replace

use hhexp, replace
sort hid
save, replace

merge hid using temp
ta _merg
drop _merg


*Ethic group
g ethnie=s1q8
recode ethnie 6/max=9
cap label drop ethnie
label define ethnie 1"Akan" 2"Krou" 3"Mande-Nord" 4"Mande-Sud" 5"Voltaique" 9"Etrangers" 
label values ethnie ethnie


*Religion
g religion=s1q9
recode religion 1/3=1 4=2 5/7=3
cap label drop religion 
label define religion 1"Chretien" 2"Musulman" 3"Animiste/Autres/Sans religion"
label values religion religion

g relat= s1q4
ta relat, m
*replace relat=3 if ( s1q6a <10 & relat==1)
recode relat 1=1 2=2 3=3 4=4 5/8=5 10=5 9=4 11=6 12/13=7 
label def relat 1"Chief" 2"Spouse" 3"Children" 4"Grand-Parents" 5"Other relatives" 6"Maid" 7"Other non relatives"
lab values relat relat 
ta relat , m


g sex= s1q3 if s1q3~=.
tab sex, m


g agey= s1q6a if s1q6a~=.
ta agey, m

replace relat=3 if (agey<10& relat==1)


label define marstat 1 "Married" 2 "Separated/Divorced" 3 "Widowed" 4 "Nver Married", add
g marstat= s1q7 if s1q7~=.
recode marstat 0=1 6=5 /*Replacing in the correct codes*/
recode marstat 1=1 2/3=2 4=3 5=4 /*Have to check if it recodes correctly*/
label value marstat marstat
ta marstat, m


*Handicap status
sort hid
g handicap=1 if s1q10~=0    /* 1 is handicaped, 0 not*/
replace handicap=0 if s1q10==0
by hid: g nhandicap=sum(handicap) 
bysort hid: egen nbhandic=max(nhandicap)  /*Number of handicaped persons in the household*/

/* Migration*/

/*Temporary migration*/   

g yrs_here=s1q24a if s1q24a~=.
recode yrs_here 99=.
replace yrs_here=(s1q24a*12)+s1q24b   /*In months*/
replace yrs_here= yrs_here/12 /*In years*/
replace yrs_here =round(yrs_here, .1) /*In years*/


g t_mig=0
replace t_mig=1 if (yrs_here <2 & s1q25>1)   /*A visitor has left his own house so is a temporary migrant*/

/*Long term migration*/ *Not very detailed
g l_mig=0
replace l_mig=1 if (yrs_here >=2 & s1q25>1)   /*A visitor has left his own house so is a temporary migrant*/


/*Education*/

g literacy=s1q27 if (s1q6a >=5&s1q27~=.)
recode literacy 0=1 7=3 /*Replacing in the correct codes*/
recode literacy 1/2=1 3=2
lab def literacy 1"Read/Write" 2"No"
lab values literacy literacy 
ta literacy, m


g everattd=s1q30 if (s1q6a >=5&s1q30~=.)
recode everattd 3=2
ta everattd, m

/*
g educlev=s1q31  if s1q6a >=5 & s1q31~=. /*I choose the last class attended , instead of the highest grade completed*/
ta educlev, m
recode educlev 1 2 3 4 5 =2
replace educlev=3 if (s1q31==6 & (s1q32==1 | s1q32==.))
recode educlev 6 =3 if s1q32==2 /* I am assuming that people with educlev=6 are complete primary*/
recode educlev 7 8 9 10 11 12  24 25 26 27 28 29 30 31 32 33 34 35 36 37 =3 /*I assume "secondaire" and "secondaire professionnelle" are the same*/
replace educlev=4 if (s1q31==13 & (s1q32==1|s1q32==.))
recode educlev 13 =5 if s1q32==4 | s1q32==11| s1q32==12| s1q32==13|s1q32==14 /* I am assuming that people with educlev=13 are complete secondary*/
replace educlev=4 if (educlev==13)
recode educlev 14 15 16 17 18 19 20 21 22 23 38 39=6
recode educlev . =1 if everattd==2 /* people who have never attended to school have "no level of education"*/
recode educlev .=2 if everattd==1
recode educlev .=1 
recode educlev 0 =1
label define educlev 1 "No level" 2 "inc. primary" 3"com. primary" 4"inc. secundaty"/*
*/ 5"com. secundary" 6"tertiary" 99 "undefined", add
*/


g educlev=s1q31  if s1q6a >=5 & s1q31~=.
ta educlev, m
recode educlev 0=1 1/5=2 6=3 7/10=4 11/15=5 16/23=6 24/39=7 .=1
#delimit;
lab define educlev 1"No level" 2"Primary Non Completed: CP1-CM1" 
3"Primary Completed: CM2" 4"Secondary Non Completed: College (6eme-3eme)" 
5"Secondary Completed and Post=Secondary: Lycee et Ecoles Preparatoires" 
6"Tertiary: Superieur General (University)" 7"Professionals & Technicians" 
;
#delimit cr
label value educlev educlev
ta educlev, m
ta educlev if relat==1, m



gen byte baby   = cond( agey <= 5,              1, 0 )
gen byte kid    = cond( agey >  5 & agey <= 14, 1, 0 )
gen byte adult  = cond( agey > 14 & agey <= 64, 1, 0 )
gen byte senior = cond( agey > 64 & agey <  99, 1, 0 )
*gen byte ad_dep = cond( adult == 1 & ( occupat == 2 | occupat == 5 | occupat == 6 ), 1, 0 )

sort hid

by hid: egen int num_bab  = sum(baby)
lab var num_bab "Number of under-5s in household"
drop baby

by hid: gen int num_bab2 = num_bab^2
lab var num_bab2 "Square of number of under-5s in household"

by hid: egen int num_kid = sum(kid)
lab var num_kid "Number of 5-14s in household"
drop kid

by hid: gen int num_kid2 = ((num_kid)^2)
lab var num_kid2 "Square of number of 5-14s in household"

by hid: egen int num_ads = sum(adult)
lab var num_ads "Number of adults in household"
drop adult

by hid: gen int num_ads2 = ((num_ads)^2)
lab var num_ads2 "Square of number of adults in household"

/*bysort hid: egen int num_adp = sum(ad_dep)
lab var num_adp "Number of non-working adults in household"

bysort hid: gen int num_adp2 = num_adp^2
lab var num_adp2 "Square of number of non-working adults in household"
drop ad_dep */

bysort hid: egen int num_srs = sum(senior)
lab var num_srs "Number of 65+ in household"

bysort hid: gen double num_srs2 = (num_srs)^2
lab var num_srs2 "Square of number of 65+ in household"



save educhealth, replace



                                                     *******************************************
                                                     *VARIABLES FOR HEADS: HEALTH AND EDUCATION*               
                                                     *******************************************                                                                   




preserve

keep if relat==1
count
bysort indid: g count=_n
ta count
keep if count==1
drop count
g h_ne=cond(educlev==1, 1, 0)
ta h_ne, m
g h_pnc =cond(educlev==2, 1, 0)
ta h_pnc , m
g h_pc =cond(educlev==3, 1, 0)
ta h_pc , m
g h_snc =cond(educlev==4, 1, 0)
ta h_snc , m
g h_sc =cond(educlev==5 | educlev==7, 1, 0)
ta h_sc , m
g h_ts=cond(educlev==6, 1, 0)
ta h_ts, m




g h_hand=cond(handicap==1, 1, 0)
ta h_hand, m

bysort hid: gen h_agey = agey 
lab var h_agey "Age of head"

bysort hid: gen h_agey_c = cond( h_agey < 99, h_agey, . ) 
lab var h_agey_c "Age of Head, no 99 allowed"

bysort hid: gen int h_agey2 = ((h_agey)^2) 
lab var h_agey2 "Square of age of household Head"

by hid: g h_t_mig=cond(t_mig==1, 1, 0) if t_mig~=.
lab var h_t_mig "Head is a Long Term Migrant"
by hid: gen h_l_mig = cond(l_mig == 1, 1, 0) if l_mig~=.
lab var h_l_mig "Head is a Long Term Migrant"

sort hid
by hid: g int h_christ=1 if religion==1 /*Head Christian*/
replace h_christ=0 if h_christ==.
by hid: g int h_musl=1 if religion==2 /*Head Muslem*/
replace h_musl=0 if h_musl==.
by hid: g int h_anim=1 if religion==3 /*Head Animist*/
replace h_anim=0 if h_anim==.

************************************ Ethnicity of the head**********************************************************
sort hid
by hid: g int h_akan=1    if ethnie==1 /*Head akan*/
replace h_akan=0 if h_akan==.
by hid: g int h_krou=1    if ethnie==2 /*Head Krou*/
replace h_krou=0 if h_krou==.
by hid: g int h_manden=1  if ethnie==3 /*Head Mande North*/
replace h_manden=0 if h_manden==.
by hid: g int h_mandes=1  if ethnie==4 /*Head mande South*/
replace h_mandes=0 if h_mandes==.
by hid: g int h_mande=cond(h_manden==1|h_mandes==1, 1, 0)   /*Mande*/ 
by hid: g int h_volta=1   if ethnie==5 /*Head voltaic*/
replace h_volta=0 if h_volta==.
by hid: g int h_etr=1     if ethnie==9 /*Head Stranger*/
replace h_etr=0 if h_etr==.

#delimit;
keep  grappe menord s1q2 grap menor hid indid  h_*
hhexp hhsize sexhead agehead csphead _region_ _milieu_ milieu pond 
strate deflat pchhexp povline pauv extline region  num_bab num_bab2 
num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 oth_agr- job  hhinc- fivepct
oth_agr- job  hhinc- fivepct ethnie;
#delimit cr

compress
sort hid indid
count
save headeduchealth, replace





restore, preserve
count


                                                     *********************************************
                                                     *VARIABLES FOR SPOUSES: HEALTH AND EDUCATION*              
                                                     *********************************************                                                                   




count if relat==2
count if s1q7==1&sex==2
count if s1q7==1&sex==2&relat==2
keep if s1q7==1&sex==2&relat==2

/*
gen sp=cond(s1q7==1 & sex==2 & relat==2, 1, 0)
ta sp, m
egen nbsp=sum(sp), by(hid)
tab nbsp, m

bysort indid: egen smaxage = max(agey) if sp == 1
keep if sp==1 & agey == smaxage

count

egen nbsp2=sum(sp), by(hid)
tab nbsp2
drop nbsp2
*============
* Controlling for the possibility of 2 spouses with same age and education,
* then keep the one with the lowest indid
* ===========

*gen realed=educlev
*recode realed 1=0 8=1 9=. 99=.
bysort hid: egen smaxeduc = max(s1q31) if s1q31~=.
ta smaxeduc, m
keep if (s1q31 == smaxeduc) | s1q31==.
egen nbsp2=sum(sp), by(hid)
tab nbsp2


count


bysort indid: g count=_n
ta count
keep if count==1
drop count
*/


g s_ne=cond(educlev==1, 1, 0)
ta s_ne, m
g s_pnc =cond(educlev==2, 1, 0)
ta s_pnc , m
g s_pc =cond(educlev==3, 1, 0)
ta s_pc , m
g s_snc =cond(educlev==4, 1, 0)
ta s_snc , m
g s_sc =cond(educlev==5| educlev==7, 1, 0)
ta s_sc , m
g s_ts=cond(educlev==6, 1, 0)
ta s_ts, m


g s_hand=cond(handicap==1, 1, 0)
ta s_hand, m

bysort hid: gen s_agey = agey 
lab var s_agey "Age of spouse"

bysort hid: gen s_agey_c = cond( s_agey < 99, s_agey, . ) 
lab var s_agey_c "Age of spouse, no 99 allowed"

bysort hid: gen int s_agey2 = ((s_agey)^2) 
lab var s_agey2 "Square of age of household spouse"

cap keep  grappe menord s1q2 grap menor hid indid  s_* sp nbsp nbsp2
compress
sort hid indid
count
save spouseeduchealth, replace

restore, preserve
count
keep grappe menord s1q2 hid indid relat agey s1q4 s1q7 s1q31 sex
sort hid indid 
save tracking, replace        /*Tracking will be used to track heads and spouses*/

restore
count
drop s1q3- s1q76
save, replace



                                                     ***********************************************
                                                     *GENERAL VARIABLES FOR INDIVIDUALS: EMPLOYMENT*               
                                                     ***********************************************                                                                   
                                                                                                                            






use tracking, clear
sort hid indid
merge hid indid using sect02
ta _mer
*keep if _merg==3
drop _merge
count




*1) Search (for the past 7 days)
* This question only reflects people searching today, but who have not worked for the past 12 months, 
* but want to work !
* Find those who are not in the labor force
gen lf=cond(s2q12==1|s2q12==3|s2q12==6,0,1)   
replace lf=0 if (agey<10 & agey>65) /*Taking a limit of age*/
replace lf=0 if s2q12==5 
replace lf=0 if s2q12==13 | agey>65
replace lf=0 if s2q12==10 & agey<10
replace lf=0 if s2q12==14 & agey<10
lab var lf "Labor force"
ta lf, m
recode s2q11 8=2 if lf==1
recode s2q8 0=2
gen search=cond(lf==1& s2q5==2 & s2q8==2 & s2q11==1, 1, 0) 
/* At this point, I have a problem: the question refers to a search of 
job during the last 4 WEEKS not the last 7 days*/ 
*Search refers to persons in labor force, who have not work last 7 days and has no job and who seek a job
replace search=0 if s2q5==2 & s2q8==2 & s2q11==2 & (lf==1) & lf~=. 
tab search, m
* 1 means "search during the past week!"

g unempl=cond(s2q5==2 & s2q8==2 & s2q11==1, 1, 0) 

g empl=cond(s2q5==1 | s2q8==1|s2q12==4, 1, 0) 
ta empl, m
ta unempl, m
replace unempl=0 if unempl==.& lf==1
g nilf=cond(empl==0&unempl==0, 1, 0)
ta nilf, m

*7) INDUSTRY (main occupation) - Only for employed individuals (OCCUPAT==1)
/*rename activite activite1*/
gen activite=s2q14 if s2q14~=.
ta activite
recode activite 1/34=9 35/119=8 120/124=7 125/182=8 183/188=9 189/206=8 207/225=4 226/237=7 238/300=8 301/307=4 308/317=7 318/336=8 337/396=9 397/439=6 440/457=1 458/507=2 508/517=10 518/536=10 537/997=11 998=. 999=. 
ta activite
ta activite, m
* other
gen industry=11 if (activite==11 & s2q14~=.)
* Agriculture
replace industry=1 if activite==1
* Manufacture
replace industry=2 if activite==2
* Mining and quarrying
*replace industry=3 if activite==3
* Contruction 
replace industry=4 if activite==4
* Utilities (water, gas, and electricity)
*replace industry=5 if activite==5
* Commerce, Hotels, and Restaurants
replace industry=6 if activite==6
* Banking, Finantial Services
replace industry=7 if activite==7
* Professional, (social work, international organizations, etc.) 
replace industry=8 if activite ==8
* Public Administration
replace industry=9 if activite ==9
* Transport
replace industry=10 if activite==10
tab activite , m
tab industry , m
recode industry 1=1 2/4=2 5/6=3 7/9=4 10=2 11=2
replace industry=9 if industry ==. & (agey>=10 & agey<=65)
label define industry 1"Agriculture" 2"Manufacturing/Mining and quarrying/construction/transport/other" 3"Utilities/commerce" 4"Banking/financial services/Professional/Public administration" 9"Other Activities/None"
label values industry industry
ta industry
ta industry, m

save empl, replace


                                                     *********************************
                                                     *VARIABLES FOR HEADS: EMPLOYMENT*               
                                                     *********************************                                                                   




count if relat==1
preserve
keep if relat==1


************************************ employment variables**********************************************************
sort indid
by indid: gen h_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . )
lab var h_ilf "Head of household in labor force"
by indid: gen h_nilf = cond( nilf==1, 1, 0 )
lab var h_nilf "Head of household not in labor force"
by indid: gen h_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )  
lab var h_em "Head of household is employed"
by indid: gen h_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . )
lab var h_unem "Head of household is unemployed"

sort hid

by hid: g h_ag=cond(industry==1, 1, 0) if ( empl == 1) 
lab var h_ag "Head is engaged in an agricultural activity"
tab h_ag, m
recode h_ag .=0

by hid: g h_man=cond(industry==2, 1, 0) if ( empl == 1) 
lab var h_man "Head is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities"
tab h_man, m
recode h_man .=0

by hid: g h_com=cond(industry==3, 1, 0) if ( empl == 1 ) 
lab var h_com "Head is engaged in Utilities/commerce activities"
tab h_com, m
recode h_com .=0

by hid: g h_adm=cond(industry==4, 1, 0) if ( empl == 1 ) 
lab var h_adm "Head is engaged in Banking/financial services/Professional/Public administration activities"
tab h_adm, m
recode h_adm .=0

by hid: g h_other=cond(industry>4, 1, 0) if ( empl == 1 ) 
lab var h_other "Head is engaged in Other activities"
tab h_other, m
recode h_other .=0


keep hid indid h_*
count
sort hid indid
save temp, replace
use headeduchealth, replace
merge hid indid using temp
ta _merge
keep if _merge==3
drop _merg
sort hid
count
save headeduchealthempl, replace

restore, preserve



                                                     ***********************************
                                                     *VARIABLES FOR SPOUSES: EMPLOYMENT*              
                                                     ***********************************                                                                   



count if relat==2
count if s1q7==1& s1q4==2& sex==2
gen sp=cond(s1q7==1 & sex==2 & relat==2, 1, 0)
keep if relat==2
ta sp, m
egen nbsp=sum(sp), by(hid)
tab nbsp, m
drop nbsp
/*
bysort indid: egen smaxage = max(agey) if sp == 1
keep if sp==1 & agey == smaxage

count

egen nbsp=sum(sp), by(hid)
tab nbsp
drop nbsp
*============
* Controlling for the possibility of 2 spouses with same age and education,
* then keep the one with the lowest indid
* ===========

*gen realed=educlev
*recode realed 1=0 8=1 9=. 99=.
bysort hid: egen smaxeduc = max(s1q31) if s1q31~=.
ta smaxeduc, m
keep if (s1q31 == smaxeduc) | s1q31==.
egen nbsp2=sum(sp), by(hid)
tab nbsp2
drop nbsp2


count


bysort indid: g count=_n
ta count
keep if count==1
drop count
*/

************************************ employment variables**********************************************************
sort indid
by indid: gen s_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . )
lab var s_ilf "spouse of household in labor force"
by indid: gen s_nilf = cond( nilf==1, 1, 0 )
lab var s_nilf "spouse of household not in labor force"
by indid: gen s_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )  
lab var s_em "spouse of household is employed"
by indid: gen s_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . )
lab var s_unem "spouse of household is unemployed"


sort hid

by hid: g s_ag=cond(industry==1, 1, 0) if ( empl == 1) 
lab var s_ag "Spouse is engaged in an agricultural activity"
tab s_ag, m
recode s_ag .=0

by hid: g s_man=cond(industry==2, 1, 0) if ( empl == 1) 
lab var s_man "Spouse is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities"
tab s_man, m
recode s_man .=0

by hid: g s_com=cond(industry==3, 1, 0) if ( empl == 1 ) 
lab var s_com "Spouse is engaged in Utilities/commerce activities"
tab s_com, m
recode s_com .=0

by hid: g s_adm=cond(industry==4, 1, 0) if ( empl == 1 ) 
lab var s_adm "Spouse is engaged in Banking/financial services/Professional/Public administration activities"
tab s_adm, m
recode s_adm .=0

by hid: g s_other=cond(industry>4, 1, 0) if ( empl == 1 ) 
lab var s_other "Spouse is engaged in Other activities"
tab s_other, m
recode s_other .=0

keep hid indid s_*
sort hid indid
count
save temp, replace
use spouseeduchealth, replace
merge hid indid using temp
ta _merge
keep if _merge==3
drop _merg
sort hid
count
save spouseeduchealthempl, replace


restore
drop  s2q1- s2dq11b s1q4-  agey
save, replace


use headeduchealthempl, clear
sort hid 
merge hid using spouseeduchealthempl
ta _mer
drop _merg
drop if h_agey==.
count
sort hid
save headspouse, replace




                                                     *****************
                                                     *LAND VARIABLES *               
                                                     *****************                                                                   




use sect03b1, clear
count
keep hid indid s3b1q14a s3b1q15a s3b1q15b
bysort hid: gen ownland=s3b1q14a
ta  ownland
recode ownland 2=0
bysort hid: gen landsize=(s3b1q15a+s3b1q15b)/100
su landsize
gen landsize2= landsize^2
keep  hid- landsize2
collapse  ownland (mean)  landsize landsize2, by(hid)
count
su  ownland landsize landsize2
sort hid
save land, replace

use headspouse, clear
merge hid using land
ta _mer
keep if _merg==3
drop _merg

save, replace
