clear
set more 1
set mem 300m
set matsize 800
set rmsg on


/*******************************************************************************************************************/
*              ANALYSIS OF DETERMINANTS OF INCOME AND EXPAENDITURE IN COTE D'IVOIRE IN 2002                         *
*              by Amadou Bassirou DIALLO, AFTPM, The World Bank and CERDI, Univ. Of Auvergne                        *
*/******************************************************************************************************************/




cd "C:\Documents and Settings\Bachir\Desktop\Bachir\World Bank\Wodon\CIV\Cote d'Ivoire Consumption\STATA"

cap log close
log using "NewConsumptionEstimatesInCotedIvoire.log", replace

use pauvre,  replace

sort grappe menord 
cap drop grappen 
cap drop menordn 
cap drop idmen 

keep grappe menord hhsize sexhead agehead csphead pchhexp hhexp _region_ _milieu_ strate pond  pauv 
rename _region_ reg
rename _milieu_ rururb
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
recode pauv .=0
label define  pauvl 1 poor 0 nopoor
label value pauv pauvl
ta pauv [aw=pond], m
  
encode reg, gen(regn)
encode rururb, gen(rururbn)

order idmen pond  pauv pchhexp hhexp regn rururbn  hhsize sexhead agehead csphead   regn rururbn strate reg rururb grappen menordn 
sort idmen
save temp, replace








use sect01, clear

/*Creating unique identification*/
sort grappe menord s1q2
cap drop grappen 
cap drop menordn 
cap drop idmen 
cap drop idind 

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
gen idind = idmen*100+s1q2
*dups idmen indid, drop

sort idmen
merge idmen using temp
ta _merge
drop _merge

*Generating individual weights

cap drop weight
sort idmen idind
g weight=pond/hhsize
save temp, replace


*Regions


sort s1q23c
gen str20(geocode2)="Lagunes" 	        if s1q23c==2 | s1q23c==52 |  s1q23c==25 |  s1q23c==45 |  s1q23c==54 |  s1q23c==56              /*Abidjan, Alp, Dabou, Grand -Lahou, Jacqueville, Tiassal*/
replace geocode2="Sud Comoe"	        if s1q23c==3 | s1q23c==55 |  s1q23c==51                                                        /*Aboisso, Adiak, Grand-Bassam*/ 
replace geocode2="Agneby"	        if s1q23c==5 | s1q23c==4                                                                       /*Agboville, Adzop*/
replace geocode2="Haut-Sassandra"	if s1q23c==17| s1q23c==27 |  s1q23c==48                                                        /*Daloa, Issia, Vavoua*/
replace geocode2="Savanes"		if s1q23c==29| s1q23c==15 |  s1q23c==23 |  s1q23c==44                                          /*Korhogo, Boundiali, Ferkessedougou, Tengrela*/	
replace geocode2="Vallee du Bandama"	if s1q23c==13| s1q23c==8  |  s1q23c==16 |  s1q23c==28 |  s1q23c==36                            /*Bouak, Boumi, Dabakala, Katiola, Sakassou*/
replace geocode2="Moyen-Comoe"		if s1q23c==1 | s1q23c==6                                                                       /*Abengourou, Agnibilkro*/
replace geocode2="18 montagnes"		if s1q23c==31| s1q23c==7  |  s1q23c==9  |  s1q23c==18                                          /*Man, Bangolo, Biankouma, Danan*/
replace geocode2="Lacs"		        if s1q23c==49| s1q23c==57 |  s1q23c==47                                                        /*Yamoussoukro, Tiebissou, Toumodi*/
replace geocode2="Zanzan"		if s1q23c==14| s1q23c==10 |  s1q23c==43                                                        /*Bouna, Bondoukou, Tanda*/
replace geocode2="Bas-Sassandra"	if s1q23c==37| s1q23c==38 |  s1q23c==41 |  s1q23c==42                                          /* San-Pedro, Sassandra, Soubr, Tabou*/
replace geocode2="Worodougou"	        if s1q23c==32| s1q23c==39                                                                      /*Mankono, Sgula*/
replace geocode2="Denguele"		if s1q23c==34                                                                                  /*Odienn*/
replace geocode2="Sud Bandama"		if s1q23c==21| s1q23c==30                                                                      /*Divo, Lakota*/
replace geocode2="Fromager"	        if s1q23c==24| s1q23c==35                                                                      /*Gagnoa, Oum*/
replace geocode2="Nzi Comoe"	        if s1q23c==11| s1q23c==19 |  s1q23c==20 |  s1q23c==33 |  s1q23c==53                            /*Bongouanou, Daoukro, Dimbokro, M'bahiakro, Bocanda*/
replace geocode2="Marahoue"	        if s1q23c==12| s1q23c==40 |  s1q23c==50                                                        /*Bouafl, Sinfra, Zuenoula*/
replace geocode2="Cavaly"	        if s1q23c==26| s1q23c==22 |  s1q23c==58                                                        /*Guiglo, Dukou, Toulepleu*/
replace geocode2="Baffing"	        if s1q23c==46   /*Touba*/ 
replace geocode2="Non CIV"              if s1q23c==59 
replace geocode2="Other regions"        if s1q23c==.
ta s1q23c, m
ta geocode2
ta geocode2, m

g double geocode1=.
replace geocode1=1      if geocode2=="Lagunes" 	
replace geocode1=2      if geocode2=="Sud Comoe"	
replace geocode1=3	if geocode2=="Agneby"
replace geocode1=4	if geocode2=="Haut-Sassandra"
replace geocode1=5	if geocode2=="Savanes"	
replace geocode1=6      if geocode2=="Vallee du Bandama"	
replace geocode1=7	if geocode2=="Moyen-Comoe"
replace geocode1=8	if geocode2=="18 montagnes"
replace geocode1=9	if geocode2=="Lacs"
replace geocode1=10	if geocode2=="Zanzan"
replace geocode1=11	if geocode2=="Bas-Sassandra"
replace geocode1=12     if geocode2=="Worodougou"	
replace geocode1=13	if geocode2=="Denguele"
replace geocode1=14	if geocode2=="Sud Bandama"
replace geocode1=15     if geocode2=="Fromager"	
replace geocode1=16	if geocode2=="Nzi Comoe"
replace geocode1=17	if geocode2=="Marahoue"
replace geocode1=18	if geocode2=="Cavaly"
replace geocode1=19	if geocode2=="Baffing"
replace geocode1=20     if geocode2=="Non CIV"
replace geocode1=21     if geocode2=="Other regions" 
ta geocode1
ta geocode1, m

recode geocode1 18=11 19=13 15=14  21=20
/*Grouping Cavaly and Bas-Sassandra, Baffing and Denguele, Fromager and Sud Bandama, Non CIV and "Other region"*/




/*Individual information*/




*Ethic group
sort idmen indid s1q8
g ethnie=s1q8
recode ethnie 6/max=6
cap label drop ethnie
label define ethnie 1"Akan" 2"Krou" 3"Mande-Nord" 4"Mande-Sud" 5"Voltaique" 6"Etrangers" 
label values ethnie ethnie
ta ethnie [aw=weig], m

*Religion
sort idmen indid s1q9
g religion=s1q9
recode religion 1/3=1 4=2 5/7=3
cap label drop religion 
label define religion 1"Chretien" 2"Musulman" 3"Animiste/Autres/Sans religion"
label values religion religion
ta religion [aw=weig], m

*Sex
sort idmen indid s1q3
g sex= s1q3 if s1q3~=.
tab sex [aw=weig], m

*Relation to head
sort idmen indid s1q4
g relat= s1q4
ta relat [aw=weig], m
recode relat 1=1 2=2 3=3 4=4 5/10=6 11=7 12/13=8 /*5 (grandchild) not coded)*/
replace relat=3 if ( s1q6a <10 & relat==1)

*Age
sort idmen indid s1q6a
g agey= s1q6a if s1q6a~=.
ta agey [aw=weig], m

*Marital status
sort idmen indid s1q7
label define marstat 1 "Married" 2"Divorsed/separated" 3"widowed" 4"Never married", add
g marstat = s1q7 if s1q7~=.
recode marstat 0=1 6=5 /*Replacing in the correct codes*/
recode marstat 1=1 2/3=2 4=3 5=4 /*Have to check if it recodes correctly*/
label value marstat marstat
ta marstat [aw=weig], m

/*Education*/
sort idmen indid s1q6a s1q27
g literacy=s1q27 if (s1q6a >=5&s1q27~=.)
recode literacy 0=3 7=3 /*Replacing in the correct codes*/
ta literacy [aw=weig], m

sort idmen indid s1q6a s1q30
g everattd=s1q30 if (s1q6a >=5&s1q30~=.)
recode everattd 3=2
ta everattd [aw=weig], m

sort idmen indid s1q6a s1q31
g educlev=s1q31  if s1q6a >=5 & s1q31~=. /*I choose the last class attended , instead of the highest grade completed*/
ta educlev [aw=weig], m
recode educlev . =99 if everattd==2 /* people who have never attended to school have "no level of education"*/
recode educlev 1 2 3 4 5 =3
recode educlev 6 =4 /* I am assuming that people with educlev=6 are complete primary*/
recode educlev 7 8 9 10 11 12 24 25 26 27 28 29 30 31 32 33 34 35 36 37 =5 /*I assume "secondaire" and "secondaire professionnelle" are the same*/
recode educlev 13 =6 /* I am assuming that people with educlev=13 are complete secondary*/
recode educlev 14 15 16 17 18 19 20 21 22 23 38 39=7
recode educlev 0 =8
recode educlev 99=1 /*No educational level*/
label define educlev 1 "No level" 2 "koranic" 3 "incomplete primary" 4 "complete primary" 5 "incomplete secundaty"/*
*/ 6 "complete secundary" 7 "tertiary" 8 "pre-school" 9 "not stated" 99 "undefined", add
label value educlev educlev
ta educlev [aw=weig], m

sort idmen indid s1q6a s1q35
g atschool=s1q35  if s1q6a >=5 & s1q6a~=.
ta atschool [aw=weig], m

sort idmen indid s1q6a s1q38
g schltyp=s1q38 if s1q38~=.
recode schltyp 1/2 =1 3/4=2 5/6=3
lab def schltyp 1"Public" 2"Private" 3"Coranique/Other", add
lab values schltyp schltyp 
ta schltyp [aw=weig], m

label define yesno 1 "Yes" 2 "No", add
label value literacy yesno
label value atschool yesno

/*Health*/
sort idmen indid s1q11 
gen morbid=s1q11 if s1q11~=.
ta morbid [aw=weig], m
sort idmen indid s1q12a s1q12b
gen morb_tr=s1q12a if s1q12a~=.
tempvar timemorbid
g timemorbid=s1q12b
recode timemorbid 1=1 2=7 3=30 4=365
replace morb_tr=s1q12a*timemorbid 
gen rtreatm = cond(s1q13==1&s1q14==1,1,2) if morbid==1
tab rtreatm [aw=weig], m
sort idmen indid s1q17
gen hprovide = s1q17 if s1q17~=.
recode hprovide 1=1 2/5=2 6=3 7=2 10=4 8/9=5 11=2 12=5 
tab hprovide [aw=weig], m
*Handicap status
sort idmen
sort idmen indid s1q10
g handicap=1 if s1q10~=0    /* 1 is handicaped, 0 not*/
replace handicap=0 if s1q10==0
ta handicap  [aw=weig],m
by idmen: g nhandicap=sum(handicap) 
bysort idmen: egen nbhandic=max(nhandicap)  /*Number of handicaped persons in the household*/
ta nbhandic  [aw=weig],m
sort idmen indid s1q20
gen prenatal= cond(s1q20==1,1,0) 
ta prenatal [aw=weig],m

/*Temporary migration*/   *No information on that topic: check the file where there is a variable of the presence of the head
* I use the variable on presence or absence to generate the temporary migration, but not sure
sort idmen indid s1q5
g t_mig=0
replace t_mig=1 if s1q5==3 | s1q5==4   /*A visitor has left his own house so is a temporary migrant*/
ta t_mig [aw=weig], m

/*Long term migration*/ *Not very detailed

#delimit;
label define dummy 1 "yes" 0 "No", add;
label define s1q26 1 "Travail" 2 "Sant" 3 "Ecole" 4 "Recherche d'emploi"
5 "Aide familiale" 6 "Prob. de logement" 7 "Visite" 8 "Mariage " 9 "Motif familial" 10"Autres", add;
#delimit cr
recode s1q26 0=1
label values s1q26 s1q26 
g mig=2
replace mig=1 if (s1q25==3|s1q25==4)
g why_mig=s1q26
label values why_mig s1q26 
g yrs_here=s1q24a if s1q24a~=.
recode yrs_here 99=.
replace yrs_here=(s1q24a*12)+s1q24b   /*In months*/
replace yrs_here = yrs_here/12        /*In years*/
replace yrs_here = round(yrs_here, 0.1)
ta yrs_here [aw=weig], m

gen spouse=cond(relat==2, 1,0) if (agey>10 & sex==2)
ta spouse [aw=weig],m
gen head=cond(relat==1, 1,0) if (agey>10)
ta head[aw=weig],m
sort idmen (indid)
egen nspouse=sum(spouse), by(idmen)
egen nhead=sum(head), by(idmen)
recode nhead 0=1
ta nspouse [aw=weig], m
ta nhead[aw=weig], m

save temp, replace









use sect02, clear
/*Creating unique identification*/
sort grappe menord s1q2
cap drop grappen 
cap drop menordn 
cap drop idmen 
cap drop idind 

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
gen idind = idmen*100+s1q2
*dups idmen indid, drop

sort idmen
save , replace
use temp, clear
merge idmen using sect02
ta _merge
keep if _merge==3
drop _merge
pause 100

sort idmen indid
recode s2q12 0=14
gen lf=cond(s2q12==1|s2q12==2|s2q12==3|s2q12==5|s2q12==6| s2q12==10|s2q12==13|s2q12==14,0,1)   
replace lf=0 if (agey<10 & agey>65) /*Taking a limit of age*/
ta lf [aw=weig] , m
lab var lf "Labor force"
recode s2q11 8=2 if lf==1
recode s2q8 0=2
gen search=cond(lf==1& s2q5==2 & s2q8==2 & s2q11==1, 1, 0) 
ta search [aw=weig], m

g empl=cond(s2q5==1 | s2q8==1| s2q12==4, 1, 0) 
tab empl [aw=weig], m
g unempl=cond(s2q5==2 & s2q8==2 & s2q11==1, 1, 0) 
ta unempl [aw=weig], m
g nilf=cond(empl==0&unempl==0, 1, 0)
ta nilf [aw=weig], m
ta lf [aw=weig], m

gen occupat=9 
/*employed*/ replace occupat=1 if (s2q12==4)
/*unemployed*/ replace occupat=2 if (search==1)
/*Retired*/ replace occupat=3 if (lf==0&s2q12==5)
/*Student*/ replace occupat=4 if (lf==0&s2q12==1)
/*Dependent */ replace occupat=5 if (lf==0&s2q12==2|s2q12==3|s2q12==10|s2q12==13)
* Dependents: invalids, children, house wifes, grandparents, etc..
ta occupat [aw=weig], m

g statocc=s2q14 if s2q14~=.
recode statocc 1/34=1 35/44=2 45/58=1 59/108=2 109/157=1 158/180=4 181/182=2 183/205=1 206=4 207/411=1 412/507=4 508/517=1 518/536=4 537/541=1 999=9 998=.
ta statocc [aw=weig], m
cap label drop occupat 
label define occupat 1 "employed" 2 "unemployed" 3 "homemaker" 4 "retires" 5 "student"/*
*/ 6 "dependent" 9 "other", add
cap label drop statocc 
label define statocc 1 "wage employee, gov." 2 "wage employee, priv." 3 "informal"/*
*/ 4 "self-employed" 5 "employer" 6 "volunteer" 9 "other",add
label values search yesno
label values occupat occupat
label values statocc statocc
ta statocc [aw=weig], m
replace statocc=9 if statocc>9
ta statocc [aw=weig], m
ta occupat [aw=weig], m

gen activite=s2q14 if occupat==1 & s2q14~=.
ta activite [aw=weig], m
recode activite 1/34=9 35/119=8 120/124=7 125/182=8 183/188=9 189/206=8 207/225=4 226/237=7 238/300=8 301/307=4 308/317=7 318/336=8 337/396=9 397/439=6 440/457=1 458/507=2 508/517=10 518/536=10 537/997=11 998=. 999=. 
ta activite [aw=weig], m
* other
gen industry=11 if (occupat==1&activite==11 & s2q14~=.)
* Agriculture
replace industry=1 if activite==1
* Manufacture
replace industry=2 if activite==2
* Mining and quarrying
*replace industry=3 if activite==3
* Contruction 
replace industry=4 if activite==4
* Utilities (water, gas, and electricity)
*replace industry=5 if activite==5
* Commerce, Hotels, and Restaurants
replace industry=6 if activite==6
* Banking, Finantial Services
replace industry=7 if activite==7
* Professional, (social work, international organizations, etc.) 
replace industry=8 if activite ==8
* Public Administration
replace industry=9 if activite ==9
* Transport
replace industry=10 if activite==10
tab activite if occupat==1 [aw=weig], m
tab industry if occupat==1 [aw=weig], m
recode industry 1=1 2/4=2 5/6=3 7/9=4 10=2 11=2
label define industry 1"Agriculture" 2"Manufacturing/Mining and quarrying/construction/transport/other" 3"Utilities/commerce" 4"Banking/financial services/Professional/Public administration"
label values industry industry
ta industry [aw=weig], m

#delimit;
* household size;
sort idmen indid;
lab var hhsize "size of household";
by idmen indid: gen dep    = cond( occupat==5, 1, 0 ) if occupat~=.;
by idmen indid: gen ind    = cond( occupat~=5, 1, 0 ) if occupat~=.;
tab dep;
tab ind;
sort idmen ;
by idmen :       egen deph  = sum(dep);
by idmen :       egen indh  = sum(ind);
by idmen :       gen double depratio = deph / indh;

lab var depratio "Dependency ratio";
sum depratio deph indh;
replace depratio =0 if depratio ==.;
sum depratio deph indh;
by idmen :       gen double depratio2 = (depratio^2);
lab var depratio2 "Square of age dependency ratio";
* structure variables;
gen byte baby   = cond( agey <= 5,              1, 0 );
gen byte kid    = cond( agey >  5 & agey <= 14, 1, 0 );
gen byte adult  = cond( agey > 14 & agey <= 64, 1, 0 );
gen byte senior = cond( agey > 64 & agey <  99, 1, 0 );
gen byte ad_dep = cond( adult == 1 & ( occupat == 2 | occupat == 5 | occupat == 6 ), 1, 0 );
sort idmen;

by idmen: egen int num_bab  = sum(baby);
lab var num_bab "Number of under-5s in household";
drop baby;

by idmen: gen int num_bab2 = num_bab^2;
lab var num_bab2 "Square of number of under-5s in household";

by idmen: egen int num_kid = sum(kid);
lab var num_kid "Number of 5-14s in household";
drop kid;

by idmen: gen int num_kid2 = ((num_kid)^2);
lab var num_kid2 "Square of number of 5-14s in household";

by idmen: egen int num_ads = sum(adult);
lab var num_ads "Number of adults in household";
drop adult;

by idmen: gen int num_ads2 = ((num_ads)^2);
lab var num_ads2 "Square of number of adults in household";

bysort idmen: egen int num_adp = sum(ad_dep);
lab var num_adp "Number of non-working adults in household";

bysort idmen: gen int num_adp2 = num_adp^2;
lab var num_adp2 "Square of number of non-working adults in household";
drop ad_dep;

bysort idmen: egen int num_srs = sum(senior);
lab var num_srs "Number of 65+ in household";

bysort idmen: gen double num_srs2 = (num_srs)^2;
lab var num_srs2 "Square of number of 65+ in household";



save, replace;


count if relat == 1;

preserve;
keep if relat == 1;

*cap drop _expand
*dups idmen indid, drop
sort idmen;

* gender of head of household: male;
by idmen: gen h_mal = cond( sex == 1, 1, 0 ) ;
lab var h_mal "Male-headed household";

* gender of head of household: female and divorced/seperated, or never married;
by idmen: gen h_fem = cond( sex == 2, 1, 0 ) ;
lab var h_fem "Female-headed household";

* female-headed households that are non-polygamous;
by idmen: gen h_npf = cond( sex == 2 & ( marstat ~= 3 ), 1, 0 ) if ( marstat ~= . );
lab var h_npf "Female head not polygamous";

* polygamous hh, female-headed;
by idmen: gen h_pf = cond( sex == 2 & marstat == 3, 1, 0 ) if ( marstat ~= . );
lab var h_pf "female-headed polygamous household";

* assumes that separated => no income from absent spouse;
by idmen: gen h_nsp = cond( marstat == 1 | marstat == 4 | marstat == 5, 1, 0 ) if ( marstat ~= . );
lab var h_nsp "Head of household is single";

* Note: agey not allowed to be missing;
by idmen: gen h_agey = agey ;
lab var h_agey "Age of head";

by idmen: gen h_agey_c = cond( h_agey < 99, h_agey, . ) ;
lab var h_agey_c "Age of Head, no 99 allowed";

by idmen: gen int h_agey2 = ((h_agey)^2) ;
lab var h_agey2 "Square of age of household Head";




by idmen: gen int h_agey2_c = ((h_agey_c)^2);
lab var h_agey2_c "Square of no-99 age of household head";



************************************ Health status of the head*****************************************************;
sort idmen;
by idmen: g int h_hand=1 if handicap==1;
replace h_hand=0 if h_hand==.;

************************************ Religion of the head**********************************************************;
sort idmen;
by idmen: g int h_christ=1 if religion==1; /*Head Christian*/;
replace h_christ=0 if h_christ==.;
by idmen: g int h_musl=1 if religion==2; /*Head Muslem*/;
replace h_musl=0 if h_musl==.;
by idmen: g int h_anim=1 if religion==3; /*Head Animist*/;
replace h_anim=0 if h_anim==.;

************************************ Ethnicity of the head**********************************************************;
sort idmen;
by idmen: g int h_akan=1    if ethnie==1; /*Head akan*/;
replace h_akan=0 if h_akan==.;
by idmen: g int h_krou=1    if ethnie==2; /*Head Krou*/;
replace h_krou=0 if h_krou==.;
by idmen: g int h_manden=1  if ethnie==3; /*Head Mande North*/;
replace h_manden=0 if h_manden==.;
by idmen: g int h_mandes=1  if ethnie==4; /*Head mande South*/;
replace h_mandes=0 if h_mandes==.;
by idmen: g int h_volta=1   if ethnie==5; /*Head voltaic*/;
replace h_volta=0 if h_volta==.;
by idmen: g int h_etr=1     if ethnie==9; /*Head Stranger*/;
replace h_etr=0 if h_etr==.;


************************************ employment variables**********************************************************;

/*by idmen: gen h_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . );
lab var h_ilf "Head of household in labor force"*/;

by idmen: gen h_nilf = cond( nilf==1, 1, 0 );
lab var h_nilf "Head of household not in labor force";

*by idmen: gen int h_hrs = hourwrk if ( empl == 1 );
*lab var h_hrs "Head's hours worked per week";

* could be amended to be those who are employed ;

by idmen: gen h_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )  ;
by idmen: gen h_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . );
lab var h_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;
sort idmen;

by idmen: g h_ag=cond(industry==1, 1, 0) if ( empl == 1) ;
lab var h_ag "Head is engaged in an agricultural activity";
tab h_ag, m;

by idmen: g h_man=cond(industry==2, 1, 0) if ( empl == 1) ;
lab var h_man "Head is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab h_man, m;

by idmen: g h_com=cond(industry==3, 1, 0) if ( empl == 1 ) ;
lab var h_com "Head is engaged in Utilities/commerce activities";
tab h_com, m;

by idmen: g h_adm=cond(industry==4, 1, 0) if ( empl == 1 ) ;
lab var h_adm "Head is engaged in Banking/financial services/Professional/Public administration activities";
tab h_adm, m;

* first test variable: head should have one employment category or be unemployed;
*egen heademp = rsum(h_unem h_ag h_mfg h_mine h_cnst h_util h_comm h_bank h_prof h_pbad h_tspt h_othr) if (relat == 1);

*egen heademp = rsum(h_unem h_pub h_pvt h_inf h_self) if (relat == 1);

egen heademp = rsum(h_unem h_ag h_com h_adm h_man) if (relat == 1);


ta heademp, m;

* must deal with known problems from definition of unemployed;

replace h_unem  = 0 if   heademp == 2;
replace heademp = 1 if   heademp == 2;
assert heademp <= 1 if ( heademp ~= . );
drop heademp;

*by idmen: gen h_job = cond( h_ag == 1   | h_mfg == 1  | h_mine == 1 | h_cnst == 1 | h_util == 1 | 
                          h_comm == 1 | h_bank == 1 | h_prof == 1 | h_pbad == 1 | h_tspt == 1 | 
                          h_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );


/*by idmen: gen h_job =  cond( h_pub == 1   | h_pvt == 1  | h_inf == 1 | h_self == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .)*/;

by idmen: gen h_job =  cond( h_ag == 1   | h_com == 1  | h_man == 1 | h_adm == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .);
lab var h_job "Head has a job";


* check that the head has a job, is unemployed, or is not in the labor force;
tempvar hjob_test;
* must deal with known problems from definition of unemployment;
replace h_unem = 0 if h_job  == 1;
replace h_nilf = 0 if h_unem == 1;
replace h_nilf = 0 if h_job  == 1;

gen int hjob_test = h_job + h_unem + h_nilf ;
assert hjob_test <= 1 if ( hjob_test ~= . );
tab hjob_test;

by idmen: gen h_nojb = cond( h_unem == 1 | h_nilf == 1, 1, 0 ) if ( occupat ~= .);
lab var h_nojb "Head unemployed or NILF";






********************************************education variables**********************************************;

by idmen: gen h_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ne "Head has no education";

by idmen: gen h_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ke "Head has koranic education";

by idmen: gen h_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pnc "Head incomplete primary";

by idmen: gen h_pc  = cond( educlev == 4, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pc "Head completed primary";

by idmen: gen h_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_snc "Head incomplete secondary";

by idmen: gen h_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_sc "Head completed secondary";

by idmen: gen h_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ts "Head has tertiary";

by idmen: gen h_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ps "Head preschool only";

by idmen: gen h_ue  = cond( educlev == 9 | educlev == 99 | educlev == ., 1, 0 );
lab var h_ue "Head unstated/unknown education";

by idmen: gen h_sct = cond(educlev == 5|educlev==6 | educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_sct "Head has at least imcomplete, completed secondary or tertiary education";

/*by idmen: gen h_st  = cond(educlev>=5 & educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_st "Head has at least some secondary education"*/;

by idmen: gen h_prim = cond(educlev==3|educlev==4|educlev==8,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_prim "Head has at least some prescholl or primary education";

by idmen: gen h_noeduc=cond(educlev==1, 1, 0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_noeduc "Head has no education or has preschool";



tempvar test_h_ed1;
egen test_h_ed1 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps );
lab var test_h_ed1 "Test that head has some level of education if educlev ~= .";
assert test_h_ed1 == 1 if ( educlev < 9 & educlev ~= . );

tempvar test_h_ed3;
egen test_h_ed3 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps h_ue );
lab var test_h_ed1 "Test that head has education information or missing";
assert test_h_ed3 <= 1;

tempvar test_h_ed2;
egen test_h_ed2 = rsum( h_sct h_sct h_prim );
lab var test_h_ed2 "Test of head's educlev for lumping education";
assert test_h_ed2 <= 2 if ( test_h_ed2 ~= . );

by idmen: gen h_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var h_lit "Head is literate";

by idmen: gen h_occup= occupat;
*by idmen: gen h_industry= industry;
by idmen: gen h_statoc= statoc;

********************************************Migration variables**********************************************;
by idmen: g t_mig_h=cond(t_mig==1, 1, 0) if t_mig~=.;
by idmen: gen mig_h = cond(mig == 1, 1, 0) if mig~=.;
lab var mig_h "Head is a Migrant";
sort idmen;
by idmen: g count=_n;
ta count;
drop if count>1;
drop count;

sort idmen;
save head, replace;

use temp, clear;
merge idmen using head;
ta _merge;
keep if _merge==3;
drop _merge;

save , replace;

restore;

count;

gen sp=1 if relat==2;
recode sp .=0;
egen nbsp=sum(sp), by(idmen);
tab nbsp;
preserve;
keep if relat==1;
tab nbsp;
restore;
drop nbsp;

bysort idmen: egen smaxage = max(agey) if relat == 2;
keep if relat==2 & agey == smaxage;

count;

sort idmen;
by idmen: g count=_n;
ta count;
drop if count>1;
drop count;

egen nbsp=sum(sp), by(idmen);
tab nbsp;
drop nbsp;
*============
* Controlling for the possibility of 2 spouses with same age and education,
* then keep the one with the lowest indid
* ===========;

gen realed=educlev;
*recode realed 1=0 8=1 9=. 99=.;
bysort idmen: egen smaxeduc = max(realed) if realed~=.;
keep if (realed == smaxeduc) | realed==.;
egen nbsp=sum(sp), by(idmen);
tab nbsp;
drop nbsp;

bysort idmen: egen sminindi = min(indid);
keep if indid == sminindi;
egen nbsp=sum(sp), by(idmen);
tab nbsp;
drop nbsp;

count;

* note: agey cannot be missing;
by idmen: gen s_agey = agey;
lab var s_agey "Age of spouse";

by idmen: gen s_agey_c = cond( agey < 99, agey, . );
lab var s_agey_c "Spouse's age corrected for 99";

by idmen: gen int s_agey2 = ((s_agey)^2);
lab var s_agey2 "Square of age of Spouse";

by idmen: gen int s_agey2_c = ((s_agey_c)^2);
lab var s_agey2_c "Square of age of spouse corrected for 99";

************************************ Health status of the spouse*****************************************************;
sort idmen;
by idmen: g int s_hand=1 if handicap==1;
replace s_hand=0 if s_hand==.;

************************************ Religion of the head**********************************************************;
sort idmen;
by idmen: g int s_christ=1 if religion==1; /*Spouse Christian*/;
replace s_christ=0 if s_christ==.;
by idmen: g int s_musl=1 if religion==2; /*Spouse Muslem*/;
replace s_musl=0 if s_musl==.;
by idmen: g int s_anim=1 if religion==3; /*Spouse Animist*/;
replace s_anim=0 if s_anim==.;

************************************ Ethnicity of the head**********************************************************;
sort idmen;
by idmen: g int s_akan=1    if ethnie==1; /*Spouse akan*/;
replace s_akan=0 if s_akan==.;
by idmen: g int s_krou=1    if ethnie==2; /*Spouse Krou*/;
replace s_krou=0 if s_krou==.;
by idmen: g int s_manden=1  if ethnie==3; /*Spouse Mande North*/;
replace s_manden=0 if s_manden==.;
by idmen: g int s_mandes=1  if ethnie==4; /*Spouse mande South*/;
replace s_mandes=0 if s_mandes==.;
by idmen: g int s_volta=1   if ethnie==5; /*Spouse voltaic*/;
replace s_volta=0 if s_volta==.;
by idmen: g int s_etr=1     if ethnie==9; /*Spouse Stranger*/;
replace s_etr=0 if s_etr==.;


***************************************** employment variables**************************************************;
/*by idmen: gen s_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . );
lab var s_ilf "Head of household in labor force"*/;

by idmen: gen s_nilf = cond( nilf==1, 1, 0 );
lab var s_nilf "Head of household not in labor force";

*by idmen: gen int s_hrs = hourwrk if ( empl == 1 );
*lab var s_hrs "Head's hours worked per week";

* could be amended to be those who are employed ;
by idmen: gen s_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )   ;
/*Here I take empl instead of occupat to take into account, those who have a job but have not worked last 7 days*/;
lab var s_em "Head of household is employed";

* could be amended to be those who are unemployed (search==1 and/or want to work) /*But I choose to drop the search condition*/;
by idmen: gen s_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . );
lab var s_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;
sort idmen;

by idmen: g s_ag=cond(industry==1, 1, 0) if ( empl == 1 & empl~=.) ;
lab var s_ag "Head is engaged in an agricultural activity";
tab s_ag;

by idmen: g s_man=cond(industry==2, 1, 0) if ( empl == 1 & empl~=.) ;
lab var s_man "Head is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab s_man;

by idmen: g s_com=cond(industry==3, 1, 0) if ( empl == 1 & empl~=.) ;
lab var s_com "Head is engaged in Utilities/commerce activities";
tab s_com;

by idmen: g s_adm=cond(industry==4, 1, 0) if ( empl == 1 & empl~=.) ;
lab var s_adm "Head is engaged in Banking/financial services/Professional/Public administration activities";
tab s_adm;

by idmen: gen s_job =  cond( s_ag == 1   | s_com == 1  | s_adm == 1 | s_man == 1 , 1, 0 ) 
			        if ( occupat ~= . /*& industry ~= .*/ );
lab var s_job "Spouse has a job";

* check that the spouse has a job, is unemployed, or is not in the labor force;
tempvar sjob_test;
replace s_unem = 0 if s_job == 1;
replace s_nilf = 0 if s_unem == 1;
replace s_nilf = 0 if s_job == 1;
gen int sjob_test = s_job + s_unem + s_nilf;
assert sjob_test <= 1 if ( sjob_test ~= . );
tab sjob_test;

by idmen: gen s_nojb = cond( s_nilf == 1 | s_unem == 1, 1, 0 ) if ( occupat ~= .);
lab var s_nojb "Spouse has no job";

* education variables;

by idmen: gen s_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_ne "Spouse has no education";

by idmen: gen s_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ke "Spouse has koranic education";

by idmen: gen s_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pnc "Spouse incomplete primary";

by idmen: gen s_pc  = cond( educlev == 4, 1, 0 ) /* if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pc "Spouse completed primary";

by idmen: gen s_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_snc "Spouse incomplete secondary";

by idmen: gen s_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_sc "Spouse completed secondary";

by idmen: gen s_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ts "Spouse tertiary";

by idmen: gen s_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ps "Spouse preschool only";

by idmen: gen s_ue  = cond( educlev == 9 | educlev == 99 | educlev==., 1, 0 );
lab var s_ue "Spouse unstated education";

by idmen: gen s_sct = cond(educlev==5|educlev==6|educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_sct "Spouse has imcomplete , completed secondary or tertiary education";

by idmen: gen s_st  = cond(educlev>=5&educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_st "Spouse has at least some secondary education";

by idmen: gen s_prim = cond(educlev==3|educlev==4|educlev==8,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_prim "Spouse has some level of primary schooling";

by idmen: gen s_noeduc = cond(educlev==1,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_noeduc "Spouse has no education or has preschool";


tempvar test_s_ed1;
egen test_s_ed1 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps );
lab var test_s_ed1 "Test that spouse has some level of education if educlev ~= .";
assert test_s_ed1 <= 1 if ( educlev < 9 & educlev ~= . );

tempvar test_s_ed3;
egen test_s_ed3 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps s_ue );
lab var test_s_ed1 "Test that spouse has education information or missing";
assert test_s_ed3 <= 1;

tempvar test_s_ed2;
egen test_s_ed2 = rsum( s_sct s_st s_prim );
lab var test_s_ed2 "Test of spouse's educlev for lumping education";
assert test_s_ed2 <= 2 if ( test_s_ed2 ~= . );

by idmen: gen s_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var s_lit "Spouse is literate";

sort idmen;
tab relat;
by idmen: gen s_occup= occupat;
*by idmen: gen s_industry= industry;
by idmen: gen s_statoc= statoc;
g s_relat=relat ;
sort idmen;
save spouse, replace;


use temp, clear;
sort idmen;
merge idmen using spouse;
ta _merge;


di "MUST SET SPOUSE OBS TO ZERO; HE/SHE HAS NO SPOUSE";

sort idmen;
by idmen: replace s_christ=0 if (_merge==1);
by idmen: replace s_anim=0 if   (_merge==1);
by idmen: replace s_musl=0 if   (_merge==1);
by idmen: replace s_hand=0 if   (_merge==1);
by idmen: replace s_akan=0 if   (_merge==1);
by idmen: replace s_krou=0 if   (_merge==1);
by idmen: replace s_manden=0 if (_merge==1);
by idmen: replace s_mandes=0 if (_merge==1);
by idmen: replace s_volta=0 if  (_merge==1);
by idmen: replace s_etr=0 if    (_merge==1);

sort idmen;
by idmen: replace s_agey    = 0 if ( _merge == 1 );
by idmen: replace s_agey_c  = 0 if ( _merge  == 1 );
by idmen: replace s_agey2   = 0 if ( _merge  == 1 );
by idmen: replace s_agey2_c = 0 if ( _merge  == 1 );
by idmen: replace s_nilf    = 0 if ( _merge  == 1 );

* employment variables;
by idmen: replace s_ag     = 0 if ( _merge  == 1 );
by idmen: replace s_adm     = 0 if ( _merge  == 1 );
by idmen: replace s_com    = 0 if ( _merge  == 1 );
by idmen: replace s_man     = 0 if ( _merge  == 1 );
by idmen: replace s_job     = 0 if ( _merge  == 1 );

* could be amended to be those unemployed;
by idmen: replace s_unem    = 0 if ( _merge  == 1 );
*by idmen: replace s_ag      = 0 if ( _merge  == 1 );

/*
by idmen: replace s_merge fg     = 0 if ( _merge  == 1 );
by idmen: replace s_merge ine    = 0 if ( _merge  == 1 );
by idmen: replace s_cnst    = 0 if ( _merge  == 1 );
by idmen: replace s_util    = 0 if ( _merge  == 1 );
by idmen: replace s_comm    = 0 if ( _merge  == 1 );
by idmen: replace s_bank    = 0 if ( _merge  == 1 );
by idmen: replace s_prof    = 0 if ( _merge  == 1 );
by idmen: replace s_pbad    = 0 if ( _merge  == 1 );
by idmen: replace s_tspt    = 0 if ( _merge  == 1 );
by idmen: replace s_othr    = 0 if ( _merge  == 1 );
*/;

* lumping variables;
/*
by idmen: replace s_bppa    = 0 if ( _merge  == 1 );
*by idmen: replace s_merge guc    = 0 if ( _merge  == 1 );
by idmen: replace s_nojb    = 0 if ( _merge  == 1 );
by idmen: replace s_svcs    = 0 if ( _merge  == 1 );
by idmen: replace s_wemp    = 0 if ( _merge  == 1 );
by idmen: replace s_ind    = 0 if ( _merge  == 1 );
*/;

* education variables;

by idmen: replace s_ne      = 0 if ( _merge  == 1 );
by idmen: replace s_ke      = 0 if ( _merge  == 1 );
by idmen: replace s_pnc     = 0 if ( _merge  == 1 );
by idmen: replace s_pc      = 0 if ( _merge  == 1 );
by idmen: replace s_snc     = 0 if ( _merge  == 1 );
by idmen: replace s_sc      = 0 if ( _merge  == 1 );
by idmen: replace s_ts      = 0 if ( _merge  == 1 );
by idmen: replace s_ps      = 0 if ( _merge  == 1 );
by idmen: replace s_ue      = 0 if ( _merge  == 1 );
by idmen: replace s_sct     = 0 if ( _merge  == 1 );
by idmen: replace s_st      = 0 if ( _merge  == 1 );
by idmen: replace s_prim    = 0 if ( _merge  == 1 );
by idmen: replace s_lit     = 0 if ( _merge  == 1 );
*by idmen: replace s_self     = 0 if ( _merge  == 1 );

* other
by idmen: replace s_hrs      = 0 if ( _merge  == 1 );
by idmen: replace s_occup    = 0 if ( _merge  == 1 );
*by idmen: replace s_industry = 0 if ( _merge  == 1 );
by idmen: replace s_statoc   = 0 if ( _merge  == 1 );
by idmen: replace s_relat    = 0 if ( _merge  == 1 );


keep if _merge==3;
drop _merge;
save, replace;

