clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of adult work*****************
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"

use ind6, clear
#delimit;


/* --------------------------- */
/*Adult Work variables */
/* --------------------------- */;

cap log close;
log using adult_work.log, replace;

count if agey>=16 & agey<=65   /*We can assume 65 years is a good time for retiring*/;  

keep if agey>=16 & agey<=65;

*cap drop _expand
*dups hid indid, drop
sort hid;

* gender of Adult: male;
by hid: gen a_mal = cond( sex == 1, 1, 0 ) ;
lab var a_mal "Adult is a Man";


by hid: gen a_fem = cond( sex == 2, 1, 0 ) ;
lab var a_fem "Adult is a Woman";

by hid: gen a_polyg = cond(marstat == 3 , 1, 0 ) if ( marstat ~= . );
lab var a_polyg  "Adult is in a polygamous family";

* Assume chil is living alone;
by hid: gen a_alone = cond( relat<2, 1, 0 ) if ( relat~= . );
lab var a_alone "Adult is alone";

* Note: agey not allowed to be missing;
by hid: gen a_agey = agey ;
lab var a_agey "Age of Adult";

by hid: gen a_agey_c = cond( a_agey < 99, a_agey, . ) ;
lab var a_agey_c "Age of Adult, no 99 allowed";

by hid: gen int a_agey2 = ((a_agey)^2) ;
lab var a_agey2 "Square of age of Adult";

by hid: gen int a_agey2_c = ((a_agey_c)^2);
lab var a_agey2_c "Square of no-99 age of Adult";

/*by hid: gen int feel_poor_c = cond(feel_poor==1,1,0) if feel_poor~=.;
lab var feel_poor_c "Adult feels poor"*/;



************************************ Health status of the Adult*****************************************************;
sort hid;
by hid: g int a_hand=1 if handicap==1;
replace a_hand=0 if a_hand==.;

************************************ Religion of the Adult**********************************************************;
sort hid;
by hid: g int a_christ=1 if religion==1; /*Adult Christian*/;
replace a_christ=0 if a_christ==.;
by hid: g int a_musl=1 if religion==2; /*Adult Muslem*/;
replace a_musl=0 if a_musl==.;
by hid: g int a_anim=1 if religion==3; /*Adult Animist*/;
replace a_anim=0 if a_anim==.;

************************************ Ethnicity of the Adult**********************************************************;
sort hid;
by hid: g int a_akan=1    if ethnie==1; /*Adult akan*/;
replace a_akan=0 if a_akan==.;
by hid: g int a_krou=1    if ethnie==2; /*Adult Krou*/;
replace a_krou=0 if a_krou==.;
by hid: g int a_manden=1  if ethnie==3; /*Adult Mande North*/;
replace a_manden=0 if a_manden==.;
by hid: g int a_mandes=1  if ethnie==4; /*Adult mande South*/;
replace a_mandes=0 if a_mandes==.;
by hid: g int a_volta=1   if ethnie==5; /*Adult voltaic*/;
replace a_volta=0 if a_volta==.;
by hid: g int a_etr=1     if ethnie==9; /*Adult Stranger*/;
replace a_etr=0 if a_etr==.;


************************************ employment variables**********************************************************;
by hid: gen a_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . );
lab var a_ilf "Adult of household in labor force";

by hid: gen a_nilf = cond( lf==0, 1, 0 ) if ( lf  ~= . );
lab var a_nilf "Adult of household not in labor force";

by hid: gen int a_hrs = hourwrk if ( occupat == 1 );
lab var a_hrs "Adult's hours worked per week";

* could be amended to be those who are employed ;
by hid: gen a_em = cond( occupat == 1, 1, 0 ) if ( occupat ~= . );
lab var a_em "Adult of household is employed";

* could be amended to be those who are unemployed (search==1 and/or want to work) /*But I choose to drop the search condition*/;
by hid: gen a_unem = cond( occupat == 2, 1, 0 ) if ( occupat ~= . );
lab var a_unem "Adult of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;


/*
by hid: gen a_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var a_pub "Adult is public sector wage employee";
by hid: gen a_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( occupat ~= . & statocc ~= . );

lab var a_pvt "Adult is private sector wage employee";
*by hid: gen a_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( occupat ~= . & statocc ~= . );
*lab var a_emp "Adult is an employer";
by hid: gen a_inf = cond(occupat==1 & statocc==3,1,0 ) if (occupat ~= . & statocc ~= .);
lab var a_inf "Adult works in informal sector";
by hid: gen a_self = cond(occupat==1 & statocc==4,1,0 ) if (occupat ~= . & statocc ~= .);
lab var a_self "Adult is self employed";
tab a_self;
by hid: gen a_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var a_ag "Adult is engaged in an agricultural activity";
tab a_ag;
*/



sort hid;

by hid: g a_ag=cond(industry==1, 1, 0) if (occupat ~= . & statocc ~= . );
lab var a_ag "Adult is engaged in an agricultural activity";
tab a_ag;

by hid: g a_man=cond(industry==2, 1, 0) if (occupat ~= . & statocc ~= . );
lab var a_man "Adult is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab a_man;

by hid: g a_com=cond(industry==3, 1, 0) if (occupat ~= . & statocc ~= . );
lab var a_com "Adult is engaged in Utilities/commerce activities";
tab a_com;

by hid: g a_adm=cond(industry==4, 1, 0) if (occupat ~= . & statocc ~= . );
lab var a_adm "Adult is engaged in Banking/financial services/Professional/Public administration activities";
tab a_adm;

/*INDUSTRY - need to include : See Rwanda*/;

* first test variable: Adult should have one employment category or be unemployed;
*egen Adultemp = rsum(a_unem a_ag a_mfg a_mine a_cnst a_util a_comm a_bank a_prof a_pbad a_tspt a_othr) if (relat == 1);

*egen Adultemp = rsum(a_unem a_pub a_pvt a_inf a_self) if (relat == 1);

egen Adultemp = rsum(a_unem a_ag a_com a_adm a_man) if (relat == 1);

* must deal with known problems from definition of unemployed;

replace a_unem  = 0 if   Adultemp == 2;
* replace Adultemp = 1 if   Adultemp == 2;
assert Adultemp <= 1 if ( Adultemp ~= . );
drop Adultemp;

*by hid: gen a_job = cond( a_ag == 1   | a_mfg == 1  | a_mine == 1 | a_cnst == 1 | a_util == 1 | 
                          a_comm == 1 | a_bank == 1 | a_prof == 1 | a_pbad == 1 | a_tspt == 1 | 
                          a_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );


/*by hid: gen a_job =  cond( a_pub == 1   | a_pvt == 1  | a_inf == 1 | a_self == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .)*/;

by hid: gen a_job =  cond( a_ag == 1   | a_com == 1  | a_man == 1 | a_adm == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .);
lab var a_job "Adult has a job";


* check that the Adult has a job, is unemployed, or is not in the labor force;
tempvar hjob_test;
* must deal with known problems from definition of unemployment;
replace a_unem = 0 if a_job  == 1;
replace a_nilf = 0 if a_unem == 1;
replace a_nilf = 0 if a_job  == 1;

gen int hjob_test = a_job + a_unem + a_nilf ;
assert hjob_test <= 1 if ( hjob_test ~= . );
tab hjob_test;

by hid: gen a_nojb = cond( a_unem == 1 | a_nilf == 1, 1, 0 ) if ( occupat ~= .);
lab var a_nojb "Adult unemployed or NILF";


********************************************education variables**********************************************;

by hid: gen a_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var a_ne "Adult has no education";

by hid: gen a_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var a_ke "Adult has koranic education";

by hid: gen a_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var a_pnc "Adult incomplete primary";

by hid: gen a_pc  = cond( educlev == 4, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var a_pc "Adult completed primary";

by hid: gen a_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var a_snc "Adult incomplete secondary";

by hid: gen a_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var a_sc "Adult completed secondary";

by hid: gen a_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var a_ts "Adult has tertiary";

by hid: gen a_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var a_ps "Adult preschool only";

by hid: gen a_ue  = cond( educlev == 9 | educlev == 99 | educlev == ., 1, 0 );
lab var a_ue "Adult unstated/unknown education";

by hid: gen a_sct = cond(educlev == 5|educlev==6 | educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var a_sct "Adult has at least imcomplete, completed secondary or tertiary education";

/*by hid: gen a_st  = cond(educlev>=5 & educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var a_st "Adult has at least some secondary education"*/;

by hid: gen a_prim = cond(educlev==3|educlev==4|educlev==8,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var a_prim "Adult has at least some prescholl or primary education";

by hid: gen a_noeduc=cond(educlev==1, 1, 0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var a_noeduc "Adult has no education or has preschool";



tempvar test_a_ed1;
egen test_a_ed1 = rsum( a_ne a_ke a_pnc a_pc a_snc a_sc a_ts a_ps );
lab var test_a_ed1 "Test that Adult has some level of education if educlev ~= .";
assert test_a_ed1 == 1 if ( educlev < 9 & educlev ~= . );

tempvar test_a_ed3;
egen test_a_ed3 = rsum( a_ne a_ke a_pnc a_pc a_snc a_sc a_ts a_ps a_ue );
lab var test_a_ed1 "Test that Adult has education information or missing";
assert test_a_ed3 <= 1;

tempvar test_a_ed2;
egen test_a_ed2 = rsum( a_sct a_sct a_prim );
lab var test_a_ed2 "Test of Adult's educlev for lumping education";
assert test_a_ed2 <= 2 if ( test_a_ed2 ~= . );

by hid: gen a_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var a_lit "Adult is literate";

by hid: gen a_occup= occupat;
*by hid: gen a_industry= industry;
by hid: gen a_statoc= statoc;

********************************************Migration variables**********************************************;

by hid: gen mig_h = cond(mig == 1, 1, 0) if mig~=.;
lab var mig_h "Adult is a Migrant";

sort hid;

******************************************* Land Variables **************************************************;
bysort hid: gen byte land = cond(ownland == 1, 1, 0 ) if ( ownland ~= . );
lab var land "Adult owns land";

replace landsize = 0 if ownland == 2;
rename landsize landsz ;
*recast double landsz;
lab var landsz " land (ha) owned by household";  

by hid: gen float landsz2 = (landsz^2);
lab var landsz2 "Square of land (ha) owned by household";

* if no observations, regression won't run;
qui sum landsz;
if ( `r(N)' == 0 ) {;
	replace landsz  = 0;
	replace landsz2 = 0;
	};

count;

sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

sort hid;

save adult_work, replace;





use hhexp, clear;
drop  homecons house hinvest hutil school internet health trcomm trschool clothing dgoods remitt  hygine entmnt domest inkind;
sort hid ;
save hhexp1, replace;

use adult_work, clear;
sort hid;

merge hid using hhexp1;

ta geocode2;
sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

ta _merge;
drop _merge;

save, replace;

count;


#delimit cr

g rururb=milieu

g wta=pond
drop  _region_ _milieu_

gen byte rural = cond( rururb == 1, 1, 0 )
lab var rural "dummy for rural areas"

gen byte urban = 1 - rural
*gen urban = cond( rururb == 2, 1, 0)
lab var urban "dummy for urban areas"
recode literacy 2=1 3=2 
save, replace








/* ------------------------------- */
/* generate the dependent variable */
/* ------------------------------- */

gen     pl = povline 
lab var pl "Poverty line"

tab2 rururb pl, m
g double total_pc=pchhexp

sum hhexp total_pc

bysort rururb hid: gen double ln_wm_pl = ln( total_pc / pl )
lab var ln_wm_pl "ln(welfare measure)"

# delimit ;

tab strate rururb;
recast double hhsize;
gen double(weight)=wta*hhsize;
sum weight wta hhsize;

summ total_pc, detail;
centile total_pc, centile(20 40 60 80);
egen rank1 =rank(total_pc), unique;
xtile riche = rank1 [w=weight], nq(5);
g riche1=cond(riche==1, 1, 0);
g riche2=cond(riche==2, 1, 0);
g riche3=cond(riche==3, 1, 0);
g riche4=cond(riche==4, 1, 0);
g riche5=cond(riche==5, 1, 0);

tab strate rururb;
recast double hhsize;
sum weight wta hhsize;

rename poor poor_old;
gen poor=cond(total_pc<pl,1,0) if (total_pc~=.&pl~=.) ;
compare poor poor_old;
ren landsz lander  /*It seems there is a bug in stata7 concerning this name; I replace landsz by lander*/;
#delimit cr
ta geocode1, m
ta geocode1 rururb
ta geocode1, gen(geo)
save, replace



/* --------------------------------------------------------------------------- */
/* REGRESSIONS                                                                 */
/* --------------------------------------------------------------------------- */

recode empl 1=1 2=0
#delimit;

cap log close;
log using reg00_adult_work.log, replace;

bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_unem a_nilf a_ag a_com a_adm a_man
        empl_numb empl_contract empl_know empl_account 
        empl_bull empl_dcont empl_paid empl_paid empl_prime 
        empl_syndic empl_msyndic empl_training 
        labinc hourwrk permanent
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*;

bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_unem a_nilf a_ag a_com a_adm a_man
        empl_numb empl_contract empl_know empl_account 
        empl_bull empl_dcont empl_paid empl_paid empl_prime 
        empl_syndic empl_msyndic empl_training 
        labinc hourwrk permanent
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
 	if poor==1;

bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_unem a_nilf a_ag a_com a_adm a_man
        empl_numb empl_contract empl_know empl_account 
        empl_bull empl_dcont empl_paid empl_paid empl_prime 
        empl_syndic empl_msyndic empl_training 
        labinc hourwrk permanent
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
 if poor==0;




bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_unem a_nilf a_ag a_com a_adm a_man
        empl_numb empl_contract empl_know empl_account 
        empl_bull empl_dcont empl_paid empl_paid empl_prime 
        empl_syndic empl_msyndic empl_training 
        labinc hourwrk permanent
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*;

/*bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_unem a_nilf a_ag a_com a_adm a_man
        empl_numb empl_contract empl_know empl_account 
        empl_bull empl_dcont empl_paid empl_paid empl_prime 
        empl_syndic empl_msyndic empl_training 
        labinc hourwrk permanent
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*;
	if feel_poor==0

*/;


/* REGRESSIONS CORRECTING FOR AGE == 99 */;


su labinc, d;
replace labinc=r(mean) if labinc>800000;
su hourwrk;
replace hourwrk=r(mean) if hourwrk==99;


/* NATIONAL*/;
xi: reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] ;
outreg using reg.xls, ctitle(national) bdec(3) br 3aster replace;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
xi: bs  "reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100)*/ ;




/* URBAN */;
xi: reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] if rururb==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
xi: bs  "reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight] if rururb==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] ", reps(100) */;




/* RURAL */;
xi: reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] if rururb==2;
outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
xi: bs  "reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight] if rururb==2" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] 
_se[geo4] _se[geo5] ", reps(100) */;





**********************************************************************************************
PERCEPTION OF POVERTY vs. POVERTY -- DETERMINANTS
**********************************************************************************************;



*sum poor feel_poor;
tab poor [aw=weight];
*tab feel_poor_h [aw=weight];
sort urban;
by urban: tab poor;
*by urban: tab feel_poor_h;


*** NATIONAL ****;
xi: probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] ;
outreg using reg.xls, ctitle(national) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
xi: bs  "probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100) */;



*** URBAN ****;
xi: probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        riche2-riche5
	/*land lander landsz2 */
	mig_h
	lomwater  lomelec
	i.riche
	[aw=weight] if urban==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
xi: bs  "probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if urban==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100) */;




***** RURAL *******; 
xi: probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if rural==1;

outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob1;
sum prob1;
drop prob;
/*set seed 123456789;
xi: bs  "probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if rural==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] 
", reps(100)*/ ; /*No s_pvt available*/



* NATIONAL;
xi: dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight];
outreg using reg.xls, ctitle(national)  bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
xi: bs  "dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100)*/ ;



* URBAN;
xi: dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if urban==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
xi: bs  "dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if urban==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100) */;



* RURAL;
xi: dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if rural==1;
outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
xi: bs  "dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*a_fem a_nsp*/ a_agey_c a_agey2_c 
	a_prim a_sct a_lit
        a_hand
        a_anim a_musl
        a_krou a_manden a_mandes a_volta a_etr
	a_com a_adm a_man
        i.empl_numb i.empl_contract i.empl_know i.empl_account 
        i.empl_bull i.empl_dcont i.empl_paid i.empl_prime 
        i.empl_syndic i.empl_msyndic i.empl_training 
        labinc hourwrk 
        i.riche
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if rural==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100)*/;


#delimit cr
set more on
log close
exit