clear
set mem 100m
set matsize 300
set more 1
set seed 123456789
set rmsg on

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of consumption and poverty****
*******************************************************************

 


cd "C:\Documents and Settings\Bachir\Desktop\Bachir\World Bank\Wodon\CIV\Cote d'Ivoire Consumption\STATA"





cap log close
log using ind.log, replace

label define ouinon 1"Yes" 2"No"


use sect01, clear

count

g surveyr=2002
gen str3(country) = "CIV"


*Regions of birth


gen str20(geocode2)="Lagunes" 	        if s1q23c==2 | s1q23c==52 |  s1q23c==25 |  s1q23c==45 |  s1q23c==54 |  s1q23c==56              /*Abidjan, Alp, Dabou, Grand -Lahou, Jacqueville, Tiassal*/
replace geocode2="Sud Comoe"	        if s1q23c==3 | s1q23c==55 |  s1q23c==51                                                        /*Aboisso, Adiak, Grand-Bassam*/ 
replace geocode2="Agneby"	        if s1q23c==5 | s1q23c==4                                                                       /*Agboville, Adzop*/
replace geocode2="Haut-Sassandra"	if s1q23c==17| s1q23c==27 |  s1q23c==48                                                        /*Daloa, Issia, Vavoua*/
replace geocode2="Savanes"		if s1q23c==29| s1q23c==15 |  s1q23c==23 |  s1q23c==44                                          /*Korhogo, Boundiali, Ferkessedougou, Tengrela*/	
replace geocode2="Vallee du Bandama"	if s1q23c==13| s1q23c==8  |  s1q23c==16 |  s1q23c==28 |  s1q23c==36                            /*Bouak, Boumi, Dabakala, Katiola, Sakassou*/
replace geocode2="Moyen-Comoe"		if s1q23c==1 | s1q23c==6                                                                       /*Abengourou, Agnibilkro*/
replace geocode2="18 montagnes"		if s1q23c==31| s1q23c==7  |  s1q23c==9  |  s1q23c==18                                          /*Man, Bangolo, Biankouma, Danan*/
replace geocode2="Lacs"		        if s1q23c==49| s1q23c==57 |  s1q23c==47                                                        /*Yamoussoukro, Tiebissou, Toumodi*/
replace geocode2="Zanzan"		if s1q23c==14| s1q23c==10 |  s1q23c==43                                                        /*Bouna, Bondoukou, Tanda*/
replace geocode2="Bas-Sassandra"	if s1q23c==37| s1q23c==38 |  s1q23c==41 |  s1q23c==42                                          /* San-Pedro, Sassandra, Soubr, Tabou*/
replace geocode2="Worodougou"	        if s1q23c==32| s1q23c==39                                                                      /*Mankono, Sgula*/
replace geocode2="Denguele"		if s1q23c==34                                                                                  /*Odienn*/
replace geocode2="Sud Bandama"		if s1q23c==21| s1q23c==30                                                                      /*Divo, Lakota*/
replace geocode2="Fromager"	        if s1q23c==24| s1q23c==35                                                                      /*Gagnoa, Oum*/
replace geocode2="Nzi Comoe"	        if s1q23c==11| s1q23c==19 |  s1q23c==20 |  s1q23c==33 |  s1q23c==53                            /*Bongouanou, Daoukro, Dimbokro, M'bahiakro, Bocanda*/
replace geocode2="Marahoue"	        if s1q23c==12| s1q23c==40 |  s1q23c==50                                                        /*Bouafl, Sinfra, Zuenoula*/
replace geocode2="Cavaly"	        if s1q23c==26| s1q23c==22 |  s1q23c==58                                                        /*Guiglo, Dukou, Toulepleu*/
replace geocode2="Baffing"	        if s1q23c==46   /*Touba*/ 
replace geocode2="Non CIV"              if s1q23c==59 
replace geocode2="Other regions"        if s1q23c==.
ta s1q23c, m
ta geocode2
ta geocode2, m

g double geocode1=.
replace geocode1=1      if geocode2=="Lagunes" 	
replace geocode1=2      if geocode2=="Sud Comoe"	
replace geocode1=3	if geocode2=="Agneby"
replace geocode1=4	if geocode2=="Haut-Sassandra"
replace geocode1=5	if geocode2=="Savanes"	
replace geocode1=6      if geocode2=="Vallee du Bandama"	
replace geocode1=7	if geocode2=="Moyen-Comoe"
replace geocode1=8	if geocode2=="18 montagnes"
replace geocode1=9	if geocode2=="Lacs"
replace geocode1=10	if geocode2=="Zanzan"
replace geocode1=11	if geocode2=="Bas-Sassandra"
replace geocode1=12     if geocode2=="Worodougou"	
replace geocode1=13	if geocode2=="Denguele"
replace geocode1=14	if geocode2=="Sud Bandama"
replace geocode1=15     if geocode2=="Fromager"	
replace geocode1=16	if geocode2=="Nzi Comoe"
replace geocode1=17	if geocode2=="Marahoue"
replace geocode1=18	if geocode2=="Cavaly"
replace geocode1=19	if geocode2=="Baffing"
replace geocode1=20     if geocode2=="Non CIV"
replace geocode1=21     if geocode2=="Other regions" 
ta geocode1
ta geocode1, m

recode geocode1 18=11 19=13 15=14  21=20
/*Grouping Cavaly and Bas-Sassandra, Baffing and Denguele, Fromager and Sud Bandama, Non CIV and "Other region"*/
lab var geocode1 "Region of birth"

*Actual region of residence
sort grappe
cap drop grappen
encode grappe, gen(grappen)
su grappe grappen
cap drop region
g region=.
replace region=1 if (grappen<141)
replace region=2 if (grappen>=341 & grappen<=374)
replace region=3 if (grappen>=256 & grappen<=280)
replace region=4 if (grappen>=519 & grappen<=524)
replace region=5 if (grappen>=187 & grappen<=217)
replace region=6 if (grappen>=218 & grappen<=255)
replace region=7 if (grappen>=431 & grappen<=449)
replace region=8 if (grappen>=281 & grappen<=323)
replace region=9 if (grappen>=423 & grappen<=430)
replace region=10 if (grappen>=537 & grappen<=540)
replace region=11 if (grappen>=530 & grappen<=536)
replace region=12 if (grappen>=141 & grappen<=186)
replace region=13 if (grappen>=375 & grappen<=422)
replace region=14 if (grappen>=525 & grappen<=529)
replace region=15 if (grappen>=450 & grappen<=463)
replace region=16 if (grappen>=324 & grappen<=340)
replace region=17 if (grappen>=488 & grappen<=502)
replace region=18 if (grappen>=503 & grappen<=518)
replace region=19 if (grappen>=464 & grappen<=487)

#delimit;
lab def region 
1"LAGUNES" 
2"ZANZAN" 
3"MOYEN COMOE" 
4"AGNEBY" 
5"SAVANES" 
6"VALLEE DU BANDAMA"
7"N'ZI COMOE"
8"MONTAGNES"
9"DENGUELE"
10"BAFING"
11"MOYEN CAVALLY"
12"HAUT SASSANDRA"
13"BAS SASSANDRA"
14"FROMAGER"
15"MARAHOUE"
16"LACS"
17"WORODOUGOU"
18"SUD BANDAMA"
19"SUD COMOE"
;
#delimit cr
lab values region region 
lab var geocode1 "Actual region of residence"
ta region, m


/*Individual information*/


sort hid indid


*Ethic group
g ethnie=s1q8
recode ethnie 6/max=9
cap label drop ethnie
label define ethnie 1"Akan" 2"Krou" 3"Mande-Nord" 4"Mande-Sud" 5"Voltaique" 9"Etrangers" 
label values ethnie ethnie


*Religion
g religion=s1q9
recode religion 1/3=1 4=2 5/7=3
cap label drop religion 
label define religion 1"Chretien" 2"Musulman" 3"Animiste/Autres/Sans religion"
label values religion religion


/*gen member=cond(s1q10==1,1,0) if s1q10~=.
tab member, missing
egen hhsize2 = sum(member), by (hid)
sum hhsize
I don't have any information here
*/

g sex= s1q3 if s1q3~=.
tab sex, m


g relat= s1q4
ta relat, m
*replace relat=3 if ( s1q6a <10 & relat==1)
recode relat 1=1 2=2 3=3 4=4 5/8=5 10=5 9=4 11=6 12/13=7 
label def relat 1"Chief" 2"Spouse" 3"Children" 4"Grand-Parents" 5"Other relatives" 6"Maid" 7"Other non relatives"
lab values relat relat 
ta relat , m


g agey= s1q6a if s1q6a~=.
ta agey, m


label define marstat 1 "Married" 2 "Separated/Divorced" 3 "Widowed" 4 "Nver Married", add
g marstat= s1q7 if s1q7~=.
recode marstat 0=1 6=5 /*Replacing in the correct codes*/
recode marstat 1=1 2/3=2 4=3 5=4 /*Have to check if it recodes correctly*/
label value marstat marstat
ta marstat, m




/*Education*/

g literacy=s1q27 if (s1q6a >=5&s1q27~=.)
recode literacy 0=1 7=3 /*Replacing in the correct codes*/
recode literacy 1/2=1 3=2
lab def literacy 1"Read/Write" 2"No"
lab values literacy literacy 
ta literacy, m


g everattd=s1q30 if (s1q6a >=5&s1q30~=.)
recode everattd 3=2
ta everattd, m


g educlev=s1q31  if s1q6a >=5 & s1q31~=. /*I choose the last class attended , instead of the highest grade completed*/
ta educlev, m
recode educlev 0 =8
/*recode educlev  =2*/ *There is no code for the coranic level
recode educlev 1 2 3 4 5 6=3
recode educlev 6 =4 if s1q32==1 /* I am assuming that people with educlev=6 are complete primary*/
recode educlev 7 8 9 10 11 12 13 24 25 26 27 28 29 30 31 32 33 34 35 36 37 =5 /*I assume "secondaire" and "secondaire professionnelle" are the same*/
recode educlev 13 =6 if s1q32==4 | s1q32==11| s1q32==12| s1q32==13|s1q32==14 /* I am assuming that people with educlev=13 are complete secondary*/
recode educlev 14 15 16 17 18 19 20 21 22 23 38 39=7
/*recode educlev  =9
recode educlev  =99*/
recode educlev . =1 if everattd==2 /* people who have never attended to school have "no level of education"*/
recode educlev .=99 if agey<5
label define educlev 1 "No level" 2 "koranic" 3 "inc. primary" 4 "com. primary" 5 "inc. secundaty"/*
*/ 6 "com. secundary" 7 "tertiary" 8 "pre-school" 9 "not stated" 99 "undefined", add
label value educlev educlev

g atschool=s1q35  if s1q6a >=5 & s1q6a~=.
ta atschool, m


g schltyp=s1q38 if s1q38~=.
recode schltyp 1/2 =1 3/4=2 5/6=3

label define yesno 1 "Yes" 2 "No", add
label value literacy yesno
label value atschool yesno


/*Health*/

gen morbid=s1q11 if s1q11~=.
ta morbid, m

gen morb_tr=s1q12a if s1q12a~=.

tempvar timemorbid
g timemorbid=s1q12b
recode timemorbid 1=1 2=7 3=30 4=365

replace morb_tr=s1q12a*timemorbid 

gen rtreatm = cond(s1q13==1&s1q14==1,1,2) if morbid==1
tab rtreatm , m

* We will have information on health provider not only on people with morbid==1 bot also
* on other people (no sick or injured) who visited the doctor because of vaccinations, consultations, etc.
* without being necessarily sick

gen hprovide = s1q17 if s1q17~=.
recode hprovide 1=1 2/5=2 6=3 7=2 10=4 8/9=5 11=2 12=5 
tab hprovide, m

* Other health variables (Infant Mortality, etc.)

*Handicap status
sort hid
g handicap=1 if s1q10~=0    /* 1 is handicaped, 0 not*/
replace handicap=0 if s1q10==0
by hid: g nhandicap=sum(handicap) 
bysort hid: egen nbhandic=max(nhandicap)  /*Number of handicaped persons in the household*/




* The survey does not have information to construct ownprovd, child vaccination, or fplan 
* No information on child mortality too.

gen prenatal= cond(s1q20==1,1,0) 

/* Aucune information sur l'utilisation du temps*/

/* Migration*/

/*Temporary migration*/   

g yrs_here=s1q24a if s1q24a~=.
recode yrs_here 99=.
replace yrs_here=(s1q24a*12)+s1q24b   /*In months*/
replace yrs_here= yrs_here/12 /*In years*/
replace yrs_here =round(yrs_here, .1) /*In years*/


g t_mig=0
replace t_mig=1 if (yrs_here <2 & s1q25>1)   /*A visitor has left his own house so is a temporary migrant*/

/*Long term migration*/ *Not very detailed
g l_mig=0
replace l_mig=1 if (yrs_here >=2 & s1q25>1)   /*A visitor has left his own house so is a temporary migrant*/


#delimit;

label define dummy 1 "yes" 0 "No", add;

label define s1q26 1 "Travail" 2 "Sant" 3 "Ecole" 4 "Recherche d'emploi"
5 "Aide familiale" 6 "Prob. de logement" 7 "Visite" 8 "Mariage " 9 "Motif familial" 10"Autres", add;

#delimit cr

recode s1q26 0=1
label values s1q26 s1q26 
g mig=2
replace mig=1 if s1q25==3|s1q25==4
g why_mig=s1q26
label values why_mig s1q26 



count
*keep grappe menord menor grap hid indid /*hhsize*/ survey-yrs_here geocode2 geocode1 t_mig ethnie religion handicap nhandicap nbhandic
compress
save ind1, replace

clear


* -------------------------------------------------------
* LA POLYGAMIE: POLYGAMIE.SPS
* -------------------------------------------------------

do poly


* =======================================================================================================
* SECTION 2: L'EMPLOI
* =======================================================================================================

cap log close
log using empl.log, replace

clear all


use sect02, clear
count
sort hid indid
compress
save, replace

use ind2, clear

sort hid indid
merge hid indid using sect02
tab _merge
drop _merge
count





* Generate Employment Variables:



*1) Search (for the past 7 days)
* This question only reflects people searching today, but who have not worked for the past 12 months, 
* but want to work !
* Find those who are not in the labor force
gen lf=cond(s2q12==1|s2q12==3|s2q12==6,0,1)   
replace lf=0 if (agey<10 & agey>65) /*Taking a limit of age*/
replace lf=0 if s2q12==5 
replace lf=0 if s2q12==13 | agey>65
replace lf=0 if s2q12==10 & agey<10
replace lf=0 if s2q12==14 & agey<10
lab var lf "Labor force"
ta lf, m
recode s2q11 8=2 if lf==1
recode s2q8 0=2
gen search=cond(lf==1& s2q5==2 & s2q8==2 & s2q11==1, 1, 0) 
/* At this point, I have a problem: the question refers to a search of 
job during the last 4 WEEKS not the last 7 days*/ 
*Search refers to persons in labor force, who have not work last 7 days and has no job and who seek a job
replace search=0 if s2q5==2 & s2q8==2 & s2q11==2 & (lf==1) & lf~=. 
tab search, m
* 1 means "search during the past week!"


/*

*2) Employment /*The empl variable here differs from the one of the reference manual: here it is if they are employed or not, not the employment sector*/
gen empl=cond(lf==1 & search==0, 1, 0) if (lf==1) & lf~=. 
tab empl, m


*/



g unempl=cond(s2q5==2 & s2q8==2 & s2q11==1, 1, 0) 

g empl=cond(s2q5==1 | s2q8==1|s2q12==4, 1, 0) 
ta empl, m
ta unempl, m
replace unempl=0 if unempl==.& lf==1
g nilf=cond(empl==0&unempl==0, 1, 0)
ta nilf, m




*Duration of employment
tempvar empldur
g empldur=s2q18b if s2q18b~=.
recode empldur 6=2
recode empldur 1=1 2=12
g empl_dur=s2q18a*empldur  /*Spell duration of employment in months*/
replace empl_dur=round(empl_dur/12, .1)   /*Years*/
ta empl_dur, m
g empl_dur2=empl_dur^2
ta empl_dur2, m

*Duration of unemployment
tempvar unempldur
g unempldur=s2dq1b if s2dq1b~=.
recode unempldur 4=3
recode unempldur 1=1 2=4 3=52
g unempl_dur=s2dq1a*empldur  /*Spell duration of unemployment in weeks*/
replace unempl_dur=round(unempl_dur/12, .1)
ta unempl_dur , m
g unempl_dur2=unempl_dur^2
ta unempl_dur2, m

*Number of employment activities
g empl_numb = s2q2 if s2q2~=.
recode empl_numb 0=0 1=1 2=2 3/9=3
label define empl_numb 1"One job" 2"2 jobs" 3"3 jobs or more"
label values empl_numb empl_numb 
ta empl_numb , m




*3) Hours of work
* Must be hours spent in main and secundary occupations (during a week) according to standarized file's def.
* Information to construct this variable comes from question asked to everybody "utlilisation de temps". 
* We will use the average hours that the person spent during the past 7 days in his/her main occupation
* (hours normally spent are not available).  
* Also note, that hours worked a week should be computed by multiplying the usual number of days a that 
* a person spends in main ocuppation during a week times the number of hours a person spends
* in the mian occupation a day 
* Also, I'll give a value of 99 to poeple who report having worked more than 80 hours a week
* Hours of work for people with just one occupation
gen hourwrk = (s2q17) if empl~=.&lf~=.  
/*I prefer to use s2q17 instead of s2q6a because s2q6a is ambiguous: the asked him how many hours
he had worked last week, and units in weeks. The hours of work of s2q17 are labelled in hours , not in days*/
* Hours of work for people with 2+ occupations:
* The survey doesn't ask how many days individuals work in other (paid) occupation. Only ask how many hours per day.
* We will assume that the days an individual works in other occupations are the same they work in their primary 
* occupation.
recode s2cq8 .=0
replace hourwrk=(s2q17)+(s2cq8) if (empl~=.&s2cq1==1)&lf~=.
recode hourwrk 0=.
replace hourwrk=70 if (hourwrk>=70&hourwrk~=.)
sum hourwrk
sum hourwrk, d


* 4) Labinc "Monthly Labor Income"
* Not complatible with standarized files (LABINC should be Yearly Labor Income)
* wage and then divide by the hours normally worked on a week in order to get the wage rate!
* Workers with one job
* Monthly monetary wage 
gen double(labinc)=0 if empl~=.&lf~=.
g double tempinc=s2q26b
ta s2q26a if s2q26b==.
sort hid
by hid: egen hidmeaninc =mean(s2q26a)    /*Mean Income of the HH*/
recode tempinc 1=52 2=12 3=4 4=2 5=1
replace labinc = s2q26a*tempinc if labinc~=.
replace labinc = 0 if labinc==.
replace labinc = hidmeaninc  if s2q26b==.
sum labinc
sum labinc, d


* Status: temporary and Permanent (only asked to workers if 0<s2q16<=13 ) /*I have some doubt in the codification since I don't know if "metayer, 
aide familial, manoeuvre agricole, apprenti, autres" can be included in independant workers. I consider the actual status
s2q16b not the status at entry s2q16a*/
gen permanent = s2q24
recode permanent 1/2=2 3=1 /* "Saisonier" is not permanent */
tab permanent, m

*Type of contract
g empl_contract =s2q22 if s2q22~=.
recode empl_contract 1/2=1 3/4=2
label define empl_contract 1"Written contract" 2"No written contract"
label values empl_contract empl_contract 
ta empl_contract , m

*Duration of contract
g empl_dcont =s2q23 if s2q23~=.
recode empl_dcont 4=1 1/2=1 3=2 
label define empl_dcont 1"Short term contract" 2"Long term contract"
label values empl_dcont empl_dcont 
ta empl_dcont , m


*Knowledge of employment availability
g empl_know =s2q19 if s2q19~=.
recode empl_know 1=1 2=2 3/6=3
label define empl_know  1"Relations"  2"Employer" 3"Other"
label values empl_know empl_know 
ta empl_know , m


*Accounting
g empl_account =s2q20 if s2q20~=.
recode empl_account 3=2
label values empl_account ouinon
ta empl_account , m

*Bulletin de paie
g empl_bull =s2q21 if s2q21~=.
label values empl_bull ouinon


*Remuneration
recode s2q25 0=1
g empl_paid =cond(s2q25==1|s2q25==2|s2q25==3|s2q25==4|s2q25==5|s2q25==6|s2q25==8, 1, 0)  if s2q25~=.
g empl_unpaid =cond(s2q25==7, 1, 0)  if s2q25~=.
ta empl_paid , m
ta empl_unpaid , m


*Syndicat
g empl_syndic = s2q27 if s2q27~=.
label values empl_syndic ouinon
ta empl_syndic , m

*Syndic member
g empl_msyndic =s2q28 ==1 if s2q28~=.
replace empl_msyndic =0 if s2q27==2 | s2q28==2
ta empl_msyndic , m

#delimit;
*Primes and subventions;
g empl_prime = cond(s2q29a==1| s2q29b==1| s2q29c==1| s2q29d==1| 
s2q29e==1| s2q29f==1| s2q30a==1|s2q30b==1|s2q30c==1|s2q30d==1|
s2q30e==1|s2q30f==1|s2q30g==1|s2q30h==1, 1, 0) if (s2q29a-s2q29f~=.) 
& (s2q30a-s2q30h~=.);
#delimit cr
label values empl_prime ouinon
ta empl_prime , m

*Formation & training
g empl_training = cond(s2q31==1, 1, 0) if s2q31~=.
label values empl_training  ouinon
ta empl_training , m

*5) Occupation
recode s2q12 0=1
gen occupat=9 if lf~=.
/*employed*/ replace occupat=1 if empl~=. | s2q12==4 & s2q16b==19&(labinc>0|hourwrk>7|hourwrk~=.)
/*unemployed*/ replace occupat=2 if (search==1|s2q12==7|s2q12==8|s2q12==9|s2q12==11|s2q12==12|s2q12==14|s2q12==15)
* unemployed : somebody who is searching for a job or is not searching but wants to work
/*homemaker*/ replace occupat=3 if s2q16b==19&(labinc==0|hourwrk<=7|hourwrk==.)
* I am assuming that homemakers are those who declare to be "aide familial", who don't report a salary or
* who work less than 7 hours a week ! (not compatible with standarizes files...). If "aide familial" earns salary
* and works more than 7 hous a week, is considered employed 
/*Retired*/ replace occupat=4 if lf==0&s2q12==5
/*Student*/ replace occupat=5 if lf==0&s2q12==6
/*Dependent */ replace occupat=6 if lf==0&s2q12==1|s2q12==2|s2q12==3|s2q12==10|s2q12==13
* Dependents: invalids, children, house wifes, grandparents, etc..
tab occupat, m
tab labinc if occupat==1
sort occupat
by occupat: sum labinc


*6) Statocc (main occupation - only if OCCUPAT==1 - not perfectly compatible with the standarized files)
tempvar occ
g occ=s2q14 if s2q14~=.
recode occ 1/34=1 35/44=2 45/58=1 59/108=2 109/157=1 158/180=4 181/182=2 183/205=1 206=4 207/411=1 412/507=4 508/517=1 518/536=4 537/541=1 999=9 998=.
/*Actually, I cannot separate the wage employees of the government and private sector, ibid with the self-employed and the 
employed by informal sector: so codes 3/5 and 6(volunteer) are omitted*/
gen statocc=occ if empl~=.
*drop occ
recode statocc 0=9 545/max=9
ta statocc, m
* Is there a way to distinguish employers from independent workers ?
tab statocc, m
* Generate income for independent workers
sum labinc if statocc==4
label define empl 1 "agric." 2 "non-agric.", add
label define occupat 1 "employed" 2 "unemployed" 3 "homemaker" 4 "retires" 5 "student"/*
*/ 6 "dependent" 9 "other", add
label define statocc 1 "wage employee, gov." 2 "wage employee, priv." 3 "informal"/*
*/ 4 "self-employed" 5 "employer" 6 "volunteer" 9 "other",add
label values search yesno
*label values empl empl
label values occupat occupat
label values statocc statocc


*7) INDUSTRY (main occupation) - Only for employed individuals (OCCUPAT==1)
/*rename activite activite1*/
gen activite=s2q14 if occupat==1 & s2q14~=.
ta activite
recode activite 1/34=9 35/119=8 120/124=7 125/182=8 183/188=9 189/206=8 207/225=4 226/237=7 238/300=8 301/307=4 308/317=7 318/336=8 337/396=9 397/439=6 440/457=1 458/507=2 508/517=10 518/536=10 537/997=11 998=. 999=. 
ta activite
ta activite, m
* other
gen industry=11 if (occupat==1&activite==11 & s2q14~=.)
* Agriculture
replace industry=1 if activite==1
* Manufacture
replace industry=2 if activite==2
* Mining and quarrying
*replace industry=3 if activite==3
* Contruction 
replace industry=4 if activite==4
* Utilities (water, gas, and electricity)
*replace industry=5 if activite==5
* Commerce, Hotels, and Restaurants
replace industry=6 if activite==6
* Banking, Finantial Services
replace industry=7 if activite==7
* Professional, (social work, international organizations, etc.) 
replace industry=8 if activite ==8
* Public Administration
replace industry=9 if activite ==9
* Transport
replace industry=10 if activite==10
tab activite if occupat==1
tab industry if occupat==1
ta industry if occupat==1, m
recode industry 1=1 2/4=2 5/6=3 7/9=4 10=2 11=2
replace industry=9 if industry ==. & (agey>=10 & agey<=65)
label define industry 1"Agriculture" 2"Manufacturing/Mining and quarrying/construction/transport/other" 3"Utilities/commerce" 4"Banking/financial services/Professional/Public administration" 9"Other Activities/None"
label values industry industry
ta industry
ta industry, m




gen hhstruc=3 if  ( relat == 1 & marstat  == 1 & sex == 1 ) 
replace hhstruc=1 if  ( relat == 1 & marstat   == 2 & sex == 1 & nspouse==1) 
replace hhstruc=2 if  ( relat == 1 & marstat   == 3 & sex == 1 & nspouse>1) 
replace hhstruc=3 if  ( relat == 1 & marstat  == 4 & sex == 1 ) 
replace hhstruc=3 if  ( relat == 1 & marstat  == 5 & sex == 1 ) 
replace hhstruc=5 if  ( relat == 1 & marstat  == 1 & sex == 2 ) 
replace hhstruc=5 if  ( relat == 1 & marstat  == 5 & sex == 2 ) 
replace hhstruc=5 if  ( relat == 1 & marstat  == 4 & sex == 2 ) 
replace hhstruc=4 if  ( relat == 1 & marstat  == 2 & sex == 2 ) 




*cap drop _expand
*dups hid indid, drop


#delimit;

*keep  grappe menord menor grap hid nspouse menord grappe indid surveyr country sex relat agey marstat literacy 
everattd educlev atschool schltyp morbid morb_tr timemorbid rtreatm hprovide prenatal 
mig why_mig t_mig yrs_here lf search empl unempl nilf empldur empl_dur empl_dur2 unempldur unempl_dur unempl_dur2 
empl_numb empl_contract empl_know empl_account empl_bull empl_dcont empl_paid empl_unpaid empl_prime 
empl_syndic empl_msyndic empl_training 
hourwrk labinc tempinc permanent occupat statocc activite industry hhstruc
geocode2 geocode1 ethnie religion handicap nhandicap nbhandic;
#delimit cr

count
compress
sort hid 
save ind3.dta, replace





* ===========================================================================================
* LAND
* ===========================================================================================

use sect03b1, clear

cap log close
log using land.log, replace

count


gen ownland=s3b1q14a
*recode ownland 2=0
tab ownland, m
lab var ownland "land owned"
* Total land in Ha..
gen landsize=s3b1q15a+s3b1q15b
sum ownland landsize

*No question on irrigation

count
sort hid 

merge hid using ind3

tab _merge
drop _merge
cap drop _expand

*keep  grappe menord menor grap hid grap- hhstruc

sort hid 

*cap drop _expand
*dups hid indid ,drop

count

*cap drop _expand
*dups hid indid, drop
compress
save ind4.dta, replace




* ===========================================================================================
* HOUSING AND INFRASTRUCTURE
* ===========================================================================================



use sect07, clear
cap log close
log using housing.log, replace

count 

g timeocc=s7q1b
recode timeocc 1=1 2=30 3=365
g occup_tr=s7q1a*timeocc
ta occup_tr
drop timeocc
label var occup_tr "Time of occupation of the house in days"
g ownhouse=s7q2 if s7q2~=.
recode ownhouse 1=1 2/7=2
lab var ownhouse "Ownership of the house"
g cost_occ=s7q3 /*Rent charges*/
ren cost_occ rent
g type_house=s7q4  if s7q4~=.
recode type_house 1/5=1 6/8=2  /*Solid and fragile*/
g walls=s7q5  if s7q5~=.
recode walls 1=1 2=3 3=4 4=3 5=5 6=9 
label define walls 1"Earth" 2"Bricks" 3"Wood" 4"Iron sheets" 5"Cement" 9"Other"
label values walls walls
g rooms=s7q8 if s7q8~=.
g floor=s7q7 if s7q7~=.
recode floor 1=5 2=2 3=1 4=3 5=9
label values floor walls
g roof=s7q6 if s7q6~=.
recode roof 1=3 2=1 3=3 4=4 5=5 6=9
label define roof 1"Earth" 2"Thatch" 3"Wood" 4"Iron sheets" 5"Cement" 6"Tiles/bricks" 9"Other"
label values roof roof 
*Main source of water
g water=s7q12 if s7q12~=.
recode water 1/2=1 4=2 3=9 5=3 6=4 7=9
label define water 1"Pipe(own tap)" 2"Pipe born" 3"Wells (protected)" 4"Surface water" 5"Rain water" 9"Other"
lab values water water
ren water water_old
g water=cond(water_old==1| water_old==2, 1, 0)

*Generating leave-out for water
gen n=1
egen ntot = sum(n), by(grap) 
egen swater=sum(water), by(grap) 
g lomwater=(swater-water)/(ntot-1)
drop grap n ntot


* Access to water
gen water_d=cond(s7q12==1|s7q12==2,1,0) if s7q12~=. /*Safe Water in the dwelling*/
gen water_pay=cond(s7q13a==0,0,1) if water_d==1
* Cost of water (per month)
g timwat=s7q13b if s7q13b~=.
recode timwat 1=90 2=45 3=30 4=12 5=32 6=1
gen water_cost= s7q13a*timwat     /*Water cost every 3 months*/
drop timwat 

* Access to electricity
gen elect_d=cond(s7q15~=1|s7q15~=5,1,0) if s7q15~=. /*Electricity in the dwelling*/
ren  elect_d elect

*Generating leave-out for electricity
gen n=1
egen ntot = sum(n) , by(grap)
egen selec=sum(elec), by(grap)
g lomelec=(selec-elec)/(ntot-1)



* Cost of electricity (per very two months)
g timwat=s7q16b if s7q16b~=.
recode timwat 1=8 2=2 3=1
gen elect_cost= s7q16a*timwat /*Electricity cost every 2 months*/
drop timwat 
*Fuel for cooking
g fuel=s7q17 if s7q17~=.
recode fuel 1=3 2=1 3=3 4=1 5=5 6=3 7=4 8=3 9=2 10=3 11=. 12=9
label define fuel 1"Firewood" 2"Kerosene" 3"Charcoal" 4"Electricity" 5"Gas"  9"Other"
label values fuel fuel
g timwat=s7q18b if s7q18b~=.
recode timwat 1=60 2=8 3=2 4=1.33 5=1
gen fuel_cost= s7q18a*timwat /*Fuel cost every 2 months*/
drop timwat
* Trash Collections
gen sanity_d=cond(s7q20==1,1,0) if s7q20~=.
*Used water
gen used_water=s7q19 if s7q19~=.
gen sanity_used_water=cond(used_water==1|used_water==2, 1, 0) /*Good evacuation of used water*/
* Toillete avec chasse d'eau d'eau;
gen toilette_d=cond(s7q21==1,1,0) if s7q21~=.
g toilet=s7q21 if s7q21~=.
* Tepephone in the dwelling;
gen telephone_d=cond(s7q21==1,1,0) if s7q21~=.
gen phone=telephone_d
*Generating leave-out for telephone
egen stelephone_d=sum(telephone_d), by(grap)
g lomtelephone =(stelephone_d-telephone_d)/(ntot-1)
drop grap n ntot


*Distance to water in mts not provided

*INFRASTRUCTURE IN THE NEIGHBORHOOD not provided: we will thus use leave-out means

sort hid
merge hid using ind4
tab _merge
drop _merge

*keep  grappe menord menor-hhstruc

count
*cap drop _expand
*dups hid indid, drop
compress
sort hid indid

save ind5, replace





use pauvre, replace
count
compress
sort hid
save, replace

use ind5, replace

sort hid 
merge hid using pauvre
tab _merge
drop _merge

replace pauv=0 if pauv==.
count

ren pauv poor

label define dummy 1 "yes" 0 "No", add
label values poor dummy

*cap drop _expand
*dups hid indid, drop
compress
save ind6, replace
count

log close




#delimit;



clear;
capture log close;
log using adhhvar.log, replace;
use ind6, clear;

/* ------------------- */
/* Household variables */
/* ------------------- */;

* household size;
sort hid indid;

lab var hhsize "size of household";

by hid indid: gen dep    = cond( occupat==6, 1, 0 ) if occupat~=.;
by hid indid: gen ind    = cond( occupat~=6, 1, 0 ) if occupat~=.;

tab dep;
tab ind;
by hid:       egen deph  = sum(dep);
by hid:       egen indh  = sum(ind);
by hid:       gen double agedep = deph / indh;

lab var agedep "Dependency ratio";

sum agedep deph indh;
/* there are 126 hhds with dep>0 and ind==0, of that's the case, replace agedp with a zero*/;

replace agedep=0 if agedep==.;

sum agedep deph indh;

by hid:       gen double agedp2 = (agedep^2);
lab var agedp2 "Square of age dependency ratio";

* structure variables;
gen byte baby   = cond( agey <= 5,              1, 0 );
gen byte kid    = cond( agey >  5 & agey <= 14, 1, 0 );
gen byte adult  = cond( agey > 14 & agey <= 64, 1, 0 );
gen byte senior = cond( agey > 64 & agey <  99, 1, 0 );
gen byte ad_dep = cond( adult == 1 & ( occupat == 2 | occupat == 5 | occupat == 6 ), 1, 0 );
sort hid;

by hid: egen int num_bab  = sum(baby);
lab var num_bab "Number of under-5s in household";
drop baby;

by hid: gen int num_bab2 = num_bab^2;
lab var num_bab2 "Square of number of under-5s in household";

by hid: egen int num_kid = sum(kid);
lab var num_kid "Number of 5-14s in household";
drop kid;

by hid: gen int num_kid2 = ((num_kid)^2);
lab var num_kid2 "Square of number of 5-14s in household";

by hid: egen int num_ads = sum(adult);
lab var num_ads "Number of adults in household";
drop adult;

by hid: gen int num_ads2 = ((num_ads)^2);
lab var num_ads2 "Square of number of adults in household";

bysort hid: egen int num_adp = sum(ad_dep);
lab var num_adp "Number of non-working adults in household";

bysort hid: gen int num_adp2 = num_adp^2;
lab var num_adp2 "Square of number of non-working adults in household";
drop ad_dep;

bysort hid: egen int num_srs = sum(senior);
lab var num_srs "Number of 65+ in household";

bysort hid: gen double num_srs2 = (num_srs)^2;
lab var num_srs2 "Square of number of 65+ in household";
compress;
save, replace;





/* --------------------------- */
/* Head of household variables */
/* --------------------------- */;

cap log close;
log using head.log, replace;

use ind6, clear;

count if relat == 1;

preserve;
keep if relat == 1;

*cap drop _expand
*dups hid indid, drop
sort hid;

* gender of head of household: male;
by hid: gen h_mal = cond( sex == 1, 1, 0 ) ;
lab var h_mal "Male-headed household";

* gender of head of household: female and divorced/seperated, or never married;
by hid: gen h_fem = cond( sex == 2, 1, 0 ) ;
lab var h_fem "Female-headed household";

* female-headed households that are non-polygamous;
by hid: gen h_npf = cond( sex == 2 & ( marstat ~= 3 ), 1, 0 ) if ( marstat ~= . );
lab var h_npf "Female head not polygamous";

* polygamous hh, female-headed;
by hid: gen h_pf = cond( sex == 2 & marstat == 3, 1, 0 ) if ( marstat ~= . );
lab var h_pf "female-headed polygamous household";

* assumes that separated => no income from absent spouse;
by hid: gen h_nsp = cond( marstat == 1 | marstat == 4 | marstat == 5, 1, 0 ) if ( marstat ~= . );
lab var h_nsp "Head of household is single";

* Note: agey not allowed to be missing;
by hid: gen h_agey = agey ;
lab var h_agey "Age of head";

by hid: gen h_agey_c = cond( h_agey < 99, h_agey, . ) ;
lab var h_agey_c "Age of Head, no 99 allowed";

by hid: gen int h_agey2 = ((h_agey)^2) ;
lab var h_agey2 "Square of age of household Head";




by hid: gen int h_agey2_c = ((h_agey_c)^2);
lab var h_agey2_c "Square of no-99 age of household head";



************************************ Health status of the head*****************************************************;
sort hid;
by hid: g int h_hand=1 if handicap==1;
replace h_hand=0 if h_hand==.;

************************************ Religion of the head**********************************************************;
sort hid;
by hid: g int h_christ=1 if religion==1; /*Head Christian*/;
replace h_christ=0 if h_christ==.;
by hid: g int h_musl=1 if religion==2; /*Head Muslem*/;
replace h_musl=0 if h_musl==.;
by hid: g int h_anim=1 if religion==3; /*Head Animist*/;
replace h_anim=0 if h_anim==.;

************************************ Ethnicity of the head**********************************************************;
sort hid;
by hid: g int h_akan=1    if ethnie==1; /*Head akan*/;
replace h_akan=0 if h_akan==.;
by hid: g int h_krou=1    if ethnie==2; /*Head Krou*/;
replace h_krou=0 if h_krou==.;
by hid: g int h_manden=1  if ethnie==3; /*Head Mande North*/;
replace h_manden=0 if h_manden==.;
by hid: g int h_mandes=1  if ethnie==4; /*Head mande South*/;
replace h_mandes=0 if h_mandes==.;
by hid: g int h_mande=cond(h_manden==1|h_mandes==1, 1, 0)   /*Mande*/ ;
by hid: g int h_volta=1   if ethnie==5; /*Head voltaic*/;
replace h_volta=0 if h_volta==.;
by hid: g int h_etr=1     if ethnie==9; /*Head Stranger*/;
replace h_etr=0 if h_etr==.;


************************************ employment variables**********************************************************;

/*by hid: gen h_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . );
lab var h_ilf "Head of household in labor force"*/;

by hid: gen h_nilf = cond( nilf==1, 1, 0 );
lab var h_nilf "Head of household not in labor force";

by hid: gen int h_hrs = hourwrk if ( empl == 1 );
lab var h_hrs "Head's hours worked per week";

* could be amended to be those who are employed ;





by hid: gen h_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )  ;
 /*Here I take empl instead of occupat to take into account, those who have a job but have not worked last 7 days*/;
lab var h_em "Head of household is employed";

* could be amended to be those who are unemployed (search==1 and/or want to work) /*But I choose to drop the search condition*/;
by hid: gen h_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . );
lab var h_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;



/*
by hid: gen h_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_pub "Head is public sector wage employee";
by hid: gen h_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );

lab var h_pvt "Head is private sector wage employee";
*by hid: gen h_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
*lab var h_emp "Head is an employer";
by hid: gen h_inf = cond(occupat==1 & statocc==3,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_inf "Head works in informal sector";
by hid: gen h_self = cond(occupat==1 & statocc==4,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_self "Head is self employed";
tab h_self;
by hid: gen h_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var h_ag "Head is engaged in an agricultural activity";
tab h_ag;
*/




sort hid;

by hid: g h_ag=cond(industry==1| s2q16b==17|s2q16b==18|s2q16b==20, 1, 0) if ( empl == 1) ;
lab var h_ag "Head is engaged in an agricultural activity";
tab h_ag, m;
recode h_ag .=0;

by hid: g h_man=cond(industry==2| s2q16b==11|s2q16b==12|s2q16b==13, 1, 0) if ( empl == 1) ;
lab var h_man "Head is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab h_man, m;
recode h_man .=0;

by hid: g h_com=cond(industry==3|(s2q16b==14| s2q16b==15| s2q16b==16), 1, 0) if ( empl == 1 ) ;
lab var h_com "Head is engaged in Utilities/commerce activities";
tab h_com, m;
recode h_com .=0;

by hid: g h_adm=cond(industry==4 | (s2q16b>=1 & s2q16b<=10), 1, 0) if ( empl == 1 ) ;
lab var h_adm "Head is engaged in Banking/financial services/Professional/Public administration activities";
tab h_adm, m;
recode h_adm .=0;

by hid: g h_other=cond(industry>4| (s2q16b==19|s2q16b==21), 1, 0) if ( empl == 1 ) ;
lab var h_other "Head is engaged in Other activities";
tab h_other, m;
recode h_other .=0;






* first test variable: head should have one employment category or be unemployed;
*egen heademp = rsum(h_unem h_ag h_mfg h_mine h_cnst h_util h_comm h_bank h_prof h_pbad h_tspt h_othr) if (relat == 1);

*egen heademp = rsum(h_unem h_pub h_pvt h_inf h_self) if (relat == 1);

egen heademp = rsum(h_unem h_ag h_com h_adm h_man) if (relat == 1);


ta heademp, m;

* must deal with known problems from definition of unemployed;

replace h_unem  = 0 if   heademp == 2;
replace heademp = 1 if   heademp == 2;
assert heademp <= 1 if ( heademp ~= . );
drop heademp;

*by hid: gen h_job = cond( h_ag == 1   | h_mfg == 1  | h_mine == 1 | h_cnst == 1 | h_util == 1 | 
                          h_comm == 1 | h_bank == 1 | h_prof == 1 | h_pbad == 1 | h_tspt == 1 | 
                          h_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );


/*by hid: gen h_job =  cond( h_pub == 1   | h_pvt == 1  | h_inf == 1 | h_self == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .)*/;

by hid: gen h_job =  cond( h_ag == 1   | h_com == 1  | h_man == 1 | h_adm == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .);
lab var h_job "Head has a job";


* check that the head has a job, is unemployed, or is not in the labor force;
tempvar hjob_test;
* must deal with known problems from definition of unemployment;
replace h_unem = 0 if h_job  == 1;
replace h_nilf = 0 if h_unem == 1;
replace h_nilf = 0 if h_job  == 1;

gen int hjob_test = h_job + h_unem + h_nilf ;
assert hjob_test <= 1 if ( hjob_test ~= . );
tab hjob_test;

by hid: gen h_nojb = cond( h_unem == 1 | h_nilf == 1, 1, 0 ) if ( occupat ~= .);
lab var h_nojb "Head unemployed or NILF";






********************************************education variables**********************************************;

by hid: gen h_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ne "Head has no education";

by hid: gen h_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ke "Head has koranic education";

by hid: gen h_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pnc "Head incomplete primary";

by hid: gen h_pc  = cond( educlev == 4, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pc "Head completed primary";

by hid: gen h_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_snc "Head incomplete secondary";

by hid: gen h_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_sc "Head completed secondary";

by hid: gen h_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ts "Head has tertiary";

by hid: gen h_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ps "Head preschool only";

by hid: gen h_ue  = cond( educlev == 9 | educlev == 99 | educlev == ., 1, 0 );
lab var h_ue "Head unstated/unknown education";

by hid: gen h_sct = cond(educlev == 5|educlev==6 | educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_sct "Head has at least imcomplete, completed secondary or tertiary education";

/*by hid: gen h_st  = cond(educlev>=5 & educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_st "Head has at least some secondary education"*/;

by hid: gen h_prim = cond(educlev==3|educlev==4|educlev==8,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_prim "Head has at least some prescholl or primary education";

by hid: gen h_noeduc=cond(educlev==1, 1, 0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_noeduc "Head has no education or has preschool";



tempvar test_h_ed1;
egen test_h_ed1 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps );
lab var test_h_ed1 "Test that head has some level of education if educlev ~= .";
assert test_h_ed1 == 1 if ( educlev < 9 & educlev ~= . );

tempvar test_h_ed3;
egen test_h_ed3 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps h_ue );
lab var test_h_ed1 "Test that head has education information or missing";
assert test_h_ed3 <= 1;

tempvar test_h_ed2;
egen test_h_ed2 = rsum( h_sct h_sct h_prim );
lab var test_h_ed2 "Test of head's educlev for lumping education";
assert test_h_ed2 <= 2 if ( test_h_ed2 ~= . );

by hid: gen h_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var h_lit "Head is literate";

by hid: gen h_occup= occupat;
*by hid: gen h_industry= industry;
by hid: gen h_statoc= statoc;

********************************************Migration variables**********************************************;
by hid: g t_mig_h=cond(t_mig==1, 1, 0) if t_mig~=.;
lab var t_mig_h "Head is a Long Term Migrant";
by hid: gen l_mig_h = cond(l_mig == 1, 1, 0) if l_mig~=.;
lab var l_mig_h "Head is a Long Term Migrant";

sort hid;

******************************************* Land Variables **************************************************;
bysort hid: gen byte land = cond(ownland == 1, 1, 0 ) if ( ownland ~= . );
lab var land "Head owns land";

replace landsize = 0 if ownland == 2;
rename landsize landsz ;
*recast double landsz;
lab var landsz " land (ha) owned by household";  

by hid: gen float landsz2 = (landsz^2);
lab var landsz2 "Square of land (ha) owned by household";

* if no observations, regression won't run;
qui sum landsz;
if ( `r(N)' == 0 ) {;
	replace landsz  = 0;
	replace landsz2 = 0;
	};

count;

sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;
compress;
sort hid;

save head, replace;

/****************************************** Remmitances Variables *******************************************;

*label define yesno 1 "Yes" 2 "No", add;

label value s9bq06 s9bq06;
label value s9bq01 yesno;

rename s9bq01 get_remit;
rename s9bq06 source_remit  ;

tab get_remit;
tab get_remit poor, row col;
tab source_remit;
tab source_remit poor, row col;

gen remit_value=s9bq09+s9bq10+s9bq11;
* If one is missing, all are missings. If one is non-missing, all are non-missing!;

gen missing_rem=cond(remit_value==.,1,0);
tab missing_rem*/;












/* ---------------- */
/* Spouse variables */
/* ---------------- */;

restore;

count;

cap log close;
log using spouse.log, replace;
gen sp=1 if relat==2;
recode sp .=0;
egen nbsp=sum(sp), by(hid);
tab nbsp;
preserve;
keep if relat==1;
tab nbsp;
restore;
drop nbsp;

bysort hid: egen smaxage = max(agey) if relat == 2;
keep if relat==2 & agey == smaxage;

count;

sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;
*============
* Controlling for the possibility of 2 spouses with same age and education,
* then keep the one with the lowest indid
* ===========;

gen realed=educlev;
*recode realed 1=0 8=1 9=. 99=.;
bysort hid: egen smaxeduc = max(realed) if realed~=.;
keep if (realed == smaxeduc) | realed==.;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

bysort hid: egen sminindi = min(indid);
keep if indid == sminindi;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

count;

* note: agey cannot be missing;
by hid: gen s_agey = agey;
lab var s_agey "Age of spouse";

by hid: gen s_agey_c = cond( agey < 99, agey, . );
lab var s_agey_c "Spouse's age corrected for 99";

by hid: gen int s_agey2 = ((s_agey)^2);
lab var s_agey2 "Square of age of Spouse";

by hid: gen int s_agey2_c = ((s_agey_c)^2);
lab var s_agey2_c "Square of age of spouse corrected for 99";

************************************ Health status of the spouse*****************************************************;
sort hid;
by hid: g int s_hand=1 if handicap==1;
replace s_hand=0 if s_hand==.;

************************************ Religion of the head**********************************************************;
sort hid;
by hid: g int s_christ=1 if religion==1; /*Spouse Christian*/;
replace s_christ=0 if s_christ==.;
by hid: g int s_musl=1 if religion==2; /*Spouse Muslem*/;
replace s_musl=0 if s_musl==.;
by hid: g int s_anim=1 if religion==3; /*Spouse Animist*/;
replace s_anim=0 if s_anim==.;

************************************ Ethnicity of the head**********************************************************;
sort hid;
by hid: g int s_akan=1    if ethnie==1; /*Spouse akan*/;
replace s_akan=0 if s_akan==.;
by hid: g int s_krou=1    if ethnie==2; /*Spouse Krou*/;
replace s_krou=0 if s_krou==.;
by hid: g int s_manden=1  if ethnie==3; /*Spouse Mande North*/;
replace s_manden=0 if s_manden==.;
by hid: g int s_mandes=1  if ethnie==4; /*Spouse mande South*/;
replace s_mandes=0 if s_mandes==.;
by hid: g int s_mande=cond(s_manden==1|s_mandes==1, 1, 0)   /*Mande*/ ;
by hid: g int s_volta=1   if ethnie==5; /*Spouse voltaic*/;
replace s_volta=0 if s_volta==.;
by hid: g int s_etr=1     if ethnie==9; /*Spouse Stranger*/;
replace s_etr=0 if s_etr==.;









***************************************** employment variables**************************************************;
/*by hid: gen s_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . );
lab var s_ilf "Head of household in labor force"*/;

by hid: gen s_nilf = cond( nilf==1, 1, 0 );
lab var s_nilf "Head of household not in labor force";

by hid: gen int s_hrs = hourwrk if ( empl == 1 );
lab var s_hrs "Head's hours worked per week";

* could be amended to be those who are employed ;
by hid: gen s_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )   ;
/*Here I take empl instead of occupat to take into account, those who have a job but have not worked last 7 days*/;
lab var s_em "Head of household is employed";

* could be amended to be those who are unemployed (search==1 and/or want to work) /*But I choose to drop the search condition*/;
by hid: gen s_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . );
lab var s_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;



/*
by hid: gen s_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_pub "Head is public sector wage employee";
by hid: gen s_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );

lab var s_pvt "Head is private sector wage employee";
*by hid: gen s_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
*lab var s_emp "Head is an employer";
by hid: gen s_inf = cond(occupat==1 & statocc==3,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_inf "Head works in informal sector";
by hid: gen s_self = cond(occupat==1 & statocc==4,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_self "Head is self employed";
tab s_self;
by hid: gen s_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var s_ag "Head is engaged in an agricultural activity";
tab s_ag;
*/



sort hid;

by hid: g s_ag=cond(industry==1| s2q16b==17|s2q16b==18|s2q16b==20, 1, 0) if ( empl == 1) ;
lab var s_ag "Head is engaged in an agricultural activity";
tab s_ag, m;
recode s_ag .=0;

by hid: g s_man=cond(industry==2| s2q16b==11|s2q16b==12|s2q16b==13, 1, 0) if ( empl == 1) ;
lab var s_man "Spouse is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab s_man, m;
recode s_man .=0;

by hid: g s_com=cond(industry==3|(s2q16b==14| s2q16b==15| s2q16b==16), 1, 0) if ( empl == 1 ) ;
lab var s_com "Spouse is engaged in Utilities/commerce activities";
tab s_com, m;
recode s_com .=0;

by hid: g s_adm=cond(industry==4 | (s2q16b>=1 & s2q16b<=10), 1, 0) if ( empl == 1 ) ;
lab var s_adm "Spouse is engaged in Banking/financial services/Professional/Public administration activities";
tab s_adm, m;
recode s_adm .=0;

by hid: g s_other=cond(industry>4| (s2q16b==19|s2q16b==21), 1, 0) if ( empl == 1 ) ;
lab var s_other "Spouse is engaged in Other activities";
tab s_other, m;
recode s_other .=0;


/*
by hid: gen int s_hrs = hourwrk;
lab var s_hrs "Spouse hours worked per week";

by hid: gen s_ag = cond( empl == 1, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var s_ag "Spouse is engaged in an agricultural activity"*/;


*by hid: gen s_job = cond( s_ag   == 1 | s_mfg  == 1 | s_mine == 1 | s_cnst == 1 | s_util == 1 | 
			       s_comm == 1 | s_bank == 1 | s_prof == 1 | s_pbad == 1 | s_tspt == 1 | 
			       s_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );




/*by hid: gen s_job =  cond( s_pub == 1   | s_pvt == 1  | s_inf == 1 | s_self == 1 , 1, 0 ) 
			        if ( occupat ~= . /*& industry ~= .*/ )*/;


by hid: gen s_job =  cond( s_ag == 1   | s_com == 1  | s_adm == 1 | s_man == 1 , 1, 0 ) 
			        if ( occupat ~= . /*& industry ~= .*/ );
lab var s_job "Spouse has a job";

* check that the spouse has a job, is unemployed, or is not in the labor force;
tempvar sjob_test;
replace s_unem = 0 if s_job == 1;
replace s_nilf = 0 if s_unem == 1;
replace s_nilf = 0 if s_job == 1;
gen int sjob_test = s_job + s_unem + s_nilf;
assert sjob_test <= 1 if ( sjob_test ~= . );
tab sjob_test;

by hid: gen s_nojb = cond( s_nilf == 1 | s_unem == 1, 1, 0 ) if ( occupat ~= .);
lab var s_nojb "Spouse has no job";






* education variables;

by hid: gen s_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_ne "Spouse has no education";

by hid: gen s_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ke "Spouse has koranic education";

by hid: gen s_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pnc "Spouse incomplete primary";

by hid: gen s_pc  = cond( educlev == 4, 1, 0 ) /* if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pc "Spouse completed primary";

by hid: gen s_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_snc "Spouse incomplete secondary";

by hid: gen s_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_sc "Spouse completed secondary";

by hid: gen s_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ts "Spouse tertiary";

by hid: gen s_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ps "Spouse preschool only";

by hid: gen s_ue  = cond( educlev == 9 | educlev == 99 | educlev==., 1, 0 );
lab var s_ue "Spouse unstated education";

by hid: gen s_sct = cond(educlev==5|educlev==6|educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_sct "Spouse has imcomplete , completed secondary or tertiary education";

by hid: gen s_st  = cond(educlev>=5&educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_st "Spouse has at least some secondary education";

by hid: gen s_prim = cond(educlev==3|educlev==4|educlev==8,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_prim "Spouse has some level of primary schooling";

by hid: gen s_noeduc = cond(educlev==1,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_noeduc "Spouse has no education or has preschool";


tempvar test_s_ed1;
egen test_s_ed1 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps );
lab var test_s_ed1 "Test that spouse has some level of education if educlev ~= .";
assert test_s_ed1 <= 1 if ( educlev < 9 & educlev ~= . );

tempvar test_s_ed3;
egen test_s_ed3 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps s_ue );
lab var test_s_ed1 "Test that spouse has education information or missing";
assert test_s_ed3 <= 1;

tempvar test_s_ed2;
egen test_s_ed2 = rsum( s_sct s_st s_prim );
lab var test_s_ed2 "Test of spouse's educlev for lumping education";
assert test_s_ed2 <= 2 if ( test_s_ed2 ~= . );

by hid: gen s_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var s_lit "Spouse is literate";

********************************************Migration variables**********************************************;
by hid: g t_mig_s=cond(t_mig==1, 1, 0) if t_mig~=.;
lab var t_mig_s "Spouse is a Long Term Migrant";
by hid: gen l_mig_s = cond(l_mig == 1, 1, 0) if l_mig~=.;
lab var l_mig_s "Spouse is a Long Term Migrant";

sort hid;
tab relat;
by hid: gen s_occup= occupat;
*by hid: gen s_industry= industry;
by hid: gen s_statoc= statoc;
g s_relat=relat ;
compress;
sort hid;
save spouse, replace;



cap log close;
log using head-spouse.log, replace;

use head, clear;
sort  hid;
merge hid using spouse;
tab _merge ;

/* this ensures that all obs have a head of household*/;
assert _merge ~= 2;

di "MUST SET SPOUSE OBS TO ZERO; HE/SHE HAS NO SPOUSE";

sort hid;
by hid: replace s_christ=0 if (_merge==1);
by hid: replace s_anim=0 if   (_merge==1);
by hid: replace s_musl=0 if   (_merge==1);
by hid: replace s_hand=0 if   (_merge==1);
by hid: replace s_akan=0 if   (_merge==1);
by hid: replace s_krou=0 if   (_merge==1);
by hid: replace s_manden=0 if (_merge==1);
by hid: replace s_mandes=0 if (_merge==1);
by hid: replace s_volta=0 if  (_merge==1);
by hid: replace s_etr=0 if    (_merge==1);

sort hid;
by hid: replace s_agey    = 0 if ( _merge == 1 );
by hid: replace s_agey_c  = 0 if ( _merge  == 1 );
by hid: replace s_agey2   = 0 if ( _merge  == 1 );
by hid: replace s_agey2_c = 0 if ( _merge  == 1 );
by hid: replace s_nilf    = 0 if ( _merge  == 1 );

* employment variables;
by hid: replace s_ag     = 0 if ( _merge  == 1 );
by hid: replace s_adm     = 0 if ( _merge  == 1 );
by hid: replace s_com    = 0 if ( _merge  == 1 );
by hid: replace s_man     = 0 if ( _merge  == 1 );
by hid: replace s_job     = 0 if ( _merge  == 1 );

* could be amended to be those unemployed;
by hid: replace s_unem    = 0 if ( _merge  == 1 );
*by hid: replace s_ag      = 0 if ( _merge  == 1 );

/*
by hid: replace s_merge fg     = 0 if ( _merge  == 1 );
by hid: replace s_merge ine    = 0 if ( _merge  == 1 );
by hid: replace s_cnst    = 0 if ( _merge  == 1 );
by hid: replace s_util    = 0 if ( _merge  == 1 );
by hid: replace s_comm    = 0 if ( _merge  == 1 );
by hid: replace s_bank    = 0 if ( _merge  == 1 );
by hid: replace s_prof    = 0 if ( _merge  == 1 );
by hid: replace s_pbad    = 0 if ( _merge  == 1 );
by hid: replace s_tspt    = 0 if ( _merge  == 1 );
by hid: replace s_othr    = 0 if ( _merge  == 1 );
*/;

* lumping variables;
/*
by hid: replace s_bppa    = 0 if ( _merge  == 1 );
*by hid: replace s_merge guc    = 0 if ( _merge  == 1 );
by hid: replace s_nojb    = 0 if ( _merge  == 1 );
by hid: replace s_svcs    = 0 if ( _merge  == 1 );
by hid: replace s_wemp    = 0 if ( _merge  == 1 );
by hid: replace s_ind    = 0 if ( _merge  == 1 );
*/;

* education variables;

by hid: replace s_ne      = 0 if ( _merge  == 1 );
by hid: replace s_ke      = 0 if ( _merge  == 1 );
by hid: replace s_pnc     = 0 if ( _merge  == 1 );
by hid: replace s_pc      = 0 if ( _merge  == 1 );
by hid: replace s_snc     = 0 if ( _merge  == 1 );
by hid: replace s_sc      = 0 if ( _merge  == 1 );
by hid: replace s_ts      = 0 if ( _merge  == 1 );
by hid: replace s_ps      = 0 if ( _merge  == 1 );
by hid: replace s_ue      = 0 if ( _merge  == 1 );
by hid: replace s_sct     = 0 if ( _merge  == 1 );
by hid: replace s_st      = 0 if ( _merge  == 1 );
by hid: replace s_prim    = 0 if ( _merge  == 1 );
by hid: replace s_lit     = 0 if ( _merge  == 1 );
*by hid: replace s_self     = 0 if ( _merge  == 1 );

* other
by hid: replace s_hrs      = 0 if ( _merge  == 1 );
by hid: replace s_occup    = 0 if ( _merge  == 1 );
*by hid: replace s_industry = 0 if ( _merge  == 1 );
by hid: replace s_statoc   = 0 if ( _merge  == 1 );
by hid: replace s_relat    = 0 if ( _merge  == 1 );

* a few quick checks;
assert relat   == 1 if _merge  == 1;
assert s_relat == 2 if _merge  == 3;
gen h_sgl=_merge ==1;

**test***;

*drop help;

*gen help= s_nojb +s_svcs+ s_pbad+ s_othr+s_ag+h_sgl;

*tab help;

* cleanup;

drop _merge ;

ta geocode2, m;
compress;
sort hid;

save head-spouse, replace;








/* Still using a rough measure of total consumption */;

/* ------------- */
/* poverty lines */
/* ------------- */;

cap log close;

log using reg00.log,replace;

use pauvre, clear;
keep _region_ hid;
sort hid;
compress;
save region, replace;

use hhexp, clear;
sort hid;
merge hid using region;
ta _merge;
drop _merge;
drop  homecons house hinvest hutil school internet health trcomm trschool clothing dgoods remitt  hygine entmnt domest inkind;
sort hid ;
compress;
save hhexp1, replace;

use head-spouse, clear;
sort hid;

merge hid using hhexp1;

ta geocode2;
sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

ta _merge;
drop _merge;
compress;
save final, replace;

count;


use final, clear; 

tab geocode2, m;

#delimit cr

g rururb=milieu

g wta=pond
drop  _region_ _milieu_

gen byte rural = cond( rururb == 1, 1, 0 )
lab var rural "dummy for rural areas"

gen byte urban = 1 - rural
*gen urban = cond( rururb == 2, 1, 0)
lab var urban "dummy for urban areas"
recode literacy 2=1 3=2 
compress
save, replace








/* ------------------------------- */
/* generate the dependent variable */
/* ------------------------------- */

gen     pl = povline 
lab var pl "Poverty line"

tab2 rururb pl, m
g double total_pc=pchhexp

sum hhexp total_pc

bysort rururb hid: gen double ln_wm_pl = ln( total_pc / pl )
lab var ln_wm_pl "ln(welfare measure)"

# delimit ;
tab nspouse;
tab h_sgl;
tab h_nsp;
cap drop geo1 ge02 geo3 geo4 geo5;
ta geocode2, m;
destring geocode2, replace;
ta geocode2;


*tab strate, gen(geo);
tab strate rururb;
recast double hhsize;
gen double(weight)=wta*hhsize;
sum weight wta hhsize;

* Note we should use h_sgl (not h_nsp) because it correspond to the same number of houses with zero spouses. ;

rename poor poor_old;
gen poor=cond(total_pc<pl,1,0) if (total_pc~=.&pl~=.) ;
compare poor poor_old;
ren landsz lander  /*It seems there is a bug in stata7 concerning this name; I replace landsz by lander*/;
#delimit cr
ta geocode1, m
ta geocode1 rururb
ta geocode1, gen(geo)
compress
save, replace







/* --------------------------------------------------------------------------- */
/* REGRESSIONS                                                                 */
/* --------------------------------------------------------------------------- */

* clean up all variables

use final, clear

#delimit;

bysort urban: sum
      total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man h_other
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr      
	s_unem s_nilf s_ag s_com s_adm s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo*;

bysort urban: sum
      total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man h_other
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr
	s_unem s_nilf s_ag s_com s_adm s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo*
 	if poor==1;

bysort urban: sum
      total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man h_other
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr
	s_unem s_nilf s_ag s_com s_adm s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo*
 if poor==0;




/*bysort urban: sum
       total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man h_other
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr  
	s_unem s_nilf s_ag s_com s_adm s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo*
	if feel_poor==1;

bysort urban: sum
      total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man h_other
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr     
	s_unem s_nilf s_ag s_com s_adm s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo*
	if feel_poor==0

*/;


/* REGRESSIONS CORRECTING FOR AGE == 99 */;



/* DO SOME POVERTY CALCULATIONS - For my Dirty Consumption Aggregate;
poverty total_pc [aw=weight], l(183450) all;
poverty total_pc [aw=weight] if urban==1, l(183450) all;
poverty total_pc [aw=weight] if rural==1, l(183450) all;
*/



/* NATIONAL*/;
reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17
	[w=weight] ;
outreg using reg.xls, ctitle(national) bdec(3) br 3aster replace;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17 [w=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100)*/ ;




/* URBAN */;
reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17
	[w=weight] if rururb==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17 [w=weight] if rururb==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] ", reps(100) */;




/* RURAL */;
reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17
	[w=weight] if rururb==2;
outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr   
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17 [w=weight] if rururb==2" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] 
_se[geo4] _se[geo5] ", reps(100) */;





**********************************************************************************************
PERCEPTION OF POVERTY vs. POVERTY -- DETERMINANTS
**********************************************************************************************;



*sum poor feel_poor;
tab poor [aw=weight];
*tab feel_poor_h [aw=weight];
sort urban;
by urban: tab poor;
*by urban: tab feel_poor_h;


*** NATIONAL ****;
dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr   
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17
	[aw=weight] ;
outreg using reg.xls, ctitle(national) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr    
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17 [aw=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100) */;



*** URBAN ****;
dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr  
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if urban==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr     
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17 [aw=weight] if urban==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100) */;




***** RURAL *******; 
dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr     
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if rural==1;

outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob1;
sum prob1;
drop prob;
/*set seed 123456789;
bs  "dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man h_other
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr  
	/*s_em s_nilf*/ s_com s_ag s_man s_other
	land lander landsz2 
	lomwater  lomelec
	geo2-geo17 [aw=weight] if rural==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] 
", reps(100)*/ ; /*No s_pvt available*/


#delimit cr

compress
save, replace





use final, replace
sort hid ethnie
cap drop ivoirien
g ivoirien=cond(ethnie<=5, 1, 0)
ta ivoirien [aw=weig], m

recode region 4=3 9=8 10=8 11=8 15=14 16=14 18=14
recode region 1=1 2=2 3=3 5=4 6=5 7=6 8=7 12=8 13=9 14=10 17=11 19=12

cap label drop reg2
#delimit;
lab def reg2 1"LAGUNES" 2"ZANZAN" 3"MOYEN COMOE/AGNEBY" 4"SAVANES" 5"VALLEE DU BANDAMA" 
6"N'ZI COMOE" 7"MONTAGNES/DENGUELE/BAFING/MOYEN CAVALLY" 8"HAUT SASSANDRA" 9"BAS SASSANDRA" 
10"FROMAGER/MARAHOUE/LACS/SUD BANDAMA" 11"WORODOUGOU" 12"SUD COMOE" ;
#delimit cr
lab val region reg2




#delimit;

global xxx
"      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	h_agey_c h_agey2_c  
        h_ne h_pnc h_pc h_snc h_sc 
        t_mig_h l_mig_h 
        h_hand
        h_anim h_musl
        h_krou h_mande h_volta h_etr
	h_com h_ag h_man h_other h_unem
        s_ne s_pnc s_pc s_snc s_sc 
	s_com s_ag s_man s_other s_unem
	lander landsz2 
	lomwater lomelec lomtelephone 
	i.rich i.region
";

global xxx2
"      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	h_agey_c h_agey2_c 
        h_ne h_pnc h_pc h_snc 
        t_mig_h l_mig_h 
        h_hand
        h_anim h_musl
	h_com h_ag h_man h_other h_unem
        s_ne s_pnc s_pc s_snc s_sc 
	s_com s_ag s_man s_other s_unem
	lander landsz2 
	lomwater lomelec lomtelephone 
	i.rich i.region
";

global xxxvars
"      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	h_agey_c h_agey2_c  
        h_ne h_pnc h_pc h_snc h_sc 
        t_mig_h l_mig_h 
        h_hand
        h_anim h_musl
        h_krou h_mande h_volta h_etr
	h_com h_ag h_man h_other h_unem
        s_ne s_pnc s_pc s_snc s_sc 
	s_com s_ag s_man s_other s_unem
	lander landsz2 
	lomwater lomelec lomtelephone 
	rich region
";

cap log close;
log using "NewEstimates3.log", replace;

su $xxxvars;
corr $xxxvars;

ren ln_wm_pl logC ;




***Log Consumption***;
xi: reg logC $xxx [aw=weight], robust;
outreg using reg.xls, ctitle(OLSLogC) bdec(3) br 3aster replace;
cap drop OLSLogC;
predict OLSLogC;
su OLSLogC;
xi: reg logC $xxx if rururb==1 [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLogCUr) bdec(3) br 3aster append;
*decompose, save(high);
cap drop OLSLogCUr;
predict OLSLogCUr;
su OLSLogCUr;
xi: reg logC $xxx if rururb==2 [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLogCRu) bdec(3) br 3aster append;
*decompose, save(low);
*decompose;
cap drop OLSLogCRu;
predict OLSLogCRu;
su OLSLogCRu;
xi: reg logC $xxx2 if ivoirien==1 [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLogCIv) bdec(3) br 3aster append;
*decompose, save(high);
cap drop OLSLogCIv;
predict OLSLogCIv;
su OLSLogCIv;
xi: reg logC $xxx2 if ivoirien==0 [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLogCNIv) bdec(3) br 3aster append;
*decompose, save(low);
*decompose;
cap drop OLSLogCNIv;
predict OLSLogCNIv;
su OLSLogCNIv;


***Poverty****;
xi: dprobit poor $xxx [aw=pond], robust;
outreg using reg.xls, ctitle(OProbPov) bdec(3) br 3aster append;
cap drop OProbPov;
predict OProbPov;
su OProbPov;
xi: dprobit poor $xxx if rururb==1 [aw=pond], robust;
outreg using reg.xls, ctitle(OProbPovUr) bdec(3) br 3aster append;
*decompose, save(high);
cap drop OProbPovUr;
predict OProbPovUr;
su OProbPovUr;
xi: dprobit poor $xxx if rururb==2 [aw=pond], robust;
outreg using reg.xls, ctitle(OProbPovRu) bdec(3) br 3aster append;
*decompose, save(low);
*decompose;
cap drop OProbPovRu;
predict OProbPovRu;
su OProbPovRu;
xi: dprobit poor $xxx2 if ivoirien==1 [aw=pond], robust;
outreg using reg.xls, ctitle(OProbPovIv) bdec(3) br 3aster append;
*decompose, save(high);
cap drop OProbPovIv;
predict OProbPovIv;
su OProbPovIv;
xi: dprobit poor $xxx2 if ivoirien==0 [aw=pond], robust;
outreg using reg.xls, ctitle(OProbPovNIv) bdec(3) br 3aster append;
*decompose, save(low);
*decompose;
cap drop OProbPovNIv ;
predict OProbPovNIv ;
su OProbPovNIv;

*restore;


cap drop lpchhinc ;
bysort rururb hid: gen double lpchhinc = ln( pchhinc / pl );
sum lpchhinc [aw=pond], detail;

***Log Income***;
xi: reg lpchhinc $xxx [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLInc) bdec(3) br 3aster append;
predict OLSLInc;
su OLSLInc;
xi: reg lpchhinc $xxx if rururb==1 [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLIncUr) bdec(3) br 3aster append;
*decompose, save(high);
cap drop OLSLIncUr;
predict OLSLIncUr;
su OLSLIncUr;
xi: reg lpchhinc $xxx if rururb==2 [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLIncRu) bdec(3) br 3aster append;
*decompose, save(low);
*decompose;
cap drop OLSLIncRu;
predict OLSLIncRu;
su OLSLIncRu;
xi: reg lpchhinc $xxx2 if ivoirien==1 [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLIncIv) bdec(3) br 3aster append;
*decompose, save(high);
cap drop OLSLIncIv;
predict OLSLIncIv;
su OLSLIncIv;
xi: reg lpchhinc $xxx2 if ivoirien==0 [aw=pond], robust;
outreg using reg.xls, ctitle(OLSLIncNIv) bdec(3) br 3aster append;
*decompose, save(low);
*decompose;
cap drop OLSLIncNIv;
predict OLSLIncNIv;
su OLSLIncNIv;

cap log close;




*restore;

#delimit cr
save, replace


set rmsg off
set more on 
cap log close
exit