capture log close
clear all
set more 1
set matsize 300
log using c:\Diego\Nigeria\log_files\educ.log, replace

#delimit;

use "C:\Diego\Nigeria\data\indinv.dta", clear;
drop poor;
drop _m;

merge hhid using "c:\Diego\Nigeria\data\temp";
tab _m;
drop _m;
sort hhid;

merge hhid using "C:\Diego\Nigeria\data\income.dta";
tab _m;
keep if _merge==3;
drop _m;
count;

* Create other needed variables;

* Contribution;
gen male_main_contr= cond(indid_income==indid&sex==1,1,0);
gen fem_main_contr= cond(indid_income==indid&sex==0,1,0);

* Decision Making;

gen mh_dec_only = cond(h_decide_educ==1&s_decide_educ==0&h_fem==0,1,0); 
lab var mh_dec_only "male head decides only";

gen fh_dec_only = cond(h_decide_educ==1&s_decide_educ==0&h_fem==1,1,0);
lab var fh_dec_only "female head decides only";

gen sp_dec_only = cond(h_decide_educ==0&s_decide_educ==0&h_fem==1,1,0);
lab var sp_dec_only "spouse decides only";


* Education Problems by PSU (Leave out mean);

egen vnop = sum(no_problem), by(PSU);
egen vnob = sum(no_books), by(PSU);
egen vptea = sum(poor_teaching), by(PSU);
egen vltea = sum(lack_teachers), by(PSU);
egen vbfac = sum(bad_facil), by(PSU);
egen vhfee = sum(high_fees), by(PSU);
egen vothp = sum(oth_problem_edu), by(PSU);
gen n=1;
egen ntot = sum(n), by(PSU);

gen rnop = (vnop - no_problem)/(ntot-1);
gen rnob = (vnob - no_books)/(ntot-1);
gen rptea = (vptea - poor_teaching)/(ntot-1);
gen rltea = (vltea - lack_teachers)/(ntot-1);
gen rbfac = (vbfac - bad_facil)/ (ntot-1); 
gen rhfee = (vhfee - high_fees)/(ntot-1);
gen  rothp = (vothp - oth_problem_edu)/(ntot-1);

lab var rnop "no problem";
lab var rnob "no books / supplies ";
lab var rptea "bad teaching";
lab var rltea "lack teachers";
lab var rbfac "bad facilities";
lab var rhfee "high fees";
lab var rothp "other problem";

keep if agey>=6&agey<=15;

rename atschool asiste;
recode asiste .=0;
gen work=cond(occupat==1,1,0);
count;

save c:\Diego\Nigeria\data\amos2, replace;

tab work asiste, m;

tab asiste work if sex==1;
tab asiste work if sex==0;

gen weight= hhweight/hhsize;
tab state, gen(state_);
gen agey2 = agey^2;

sum 	asiste work agey agey2
	num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	h_fem h_nsp h_agey h_agey2 s_agey s_agey2 
	h_islam h_chris
	h_pnc h_pc h_snc h_sc h_ts 
	s_pnc s_pc s_snc s_sc s_ts 
	h_job h_pub h_sal h_self h_unp  
	s_job s_nilf s_pub s_sal s_self s_unp  
	h_macotr h_retail h_svs 
	s_macotr s_retail s_svs 
	landsz landsz2 
	rnop rnob rptea rltea rbfac rhfee rothp
	state_1 state_2 state_3 state_4 state_5 state_6 state_8
	mh_dec_only fh_dec_only sp_dec_only
	quintile rural;
	

******** RURAL *************;

* Boys;

biprobit  
	asiste work 
	agey agey2
	num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	h_fem h_nsp h_agey h_agey2 s_agey s_agey2 
	h_islam h_chris
	h_pnc h_pc h_snc h_sc h_ts 
	s_pnc s_pc s_snc s_sc s_ts 
	h_job h_pub h_sal h_self h_unp  
	s_job s_nilf s_pub s_sal s_self s_unp  
	h_macotr h_retail h_svs 
	s_macotr s_retail s_svs 
	landsz landsz2 
	/*rnop rnob rptea rltea rbfac rhfee rothp*/
	state_1 state_2 state_3 state_4 state_5 state_6 state_8
	mh_dec_only fh_dec_only sp_dec_only
	quintile 
	if sex==1&rural==1;

outreg using "C:\Diego\Nigeria\tables\amos", bdec(3) br 3aster replace;

predict Bpsifw_r if sex==1&rural==1, pcond1;
count if Bpsifw_r>1&Bpsifw_r~=.;
drop if Bpsifw_r>1&Bpsifw_r~=.;
predict Bps_nw_r if sex==1&rural==1, p10;
predict Bm_w_r if sex==1&rural==1, pmarg2;
gen Bpsifnw_r=Bps_nw_r/(1-Bm_w_r) if sex==1&rural==1;
gen Bpdiff_r=Bpsifnw_r-Bpsifw_r if sex==1&rural==1;
sum Bpsifw_r Bpsifnw_r Bpdiff_r [w=weight] if sex==1&rural==1;
tab asiste work if sex==1&rural==1;

*details of pcond1, test is equal to pcond1 or Bpsifw;
predict help2 if sex==1&rural==1, p11;
gen test=help2/Bm_w_r if sex==1&rural==1;
sum test Bpsifw_r [w=weight];
drop test help2; 

* Girls;

biprobit 
	asiste work 
	agey agey2
	num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	h_fem h_nsp h_agey h_agey2 s_agey s_agey2 
	h_islam h_chris
	h_pnc h_pc h_snc h_sc h_ts 
	s_pnc s_pc s_snc s_sc s_ts 
	h_job h_pub h_sal h_self h_unp  
	s_job s_nilf s_pub s_sal s_self s_unp  
	h_macotr h_retail h_svs 
	s_macotr s_retail s_svs 
	landsz landsz2 
	/*rnop rnob rptea rltea rbfac rhfee rothp*/
	state_1 state_2 state_3 state_4 state_5 state_6 state_8
	mh_dec_only fh_dec_only sp_dec_only
	quintile 
	if sex==0&rural==1;

outreg using "C:\Diego\Nigeria\tables\amos", bdec(3) br 3aster append;

predict Gpsifw_r if sex==2&rural==1, pcond1;
predict Gps_nw_r if sex==2&rural==1, p10;
predict Gm_w_r if sex==2&rural==1, pmarg2;
gen Gpsifnw_r=Gps_nw_r/(1-Gm_w_r) if sex==2&rural==1;
gen Gpdiff_r=Gpsifnw_r-Gpsifw_r if sex==2&rural==1;
sum Gpsifw_r Gpsifnw_r Gpdiff_r [w=weight] if sex==2&rural==1;
tab asiste work if sex==2&rural==1;

*details of pcond1, test is equal to pcond1 or Bpsifw;
predict help2 if sex==2&rural==1, p11;
gen test=help2/Gm_w_r if sex==0&rural==1;
sum test Gpsifw_r [w=weight];
drop test help2; 

* the problem comes when the probability p11 if higher than the univariate probability of working pmarg2;

******** URBAN *************;

* Boys;
/*
biprobit 
	asiste work 
	agey agey2
	num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	h_fem h_nsp h_agey h_agey2 s_agey s_agey2 
	h_islam h_chris
	h_pnc h_pc h_snc h_sc h_ts 
	s_pnc s_pc s_snc s_sc s_ts 
	h_job h_pub h_sal h_self h_unp  
	s_job s_nilf s_pub s_sal s_self s_unp  
	h_macotr h_retail h_svs 
	s_macotr s_retail s_svs 
	landsz landsz2 
	/*rnop rnob rptea rltea rbfac rhfee rothp*/
	state_1 state_2 state_3 state_4 state_5 state_6 state_8
	mh_dec_only fh_dec_only sp_dec_only
	quintile 
	if sex==1&rural==0;

outreg using "C:\Diego\Nigeria\tables\amos", bdec(3) br 3aster append;

predict Bpsifw_u if sex==1&rural==0, pcond1;
count if Bpsifw_u>1&Bpsifw_u~=.;
drop if Bpsifw_u>1&Bpsifw_u~=.;
predict Bps_nw_u if sex==1&rural==0, p10;
predict Bm_w_u if sex==1&rural==0, pmarg2;
gen Bpsifnw_u=Bps_nw_u/(1-Bm_w_u) if sex==1&rural==0;
gen Bpdiff_u=Bpsifnw_u-Bpsifw_u if sex==1&rural==0;
sum Bpsifw_u Bpsifnw_u Bpdiff_u [w=weight] if sex==1&rural==0;
tab asiste work if sex==1&rural==0;

*details of pcond1, test is equal to pcond1 or Bpsifw;
predict help2 if sex==1&rural==0, p11;
gen test=help2/Bm_w_u if sex==1&rural==0;
sum test Bpsifw_u [w=weight];
drop test help2; 
*/;

* Girls;

biprobit asiste work 
	agey agey2
	num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	h_fem h_nsp h_agey h_agey2 s_agey s_agey2 
	h_islam h_chris
	h_pnc h_pc h_snc h_sc h_ts 
	s_pnc s_pc s_snc s_sc s_ts 
	h_job h_pub h_sal h_self h_unp  
	s_job s_nilf s_pub s_sal s_self s_unp  
	h_macotr h_retail h_svs 
	s_macotr s_retail s_svs 
	landsz landsz2 
	/*rnop rnob rptea rltea rbfac rhfee rothp*/
	state_1 state_2 state_3 state_4 state_5 state_6 state_8
	mh_dec_only fh_dec_only sp_dec_only
	quintile 
	if sex==0&rural==0;

outreg using "C:\Diego\Nigeria\tables\amos", bdec(3) br 3aster append;

predict Gpsifw_u if sex==2&rural==0, pcond1;
predict Gps_nw_u if sex==2&rural==0, p10;
predict Gm_w_u if sex==2&rural==0, pmarg2;
gen Gpsifnw_u=Gps_nw_u/(1-Gm_w_u) if sex==2&rural==0;
gen Gpdiff_u=Gpsifnw_u-Gpsifw_u if sex==2&rural==0;
sum Gpsifw_u Gpsifnw_u Gpdiff_u [w=weight] if sex==2&rural==0;
tab asiste work if sex==2&rural==0;

*details of pcond1, test is equal to pcond1 or Bpsifw;
predict help2 if sex==2&rural==0, p11;
gen test=help2/Gm_w_u if sex==0&rural==0;
sum test Gpsifw_u [w=weight];
drop test help2; 

*log close;


