/*===============================================================================

                         	 BURUNDI: Poverty Assessment
                       
						Cross tables          
                        
				             Gaston Gohou
                                     August 2004
       					

Objective: 

This data contains all the variables of bdi_perc_v2.dta, in addition, it includes the 
imputed expenditure and quantile for 2004. I also included the 2 first factors on the correpondance
analysis using the psychological variables (factor 1=distress and factor 2)

1. I add the 2 first factors of the correspondence analysis I've with SPADN (distress and f2)
2. Using the data set bdi_perc_v2.dta, I created variables: poor, subjective poor, coffee producers
3. and then, I do the cross tables

Results: Basic statistics on the 2004 Persception survey

  ================================================================================= */

version 7.0

clear all
capture log close
log using "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\logfiles\bur04_coffee.txt", replace text 
set more off
set mem 64m
set matsize 800

log off


/*RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
  OOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOOO
  WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW*/
 

use "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\datafiles\bdi_perc_v2.dta", clear
sort persid
save "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\datafiles\bdi_perc_v2.dta", replace

/*Using SPADN software and correspondance analysis technics, I created the 2 first factors of of the 
psychological impact of the crisis: f1 (distress) and f2. */

insheet using "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\datafiles\bur04_factor.txt", clear
keep persid f1 f2
sort persid

merge persid using "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\datafiles\bdi_perc_v2.dta"
drop _merge

ren f1 factor1
ren f2 factor2 /* correspondance analysis factors from SPADN*/

gen hhsize=i14
label var hhsize "Household size"
recode hhsize 99=30
drop i14

gen edu=i15
recode edu  3=2 4=3 5=4
label define edu 1 "no education" 2 "primary" 3 "secondary" 4 "superior"
label value edu edu
label var edu "education"
drop i15

ren i7 sex
label define sexl 1 male 2 female
label value sex sexl
lab var sex "sex"

gen marist=i10
recode marist 5=2 6 9=3
label define marist 1 single 2 married 3 "divorce/separated" 4 widow
label value marist marist 
label var marist "marital statut"
drop i10

gen urban=i13
recode urban 0=2
label define urban 1 urban 2 rural
label value urban urban
label var urban "urban/rural sector"
drop i13
 
 
/*================
	Define a dummy variable for poor and non poor in urban and rural area
================*/

/*Objective poverty based on quintile distribution*/
gen o_poor=cond(quintile04<=3, 1,0) /*var poor nopoor:"poor represent 60% of the population" */
label define o_poor 1 obj_poor 0 obj_nopoor
label value o_poor o_poor
label var o_poor "Objective poverty: poor"

/*Subjective poverty*/
gen s_poor=cond(q6==4|q6==5, 1,0)
label define s_poor 1 sub_poor 0 sub_nopoor
label value s_poor s_poor
label var s_poor "Subjective poverty: feeling poor"


/*============================
     Coffee producers
=============================*/
/*label define yesno 1 yes 0 no*/

gen coffe=cond(q26==1,1,0)
label var coffe "coffee producers in 2004"
label value coffe yesno

gen oldcoffe=cond(q27==1,1,0)
label var oldcoffe "coffee producers 5 years ago"
label value oldcoffe yesno

gen coffeq=q29
label var coffeq "coffee production in kg"
recode coffeq  .=0

gen coffe_inc_share = q30/(q30+q31)
label var coffe_inc_share "share of coffee income in total income"

recode coffeq .=0
recode q30 99999997952=0 /*Valeur aberante*/

gen coffep=q30/coffeq if (coffeq>0 & q30>0)
label var coffep "coffee price BF/kg"

qui sum coffep if coffep<2000, detail  

gen priccoffe=r(mean)
label var priccoffe "imputed coffee price BF/kg"


gen qcoffee=q30/priccoffe
label var qcoffee "imputed coffee production in kg"

keep persid sex pcexp04 quintile04 hhsize edu marist urban o_poor s_poor coffe coffeq coffep priccoffe qcoffee

save "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\datafiles\bur04_coffee.dta", replace


log on

/*POVERTY SIMULATION*/
/*THe poverty ratio represents the three first poorest quintiles.
The quintiles are based on the per capita imputed expenditure.
From this poverty ratio, I got the poverty line PL=2474.348*/

ren qcoffee q
recode q .=0
ren priccoffe p

/*Benchmark: Actual situation: unit price of coffee 247 BF/kg*/
poverty pcexp04 if coffe==1, line(2474.348) h pgr fgt3 /*coffee producers*/
poverty pcexp04, line(2474.348) h pgr fgt3 /*all population*/

/*Sc1:  unit price of coffee 210 BF/kg*/

gen pcexp1 = (((210-p)*q)/hhsize) + pcexp04  /*new per capita expenditure*/

poverty pcexp1 if coffe==1 & pcexp1>0, line(2474.348) h pgr fgt3 /*coffee producers*/
poverty pcexp1 , line(2474.348) h pgr fgt3 /*all population*/

/*Sc2:  unit price of coffee 220 BF/kg*/

gen pcexp2 = (((220-p)*q)/hhsize) + pcexp04  /*new per capita expenditure*/

poverty pcexp2 if coffe==1 & pcexp2>0, line(2474.348) h pgr fgt3 /*coffee producers*/
poverty pcexp2 , line(2474.348) h pgr fgt3 /*all population*/

/*Sc3:  unit price of coffee 230 BF/kg*/

gen pcexp3 = (((230-p)*q)/hhsize) + pcexp04  /*new per capita expenditure*/

poverty pcexp3 if coffe==1 & pcexp3>0, line(2474.348) h pgr fgt3 /*coffee producers*/
poverty pcexp3 , line(2474.348) h pgr fgt3 /*all population*/

/*Sc4:  unit price of coffee 240 BF/kg*/

gen pcexp4 = (((240-p)*q)/hhsize) + pcexp04  /*new per capita expenditure*/

poverty pcexp4 if coffe==1 & pcexp4>0, line(2474.348) h pgr fgt3 /*coffee producers*/
poverty pcexp4 , line(2474.348) h pgr fgt3 /*all population*/

/*Sc5:  unit price of coffee 260 BF/kg*/

gen pcexp5 = (((260-p)*q)/hhsize) + pcexp04  /*new per capita expenditure*/

poverty pcexp5 if coffe==1 & pcexp5>0, line(2474.348) h pgr fgt3 /*coffee producers*/
poverty pcexp5 , line(2474.348) h pgr fgt3 /*all population*/

/*Sc6:  unit price of coffee 270 BF/kg*/

gen pcexp6 = (((270-p)*q)/hhsize) + pcexp04  /*new per capita expenditure*/

poverty pcexp6 if coffe==1 & pcexp6>0, line(2474.348) h pgr fgt3 /*coffee producers*/
poverty pcexp6 , line(2474.348) h pgr fgt3 /*all population*/

/*Sc7:  unit price of coffee 280 BF/kg*/

gen pcexp7 = (((280-p)*q)/hhsize) + pcexp04  /*new per capita expenditure*/

poverty pcexp7 if coffe==1 & pcexp7>0, line(2474.348) h pgr fgt3 /*coffee producers*/
poverty pcexp7 , line(2474.348) h pgr fgt3 /*all population*/



log off

/*
povdeco pcexp04, pline(2474.348)  /*all population*/






log on
tab coffe oldcoffe
sum coffeq coffe_inc_share if coffe==1
tab o_poor s_poor, cel nof
tab o_poor s_poor, row nof
tab o_poor s_poor, col nof

tab o_poor s_poor if coffe==1, cel nof
tab o_poor s_poor if coffe==1, row nof
tab o_poor s_poor if coffe==1, col nof

tab coffe s_poor, row nof
tab coffe s_poor, col nof
tab coffe o_poor, row nof
tab coffe o_poor, col nof


/*=========================
		CROSS TABLES 
===================================*/
/*General characteristics*/
tab edu coffe , col nof
tab edu coffe if o_poor==1, col nof

tab sex coffe , col nof
tab sex coffe if o_poor==1, col nof

tab marist coffe , col nof
tab marist coffe if o_poor==1, col nof

/*generate hh size class*/
gen hhclass=cond(i14<=3,1,0)
replace hhclass=2 if (i14>3 & i14<=6)
replace hhclass = 3 if (i14>6)
label define hhclass 1 "0-3 hh members" 2 "4-6 members" 3 "+6 members"
label value hhclass hhclass

tab hhclass coffe , col nof
tab hhclass coffe if o_poor==1, col nof


/*Household assets*/
# delimit;
local var "voiture motocycle bicyclette refrigerateur television radio pirogue hache secateur brouette scie 
		machette serpette pelle iron chaise table lit matelas couverture seau lmptampete bobeche rechaud 
		foytradamel stove imbabura_ameliore";
foreach x of local var {;
	tab  `x' coffe, row nof;
	tab  `x' coffe, col nof;
	tab  `x' o_poor, row nof;
	tab  `x' o_poor, col nof;
	tab  `x' s_poor, row nof;
	tab  `x' quintile04  , row nof;
};

# delimit cr
	


/*Poverty's Perception*/ 
local var " q101 q102 q103 q104 q105 q106 q107"
foreach xx of local var {
	tab  `xx' coffe, row nof
	tab  `xx' o_poor, row nof
	tab  `xx' s_poor, row nof
	tab  `xx' quintile04  , row nof
}

/*Feeling about welfare of your community*/
tab  coffe  q2, row nof
tab  o_poor  q2, row nof
tab  s_poor  q2, row nof
tab  quintile04  q2, row nof

/*Signs of poverty*/
local var " q301 q302 q303"
foreach xx of local var {
	tab  `xx' coffe, row nof
	tab  `xx' o_poor, row nof
	tab  `xx' s_poor, row nof
	tab  `xx' quintile04, row nof  
}

/*Poverty's perception the last 5 yrs in communuty*/
tab  q4 coffe, row nof
tab  q4 o_poor, row nof
tab  q4 s_poor, row nof
tab  q4 quintile04 , row nof

tab  q5 coffe, row nof
tab  q5 o_poor, row nof
tab  q5 s_poor, row nof
tab  q5 quintile04, row nof


/*Are you feeling poor*/ 
tab  q6 quintile04 , row nof

log off

/*== Crisis impact====*/
recode nitmare 9=0  /*1=yes  0=no*/
/*label define yesno 0 no 1 yes*/
label value nitmare yesno

recode scare 9=0 
label value scare yesno

recode useful 9=0 
label value useful yesno

recode resful 9=0
label value resful yesno

recode sad 9=0
label value sad yesno

recode strong 9=0
label value strong  yesno

recode angry 9=0
label value angry yesno

recode project 9=0
label value project yesno

recode cimpact 9=0  
label value cimpact yesno


log on
local var " nitmare scare useful resful sad strong angry project cimpact"
foreach xx of local var {
	tab  `xx' coffe,row  nof
	tab  `xx' o_poor,row  nof
	tab  `xx' s_poor, row nof
	tab  `xx' quintile04  , row nof
}


/* Solutions for the actual crisis*/
local var "q801 q802 q803 q804 q805 q806 q807 q808 q809 q810 q811 q812 q813"
foreach x of local var  {
	recode `x' 9=0 2=1 3=0
	label value `x' yesno
	tab coffe `x'  ,row  nof
	tab o_poor `x'  ,row  nof
	tab s_poor `x'  , row nof
	tab  quintile04 `x', row nof
}		

/*Priorities of your community*/

local var  "q901 q902 q903 q904"
foreach xx of local var  {
	/*tab  `xx' coffe, row nof*/
	tab  `xx' o_poor, row nof
	tab  `xx' s_poor, row nof
	tab `xx' quintile04 , row nof
}		

/*What should be the priorities of commumity?*/
local var  "q1001 q1002 q1003"
foreach xx of local var  {
	/*tab  `xx' coffe, row nof*/
	tab  `xx' o_poor, row nof
	tab  `xx' s_poor, row nof
	tab `xx' quintile04 , row nof
}		

/*Main ways to reduce poverty*/
/*tab q1101 coffe, row nof*/
tab q1101 o_poor, row nof
tab q1101 s_poor, row nof
tab q1101 quintile04, row nof
/*tab q1102 coffe, row nof*/
tab q1102 o_poor, row nof
tab q1102 s_poor, row nof
tab q1102 quintile04, row nof


/*===========Institution perception========*/
log off
recode q15 3=0 2=0
recode q16 3=0 4=0 2=1
recode q17 3=0 2=0
recode q18 3=0 2=0
recode q21 3=0 2=0
recode q22 3=0 2=0

recode q23 3=0 2=0

log on
local var  "q15 q16 q17 q18 q19a q19b q20a q20b q21 q22 q23"
foreach xx of local var  {
	tab  `xx' coffe, row nof
	tab  `xx' o_poor, row nof
	tab  `xx' s_poor, row nof
	tab `xx' quintile04 , row nof
}		

/* Access to community services*/
log off

local var " q2411 q2412 q2413 q2414 q2415 q2416 q2417 q2418 q2419"
foreach x of local var  {
	recode `x' 9=5
	label value `x' yesno
}		

local var " q2421 q2422 q2423 q2424 q2425 q2426 q2427 q2428 q2429"
foreach x of local var  {
	recode `x' 9=4
	label value `x' yesno
}		

local var "q142_01 q142_02 q142_03 q142_04 q142_05 q142_06 q142_07 q142_08 q142_09 q142_10 q142_11 q142_12"
foreach x of local var {
		tab    `x' o_poor, col nof
		tab    `x' s_poor, col nof
}



rename q2412 market_time
recode market_time 9=5
lab var market_time "How long to market?"
lab define 	market_time 1 " less than 1 km" 2 "1-3 km" 3 "3-5 km" 4 " 5km +"  5 "no_use"
lab value market_time market_time
	
rename q2422 market_qty
recode market_qty 2=1 3=0  4 = 3
lab var market_qty "Are satisfay of this service?"
lab define 	market_qty 1 "yes" 2 "no" 3 "no_use" 
lab value market_qty market_qty 

rename q2411 pwater_time
recode pwater_time 9=5
lab var pwater_time "How long to pwater?"
lab define 	pwater_time 1 " less than 1 km" 2 "1-3 km" 3 "3-5 km" 4 " 5km +"  5 "no_use"
lab value pwater_time pwater_time
	
rename q2421 pwater_qty
recode pwater_qty 2=1 3=0  4 = 3
lab var pwater_qty "Are satisfay of this service?"
lab define 	pwater_qty 1 "yes" 2 "no" 3 "no_use" 
lab value pwater_qty pwater_qty 

rename q2413 bustop_time
recode bustop_time 9=5
lab var bustop_time "How long to public transport?"
lab define 	bustop_time 1 " less than 1 km" 2 "1-3 km" 3 "3-5 km" 4 " 5km +"  5 "no_use"
lab value bustop_time bustop_time
	
rename q2423 bustop_qty
recode bustop_qty 2=1 3=0  4 = 3
lab var bustop_qty "Are satisfay of this service?"
lab define 	bustop_qty 1 "yes" 2 "no" 3 "no_use" 
lab value bustop_qty bustop_qty 

rename q2414 school_time
recode school_time 9=5
lab var school_time "How long to school?"
lab define 	school_time 1 " less than 1 km" 2 "1-3 km" 3 "3-5 km" 4 " 5km +"  5 "no_use"
lab value school_time school_time
	
rename q2424 school_qty
recode school_qty 2=1 3=0  4 = 3
lab var school_qty "Are satisfay of this service?"
lab define 	school_qty 1 "yes" 2 "no" 3 "no_use" 
lab value school_qty school_qty 

rename q2416 healthctr_time
recode healthctr_time 9=5
lab var healthctr_time "How long to healthctr?"
lab define 	healthctr_time 1 " less than 1 km" 2 "1-3 km" 3 "3-5 km" 4 " 5km +"  5 "no_use"
lab value healthctr_time healthctr_time

rename q2426 healthctr_qty
recode healthctr_qty 2=1 3=0  4 = 3
lab var healthctr_qty "Are satisfay of this service?"
lab define 	healthctr_qty 1 "yes" 2 "no" 3 "no_use" 
lab value healthctr_qty healthctr_qty 

rename q2418 coper_time
recode coper_time 9=5
lab var coper_time "How long to coper?"
lab define 	coper_time 1 " less than 1 km" 2 "1-3 km" 3 "3-5 km" 4 " 5km +"  5 "no_use"
lab value coper_time coper_time
	
rename q2428 coper_qty
recode coper_qty 2=1 3=0  4 = 3
lab var coper_qty "Are satisfay of this service?"
lab define 	coper_qty 1 "yes" 2 "no" 3 "no_use" 
lab value coper_qty copec_qty 

rename q2419 police_time
recode police_time 9=5
lab var police_time "How long to police?"
lab define 	police_time 1 " less than 1 km" 2 "1-3 km" 3 "3-5 km" 4 " 5km +"  5 "no_use"
lab value police_time police_time
	
rename q2429 police_qty
recode police_qty 2=1 3=0  4 = 3
lab var police_qty "Are satisfay of this service?"
lab define 	police_qty 1 "yes" 2 "no" 3 "no_use" 
lab value police_qty police_qty 

 
log on
local ggg  " pwater_time pwater_qty market_time market_qty bustop_time bustop_qty school_time school_qty healthctr_time healthctr_qty coper_time coper_qty police_time police_qty"
foreach xx of local ggg  {
	tab  `xx' coffe, row nof
	tab  `xx' o_poor, row nof
	tab  `xx' s_poor, row nof
	tab `xx' quintile04 , row nof
	}		

/* in 1998, the age classes were 0-25; 25-45; 45-55; and 55+.
for tthe 2004 survey, to follow the same cohort, I keep the same class and and 6 years*/
log off

gen age=cond(i8<31,1,0)
replace age=2 if (i8>=31 & i8<51)
replace age=3 if (i8>=51 & i8<61)
replace age=4 if (i8>=61)

gen hhsize=1
replace hhsize=2 if i14>3 & i14<=6
replace hhsize=3 if i14>6

gen job =1 /*public or private formal job*/
replace job=2 if i9==10 /*agriculture*/
replace job=3 if i9==9 |i9== 11|i9==12 /*informal job*/
replace job=4 if i9==8 | i9==13 |i9==14 /*no job*/

label define job 1 "public or private "  2 agriculture  3 "self-employed" 4 "no job"   
label value job job

gen title=cond(i11==1, 1,2) /*1 HH head*/


local var "nitmare scare useful resful sad strong angry project cimpact s_poor o_poor urban"
foreach xx of local var {
	recode `xx' 0=2
}

outsheet  urban hhsize sex marist  job title  edu s_poor o_poor quintile04  age /*
	 */nitmare scare useful resful sad strong angry project cimpact using "C:\gohou\bur04.xls", replace nolabel 

sort persid
save "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\datafiles\bur04_xtables.dta",replace

factor nitmare scare useful resful sad strong angry project cimpact, factor(2) pcf
score f1 f2

qui sum f1, detail 
gen t=r(min)
gen psycho_04=f1-(t-0.1) /*this trick is to avoid negative value of f1 so the log can be calculated*/
drop f1 t 
label var psycho_04 "psychologic index  factor 1"

qui sum f2, detail 
gen t=r(min)
gen psyf2_04=f2-(t-0.1)
label var psyf2_04 "psychologic index  factor 2"
drop f2 t 

log on
bys o_poor: sum  psycho_04  psyf2_04
bys s_poor: sum  psycho_04  psyf2_04
bys quintile04: sum  psycho_04  psyf2_04
sum  psycho_04  psyf2_04 if urban==1
sum  psycho_04  psyf2_04 if urban~=1
sum  psycho_04  psyf2_04 


/*quintile based on the factor (distress) score*/

xtile quint_factor = factor1, nq(5)


sort persid
save "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\datafiles\bur04_xtables.dta",replace

tab s_poor  quint_factor , cel nof
tab s_poor  quint_factor , row nof
tab s_poor  quint_factor , col nof
tab o_poor  quint_factor , cel nof
tab o_poor  quint_factor , row nof
tab o_poor  quint_factor , col nof

tab o_poor  urban , cel nof

tab quint_factor quintile04, cel nof
tab quint_factor quintile04, col nof

/*Signs of poverty*/

tab  q301 quint_factor, col nof

local var " q301 q302 q303"
foreach xx of local var {
	tab  `xx' quint_factor, col nof
}

tab  quint_factor q107, row nof


/*Poverty's Perception*/ 
local var " q101 q102 q103 q104 q105 q106 q107"
foreach xx of local var {
	tab  `xx' quint_factor , col nof
}

/* Access to community services*/

local ggg  " pwater_time pwater_qty market_time market_qty bustop_time bustop_qty school_time school_qty healthctr_time healthctr_qty coper_time coper_qty police_time police_qty"
foreach xx of local ggg  {
	tab  `xx' quint_factor, col nof
	}		



/*== Crisis impact====*/

local var " nitmare scare useful resful sad strong angry project cimpact"
foreach xx of local var {
	tab  `xx' quint_factor, col  nof
}

bys quint_factor: sum  psycho_04  psyf2_04



/*Priorities of your community*/



local var  "q901 q902 q903 q904"
foreach xx of local var  {
	tab `xx' o_poor , col nof
	tab `xx' s_poor, col nof
	tab `xx' quintile04 , col nof
	tab `xx' quint_factor, col nof
}		

/*What should be the priorities of commumity?*/

tab q1003  o_poor , col nof
tab q1003  s_poor, col nof
tab q1003  quintile04 , col nof
tab q1003  quint_factor, col nof

local var  "q1001 q1002 q1003"
foreach xx of local var  {
	tab  `xx' coffe, row nof
	tab  `xx' o_poor, row nof
	tab  `xx' s_poor, row nof
	tab `xx' quintile04 , row nof
}		

ren i14 size
label var size "household size"

gen size2=size^2
label var size2 "household size squared"

ren i8 hage
label var hage "age of person"

gen hage2=age^2
label var hage2 "age of person squared"

sort persid
save "Q:\My Documents\AfrPRSP\Survey\Burundi\Bur2004\datafiles\bur04_xtables.dta",replace
*/

log off


capture log close
exit

