clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of child work ****************
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"

use ind6, clear



*Generating variables for heads
preserve
keep if relat==1





#delimit;
/* --------------------------- */
/*Children Work variables */
/* --------------------------- */;

cap log close;
log using Child_work.log, replace;

sort indid;

count if agey>=7 & agey<16;

keep if agey>=7 & agey<16;

*cap drop _expand
*dups hid indid, drop
sort hid;

* gender of child: male;
by hid: gen c_mal = cond( sex == 1, 1, 0 ) ;
lab var c_mal "Child is a Boy";


by hid: gen c_fem = cond( sex == 2, 1, 0 ) ;
lab var c_fem "Child is a Girl";

by hid: gen c_polyg = cond(marstat == 3 , 1, 0 ) if ( marstat ~= . );
lab var c_polyg  "Child is in a polygamous family";

* Assume chil is living alone;
by hid: gen c_alone = cond( relat<2, 1, 0 ) if ( relat~= . );
lab var c_alone "Child is alone";

* Note: agey not allowed to be missing;
by hid: gen c_agey = agey ;
lab var c_agey "Age of child";

by hid: gen c_agey_c = cond( c_agey < 99, c_agey, . ) ;
lab var c_agey_c "Age of child, no 99 allowed";

by hid: gen int c_agey2 = ((c_agey)^2) ;
lab var c_agey2 "Square of age of child";

by hid: gen int c_agey2_c = ((c_agey_c)^2);
lab var c_agey2_c "Square of no-99 age of child";

/*by hid: gen int feel_poor_c = cond(feel_poor==1,1,0) if feel_poor~=.;
lab var feel_poor_c "Child feels poor"*/;



************************************ Health status of the child*****************************************************;
sort hid;
by hid: g int c_hand=1 if handicap==1;
replace c_hand=0 if c_hand==.;

************************************ Religion of the Child**********************************************************;
sort hid;
by hid: g int c_christ=1 if religion==1; /*Child Christian*/;
replace c_christ=0 if c_christ==.;
by hid: g int c_musl=1 if religion==2; /*Child Muslem*/;
replace c_musl=0 if c_musl==.;
by hid: g int c_anim=1 if religion==3; /*Child Animist*/;
replace c_anim=0 if c_anim==.;

************************************ Ethnicity of the Child**********************************************************;
sort hid;
by hid: g int c_akan=1    if ethnie==1; /*Child akan*/;
replace c_akan=0 if c_akan==.;
by hid: g int c_krou=1    if ethnie==2; /*Child Krou*/;
replace c_krou=0 if c_krou==.;
by hid: g int c_manden=1  if ethnie==3; /*Child Mande North*/;
replace c_manden=0 if c_manden==.;
by hid: g int c_mandes=1  if ethnie==4; /*Child mande South*/;
replace c_mandes=0 if c_mandes==.;
by hid: g int c_volta=1   if ethnie==5; /*Child voltaic*/;
replace c_volta=0 if c_volta==.;
by hid: g int c_etr=1     if ethnie==9; /*Child Stranger*/;
replace c_etr=0 if c_etr==.;


************************************ employment variables**********************************************************;

by hid: gen c_ilf = cond( occupat ==1, 1, 0 ) if ( occupat ~= . );
lab var c_ilf "Child in labor force";

by hid: gen c_nilf = cond( occupat > 2, 1, 0 ) if ( occupat ~= . );
lab var c_nilf "Child not in labor force";

by hid: gen int c_hrs = hourwrk if ( occupat == 1 );
lab var c_hrs "Child's hours worked per week";

* could be amended to be those children who are employed ;
by hid: gen c_em = cond( occupat == 1, 1, 0 ) if ( occupat ~= . );
lab var c_em "Child is employed";

* could be amended to be those children who are unemployed (search==1 and/or want to work);
by hid: gen c_unem = cond( occupat == 2, 1, 0 ) if ( occupat ~= . ) & search==1 /*Not sure of adding search==1 to this*/;
lab var c_unem "Child is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;



/*
by hid: gen c_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var c_pub "Child is public sector wage employee";
by hid: gen c_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( occupat ~= . & statocc ~= . );

lab var c_pvt "Child is private sector wage employee";
*by hid: gen c_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( occupat ~= . & statocc ~= . );
*lab var c_emp "Child is an employer";
by hid: gen c_inf = cond(occupat==1 & statocc==3,1,0 ) if (occupat ~= . & statocc ~= .);
lab var c_inf "Child works in informal sector";
by hid: gen c_self = cond(occupat==1 & statocc==4,1,0 ) if (occupat ~= . & statocc ~= .);
lab var c_self "Child is self employed";
tab c_self;
by hid: gen c_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var c_ag "Child is engaged in an agricultural activity";
tab c_ag;
*/



sort hid;

by hid: g c_ag=cond(industry==1, 1, 0) if (occupat ~= . & statocc ~= . );
lab var c_ag "Child is engaged in an agricultural activity";
tab c_ag;

by hid: g c_man=cond(industry==2, 1, 0) if (occupat ~= . & statocc ~= . );
lab var c_man "Child is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab c_man;

by hid: g c_com=cond(industry==3, 1, 0) if (occupat ~= . & statocc ~= . );
lab var c_com "Child is engaged in Utilities/commerce activities";
tab c_com;

by hid: g c_adm=cond(industry==4, 1, 0) if (occupat ~= . & statocc ~= . );
lab var c_adm "Child is engaged in Banking/financial services/Professional/Public administration activities";
tab c_adm;

/*INDUSTRY - need to include : See Rwanda*/;

* first test variable: Child should have one employment category or be unemployed;
*egen Childemp = rsum(c_unem c_ag c_mfg c_mine c_cnst c_util c_comm c_bank c_prof c_pbad c_tspt c_othr) if (relat == 1);

*egen Childemp = rsum(c_unem c_pub c_pvt c_inf c_self) if (relat == 1);

egen Childemp = rsum(c_unem c_ag c_com c_adm c_man) if (relat == 1);

* must deal with known problems from definition of unemployed;

replace c_unem  = 0 if   Childemp == 2;
* replace Childemp = 1 if   Childemp == 2;
assert Childemp <= 1 if ( Childemp ~= . );
drop Childemp;

*by hid: gen c_job = cond( c_ag == 1   | c_mfg == 1  | c_mine == 1 | c_cnst == 1 | c_util == 1 | 
                          c_comm == 1 | c_bank == 1 | c_prof == 1 | c_pbad == 1 | c_tspt == 1 | 
                          c_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );


/*by hid: gen c_job =  cond( c_pub == 1   | c_pvt == 1  | c_inf == 1 | c_self == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .)*/;

by hid: gen c_job =  cond( c_ag == 1   | c_com == 1  | c_man == 1 | c_adm == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .);
lab var c_job "Child has a job";


* check that the Child has a job, is unemployed, or is not in the labor force;
tempvar hjob_test;
* must deal with known problems from definition of unemployment;
replace c_unem = 0 if c_job  == 1;
replace c_nilf = 0 if c_unem == 1;
replace c_nilf = 0 if c_job  == 1;

gen int hjob_test = c_job + c_unem + c_nilf ;
assert hjob_test <= 1 if ( hjob_test ~= . );
tab hjob_test;

by hid: gen c_nojb = cond( c_unem == 1 | c_nilf == 1, 1, 0 ) if ( occupat ~= .);
lab var c_nojb "Child unemployed or NILF";


********************************************education variables**********************************************;

by hid: gen c_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var c_ne "Child has no education";

by hid: gen c_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var c_ke "Child has koranic education";

by hid: gen c_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var c_pnc "Child incomplete primary";

by hid: gen c_pc  = cond( educlev == 4, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var c_pc "Child completed primary";

by hid: gen c_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var c_snc "Child incomplete secondary";

by hid: gen c_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var c_sc "Child completed secondary";

by hid: gen c_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var c_ts "Child has tertiary";

by hid: gen c_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var c_ps "Child preschool only";

by hid: gen c_ue  = cond( educlev == 9 | educlev == 99 | educlev == ., 1, 0 );
lab var c_ue "Child unstated/unknown education";

by hid: gen c_sct = cond(educlev == 5|educlev==6 | educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var c_sct "Child has at least imcomplete, completed secondary or tertiary education";

/*by hid: gen c_st  = cond(educlev>=5 & educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var c_st "Child has at least some secondary education"*/;

by hid: gen c_prim = cond(educlev==3|educlev==4|educlev==8,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var c_prim "Child has at least some prescholl or primary education";

by hid: gen c_noeduc=cond(educlev==1, 1, 0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var c_noeduc "Child has no education or has preschool";



tempvar test_c_ed1;
egen test_c_ed1 = rsum( c_ne c_ke c_pnc c_pc c_snc c_sc c_ts c_ps );
lab var test_c_ed1 "Test that Child has some level of education if educlev ~= .";
assert test_c_ed1 == 1 if ( educlev < 9 & educlev ~= . );

tempvar test_c_ed3;
egen test_c_ed3 = rsum( c_ne c_ke c_pnc c_pc c_snc c_sc c_ts c_ps c_ue );
lab var test_c_ed1 "Test that Child has education information or missing";
assert test_c_ed3 <= 1;

tempvar test_c_ed2;
egen test_c_ed2 = rsum( c_sct c_sct c_prim );
lab var test_c_ed2 "Test of Child's educlev for lumping education";
assert test_c_ed2 <= 2 if ( test_c_ed2 ~= . );

by hid: gen c_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var c_lit "Child is literate";

by hid: gen c_occup= occupat;
*by hid: gen c_industry= industry;
by hid: gen c_statoc= statoc;

********************************************Migration variables**********************************************;

by hid: gen mig_h = cond(mig == 1, 1, 0) if mig~=.;
lab var mig_h "Child is a Migrant";

sort hid;

******************************************* Land Variables **************************************************;
bysort hid: gen byte land = cond(ownland == 1, 1, 0 ) if ( ownland ~= . );
lab var land "Child owns land";

replace landsize = 0 if ownland == 2;
rename landsize landsz ;
*recast double landsz;
lab var landsz " land (ha) owned by household";  

by hid: gen float landsz2 = (landsz^2);
lab var landsz2 "Square of land (ha) owned by household";

* if no observations, regression won't run;
qui sum landsz;
if ( `r(N)' == 0 ) {;
	replace landsz  = 0;
	replace landsz2 = 0;
	};

count;

sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

count;

sort hid;

save Child_work, replace;




* Generating additionnal child variables for children under 16;

use sect01, clear;

sort hid;
by hid: g child_own=cond(s1q4==3, 1, 0) if s1q6a<16;
ta child_own;
by hid: g child_bro=cond(s1q4==6, 1, 0) if s1q6a<16;
ta child_bro;
by hid: g child_bf=cond(s1q4==7, 1, 0) if s1q6a<16;
ta child_bf;
by hid: g child_dom=cond(s1q4==11, 1, 0) if s1q6a<16;


*Education variables;

by hid: g child_school=cond(s1q35==1, 1, 0) if s1q6a<16;
ta child_school,m;
by hid: g child_scwork=cond(s1q36==2| s1q36==4, 1, 0) if s1q6a<16 /*Reason of non schooling: work*/;
ta child_scwork,m;
by hid: g child_tp=cond(s1q47~=1, 1, 0) if s1q6a<16  /*Child is not going to school in full time*/;
ta child_tp,m;
by hid: g child_neat=cond(s1q45~=1, 1, 0) if s1q6a<16 /* Child is not having lunch at home*/;
ta child_neat,m;
by hid: g child_educgen=cond(s1q37==1, 1, 0) if s1q6a<16 /* Child is following a general education*/;
ta child_educgen,m;
by hid: g child_eductech=cond(s1q37~=1, 1, 0) if s1q6a<16 /* Child is following a technical/professional education*/;
ta child_eductech,m;
by hid: g child_educsup=cond(s1q51~=8 & s1q51~=9 &s1q51~=10, 1, 0) if s1q6a<16  /*Education support from an institution*/;
ta child_educsup,m;
by hid: g child_educsuphh=cond(s1q51==8| s1q51==9|s1q51==10, 1, 0) if s1q6a<16  /*Education support from family*/;
ta child_educsuphh,m;

sort hid;
merge hid using Child_work;
ta _merge;
keep grappe menord grap- landsz2;
save Child_work, replace; 



/*
use sect02, clear;
g child









sort hid;
merge hid using Child_work;
ta _merge;
keep grappe menord grap- landsz2;
save Child_work, replace*/; 






use hhexp, clear;
drop  homecons house hinvest hutil school internet health trcomm trschool clothing dgoods remitt  hygine entmnt domest inkind;
sort hid ;
save hhexp1, replace;

use Child_work, clear;
sort hid;

merge hid using hhexp1;

ta geocode2;
sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

ta _merge;
drop _merge;

save, replace;

count;


#delimit cr

g rururb=milieu

g wta=pond
drop  _region_ _milieu_

gen byte rural = cond( rururb == 1, 1, 0 )
lab var rural "dummy for rural areas"

gen byte urban = 1 - rural
*gen urban = cond( rururb == 2, 1, 0)
lab var urban "dummy for urban areas"
recode literacy 2=1 3=2 
save, replace








/* ------------------------------- */
/* generate the dependent variable */
/* ------------------------------- */

gen     pl = povline 
lab var pl "Poverty line"

tab2 rururb pl, m
g double total_pc=pchhexp

sum hhexp total_pc

bysort rururb hid: gen double ln_wm_pl = ln( total_pc / pl )
lab var ln_wm_pl "ln(welfare measure)"

cap drop weight
gen double(weight)=wta*hhsize

summ total_pc, detail
centile total_pc, centile(20 40 60 80)
egen rank1 =rank(total_pc), unique
xtile riche = rank1 [w=weight], nq(5)
g riche1=cond(riche==1, 1, 0)
g riche2=cond(riche==2, 1, 0)
g riche3=cond(riche==3, 1, 0)
g riche4=cond(riche==4, 1, 0)
g riche5=cond(riche==5, 1, 0)

# delimit ;

tab strate rururb;
recast double hhsize;
sum weight wta hhsize;

rename poor poor_old;
gen poor=cond(total_pc<pl,1,0) if (total_pc~=.&pl~=.) ;
compare poor poor_old;
ren landsz lander  /*It seems there is a bug in stata7 concerning this name; I replace landsz by lander*/;
#delimit cr
ta geocode1, m
ta geocode1 rururb
ta geocode1, gen(geo)
save, replace



#delimit;

/* --------------------------------------------------------------------------- */
/* REGRESSIONS                                                                 */
/* --------------------------------------------------------------------------- */;

cap log close;
log using reg00_child_work.log, replace;
use Child_work, replace;

recode empl 1=1 2=0;

bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom child_school child_scwork
        child_tp child_neat child_eductech child_educsup 
	c_prim c_st c_lit
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*;

bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c 
        child_own child_bro child_bf child_dom child_school child_scwork
        child_tp child_neat child_eductech child_educsup 
	c_prim c_st c_lit
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
 	if poor==1;

bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c 
        child_own child_bro child_bf child_dom child_school child_scwork
        child_tp child_neat child_eductech child_educsup 
	c_prim c_st c_lit
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
 if poor==0;




/*bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c 
        child_own child_bro child_bf child_dom child_school child_scwork
        child_tp child_neat child_eductech child_educsup 
	c_prim c_st c_lit
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche1-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
	if feel_poor==1;

bysort urban: sum
      empl num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c 
        child_own child_bro child_bf child_dom child_school child_scwork
        child_tp child_neat child_eductech child_educsup 
	c_prim c_st c_lit
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche1-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
	if feel_poor==0

*/;






/* NATIONAL*/;
reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] ;
outreg using reg.xls, ctitle(national) bdec(3) br 3aster replace;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100)*/ ;




/* URBAN */;
reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] if rururb==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom child_school child_scwork
        child_tp child_neat child_eductech child_educsup 
	c_prim c_sct c_lit
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight] if rururb==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] ", reps(100) */;




/* RURAL */;
reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] if rururb==2;
outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight] if rururb==2" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] 
_se[geo4] _se[geo5] ", reps(100) */;


tab poor [aw=weight];


*** NATIONAL ****;
probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] ;
outreg using reg.xls, ctitle(national) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100) */;



*** URBAN ****;
probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if urban==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if urban==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100) */;




***** RURAL *******; 
probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if rural==1;

outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob1;
sum prob1;
drop prob;
/*set seed 123456789;
bs  "probit empl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if rural==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] 
", reps(100)*/ ; /*No s_pvt available*/



* NATIONAL;
dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight];
outreg using reg.xls, ctitle(national)  bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100)*/ ;



* URBAN;
dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if urban==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if urban==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100) */;



* RURAL;
dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if rural==1;
outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit empl
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 
	/*c_fem c_nsp*/ c_agey_c c_agey2_c  
        child_own child_bro child_bf child_dom 
        c_hand
        c_anim c_musl
        c_krou c_manden c_mandes c_volta c_etr
	/*c_em c_nilf c_com c_adm c_man*/
        riche2-riche5
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if rural==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[c_fem] _b[c_nsp] _b[c_agey_c] _b[c_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[c_prim] _b[c_st] _b[c_lit]
_b[s_prim] _b[s_st] _b[c_unem] _b[c_nilf] _b[c_pub] _b[c_pvt] _b[c_self] _b[c_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[c_fem] _se[c_nsp] _se[c_agey_c] _se[c_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[c_prim] _se[c_st]
_se[c_lit] _se[s_prim] _se[s_st] _se[c_unem] _se[c_nilf] _se[c_pub] _se[c_pvt] _se[c_self] _se[c_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100)*/;




#delimit cr
set more on
log close
exit


