/*===============================================================================

                         	 CI: Poverty Assessment
                       
				               Gaston Gohou
                                         January 2005

THis code evaluates the impact on household welfare when the coffee price changes.

 ================================================================================= */

version 8.0
clear all
capture log close
log using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\logfiles\civ02_coffee.txt", replace text 
set more off
set mem 64m
set matsize 800
log off 

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta", clear
keep  idmen pond   strate pauv pchhexp hhexp rururb hhsize  coffq coffqs cofprice coffee
ren coffee coffe

sort idmen 


/* population distribution by quintile*/
sort pchhexp
xtile quintile= pchhexp [pweight=pond], nq(5)

gen pondn=pond*hhsize
xtile quint2= pchhexp [pweight=pondn], nq(5)
xtile decile= pchhexp [pweight=pondn], nq(10)

/*gen pondn = coefpond* hhsize_1*/
svyset [pw=pondn], strata (strate) psu (idmen)


save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\civ02_coffee.dta", replace

/*POVERTY SIMULATION*/
/*The poverty line in CI in 2002 is CFAF 183,450 per capita

3 models: i) ref price is the mean price (169) then simulation price= 130; 140; 150; 160; 180; 190; 200; 210
	   ii) ref price is the median price (150) then simulation price= 110; 120; 130; 140; 150; 160; 170; 180; 190 
	  iii) ref price ind price then simulation price = -30%; -20%; -10%; +10%; +20%; 30%

*/

ren coffqs q
recode q .=0

ren cofprice p
recode p .=0

gen p1=169 /*Mean price of coffee*/
gen p2=150 /*Median price of coffee*/

log on



/*
svytab decile pauv if q>0
sum q if q>0

preserve
collapse (sum) q  [pw= pond] , by(decile)
restore

preserve
collapse (mean) q  [pw= pond], by(decile)
restore

collapse (mean) p  [pw= pond] if p>0, by(decile)


*/







/*===============================
                                  First model: p1 mean price (169)
                                                =========================================*/

/*Benchmark: Actual situation: unit price of coffee 169 FCFA/kg*/
poverty pchhexp [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pchhexp  [aw=pondn] if coffe==1 , line(183450) h pgr fgt3 /*coffee producers*/

/*Sc1:  unit price of coffee 100 BF/kg*/
gen pcexp1 = (((130-p1)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp1 [aw=pondn] , line(183450) h pgr fgt3 /*all population*/
poverty pcexp1 [aw=pondn] if coffe==1 & pcexp1>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc2:  unit price of coffee 220 BF/kg*/
gen pcexp2 = (((140-p1)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp2 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp2 [aw=pondn] if coffe==1 & pcexp2>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc3:  unit price of coffee 230 BF/kg*/
gen pcexp3 = (((150-p1)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp3 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp3 [aw=pondn]if coffe==1 & pcexp3>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc4:  unit price of coffee 240 BF/kg*/
gen pcexp4 = (((160-p1)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp4 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp4 [aw=pondn]if coffe==1 & pcexp4>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc5:  unit price of coffee 260 BF/kg*/
gen pcexp5 = (((180-p1)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp5 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp5 [aw=pondn] if coffe==1 & pcexp5>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc6:  unit price of coffee 270 BF/kg*/
gen pcexp6 = (((190-p1)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp6 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp6 [aw=pondn] if coffe==1 & pcexp6>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc7:  unit price of coffee 280 BF/kg*/
gen pcexp7 = (((200-p1)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp7 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp7 [aw=pondn]if coffe==1 & pcexp7>0, line(183450) h pgr fgt3 /*coffee producers*/



/*===============================
                                  Second model: p2 median price (150)
                                                =========================================*/

/*Benchmark: Actual situation: unit price of coffee 90 BF/kg*/
poverty pchhexp [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pchhexp  [aw=pondn] if coffe==1 , line(183450) h pgr fgt3 /*coffee producers*/

/*Sc1:  unit price of coffee 100 BF/kg*/
gen pcexp12 = (((110-p2)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp12 [aw=pondn] , line(183450) h pgr fgt3 /*all population*/
poverty pcexp12 [aw=pondn] if coffe==1 & pcexp12>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc2:  unit price of coffee 220 BF/kg*/
gen pcexp22 = (((120-p2)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp22 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp22 [aw=pondn] if coffe==1 & pcexp22>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc3:  unit price of coffee 230 BF/kg*/
gen pcexp32 = (((130-p2)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp32 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp32 [aw=pondn]if coffe==1 & pcexp32>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc4:  unit price of coffee 240 BF/kg*/
gen pcexp42 = (((140-p2)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp42 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp42 [aw=pondn]if coffe==1 & pcexp42>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc5:  unit price of coffee 260 BF/kg*/
gen pcexp52 = (((160-p2)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp52 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp52 [aw=pondn] if coffe==1 & pcexp52>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc6:  unit price of coffee 270 BF/kg*/
gen pcexp62 = (((170-p2)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp62 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp62 [aw=pondn] if coffe==1 & pcexp62>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc7:  unit price of coffee 280 BF/kg*/
gen pcexp72 = (((180-p2)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp72 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp72 [aw=pondn]if coffe==1 & pcexp72>0, line(183450) h pgr fgt3 /*coffee producers*/



/*===============================
                                  Third model: p individual price 
                                                =========================================*/

/*Benchmark: Actual situation: unit price of coffee 136.3985 BF/kg*/
poverty pchhexp [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pchhexp  [aw=pondn] if coffe==1 , line(183450) h pgr fgt3 /*coffee producers*/

/*Sc1:  unit price of coffee -30% price BF/kg*/
gen pcexp13 = (((-0.3*p)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp13 [aw=pondn] , line(183450) h pgr fgt3 /*all population*/
poverty pcexp13 [aw=pondn] if coffe==1 & pcexp13>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc2:  unit price of coffee -20% BF/kg*/
gen pcexp23 = (((-0.2*p)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp23 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp23 [aw=pondn] if coffe==1 & pcexp23>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc3:  unit price of coffee -10% BF/kg*/
gen pcexp33 = (((-0.1*p)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp33 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp33 [aw=pondn]if coffe==1 & pcexp33>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc4:  unit price of coffee +10% BF/kg*/
gen pcexp43 = (((0.1*p)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp43 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp43 [aw=pondn]if coffe==1 & pcexp43>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc5:  unit price of coffee +20% BF/kg*/
gen pcexp53 = (((0.2*p)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp53 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp53 [aw=pondn] if coffe==1 & pcexp53>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc6:  unit price of coffee +30% BF/kg*/
gen pcexp63 = (((0.3*p)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp63 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp63 [aw=pondn] if coffe==1 & pcexp63>0, line(183450) h pgr fgt3 /*coffee producers*/

/*Sc7:  unit price of coffee 280 BF/kg*/
gen pcexp73 = (((0.4*p)*q)/hhsize) + pchhexp/*new per capita expenditure*/
poverty pcexp73 [aw=pondn], line(183450) h pgr fgt3 /*all population*/
poverty pcexp73 [aw=pondn]if coffe==1 & pcexp73>0, line(183450) h pgr fgt3 /*coffee producers*/

gen t3=0.3*p
gen t2=0.2*p
gen t1=0.1*p

sum t1 t2 t3 if p>0

log off

capture log close
exit


