/*===============================================================================

                         	 CI: Poverty Assessment
                       
				               Gaston Gohou
                                         January 2005

THis code evaluates the impact on household welfare when the coffee price changes.

 ================================================================================= */

version 8.0
clear all
capture log close
log using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\logfiles\civ02_coffee_qpaper.txt", replace text 
set more off
set mem 64m
set matsize 800
log on 

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta", clear

keep idmen pond strate pauv pchhexp hhexp rururb hhsize coffee coffq coffqs cofprice cofrev 

gen pondn= pond * hhsize 
svyset [pweight=pondn], strata(strate) psu(idmen)

ren coffee coffe
sort idmen 

/* population distribution by quintile*/
sort pchhexp
xtile quint2= pchhexp [pweight=pondn], nq(5)
xtile decile= pchhexp [pweight=pondn], nq(10)


ren pchhexp pcexp
ren cofrev revcof

/*gen pcexp=exp/(hhsize*pindex)*/

gen pccof=revcof/(hhsize)
gen byte poor = pcexp <=359840/2 ///relative poverty line: poverty line is half of the mean pcexp
/* For CI, the pc mean income is CFAF444021, but I used the value in Quentin paper CFAF 359840*/

sum poor [w=pondn]
sum poor [w=pondn] if pccof~=0 & pccof~=.

sum pcexp [w=pondn] /*359840.1*/
sum pcexp [w=pondn] if pccof~=0 & pccof~=.
sum pccof [w=pondn] if pccof~=0 & pccof~=. 
sum pcexp [w=pondn] if pccof~=0 & poor==1 & pccof~=.
sum pccof [w=pondn] if pccof~=0 & poor==1 & pccof~=. 

gen p=292.7
gen q=pccof/p
gen DvarP=5243.3-3258

gen ratio=q/pcexp
sum ratio if revcof~=0, detail

gen rho=1
gen DMinP=0.5*rho*(q/pcexp)*DvarP
sum DMinP if revcof~=0  & pccof~=. [w=pondn], detail
sum DMinP if revcof~=0 & poor==1 & pccof~=. [w=pondn], detail
/*lowess DMinP pcexp if revcof~=0*/

replace rho=2
replace DMinP=0.5*rho*(q/pcexp)*DvarP
sum DMinP if revcof~=0 [w=pondn], detail
sum DMinP if revcof~=0 & poor==1  [w=pondn], detail
/*lowess DMinP pcexp if revcof~=0*/

replace rho=4
replace DMinP=0.5*rho*(q/pcexp)*DvarP
sum DMinP if revcof~=0 [w=pondn], detail
sum DMinP if revcof~=0 & poor==1  [w=pondn], detail
/*lowess DMinP pcexp if revcof~=0*/

replace rho=8
replace DMinP=0.5*rho*(q/pcexp)*DvarP
sum DMinP if revcof~=0 [w=pondn], detail
sum DMinP if revcof~=0 & poor==1  [w=pondn], detail
/*lowess DMinP pcexp if revcof~=0*/

replace rho=12
replace DMinP=0.5*rho*(q/pcexp)*DvarP
sum DMinP if revcof~=0 [w=pondn], detail
sum DMinP if revcof~=0 & poor==1  [w=pondn], detail
/*lowess DMinP pcexp if revcof~=0*/

replace rho=16
replace DMinP=0.5*rho*(q/pcexp)*DvarP
sum DMinP if revcof~=0 [w=pondn], detail
sum DMinP if revcof~=0 & poor==1  [w=pondn], detail
/*lowess DMinP pcexp if revcof~=0*/

replace rho=20
replace DMinP=0.5*rho*(q/pcexp)*DvarP
sum DMinP if revcof~=0 [w=pondn], detail
sum DMinP if revcof~=0 & poor==1  [w=pondn], detail
/*lowess DMinP pcexp if revcof~=0*/

* with rho=12 and various changes in prices, impact on poverty

keep if pccof~=0 & pccof~=.

gen pcexp00 = pcexp + 0*q/hhsize-0.5*12*(q/hhsize)^2/pcexp*DvarP
gen pcexp10 = pcexp + 10*q/hhsize-0.5*12*(q/hhsize)^2/pcexp*DvarP
gen pcexp20 = pcexp + 20*q/hhsize-0.5*12*(q/hhsize)^2/pcexp*DvarP
gen pcexp30 = pcexp + 30*q/hhsize-0.5*12*(q/hhsize)^2/pcexp*DvarP
gen pcexp40 = pcexp + 40*q/hhsize-0.5*12*(q/hhsize)^2/pcexp*DvarP
gen pcexp50 = pcexp + 50*q/hhsize-0.5*12*(q/hhsize)^2/pcexp*DvarP








save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\civ02_coffee_qpaper.dta", replace




log off

capture log close
exit


