/* ========================================================
		COte d'Ivoire: Poverty line 2002
				G. Gohou
			    Febuary 2003
			(updated August 2004)


This program (ci_pov_line.do) estimates the 2002 poverty line for CI using the hh survey.
The different steps are:
1. Determination of a good basket
2. Determination of the price of the goods in the basket
3. Conversion to the monetary HH consumption into calories
4. Food poverty line estimation
5.Extreme and normal poverty line

==========================================================*/

version 7.0
clear
capture log close
set more off
set mem 100m
set matsize 800


/*cd "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata"*/
log using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\logfiles\ci_pl_res.log", replace 

/*1. Determination of a good basket
THe basket of goods is calculated usong the following method:
(i) estimate the consumption of each good per hh; (ii)agregate this consumption per good and 
per decile (all, dec 2-6, dec3-8); (iii) order the goods from the most consumed to the least
one and keep the goods that represent 80% of the total HH consumption
*/

/* (i) ===Basket goods part 1 (sect 8G) ====*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\sect08g.dta", clear

/* generate hh id*/
generate grappen = real(grappe)
drop grappe 
generate menordn = real(menord)
drop menord
gen idmen = grappen*100 + menordn
drop grappen menordn  

/* */
ren  s8gq1a goods
label var goods "Goods consume by the HH"
drop if goods ==.
ren  s8gq1b consume
lab define yesno 1 yes 2 no
lab value consume yesno

/* cleaning the data*/
recode consume 3 5 6 =.
drop if consume==.
drop if consume==2 /*drop all goods not consumed*/

/*replace s8gq5=s8gq4*4 if (s8gq5<s8gq4 & s8gq4~=.)*/
replace s8gq4=s8gq5/4 if (s8gq4==. & (s8gq5>=100 & s8gq5<=25000)) 
/*rule out case where expenditure for one item is more than CFAF 25000 a month*/
drop s8gq5

/*Daily consumption from market */
recode s8gq4 .=0
gen markcons = s8gq4/7
label var markcons "daily consumption from market"

/*daily autoconsumption*/
gen autocons=s8gq10  
label var autocons "daily auto consumption"

/*rule out the outliers where daily autoconsumption is more than CFAF 500
This enables us to obtain a mean of market consumption higher than those of autoconsumption*/
replace autocons=0 if autocons >500 |autocons<5

/*daily consumption*/
recode markcons .=0
recode autocons .=0
gen consumption = markcons + autocons
recode consumption 0=. /*missing data if total consumption value is zero*/
lab var consumption  "daily comsumption"

keep if consumption  ~=.

/*daily Quantity consumed*/
gen quantity=s8gq3a/30 
ren s8gq3b unit
recode unit 5 6 7 8 12 16 20 28 50 = 0
drop if unit==0

keep idmen goods consumption quantity unit  markcons autocons
order  idmen goods consumption quantity unit  markcons autocons
sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta", replace


/*===Basket goods part 2 (sect 8H) ====*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\sect08h.dta", clear

/* generate hh id*/
generate grappen = real(grappe)
drop grappe 
generate menordn = real(menord)
drop menord
gen idmen = grappen*100 + menordn
drop grappen menordn 

/* */
ren s8hq1a goods
label var goods "Goods consume by the HH"
drop if goods ==.
drop if goods==99
ren  s8hq1b consume
lab define yesno 1 yes 2 no
lab value consume yesno

/* cleaning the data*/
recode consume 8 9 =.
drop if consume==.
drop if consume==2 /*drop all the observations with no consumption*/
drop consume

replace s8hq4=s8hq5/4 if (s8hq4==. & (s8hq5>=100 & s8hq5<=25000)) 
/*rule out case where expenditure for one item is more than CFAF 25000 a month*/
drop s8hq5

/*daily consumption (no autoconsumption)*/
recode s8hq4 .=0
gen consumption = s8hq4/7
recode consumption 0=. /*missing data if total consumption value is zero*/
lab var consumption  "daily comsumption"

keep if consumption  ~=.

/*daily Quantity consumed*/
gen quantity=s8hq3a/30
ren s8hq3b unit
drop if unit==.

keep idmen goods consumption quantity unit
order  idmen goods consumption quantity unit
sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp2.dta", replace

append  using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta"
replace consumption= -consumption if consumption<0
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta", replace

/*=== Adding decile number===*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\pauvre.dta", clear
keep  grappe menord hhsize pond _region_ milieu strate pchhexp 

generate grappen = real(grappe)
drop grappe 
generate menordn = real(menord)
drop menord
gen idmen = grappen*100 + menordn
drop grappen menordn 

encode _region_, generate(region)

svyset strata strate
svyset psu idmen
svyset pweight pond
gen pondn = pond*hhsize

/* population distribution by decile*/
sort pchhexp
xtile decile = pchhexp [pweight=pondn], nq(10)
keep  idmen decile  strate milieu region pond hhsize pondn pchhexp 
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\decile.dta", replace

/*= Add decile into the consumption data set==*/

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta", clear
merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\decile.dta"
keep if _merge==3
drop _merge

save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\hhcons.dta", replace

/*===Reference population for the determination of the national reference basket of goods=====*/

/* Total daily consumption for all hh*/
collapse (sum) consumption [aweight=pond] , by(goods) fast
ren consumption cons_t
sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta", replace

/* Total daily consumption for decile 2 to 6 for hh*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\hhcons.dta", clear
keep if (decile >=2 & decile<=6)
collapse (sum) consumption [aweight=pond] , by(goods) fast
ren consumption cons2_6
sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta", replace

merge goods using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta"
drop _merge
sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta", replace

/* Total daily consumption for decile 3 to 8 for hh*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\hhcons.dta", clear
keep if (decile >=3 & decile<=8)
collapse (sum) consumption [aweight=pond] , by(goods) fast
ren consumption cons3_8
sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta", replace

merge goods using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta"
drop _merge
sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta", replace

/*Adding the name of the goods*/
insheet using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\basket.txt", clear
sort goods
merge goods using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta"
drop _merge
sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta", replace

/*(iii) Consumption share when considering all the hh
Keep the goods which represent 80% of the HH consumption*/
drop  cons2_6 cons3_8
egen total=sum(cons_t)
gen share_t=cons_t/total
sort share_t
gen cumpi_t=sum(share_t)
sort share_t
keep if cumpi_t>=0.20
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket_all.dta", replace
outsheet using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket_all.txt", replace

/*Consumption share when considering the decile 2 to 6
Keep the goods which represent 80% of the HH consumption*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta", replace
drop  cons_t cons3_8
egen total_2=sum(cons2_6)
gen share2_6=cons2_6/total_2
sort share2_6
gen cumpi2_6=sum(share2_6)
sort share2_6
keep if cumpi2_6>=0.20
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket2_6.dta", replace
outsheet using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket2_6.txt", replace

/*Consumption share when considering the decile 3 to 8
Keep the goods which represent 80% of the HH consumption*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket.dta", replace
drop  cons2_6 cons_t
egen total_3=sum(cons3_8)
gen share3_8=cons3_8/total_3
sort share3_8
gen cumpi3_8=sum(share3_8)
sort share3_8
keep if cumpi3_8>=0.20
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket3_8.dta", replace
outsheet using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\basket3_8.txt", replace


/* For the urban and rural poverty line, I used the same basket of goods
Same goods and same average quantity*/
/*The reference basket of goods are goods representing 80% of the consumption of the ref. pop.
THe next step is to calculate the hh mean consumption of each of these goods*/

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\hhcons.dta", clear
# delimit ;
drop if goods==3; drop if (goods>6 & goods<15); drop if goods==22; drop if goods==26;
drop if (goods>27 & goods<31); drop if goods==32; drop if (goods>33 & goods<56);
drop if (goods>56 & goods<59); drop if goods==63; drop if (goods>67 & goods<73);
drop if (goods>73 & goods<85) ; drop if (goods>86 );
# delimit cr

/*
label define lab 1 rlc 2 rip 4 crn 5 crs 6 crp 15 yam 16 csv 17 atk 18 csp 19 pcl 20 gar 21 ptt 23 bnn /*
	*/ 24 pnt 25 pnb 27 plm 31 aub 33 okr 56 mng 59 bef 60 chp 61 prc 62 chk 64 fsh 65 fss 66 snl  /*
	*/ 67 jgm 73 brd 85 oil 86 sgr
label value goods lab


decode goods , gen(goods_n)
label var goods_n "short name"
*/


/*2. Goods' price: This section computes the unit price of each good in the basket
For each good in the basket, calculate the unit price. If it's not possible to that,
inpute the unit price by using the mediane price for all the hhouseholds where it is available
*/

gen quant=.
/*===1. Local rice===*/
drop if (goods==1 & (unit==1|unit==4|unit==.))
replace quant=quantity/1000 if (goods==1 & unit==2)
replace quant=quantity if (goods==1 & unit==3)
recode unit 2=3 if (goods==1)

/*===2. imported rice===*/
drop if (goods==2 & (unit==1|unit==4|unit==.))
replace quant=quantity/1000 if (goods==2 & unit==2)
replace quant=quantity if (goods==2 & unit==3)
recode unit 2=3 if (goods==2)


/*
drop if (goods==2 & (unit==1|unit==.))
replace quant=quantity/1000 if (goods==2 & unit==2)
replace quant=quantity if (goods==2 & unit==3)
recode unit 2=3 if (goods==2)
gen rip_pr=.
replace rip_pr=consumption/ quantity if (goods==2 & unit==3)
gen rip_price=.
qui sum  rip_pr if rip_pr<500, detail
replace rip_price=r(p50) if (goods==2 & unit==4) /*imput median price for goods without unit*/
replace rip_price=rip_pr if (goods==2 & unit==3)
replace quant=consumption/rip_price if (goods==2 & (unit==3|unit==4))
recode unit 4=3 if goods==2
drop rip_price rip_pr
*/

/*==corn, seed corn and powder corn=*/
local xxxx "crn crs crp csp"
foreach var of local xxxx {
		drop if (goods_n=="`var'" & (unit==2|unit==1|unit==.))
		gen `var'_pr=.
		replace `var'_pr=consumption/ quantity if (goods_n=="`var'" & unit==3)
		gen `var'_price=.
		qui sum  `var'_pr if `var'_pr<300, detail
		replace `var'_price=r(p50) if (goods_n=="`var'" & unit==4) /*imput median price for goods without unit*/
		replace `var'_price=`var'_pr if (goods_n=="`var'" & unit==3)
		replace quant=consumption/`var'_price if (goods_n=="`var'" & (unit==3|unit==4))
		recode unit 4=3 if goods_n=="`var'"
		drop `var'_price `var'_pr
		/*replace quant=quantity if (goods_n=="`var'" & (unit==3))*/
		}

/*===85. oil===*/
drop if (goods==85 & (unit==2|unit==3|unit==.))

gen corn_pr=.
replace corn_pr=consumption/ quantity if (goods==85 & unit==1)
gen corn_price=.
qui sum  corn_pr if corn_pr<800, detail
replace corn_price=r(p50) if (goods==85 & unit==4) /*imput median price for goods without unit*/
replace corn_price=corn_pr if (goods==85 & unit==1)
replace quant=consumption/corn_price if (goods==85 & (unit==1|unit==4))
recode unit 4=1 if goods==85
drop corn_price corn_pr
/*replace quant=quantity if (goods==85 & (unit==1))*/


/*===86. sgr===*/
drop if (goods==86 & (unit==2|unit==1|unit==.))
gen corn_pr=.
replace corn_pr=consumption/ quantity if (goods==86 & unit==3)
gen corn_price=.
qui sum  corn_pr if corn_pr<800, detail
replace corn_price=r(p50) if (goods==86 & unit==4) /*imput median price for goods without unit*/
replace corn_price=corn_pr if (goods==86 & unit==3)
replace quant=consumption/corn_price if (goods==86 & (unit==3|unit==4))
recode unit 4=3 if goods==86
drop corn_price corn_pr
/*
replace quant=quantity if (goods==86 & (unit==3))
*/

/*=roots=*/
local x "yam atk csv pcl gar ptt bnn pnt pnb plm aub okr mng brd"
foreach var of local x {
		drop if (goods_n=="`var'" & (unit==2|unit==1|unit==.))
		gen `var'_pr=.
		replace `var'_pr=consumption/ quantity if (goods_n=="`var'" & unit==3)
		gen `var'_price=.
		qui sum  `var'_pr if `var'_pr<600, detail
		replace `var'_price=r(p50) if (goods_n=="`var'" & unit==4) /*imput median price for goods without unit*/
		replace `var'_price=`var'_pr if (goods_n=="`var'" & unit==3)
		replace quant=consumption/`var'_price if (goods_n=="`var'" & (unit==3|unit==4))
		recode unit 4=3 if goods_n=="`var'"
		drop `var'_price `var'_pr
		/*replace quant=quantity if (goods==86 & (unit==3))*/
		}

/*==meat and fish==*/
local xx " bef chp prc chk fsh fss snl jgm "
foreach var of local xx {
		drop if (goods_n=="`var'" & (unit==2|unit==1|unit==.))
		
		gen `var'_pr=.
		replace `var'_pr=consumption/ quantity if (goods_n=="`var'" & unit==3)
		gen `var'_price=.
		qui sum  `var'_pr if `var'_pr<500, detail
		replace `var'_price=r(p50) if (goods_n=="`var'" & unit==4) /*imput median price for goods without unit*/
		replace `var'_price=`var'_pr if (goods_n=="`var'" & unit==3)
		replace quant=consumption/`var'_price if (goods_n=="`var'" & (unit==3|unit==4))
		recode unit 4=3 if goods_n=="`var'"
		drop `var'_price `var'_pr
		/*replace quant=quantity if (goods_n=="`var'" & (unit==3))*/
		}

/*Use the hh in the decile 2 to 6*/
keep if (decile>=2 & decile <=6)

gen pc_cons=consumption /hhsize
lab var pc_cons "daily consumption per capita"
gen pc_quant=quant /hhsize
lab var pc_quant "daily quantity consumed per capita"

gen pc_quant_av=.
lab var pc_quant_av "Average daily quantity consumed per capita per goods"

/*Average quantity consumed for oil*/
means  pc_quant [aweight=pondn] if (unit==1 & goods_n=="oil")
gen oil_q = r(mean)
replace pc_quant_av=oil_q if goods_n=="oil"

/*Average unit price for the other 24 goods*/
local list "rlc rip crn crs crp yam csv atk csp pcl gar ptt bnn pnt pnb plm aub okr mng bef chp prc chk fsh fss snl jgm brd sgr"
/*looping procedure*/
foreach var of local list {
		qui means  pc_quant [aweight=pondn] if (unit==3 & goods_n=="`var'")
		gen `var'_q = r(mean)
		replace pc_quant_av=`var'_q if goods_n=="`var'"
		}

/* 3. Conver consumption into calories
Calories include in 1 kg of foods item*/

gen coef =0
#delimit ;
replace coef=1160	if goods_n=="rlc" ;replace coef=1160 if goods_n=="rip"; replace coef=1920 if goods_n=="crn";
replace coef=3560	if goods_n=="crs"; replace coef=3680 if goods_n=="crp"; replace coef=1020	if goods_n=="yam";
replace coef=1460	if goods_n=="csv"; replace coef=1960 if goods_n=="atk"; replace coef=3540	if goods_n=="csp"; 
replace coef=1670	if goods_n=="pcl";replace coef=1960	if goods_n=="gar"; replace coef=1730	if goods_n=="ptt"; 
replace coef=1050	if goods_n=="bnn"; replace coef=5850 if goods_n=="pnt"; replace coef=5850	if goods_n=="pnb"; 
replace coef=5440	if goods_n=="plm"; replace coef=180	if goods_n=="aub";replace coef=360	if goods_n=="okr"; 
replace coef=640	if goods_n=="mng"; replace coef=2496 if goods_n=="bef"; replace coef=2480	if goods_n=="chp"; 
replace coef=2896	if goods_n=="prc"; replace coef=1496 if goods_n=="chk"; replace coef=768	if goods_n=="fsh";
replace coef=2240	if goods_n=="fss"; replace coef=1240 if goods_n=="snl"; replace coef=1430	if goods_n=="jgm"; 
replace coef=2495	if goods_n=="brd"; replace coef=8840 if goods_n=="oil"; replace coef=3850	if goods_n=="sgr";
# delimit cr

save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\hhcons2.dta", replace


/* =========================================
National Poverty line AND DECILE 2 AND 6 
=======================================================*/

/*Per capita daily consumption in calorie
using the unit price, transform the monetary consumption into quantity and
then into calories using the coversion coeficient
*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\hhcons2.dta", clear
/*keep if milieu==1*/
keep if (decile>=2 & decile <=6)

gen price=.
lab var price "Average price"
gen pccons=.
lab var pccons "Average consumption per capita per goods"

/*Average Unit price and value of consumption for oil*/
qui means  pc_cons [aweight=pondn] if (unit==1 & goods_n=="oil")
gen oil_c = r(mean)
replace pccons =oil_c if goods_n=="oil"
gen oil_p=oil_c/oil_q
replace price=oil_p if goods_n=="oil"
drop oil_c oil_q oil_p


/*Average unit price for the other 24 goods*/
local list "rlc rip crn crs crp yam csv atk csp pcl gar ptt bnn pnt pnb plm aub okr mng bef chp prc chk fsh fss snl jgm brd sgr"

/*looping procedure*/
foreach var of local list {
		qui means  pc_cons [aweight=pondn] if (unit==3 & goods_n=="`var'")
		gen `var'_c = r(mean)
		replace pccons=`var'_c if goods_n=="`var'"

		gen `var'_p=`var'_c/`var'_q
		replace price=`var'_p if goods_n=="`var'"
		drop `var'_c `var'_q `var'_p
		}

collapse (mean) pc_quant_av pccons coef (median) price, by (goods) fast

order goods pc_quant_av price  pccons coef 
 
/*Total annual calorie in the average basket*/
gen calo = pc_quant_av*coef
egen total=sum(calo)
gen adjust = 2400/total


gen calo_adj = calo*adjust
gen pc_quant_adj = calo_adj / coef
gen pc_cons_adj = pc_quant_adj * price

/*4.  Food poverty line
Using the basket of goods, calculate the average consumption of good in calorie
and scale it to get the 2400 calorie. Using the unit price estimate the money value of the average
This will be the food poverty line
*/
egen pl=sum(pc_cons_adj)
scalar pln=pl in 1

sort goods
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta", replace


/*====================
5. Urban poverty line
	(i)  Extreme poverty line
	(ii) poverty line

WIth the food poverty line known, the non food poverty line is the last element we need to get the poverty line.
For each HH, the food and non food consumption are known. Using them, I made 2 groups of HH. 
One for which the total per capita consumption is in the interval (0.9* Pov_line food; 1.1*Pov_line) and the 
the second for which the total per capita food consumption is in the interval (0.9* Pov_line food; 1.1*Pov_line).

The extreme poverty line is obtianed by adding the food poverty line to the average non food consumption of group 1
The normal poverty line is obtained   by adding the food poverty line to the average non food consumption of group 2
============================*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\hhexp.dta", clear
keep grappe menord food hhexp
generate grappen = real(grappe)
drop grappe 
generate menordn = real(menord)
drop menord
gen idmen = grappen*100 + menordn
drop grappen menordn  
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta", replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\pauvre.dta", clear
keep grappe menord  pchhexp hhsize milieu strate pond
keep if milieu==1  /* Urban pop only*/
generate grappen = real(grappe)
drop grappe 
generate menordn = real(menord)
drop menord
gen idmen = grappen*100 + menordn
drop grappen menordn  

sort idmen
merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta"
keep if _merge==3
drop _merge

gen pcfood = food/hhsize
gen pcnfood = pchhexp-pcfood

/*gen pcnfood = (hhexp-food)/hhsize
gen pchhexp=hhexp/hhsize
*/
svyset strata strate
svyset psu idmen
svyset pweight pond
gen pondn = pond*hhsize

/* population distribution by decile*/
sort pchhexp
xtile decile = pchhexp [pweight=pondn], nq(10)
/*keep  idmen decile  strate milieu pond hhsize pondn*/
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\decile.dta", replace

keep if decile>=2 & decile <=6

scalar pl_food=pln*365 /*annual food poverty line; urban*/
gen pl_f = cond(pcfood >= (0.9*pl_food) & pcfood <=(1.1*pl_food), 1,0)
gen pl_x = cond(pchhexp>= (0.9*pl_food) & pchhexp<=(1.1*pl_food), 1,0)

/* urban PL*/
qui sum pcnfood [aweight=pondn] if pl_f==1
gen pl_nf = r(mean)
gen pl = pl_food + pl_nf
lab var pl "poverty line urban"

/* Extreme PL*/
qui sum pcnfood [aweight=pondn] if pl_x==1
gen pl_nf_x = r(mean)
gen pl_n_x = pl_food + pl_nf_x
lab var pl_n_x "Extreme Poverty line urban"
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\n_pl.dta", replace


/*==========
Calculation of the total rural poverty line
=========================*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\hhexp.dta", clear
keep grappe menord food hhexp
generate grappen = real(grappe)
drop grappe 
generate menordn = real(menord)
drop menord
gen idmen = grappen*100 + menordn
drop grappen menordn  
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta", replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\pauvre.dta", clear
keep grappe menord /*pchhexp*/ hhsize milieu strate pond
keep if milieu==2  /* rural pop only*/
generate grappen = real(grappe)
drop grappe 
generate menordn = real(menord)
drop menord
gen idmen = grappen*100 + menordn
drop grappen menordn  

sort idmen
merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\tmp1.dta"
keep if _merge==3
drop _merge

gen pcfood = food/hhsize
/*gen pcnfood = pchhexp-pcfood*/
gen pcnfood = (hhexp-food)/hhsize
gen pchhexp=hhexp/hhsize


svyset strata strate
svyset psu idmen
svyset pweight pond
gen pondn = pond*hhsize

/* population distribution by decile*/
sort pchhexp
xtile decile = pchhexp [pweight=pondn], nq(10)
/*keep  idmen decile  strate milieu pond hhsize pondn*/
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\decile.dta", replace

keep if decile>=2 & decile <=6

scalar pl_food_r=pln*365 /*annual food poverty line; urban*/
gen pl_f = cond(pcfood >= (0.9*pl_food_r) & pcfood <=(1.1*pl_food_r), 1,0)
gen pl_x = cond(pchhexp>= (0.9*pl_food_r) & pchhexp<=(1.1*pl_food_r), 1,0)

/* PL*/
qui sum pcnfood [aweight=pondn] if pl_f==1
gen pl_nf_r = r(mean)
gen pl_rur= pl_food_r + pl_nf_r
lab var pl_rur "poverty line urban"

/* Extreme PL*/
qui sum pcnfood [aweight=pondn] if pl_x==1
gen pl_nf_r_x = r(mean)
gen pl_rur_x = pl_food_r + pl_nf_r_x
lab var pl_rur_x "extreme Poverty line rural"
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\rural_pl.dta", replace

merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\datafiles\urban_pl.dta"

/*==================================================
================================================*/
/*poverty ratio etimation*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\data\stata\pauvre.dta", clear
keep grappe menord hhsize _region_ pond strate pchhexp pauv milieu
generate grappen = real(grappe)
drop grappe 
generate menordn = real(menord)
drop menord
gen idmen = grappen*100 + menordn
drop grappen menordn

gen pl_u=239463
gen pl_r=204679

gen pauv_u=cond(pchhexp<=pl_u, 1,0)  if milieu==1
gen pauv_r=cond(pchhexp<=pl_r, 1,0) if milieu==2 
gen pauv_t=cond(pauv_u==1 |pauv_r==1,1,0)

svyset strata strate
svyset psu idmen
svyset pweight pond
gen pondn=pond*hhsize
svyset pweight pondn

encode _region_, generate(region)

svytab region pauv_u, percent
svytab region pauv_r, percent
svytab region pauv_t, percent

recode pauv .=0
svytab region pauv, percent
svytab region pauv if milieu==1, percent
svytab region pauv if milieu==2, percent
*/

