/*===============================================================================

                         	  CI: Poverty Assessment
                                         
                                        Gaston Gohou
                                         January 2004

  ================================================================================= */

version 7.0
clear
capture log close
log using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\program\civ02_pa_res.txt", replace text 
set more off
set mem 32m
set matsize 800

cd "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata"

use pauvre.dta,  replace
/*use "g:\stata\pauvre.dta",  replace*/
keep grappe menord hhsize sexhead agehead csphead pchhexp hhexp _region_ _milieu_ strate pond  pauv 
rename _region_ reg
rename _milieu_ rururb
generate grappen = real(grappe)
generate menordn = real(menord)

gen idmen = grappen*100 + menordn

recode pauv .=0
label define  pauvl 1 poor 0 nopoor
label value pauv pauvl
  
order idmen pond  pauv pchhexp hhexp reg rururb hhsize sexhead agehead csphead   strate grappe menord  grappen menordn 
sort idmen
save civ_pa.dta,  replace
/*save "g:\stata\civ_pa.dta",  replace*/

/*adding head of HH characteristics*/
use sect01.dta,  clear

keep grappe menord s1q2 s1q7 s1q8 s1q9 s1q27 s1q30 s1q32
keep if s1q2==1

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn

drop grappe menord  grappen menordn

generate married = cond(s1q7==1,1,0) 
label define marrl 1 married 0 not_marr 
label value married marrl 

rename s1q8 ethnic
recode ethnic 4=3 5=4 6/10=5
label define ethl 1 akan 2 krou 3 mande 4 volta 5 african
label value ethnic ethl

rename s1q9 relig
recode relig 1/3=1 4=2 5/7=3
label define religl 1 christian 2 muslim 3 no_relig
label value relig religl

generate read = cond(s1q27<=2, 1, 0)
lab var read "reading skill"

generate school = cond(s1q30==1, 1, 0)
lab define sch 1 school  0 no_school
label value school sch
sort idmen

rename s1q32 degree
recode degree  2/4=2 5/10=3 11/18=4 .=1
label define dgel 1 no_degree 2 highsch 3 university 4 tech  
label value degree dgel

sort idmen
save tmp1.dta, replace

merge idmen using civ_pa.dta

drop s1q2 s1q7 s1q27 s1q30 _merge

order idmen pond  strate pauv pchhexp hhexp reg rururb hhsize sexhead agehead csphead school ethnic read married /*
	*/ relig grappe menord  grappen menordn 
drop csphead
sort idmen
save civ_pa.dta,  replace


/*==============================
/*adding domestic labor*/
=============================*/

use sect01.dta,  clear

keep grappe menord s1q2 s1q6a 

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn

drop grappe menord  grappen menordn

generate kid = cond(s1q6<15 & s1q6>5,1,0) 
label define kidl 1 kid 0 not_kid 
label value kid kidl

generate adult = cond(s1q6>15 & s1q6<70,1,0) 
label define adultl 1 adult 0 not_adult 
label value adult adultl

collapse (sum) kid adult, by (idmen) fast

/* domestic labor force*/
gen dlabor = adult+ (0.5)*kid
gen ldlabor=ln(dlabor)
drop dlabor

sort idmen
save tmp1.dta, replace

merge idmen using civ_pa.dta

drop kid adult _merge
sort idmen
save civ_pa.dta,  replace


/*=============================*/
use sect02.dta, clear

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

keep idmen s1q2 s2q16b
keep if s1q2==1
drop s1q2

rename s2q16b csphead

recode csphead 1/7=1 8/13=2 14/15=3 16/20=4  *=5
label define cspl  1 civ_serv 2 handyman 3 independent 4 agriculture 5 nojob
label value csphead cspl

sort idmen
save tmp1.dta,  replace

use civ_pa.dta,  clear

sort idmen
merge idmen using tmp1.dta


recode csphead .=5
drop _merge
gen lagehead=ln(agehead)

gen agehdsq=agehead*agehead
gen lagehdsq=ln(agehead)

encode reg, gen(regn)
encode rururb, gen(rururbn)

tabulate degree, generate (degree)
tabulate ethnic, generate (ethnic)
tabulate relig, generate (relig)
tabulate rururbn, generate (rururbn)
tabulate regn, generate (regn)

sort grappen
save civ_pa.dta,  replace

/* insert rainfall for each city*/

insheet using grappcityrain.txt, clear
ren grappe grappen
sort grappen

save tmp1.dta, replace

merge grappen using civ_pa.dta
drop _merge
gen lrainav=ln(rain)
sort idmen
save civ_pa.dta,  replace


/*==================================*/
insheet using sect03b2_v3.txt,  clear
recode s3b2q1 0=.

gen idmen = grappe*100 + menord
label define s3b2q1l 1 acard 2 pinaple 3 peanut 4 auberg 5 avogad  6 bana  7 plantain 8 coffee 9 cocoa 10 /* 
	*/ carot 11 choux 12 lemon 13 citroul 14 coco 15 concmb 16 cotton 17 courg 18 fonio 19 ocra 20 goyv 21 /*
	*/  bean 22 rubber 23 yam 24 corn 25 mandrn 26 mango 27 cassava 28 mil 29 onion 30 orange  31 palm 32 /* 
	*/  grapp 33 papaya  34 spott 35 pott 36 pepper 37 wpeppr 38 rice 39 salad 40 sorgho 41 taro 42 tomato 43 other
label value s3b2q1 s3b2q1l

decode s3b2q1, gen(product)
label var product "Production Name"
save tmp2.dta,  replace

/*
bana  plantain carot  avogad   peanut  choux lemon concmb bean coco citroul rubber  courg fonio goyv mandrn mango mil grapp papaya  pott spott taro wpeppr salad sorgho other 
*/ 

local indvar " acard  pinaple auberg coffee cocoa cotton ocra yam corn cassava onion orange  palm pepper rice tomato "
/*looping procedure*/

foreach var of local indvar {
		use tmp2.dta, clear
		gen `var'=cond(product=="`var'",1,0)

		keep if product=="`var'"
		
		rename s3b2q3a `var'qp
		lab var `var'qp "quantity of `var' produced"
		
		rename s3b2q3b `var'qpu
		recode `var'qpu 2=1
		lab var `var'qpu "unit of quantity of `var' produced"

		rename s3b2q4 `var'sold
		recode `var'sold 2=0
		lab var `var'sold "production `var' sold yesno"
		label define `var'soldl 1 yes 0 no
		label value `var'sold `var'soldl

		rename s3b2q6a `var'qs
		lab var `var'qs "quantity of `var' sold"

		rename s3b2q6b `var'qsu
		recode `var'qsu 2=1
		lab var `var'qsu "unit of quantity of `var' sold"

		/*Unit price of the production*/
		rename s3b2q7 `var'price
		lab var `var'price "unit price of `var'"
		
		/*take the average price if production not sold*/
		egen price`var'=sum(`var'price) if `var'price ~=. 
		gen n=cond(`var'price==., 0,1)
		egen ntot=sum(n) 
		gen price2`var'=(price`var')/ntot

		replace `var'price=price2`var' if `var'sold==0

		gen `var'rev2 = `var'price*`var'qs
		lab var `var'rev2 "total `var'  revenu  from Q and P"
		drop n ntot  

		rename s3b2q8 `var'rev
		lab var `var'rev "total `var' revenue"

		rename s3b2q9 `var'sduse
		recode `var'sduse 2=0
		lab var `var'sduse "use of `var' seed yesno"
		label define `var'sdusel 1 yes 0 no
		label value `var'sduse `var'sdusel

		rename s3b2q10a `var'sdq
		lab var `var'sdq "total `var' quatity"

		rename s3b2q10b `var'sdqu
		recode `var'sdqu 2=1
		lab var `var'sdqu "total `var' unit"

		rename s3b2q11 `var'py
		recode `var'py 2=0
		lab var `var'py "crop `var' previous year yesno"

		rename s3b2q12 `var'ev
		lab var `var'ev "`var' evolution"
		label define `var'evl 1 increase 2 decrease 3 same
		label value `var'ev `var'evl

		rename s3b2q13 `var'area
		label define `var'areal 1 increase 2 decrease 3 same
		label value `var'area `var'areal

		rename s3b2q15 `var'hire
		recode `var'hire 2=1 3=1 4=0
		label define `var'hirl 1 yes 0 no
		label value `var'hire `var'hirl

		rename s3b2q16 `var'hev
		label define `var'hevl  1 increase 2 decrease 3 same
		label value `var'hev `var'hevl

		rename s3b2q18 `var'fert
		recode `var'fert 2=0
		label define `var'fl 1 yes 0 no
		label value `var'fert `var'fl

		rename s3b2q19 `var'fertc
		lab var `var'fertc "`var'  fertilizer cost"

		rename s3b2q20 `var'ins
		recode `var'ins 2=0
		label define `var'il 1 yes 0 no
		label value `var'ins `var'il

		rename s3b2q21 `var'insc
		lab var `var'insc "`var' insecticide cost"

		rename s3b2q22 `var'gseed
		recode `var'gseed 2=0
		label define `var'gseedl 1 yes 0 no
		label value `var'gseed `var'gseedl

		rename s3b2q23 `var'gseedc
		lab var `var'gseedc "`var'global seed cost"

		keep idmen `var'  `var'qp  `var'qpu  `var'sold  `var'qs  `var'qsu  `var'price  `var'rev  `var'rev2 /* 
			*/ `var'sduse  `var'sdq  `var'sdqu `var'py  `var'ev  `var'area  `var'hire  `var'hev  `var'fert /*
			*/ `var'fertc  `var'ins  `var'insc  `var'gseed  `var'gseedc
		
		
		sort idmen
		save tmp1.dta,  replace

		collapse (sum) `var'qp  `var'qs  `var'rev  `var'rev2 `var'sdq   `var'fertc  `var'insc   (mean) `var'qpu   `var'qsu  `var'price  `var'ev  `var'area  `var'hev  (max) `var'sdqu  `var'sold  `var'sduse  `var'py  `var'hire  `var'fert   `var'ins  `var'gseed  `var'gseedc, by(idmen) fast
		
		replace `var'ev =int(`var'ev)
		replace `var'area =int(`var'area)
		replace `var'hev =int(`var'hev)

		gen l`var'rev=ln(`var'rev)
		gen l`var'rev2=ln(`var'rev2)
		gen l`var'qs=ln(`var'qs)
		gen l`var'sdq = ln(`var'sdq)
		gen l`var'fertc = ln(`var'fertc)
		gen l`var'insc = ln(`var'insc)
		gen l`var'gseedc = ln(`var'gseedc)

		sort idmen
		save tmp1.dta,  replace
		
		use civ_pa.dta,  clear
		
		sort idmen
		merge idmen using tmp1.dta 
		
		/*keep if _merge==3*/
		drop _merge

		sort idmen
		save civ_pa.dta,  replace

		svyset strata strate
		svyset psu idmen
		svyset pweight pond
		/*gen pondn = pond*hhsize
		svyset pweight pondn*/
		
 		#delimit ;
		 recode `var'qp .=0; recode `var'qpu .=0; recode l`var'qs .=0;
		recode `var'qs .=0; recode `var'qsu .=0; recode `var'price .=0; recode `var'rev .=0; recode `var'rev2 .=0; recode l`var'rev .=0;
		recode l`var'rev2 .=0; recode `var'sduse .=0; recode `var'sdq .=0;  recode l`var'qs .=0; recode l`var'sdq .=0; recode `var'sdqu .=0;
		recode `var'py .=0; recode `var'ev .=0; recode `var'area .=0; recode `var'hire .=0;
		recode `var'hev .=0; recode `var'fert .=0; recode `var'fertc .=0; recode l`var'fertc .=0;
		recode `var'ins .=0; recode `var'insc .=0; recode l`var'insc .=0;
		recode `var'gseed .=0; recode `var'gseedc .=0; recode l`var'gseedc .=0;
		#delimit cr
           
		gen `var'=cond(`var'qp~=0,1,0)

		save civ_pa.dta,  replace
		
		/*Creation dummy variables for the regression*/
		tabulate `var'area, generate (`var'area)
		tabulate `var'ev, generate (`var'ev)	
		tabulate `var'hev, generate (`var'hev)	

				
		svyreg l`var'rev  lagehead lagehdsq /*ethnic1-ethnic4*/  married /* school*/ read /*degree1-degree3  relig1-relig2*/ /*
			*/ ldlabor  /*rururbn1*/   regn1-regn10 lrainav /*lrainvar  lrainstdv */  `var'sduse  /*`var'py*/ /* 
			*/ `var'ev? `var'area? `var'hire `var'hev? /*`var'fert*/   l`var'fertc  /*`var'ins*/  l`var'insc /* 
			*/ /*`var'gseed*/  l`var'gseedc  if `var'qp~=0
		
		outreg using pf_`var'.xls, bdec(5) ctitle (" "`var'" producers") 3aster replace
		
		
		
		svyreg l`var'rev  lagehead lagehdsq  /*ethnic1-ethnic4*/  married /* school*/ read /*degree1-degree3  relig1-relig2*/ /*
			*/ ldlabor  /*rururbn1*/   regn1-regn10 lrainav /* lrainvar  lrainstdv */  `var'sduse  /*`var'py*/ /* 
			*/ `var'ev? `var'area? `var'hire `var'hev? /*`var'fert*/   l`var'fertc  /*`var'ins*/  l`var'insc /*
			*/ /*`var'gseed*/  l`var'gseedc  if `var'qp~=0
		
		outreg using pf_`var'.xls, bdec(5) ctitle (" "`var'" prod. w rev. calc.") 3aster  replace append
		
		drop  *`var'*  
}

/*Global Production function*/

#delimit ;
gen gprodrev=0; gen gprodrev2=0; gen gprosduse=0; gen gpropy=0; gen gprohire=0;
gen gprofert=0; gen gprofertc=0; gen gproins=0; gen gproinsc=0; gen gprogseed=0; gen gprogseedc=0;
#delimit cr

local indvar "pinaple  coffee cocoa cotton  corn   palm  rice"

/*looping procedure*/
foreach var of local indvar {
		replace gprodrev = `var'rev + gprodrev 
		replace gprodrev2 = `var'rev2 + gprodrev2 
		replace gprosduse =max(`var'sduse, gprosduse ) 
		replace gpropy =max(`var'py, gpropy ) 
		replace gprohire=max(`var'hire, gprohire)
		replace gprofert=max(`var'fert, gprofert)
		replace gprofertc= `var'fertc + gprofertc
		replace gproins=max(`var'ins, gproinsc)
		replace gproinsc= `var'insc + gproinsc
		replace gprogseed=max(`var'gseed, gprogseed)
		replace gprogseedc= `var'gseedc + gprogseedc
}

gen lgprodrev = ln(gprodrev )
gen lgprodrev2 =ln(gprodrev2 )
gen lgprofertc = ln(gprofertc)
gen lgproinsc =ln(gproinsc)
gen lgprogseedc=ln(gprogseedc)

recode lgprodrev .=0
recode lgprodrev2 .=0
recode lgprofertc .=0
recode lgproinsc .=0
recode lgprogseedc .=0


	svyreg lgprodrev  lagehead lagehdsq /*ethnic1-ethnic4*/  married /* school*/ read /*degree1-degree3  relig1-relig2*/  /*
		*/ ldlabor  /*rururbn1*/   regn1-regn10 lrainav /* lrainvar  lrainstdv */  gprosduse  /*gpropy*/ gprohire /*
		*/  /*gprofert*/   lgprofertc  /*gproins*/  lgproinsc /*gprogseed*/  lgprogseedc  if lgprodrev ~=0
		
	outreg using pf_gpro.xls, bdec(5) ctitle (" Global producers only") 3aster  replace
		
	svyreg lgprodrev   lagehead  /*ethnic1-ethnic4*/  married /* school*/ read /*degree1-degree3  relig1-relig2*/ /*
		*/ ldlabor  /*rururbn1*/   regn1-regn10 lrainav /* lrainvar lrainstdv */   gprosduse  /*gpropy*/ gprohire /*
		 */ /*gprofert*/   lgprofertc  /*gproins*/  lgproinsc /*gprogseed*/  lgprogseedc if lgprodrev2~=0
		
	outreg using pf_gpro.xls, bdec(5) ctitle (" Global producers w rev. calc.") 3aster  append replace
             



/*========================================================================*/
/* some settings for later regression and survey analysis*/
svyset strata strate
svyset psu idmen
svyset pweight pond

gen pondn = pond*hhsize

svyset pweight pondn

/* Poverty by region*/
svytab regn pauv, percent

/* Poverty by living area*/
svytab rururbn pauv, percent

capture log close
exit

