/*===============================================================================

                           Agricultural Policy and Rural Poverty: The CI case
                                         
                                        Gaston Gohou
                                         Decembre 2003
This code estimated the models used in my paper "Export tax and rural poverty; the case of CI"
Three models of export tax reduction are estimated: 
	(i) the reduction of 50% or 100% of the DUS
 	(ii) the second is based on Panagariya and Schiff (1990) based on elasticity change
	(iii) the last one is based on a concumption regression
  ================================================================================= */

version 7.0
clear
capture log close
log using "Q:\My Documents\AfrPRSP\Survey\CIV\EP2002\Data\STATA\logfiles\civ02_RurPov_res.txt", replace text 
set more off
set mem 32m
set matsize 800

log off

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\pauvre.dta",  replace
keep grappe menord hhsize sexhead agehead csphead pchhexp hhexp _region_ _milieu_ strate pond  pauv 
rename _region_ reg
rename _milieu_ rururb
generate grappen = real(grappe)
generate menordn = real(menord)

gen idmen = grappen*100 + menordn

replace pauv=0 if pauv==.
label define  pauvl 1 poor 0 nopoor
label value pauv pauvl
  
order idmen pond  pauv pchhexp hhexp reg rururb hhsize sexhead agehead csphead   strate grappe menord  grappen menordn 
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect01.dta",  clear
keep grappe menord s1q2 s1q7 s1q8 s1q9 s1q27 s1q30 s1q32
keep if s1q2==1

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn

drop grappe menord  grappen menordn

generate married = cond(s1q7==1,1,0) 
label define marrl 1 married 0 not_marr 
label value married marrl 

rename s1q8 ethnic
recode ethnic 4=3 5=4 6/10=5
label define ethl 1 akan 2 krou 3 mande 4 volta 5 african
label value ethnic ethl

rename s1q9 relig
recode relig 1/3=1 4=2 5/7=3
label define religl 1 christian 2 muslim 3 no_relig
label value relig religl

generate read = cond(s1q27<=2, 1, 0)
lab var read "reading skill"

generate school = cond(s1q30==1, 1, 0)
lab define sch 1 school  0 no_school
label value school sch
sort idmen

rename s1q32 degree
recode degree  2/4=2 5/10=3 11/18=4 .=1
label define dgel 1 no_degree 2 highsch 3 university 4 tech  
label value degree dgel

merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta"
drop s1q2 s1q7 s1q27 s1q30 _merge

order idmen pond  pauv pchhexp hhexp reg rururb hhsize sexhead agehead csphead   school ethnic read married relig grappe menord  grappen menordn 
drop csphead
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect02.dta", clear
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

keep idmen s1q2 s2q16b
keep if s1q2==1
drop s1q2

rename s2q16b csphead


recode csphead 1/7=1 8/13=2 14/16=3 17/20=4  *=5
label define cspl  1 civ_serv 2 handyman 3 independent 4 agriculture 5 nojob
label value csphead cspl

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\tmp1.dta",  replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  clear
sort idmen
merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\tmp1.dta"
recode csphead .=5
drop _merge

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  replace




/*Coffee variables
==================================================================*/
insheet using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect03b2_v3.txt",  clear

/*keep grappe menord s3b2q1 s3b2q3a s3b2q3b s3b2q7 s3b2q13 s3b2q15 */
gen idmen = grappe*100 + menord


keep if s3b2q1==9
rename s3b2q1 coffee
recode coffee 9=1

rename s3b2q3a coffq
recode s3b2q3b 2  4 =1
replace coffq=coffq*1000 if s3b2q3b==3
lab var coffq "quantity of coffee produced in kg"

rename s3b2q6a coffqs
recode s3b2q6b 2  4 =1 
replace coffqs=coffqs*1000 if s3b2q6b==3 
replace coffqs=coffq if (coffq>0 & coffqs<coffq)
lab var coffq "quantity sold  of coffee in kg"

rename s3b2q7 cofprice
replace cofprice=cofprice/1000 if cofprice>1000
lab var cofprice "unit price of one kg of coffee"

rename s3b2q8 cofrev
lab var cofrev "total coffee revenue"

rename s3b2q13 cofarea
label define cofareal 0 noarea 1 increase 2 decrease 3 same
label value cofarea cofareal

rename s3b2q15 cofhire
recode cofhire 2=1 3=1 4=0
label define cofhirl 1 yes 0 no
label value cofhire cofhirl

rename s3b2q18 coffert
recode coffert 2=0
label define coffl 1 yes 0 no
label value coffert coffl

rename s3b2q20 cofins
recode cofins 2=0
label define cofil 1 yes 0 no
label value cofins cofil

keep idmen coffee coffq coffqs cofprice cofrev cofarea cofhire coffert cofins
collapse (sum) coffq coffqs cofrev (mean) cofprice (max) cofarea cofhire coffert cofins coffee , by(idmen) fast

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\tmp1.dta",  replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  clear
sort idmen
merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\tmp1.dta"

/*keep if _merge==3*/
drop _merge

sort idmen
/*Data base with coffee producters characteristics*/
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  replace

/*Cocoa variables
==================================================================*/
insheet using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect03b2_v3.txt",  clear

gen idmen = grappe*100 + menord

keep if s3b2q1==8
rename s3b2q1 cocoa
recode cocoa 8=1

rename s3b2q3a cocq
recode s3b2q3b 2 4 = 1
replace cocq=cocq*1000 if s3b2q3b==3
lab var cocq "quantity of cocoa produced in kg"

rename s3b2q6a cocqs
recode s3b2q6b 2  4 =1 
replace cocqs=cocqs*1000 if s3b2q6b==3
replace cocqs=cocq if (cocq>0 & cocq>cocqs)
lab var cocqs "quantity sold  of cocoa in kg"

rename s3b2q7 cocprice
replace cocprice=cocprice/1000 if cocprice>1000
lab var cocprice "unit price of one kg of cocoa"

rename s3b2q8 cocrev
lab var cocrev "total coffee revenue"

rename s3b2q13 cocarea
label define cocareal 1 increase 2 decrease 3 same
label value cocarea cocareal

rename s3b2q15 cochire
recode cochire 2=1 3=1 4=0
label define cochirl 1 yes 0 no
label value cochire cochirl

rename s3b2q18 cocfert
recode cocfert 2=0
label define cocfl 1 yes 0 no
label value cocfert cocfl

rename s3b2q20 cocins
recode cocins 2=0
label define cocil 1 yes 0 no
label value cocins cocil

keep idmen cocoa cocq cocqs cocprice cocrev cocarea cochire cocfert cocins

collapse (sum) cocq cocqs cocrev (mean) cocprice (max) cocarea cochire cocfert cocins cocoa, by(idmen) fast

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\tmp1.dta",  replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  clear
sort idmen
merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\tmp1.dta"

/*keep if _merge==3*/
drop _merge

sort idmen
/*Data base with cocoa producters characteristics*/
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  replace

/*=============================================================================*/
/* Adding housing and equipment characteristics*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect07.dta",  clear
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

rename s7q2 ohouse
recode ohouse 5=1  2 3 4 6 7=0
label define ohousel 1 yes 0 no
label value ohouse ohousel

rename s7q4 thouse
recode thouse 2 3 4 =1  5 6 7 8=2
label define thousel 1 villa 2 barac
label value thouse thousel

rename s7q6 hroof
recode hroof 2 3  =1  4 5 6=2
label define hroofl 1 precary 2 tole
label value hroof hroofl

rename s7q8 nroom
recode nroom 15/70 = 14

rename s7q12 water
recode water 2 =1   3 4=2  5 6 7 = 3
label define waterl 1 potable 2 public 3 lake
label value water waterl

rename s7q15 elect
recode elect 2 3 4 =1  1 5=2
label define electl 1 elect 2 lamp
label value elect electl

rename s7q17 kitchen
recode kitchen  2 3 4 =1  5 6 7 8=2  9 10 11 12=3
label define kitchenl 1 wood 2 gas 3 oil
label value kitchen kitchenl

rename s7q23 phone
recode phone 2=0
label define phonel  1 yes 0 no
label value phone phonel

keep idmen ohouse thouse hroof nroom water elect kitchen phone
 
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\tmp1.dta",  replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  clear
sort idmen
merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\tmp1.dta"

/*keep if _merge==3*/
drop _merge

sort idmen

save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\datafiles\rurpov.dta",  replace


/*========================================================================*/
/* some settings for later regression and survey analysis*/
svyset strata strate
svyset psu idmen
svyset pweight pond

/*Total number of cocoa and coffee farmers (see 'population size' of the following command result 
svytab rururbn pauv if cocoa==1|coffee==1, percent
*/

gen pondn = pond*hhsize

/* population distribution by decile*/

sort pchhexp
xtile decile = pchhexp [pweight=pondn], nq(10)
pctile dec_val = pchhexp [pweight=pondn], nq(10) genp(percent)
drop percent

/* Generate cumulative per capita expenditure distribution function*/
cumul pchhexp [aweight=pondn], gen(cdf_exp) 
graph cdf_exp pchhexp if pchhexp <1500000, c(l) s(i) border ylab(0(.1)1)/*
 */ xlab(0,183450,421716,750000,1000000,1250000,1500000) yline(0(.1)1) /*
 */xline(183450,421716,750000,1000000,1250000,1500000) /*
 */ t1("Coted'Ivoire: Cumulative of per Capita Expenditure") t2("2002 Household Survey")

svyset pweight pondn
encode reg, gen(regn)
encode rururb, gen(rururbn)

log on
/*============================
			Actual situation
						==============================*/ 

/* Poverty by region*/
svytab regn pauv, percent
/* Poverty by living area*/
svytab rururbn pauv, percent

/* Poverty among coffee producers*/
svytab rururbn pauv if coffee==1, percent

/* Poverty among cocoa producers*/
svytab rururbn pauv if cocoa==1, percent

/* Poverty among coffee and cocoa producers*/
svytab rururbn pauv if cocoa==1|coffee==1, percent

/*Poverty and occupation*/
svytab csphead pauv if cocoa==1, percent
svytab csphead pauv, percent
svytab ethnic pauv, percent

log off

/*Introduction of DUS*/
/* The HH survey took place between May and July 2002 and the questions were asked for the last 12 months.
This covers the period between May/July 2001 and May/July 2002.
In term of cocoa and coffee producers, the crops' year covered is 2000/01
Average CIF  cocoa price = CFAF712/kg and the DUS CFAF 140/kg 
while for coffee it was respectively CFAF 326/kg and CFAF10/kg*/

generate coccafr=cocprice/712
label var coccafr "ratio cocoa dom. price over CIF price"

generate duscocr=140/cocprice
label var duscocr "ratio DUS over cocoa price"

generate cofcafr=cofprice/326
label var cofcafr "ratio coffee price over CIF price"

generate duscofr=10/cofprice
label var duscofr "ratio DUS over coffee price"

recode agehead .=99

generate agehsq=agehead*agehead
generate lagehsq =ln(agehsq)
generate lageh =ln(agehead)
generate lhhexp=ln(hhexp)
generate lhhsize=ln(hhsize)
generate lpchhexp=ln(pchhexp)

generate lcofprice=ln(cofprice)
generate lcofrev=ln(cofrev)
generate lcocprice=ln(cocprice)
generate lcocrev=ln(cocrev)
generate lcoccafr=ln(coccafr)
generate lduscocr=ln(duscocr)
generate lcofcafr=ln(cofcafr)
generate lduscofr=ln(duscofr)
generate lcoffqs =ln(coffqs)
generate lcocqs =ln(cocqs)

log on
/*=========================================================*/
/*scenario 1: reduction of the DUS by 50% for the farmers*/
/*This is equivalent to an income increase of 0.5*140 *cocoa quantity
=========================================================*/
log off

generate acocrev1=70*cocqs
recode acocrev1 .=0
/*
generate acofrev=5*coffqs
recode acofrev  .=0
generate nhhexp=acocrev+acofrev+hhexp
generate npchhexp=nhhexp/hhsize
*/
generate pchhexp1=pchhexp+ ((acocrev1)/hhsize)
generate pauv1=cond(pchhexp1<183450,1,0)
label define  pauv1l 1 poor 0 nopoor
label value pauv1 npauv1l

log on
/* Poverty by region*/
svytab regn pauv1, percent

/* Poverty by living area*/
svytab rururbn pauv1, percent

/*
/* Poverty among coffee producers*/
svytab rururbn pauv1 if coffee==1, percent
*/

/* Poverty among cocoa producers*/
svytab rururbn pauv1 if cocoa==1, percent

/* Poverty among coffe and cocoa producers*/
svytab rururbn pauv1 if cocoa==1|coffee==1, percent

/*=========================================================*/
/*scenario 2: suppresion of the DUS (100% reduction)*/
/*Additionnal revenue if 100%  DUS transfer: cocoa DUS=CFAF140
===========================================================*/
log off

generate acocrev2=140*cocqs
recode acocrev2 .=0
/*
generate aacofrev=10*coffqs
recode aacofrev  .=0
generate nnhhexp=aacocrev+aacofrev+hhexp
generate nnpchhexp=nnhhexp/hhsize
*/
generate pchhexp2=pchhexp+ ((acocrev2)/hhsize)
generate pauv2=cond(pchhexp2<183450,1,0)
label define pauv2l 1 poor 0 nopoor
label value pauv2 pauv2l


log on
/* Poverty by region*/
svytab regn pauv2, percent

/* Poverty by living area*/
svytab rururbn pauv2, percent

/* 
Poverty among coffee producers
svytab rururbn pauv2 if coffee==1, percent
*/

/* Poverty among cocoa producers*/
svytab rururbn pauv2 if cocoa==1, percent

/* Poverty among coffe and cocoa producers*/
svytab rururbn pauv2 if cocoa==1|coffee==1, percent

/*Poverty and occupation
svytab csphead pauv2 if cocoa==1, percent
svytab csphead pauv2, percent
svytab ethnic pauv2, percent
*/

/*=================================================================
Scenarii 3 and 4 based on Panagariya and Schiff model
===================================================================*/

/*Scenario 3: Additionnal revenue if there is a 50% reduction of DUS: Elasticity approach
since the production increases, I have to take off the production cost of any additional revenue
Assume that production cost per kg is CFAF 100
============================================================================*/

generate acocrev3=0.053*cocrev-(10*cocqs)
recode acocrev3 .=0
generate pchhexp3=pchhexp+ ((max(0,acocrev3))/hhsize)
generate pauv3=cond(pchhexp3<183450,1,0)
label define  pauv3l 1 poor 0 nopoor
label value pauv3 pauv3l

/* Poverty by region*/
svytab regn pauv3, percent

svytab rururbn pauv3 if coffee==1, percent


/* Poverty by living area*/
svytab rururbn pauv3, percent

/* Poverty among cocoa producers*/
svytab regn pauv3 if cocoa==1, percent

/* Poverty among coffe and cocoa producers*/
svytab rururbn pauv3 if cocoa==1|coffee==1, percent

/*==================================
               Scenario 4: Additionnal revenue if 100% DUS transfer: cocoa DUS=CFAF140: Elasticity approach
                                                    =========================================================*/

generate acocrev4=0.106*cocrev-(10*cocqs)
recode acocrev4 .=0
generate pchhexp4=pchhexp+ ((max(0,acocrev4))/hhsize)
generate pauv4=cond(pchhexp4<183450,1,0)
label define  pauv4l 1 poor 0 nopoor
label value pauv4 pauv4l

/* Poverty by region*/
svytab regn pauv4, percent

/* Poverty by living area*/
svytab rururbn pauv4, percent

svytab rururbn pauv4 if coffee==1, percent


/* Poverty among cocoa producers*/
svytab regn pauv4 if cocoa==1, percent

/* Poverty among coffe and cocoa producers*/
svytab rururbn pauv4 if cocoa==1|coffee==1, percent

log off

/*=================================================================================*/
gen agehead1=agehead
recode agehead1 0/19=20 .=99

#delimit;
global var " ohouse thouse hroof nroom  water elect kitchen  coffee  coffq coffqs lcoffqs cofarea cofhire coffert cofins 
		cofrev cofprice   cofcafr duscofr lcofprice lcocprice  cocoa cocprice cocrev cocprice cocq cocqs lcocqs 
		cocarea cochire  cocfert  cocins coccafr duscocr lcoccafr lcofcafr lduscocr ";
#delimit cr
foreach  i of global var {
				  recode `i' .=0
				}	

recode phone 3 .=0
recode relig .=3

generate rcocrev=cocrev/712 /*qi for scenario 5 and 6*/
gen lrcocrev=ln(rcocrev)
label var rcocrev "quantity produced based of FOB price"

/*Creation dummy variables for the regression for the region*/
tabulate regn, generate (regn)

/*define the variables for regression*/
#delimit ;

gen male=cond(sexhead==1,1,0); label var male "head of HH=male";
gen female=cond(sexhead==2,1,0); label var female "head of HH=female";

recode agehead 0=1; gen agehead2=agehead^2;
label var agehead "head of HH age"; label var agehead2 "head of HH age squared";

gen nojob=cond(csphead==5, 1,0); lab var nojob "Unemployed";
gen agriculture=cond(csphead==4, 1,0); lab var agriculture  "Agriculture";
gen manual=cond(csphead==2, 1,0); lab var manual "Manual worker";
gen private=cond(csphead==3, 1,0); lab var private "Private sector";
gen civil_servant=cond(csphead==1, 1,0); lab var civil_servant "Civil Servant"; 

lab var school "went to school";

gen nodegree=cond(degree==1, 1, 0); lab var nodegree "No Degree";
gen highschool=cond(degree==2, 1, 0); lab var highschool"High School Degree";
gen university=cond(degree==3, 1, 0); lab var university "University Degree";
gen technic=cond(degree==3, 1, 0); lab var technic "Profesional Degree";

gen akan=cond(ethnic==1, 1,0); lab var akan "Akan"; 
gen krou=cond(ethnic==2, 1,0); lab var krou "Krou";
gen mande=cond(ethnic==3, 1,0); lab var mande "Mande";
gen volta=cond(ethnic==4, 1,0);lab var volta "Volta";
gen african=cond(ethnic==5, 1,0); lab var african "African";

recode relig 0=3; gen christian=cond(relig==1, 1,0); lab var christian "Christian";
gen muslim=cond(relig==2, 1,0); lab var muslim "Muslim";
gen no_relig=cond(relig==3, 1,0); lab var no_relig "no_relig";

lab var married "head is married";

gen urban=cond(rururbn==1, 1,0); lab var urban "urban";
#delimit cr

/*Regression of hh expenditure*/
/* Regression with ratio cocrev on DUs for all the pop*/

svyreg lpchhexp male agehead agehead2  akan krou mande volta /*african*/ married christian muslim /*no_relig*/ school read/*
	*/ nodegree highschool university /*technic*/ nojob agriculture manual private /*civil_servant*/ hhsize urban /*
	*/ regn1-regn10 coffqs cofprice cofhire coffert cofins cocqs cocprice cochire cocfert  cocins rcocrev

outreg using c:\civ02_rurpov_v3.xls, bdec(5) ctitle ("All popuplation") 3aster  replace

svyreg lpchhexp male agehead agehead2  akan krou mande volta /*african*/ married christian muslim /*no_relig*/ school read/*
	*/ nodegree highschool university /*technic*/ nojob agriculture manual private /*civil_servant*/ hhsize urban /*
	*/ regn1-regn10 coffqs cofprice cofhire coffert cofins cocqs cocprice cochire cocfert  cocins rcocrev if urban==1

outreg using c:\civ02_rurpov_v3.xls, bdec(5) ctitle ("Urban") 3aster append replace

svyreg lpchhexp male agehead agehead2  akan krou mande volta /*african*/ married christian muslim /*no_relig*/ school read/*
	*/ nodegree highschool university /*technic*/ nojob agriculture manual private /*civil_servant*/ hhsize urban /*
	*/ regn1-regn10 coffqs cofprice cofhire coffert cofins cocqs cocprice cochire cocfert  cocins rcocrev if urban==0

outreg using c:\civ02_rurpov_v3.xls, bdec(5) ctitle ("Rural") 3aster append  replace

svyreg lpchhexp male agehead agehead2  akan krou mande volta /*african*/ married christian muslim /*no_relig*/ school read/*
	*/ nodegree highschool university /*technic*/ nojob agriculture manual private /*civil_servant*/ hhsize urban /*
	*/ regn1-regn10 coffqs cofprice cofhire coffert cofins cocqs cocprice cochire cocfert  cocins rcocrev if cocoa==1

outreg using c:\civ02_rurpov_v3.xls, bdec(5) ctitle ("Cocoa Producers") 3aster append  replace

svyreg lpchhexp male agehead agehead2  akan krou mande volta /*african*/ married christian muslim /*no_relig*/ school read/*
	*/ nodegree highschool university /*technic*/ nojob agriculture manual private /*civil_servant*/ hhsize urban /*
	*/ regn1-regn10 coffqs cofprice cofhire coffert cofins cocqs cocprice cochire cocfert  cocins rcocrev if (cocoa==1 | coffee==1)

outreg using c:\civ02_rurpov_v3.xls, bdec(5) ctitle ("Cocoa-coffee Producers") 3aster  append  replace


/*===============================================================*/
log on
/*scenario 5: Econometric result and DUS simulation impact*/

/*Additionnal revenue if 50% DUS transfer: cocoa DUS=CFAF140
1-t=(1/q)*(cocrev/CIF)+a where t=DUS/CIF
If DUS decreases from 140 to 70 then t decreases by ((70-140)/712)=9.8% then rcocrev will increase by Qi*9.8%*/
generate drcocrev5=0.098*cocqs if cocoa==1
recode drcocrev5 .=0
generate acocrev5=(drcocrev5*0.00004)/* *lpchhexp*/
recode acocrev5 .=0
gen lpchhexp2=lpchhexp+acocrev5
gen pchhexp5=exp(lpchhexp2)
/*generate pchhexp5 =pchhexp + exp(acocrev5)/hhsize*/ 

generate pauv5=cond(pchhexp5<183450,1,0)
label define pauv5l 1 poor 0 nopoor
label value pauv5 pauv5l

/* Poverty by region*/
svytab regn pauv5, percent
svytab rururbn pauv5, percent

/* Poverty among coffee producers*/
svytab regn pauv5 if coffee==1, percent

/* Poverty among cocoa producers*/
svytab regn pauv5 if cocoa==1, percent

/* Poverty among coffe and cocoa producers*/
svytab regn  pauv5 if cocoa==1|coffee==1, percent


/*Scenario 6: Additionnal revenue if 100% DUS transfer: cocoa DUS=CFAF140
1-t=(1/q)*(cocrev/CIF)+a where t=DUS/CIF
If DUS decreases from 140 to 0 then t decreases by (-140/712)=19.6% then rcocrev will increase by q*19.6%*/

generate drcocrev6=0.196*cocqs if cocoa==1
recode drcocrev6 .=0
generate acocrev6=(drcocrev6*0.00004) /**lhhexp*/
recode acocrev6 .=0
generate lpchhexp3 =lpchhexp + acocrev6
gen pchhexp6=exp(lpchhexp3)

generate pauv6=cond(pchhexp6<183450,1,0)
label define pauv6l 1 poor 0 nopoor
label value pauv6 pauv6l


/* Poverty by region*/
svytab regn pauv6, percent

/* Poverty among coffee producers*/
svytab regn pauv6 if coffee==1, percent

svytab rururbn pauv6, percent


/* Poverty among cocoa producers*/
svytab regn pauv6 if cocoa==1, percent

/* Poverty among coffe and cocoa producers*/
svytab regn  pauv6 if cocoa==1|coffee==1, percent

log off

log on

/*=================================================================
Scenarii 7 and 8 Reduction of parafiscal tax only
===================================================================*/

/*Scenario 7: Parafiscal taxe are suppresss
The custom and fiscal taxes represent about 7% of the FOB price. 
This scenario assumes that the price receives by the producers increases by 7% of the FOB price
Thus the additionnal revenue for each farmer is [(7% * (FOB price)) * (quantity sold)]
============================================================================*/

generate acocrev7=0.07*712 * cocqs
recode acocrev7 .=0
generate pchhexp7=pchhexp+ ((acocrev7)/hhsize)
generate pauv7=cond(pchhexp7<183450,1,0)
label define  pauv7l 1 poor 0 nopoor
label value pauv7 pauv7l

/* Poverty by region*/
svytab regn pauv7, percent

svytab rururbn pauv7 if coffee==1, percent


/* Poverty by living area*/
svytab rururbn pauv7, percent

/* Poverty among cocoa producers*/
svytab regn pauv7 if cocoa==1, percent

/* Poverty among coffe and cocoa producers*/
svytab rururbn pauv7 if cocoa==1|coffee==1, percent

log off





/*

/*Logit model*/ 
svylogit pauv hhsize sexhead1 agehead1 /*lagehsq agehsq lageh   */ ohouse thouse2 hroof1 nroom water2 water3 elect2 kitchen1 kitchen3 phone csphead2-csphead5 /*
  */ school read degree1-degree3 ethnic1-ethnic4 relig1-relig2 married regn1-regn10 rururbn1 lcoffqs /*
    */ cofarea2-cofarea4 cofhire coffert cofins cofcafr lcocqs cocarea2-cocarea4 cochire cocfert cocins   rcocrev coccafr , or

 outreg using c:\regout_res_logit.txt, bdec(5) ctitle ("All popuplation") 3aster   eform replace

svylogit pauv hhsize sexhead1 agehead1 /*lagehsq agehsq lageh   */ ohouse thouse2 hroof1 nroom water2 water3 elect2 kitchen1 kitchen3 phone csphead2-csphead5 /*
  */ school read degree1-degree3 ethnic1-ethnic4 relig1-relig2 married regn1-regn10 rururbn1 lcoffqs /*
    */ cofarea2-cofarea4 cofhire coffert cofins cofcafr lcocqs cocarea2-cocarea4 cochire cocfert cocins   rcocrev coccafr  if rururbn==2, or

outreg using c:\regout_res_logit.txt, bdec(5) ctitle ("Urban") 3aster eform  append replace

svylogit pauv hhsize sexhead1 agehead1 /*lagehsq agehsq lageh   */ ohouse thouse2 hroof1 nroom water2 water3 elect2 kitchen1 kitchen3 phone csphead2-csphead5 /*
  */ school read degree1-degree3 ethnic1-ethnic4 relig1-relig2 married regn1-regn10 rururbn1 lcoffqs /*
    */ cofarea2-cofarea4 cofhire coffert cofins cofcafr lcocqs cocarea2-cocarea4 cochire cocfert cocins   rcocrev coccafr  if rururbn==1 , or

outreg using c:\regout_res_logit.txt, bdec(5) ctitle ("Rural") 3aster  eform  append replace

svylogit pauv hhsize sexhead1 agehead1 /*lagehsq agehsq lageh   */ ohouse thouse2 hroof1 nroom water2 water3 elect2 kitchen1 kitchen3 phone csphead2-csphead5 /*
  */ school read degree1-degree3 ethnic1-ethnic4 relig1-relig2 married regn1-regn10 rururbn1 lcoffqs /*
    */ cofarea2-cofarea4 cofhire coffert cofins cofcafr lcocqs cocarea2-cocarea4 cochire cocfert cocins   rcocrev coccafr  if (cocoa==1|coffee==1) & cocprice<712 , or

outreg using c:\regout_res_logit.txt, bdec(5) ctitle ("Cocoa-Coffee Producer") 3aster eform  append replace
*/


capture log close
exit

