/*===============================================================================

                         	  CI: Heckman Wage Regression from CI 2002 survey                                         
                                        Gaston Gohou
                                         January 2004

  ================================================================================= */

version 7.0
clear
capture log close
log using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\program\civ02_heckm_res.txt", replace text 
set more off
set mem 32m
set matsize 800
log off

/*================================================================================================
   Take everybody with a job and between age of 15 to 65
=================================================================================================*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect01.dta",  clear
keep grappe menord s1q2 s1q3 s1q6a s1q7 s1q8 s1q9   s1q24a  s1q32 s1q33 s1q58  s1q60 
 
/* Create ID # for each individual*/
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
gen idmenp = idmen*100+s1q2
drop grappe menord  grappen menordn  s1q2 

/* keep hh member between age of 15 and 65yr*/
ren s1q6a agey
keep if (agey>=15 & agey<=65)
/*generate age square*/
gen age2=agey*agey

/* Gender*/
ren s1q3 male
recode male 2=0
label define malel 1 male 0 female
label value male malel

/*marrital statut*/
ren s1q7 married
recode married 2 3 4 5 = 0
label define marrl 1 married 0 notmarried
label value married marrl

/* ethnic group*/
ren s1q8 ethni
gen alien=cond(ethni==6 |ethni==7 |ethni==8 |ethni==9,1,0)
label define all 1 alien 0 ivorian
label value alien all

recode ethni 4=3 5=4  6 7 8 9 10=5
label define ethl 1 akan 2 krou 3 mande 4 voltaic 5 afr
label value ethni ethl

/*Religion*/ 
ren  s1q9  relig  
recode relig 2 3=1 4=2 5 6=3 7=4
label define rel 1 christian 2 muslim 3 other 4 norelig
label value relig rel

/*Migration*/
ren  s1q24a dmig
gen n_mig=cond(dmig<=1, 1, 0)
label define nmig 1 newmigrant 2 no_n_m
label value n_mig nmig

gen evr_mig=cond(dmig<=2 & dmig>1, 1, 0)
label define emig 1 oldmigrant 2 no_o_m
label value evr_mig emig

drop dmig

/*education*/
rename s1q32 degree
recode degree  2/4=2 5/7=3 8 9 10=4 11 12 13 14 16=5 15 17 18=6 .=1
label define dgel 1 no_degree 2 highsch 3 univ1 4 univ2 5 tech1 6 tech2  
label value degree dgel

/*type of school*/
ren s1q33 tchool
recode tchool 2=1 3 4=2 5 6=3
label define tchl 1 pubSchool 2 PriSch 3 Koranic  
label value tchool tchl 

/* computer use*/
ren s1q58 pc_use
recode pc_use 2=0
label define pcl 1 yes 0 no
label value pc_use pcl

/*Internet Access*/
ren  s1q60 web_acc
recode web_acc 2=0
label define webl 1 yes 0 no
label value web_acc webl

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta", replace

/* Add the HH level varrables: hh expenditure, weight, poverty statut*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\pauvre.dta",  replace
keep grappe menord hhsize pchhexp hhexp _region_ _milieu_ strate pond  pauv 
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn

rename _region_ reg
rename _milieu_ rururb
encode reg, gen(regn)
encode rururb, gen(rururbn)
drop rururb reg menordn menord grappen grappe 

gen urban=cond(rururbn==2, 1,0)
label define urbl 1 urban 0 rural
label value urban urbl
drop rururbn

recode pauv .=0
label define  pauvl 1 poor 0 nopoor
label value pauv pauvl


sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\tmp1.dta", replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta",  replace

merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\tmp1.dta"
keep if _merge~=2
drop _merge

/*generate weight*/
gen pondn = pond*hhsize

sort idmenp
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta", replace

  /* =================================================
        add job and wage variables
==================================================*/
insheet using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect02_v3.txt",  clear
keep grappe menord s1q2 s2q8 s2q16a  s2q16b s2q17 s2q26a  s2q26b s2cq8  s2cq12a  s2cq12b 
 
/*generate grappen = real(grappe)
generate menordn = real(menord)*/
gen idmen = grappe*100 + menord
gen idmenp = idmen*100+s1q2
drop grappe menord s1q2 

recode s2q8  2 .=0
ren s2q8 job
label define jobl 1 job 0 nojob

gen csp =1
/*replace s2q16b=s2q16a if (s2q16b==. & (s2q26a~. | s2q26a ~=0))*/
replace csp=2 if s2q16b==6 | s2q16b ==7
replace csp=3 if (s2q16b==8 | s2q16b ==9 | s2q16b ==10 | s2q16b ==11| s2q16b ==12 | s2q16b ==13)
replace csp=4 if (s2q16b==14 | s2q16b ==15 | s2q16b ==16)

/*replace csp=41 if s2q16b==14 
replace csp=42 if s2q16b==15
replace csp=43 if s2q16b ==16*/

replace csp=5 if (s2q16b==17 | s2q16b ==18 | s2q16b ==19 | s2q16b ==20 | s2q16b ==21)

/*replace csp=51 if s2q16b==17
replace csp=52 if s2q16b==18
replace csp=53 if s2q16b==19
replace csp=54 if s2q16b==20
replace csp=55 if s2q16b==21*/

replace csp=6 if  (s2q16b==.)
label define cspl 1 cvserc 2 prsect 3 ast_prsc 4  ind  5 agr 6 other
/*label define cspl 1 cvserc 2 prsect 3 ast_prsc 41 iboss_woe 42 iboss_we 43 aid 51 agr 52 mty 53 d_aid 54 Agr_aid 55 oth_agr 6 other*/
label value csp cspl

/*hourly wage for prinary and secondary job*/

rename s2q26a wage1
rename s2q26b unit1
rename s2cq12a wage2
rename s2cq12b unit2
rename s2q17 whour1
rename s2cq8  whour2

/*Primary job*/
recode unit1 .=2 if wage1~=.
recode wage1 .=0 if whour1 ~=.
recode whour1 .=40 if (wage1~=.) /*total weekly hours is fixed to 40 if hh receive a wage*/
replace whour1=84 if whour1>=85  /* set total wk hours to 84: assuming a 12 (?) hour day of work */
 
gen hwage1=0
replace hwage1=wage1/whour1  if unit1==1
replace hwage1=wage1/40  if (unit1==1 & whour1==0)
replace hwage1=wage1/(whour1*4) if unit1==2
replace hwage1=wage1/(40*4) if (unit1==2 & whour1==0)
replace hwage1=wage1/(whour1*4*3) if unit1==3
replace hwage1=wage1/(40*4*3) if (unit1==3 & whour1==0)
replace hwage1=wage1/(whour1*4*6) if unit1==4
replace hwage1=wage1/(40*4*6) if (unit1==4 & whour1==0)
replace hwage1=wage1/(whour1*4*12) if unit1==5
replace hwage1=wage1/(40*4*12) if (unit1==5 & whour1==0)
label var hwage1 "hourly wage from main job"
recode hwage1 0=. if  wage1==. & unit1==.

/*Second  job*/
recode unit2 .=2 if wage2~=.
recode wage2 .=0 if whour2 ~=.
recode whour2 .=8 if (unit2==1 & wage2~=.)
recode whour2 .=40 if (unit2==2 & wage2~=.)
recode whour2 .=160 if (unit2==3 & wage2~=.)
recode whour2 .=1920 if (unit2==4 & wage2~=.)

gen hwage2=0
replace hwage2=wage2/ (whour2/5)  if unit2==1
replace hwage2=wage2/whour2  if unit2==2
replace hwage2=wage2/(whour2*4) if unit2==3
replace hwage2=wage2/(whour2*4*12) if unit2==4
label var hwage2 "hourly wage from 2nd job"
recode hwage2 0=. if wage2==. & unit2==.


keep if  wage1~=. |  wage2~=.
/*recode hwage1 .=0
recode hwage2 .=0*/

gen hwage=(hwage1 + hwage2)/2 if ( hwage1~=. & hwage2 ~=. ) & ( hwage1~=0 & hwage2 ~=0 )
replace hwage=(hwage1 + hwage2)/2 if  ( hwage1==0 | hwage2==0 )
replace hwage=hwage1 if (hwage2==. | hwage2==0)
recode hwage  .=0 

drop  hwage1 hwage2 job  s2q16a s2q16b whour1 wage1 unit1 whour2 wage2 unit2
sort idmenp
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\tmp1.dta", replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta",  replace

merge idmenp using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\tmp1.dta"
keep if _merge==3
drop _merge

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta", replace


/* Add # of kids and adult and senior*/

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect01.dta",  clear
keep grappe menord s1q2 s1q6a  
 
/* Create ID # for each individual*/
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
gen idmenp = idmen*100+s1q2
drop grappe menord  grappen menordn  s1q2 

/* keep hh member between age of 15 and 65yr*/
ren s1q6a agey
gen baby=cond(agey<5,1,0)
gen kid=cond(agey<15 & agey>=5,1,0)
gen adult=cond(agey>=15&agey<65,1,0)
gen senior=cond(agey>=65,1,0)
collapse (sum) baby kid adult senior, by(idmen ) fast

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\tmp1.dta", replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta",  replace

merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\tmp1.dta"
keep if _merge==3
drop _merge
replace hhsize = baby+kid+adult+senior if hhsize- baby-kid-adult-senior <0
sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta", replace


/* Electricity, Water and phone access*/
use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect07.dta",  clear
keep  grappe menord s7q12 s7q15 s7q23
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn  

ren  s7q12  water 
recode water 1 2=1 3 4 5 6 7 .=0
lab var water "access to potable water"

ren s7q15 elect
recode elect 1 5 .=0 2 3 4=1
lab var elect "access to electricity"

ren s7q23 phone
recode phone 2 .=0
lab var phone "access to phone"

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\tmp1.dta", replace

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta",  replace

merge idmen using "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\tmp1.dta"
keep if _merge==3
drop _merge

/* Creation of dummy for the discrete variables*/
tab  ethni [aw=pondn], gen (ethni)
tab  relig [aw=pondn], gen (relig )
tab  degree [aw=pondn], gen (degree )
tab  tchool [aw=pondn], gen (tchool )
tab  regn [aw=pondn], gen (regn)
tab  csp [aw=pondn], gen (csp)

gen lwage=ln(hwage)

sort idmen
save "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\civ02_heck.dta", replace


log on
svyset strata strate
svyset psu idmen
/*svyset pweight pond
gen pondn = pond*hhsize*/
svyset pweight pondn


sum pchhexp if pchhexp<=1000000, detail
sum hwage if hwage~=0, detail

/*Stat wage for ivorian and foreigner*/
sum hwage if hwage~=0 & alien==0 [aweight=pondn], detail
sum hwage if hwage~=0 & alien==1 [aweight=pondn], detail

/*Stat wage for ivorian and foreigner in rural and urban sector*/
sum hwage if hwage~=0 & alien==0 & urban==0 [aweight=pondn], detail
sum hwage if hwage~=0 & alien==0 & urban==1 [aweight=pondn], detail
sum hwage if hwage~=0 & alien==1 & urban==0 [aweight=pondn], detail
sum hwage if hwage~=0 & alien==1 & urban==1 [aweight=pondn], detail


gen aliurb=cond(urban==1 & alien==1,1,0)
gen alirur=cond(urban==0 & alien==1,1,0)
gen ivurb=cond(urban==1 & alien==0,1,0)
gen ivrur=cond(urban==0 & alien==0,1,0)

gen popurb=.
recode popurb .=1 if aliurb==1
recode popurb .=2 if ivurb==1

gen poprur=.
recode poprur .=1 if alirur==1
recode poprur .=2 if ivrur==1


/*Heckman regression for all the person employed with or without wage
This code estimates the wage equation using the Heckman selection process and use the 
Oaxaca decomposition method for an estimation of the differences between ivoirians and 
foreigners in rural and urban sector.
Three estimations are done: Ivoirain vs foreigners, and the same in the rural and the urban sector*/

/*==========================================
   Ivoirian vs Foreigner 
===========================================*/

/*Heckman regression for all ivorian national*/
heckman   lwage agey age2 /*married*/ degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
        water elect phone*/  n_mig evr_mig /*pc_use web_acc*/ /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 [aweight=pondn] if alien==0,  /*
    */ robust select (agey age2 married baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_IvAlien.txt, bdec(3) br 3aster ctitle("Ivorian") replace

predict yhat_i
matrix Rw_i=e(b)					/* coefficients of regression equation */
matrix Vregw_i=e(V)  				/* var-cov matrix of regression coefficients */
/*local m_i=colsof(Rw_i)*/			/* number of regressors of regression equation */
local m_i=27					/* number of regressors of regression equation */
matrix Rwd_i=Rw_i[1,1..`m_i']
local names : colnames Rwd_i
matrix Xw_i=J(1,`m_i', 1)
mat Xwa_i=J(1,`m_i', 1)  

tokenize `names'
local i 1			/* counter for regressors */
	while "`1'"~=""{	
		qui su `1' if alien==0 
		local mean`i'=r(mean)
		mat Xw_i[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xm */
		qui su `1' if alien==0 
		local mean`i'=r(mean)
		mat Xwa_i[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xma */	
		local i=`i'+1	
	macro shift	
}


/*Heckman regression for all foreigner */
heckman   lwage agey age2 /*married*/ degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
        water elect phone*/  n_mig evr_mig /*pc_use web_acc*/ /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 [aweight=pondn] if alien==1,  /*
    */ robust select (agey age2 married baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_IvAlien.txt, bdec(3) br 3aster ctitle("Foreigner") append replace

predict yhat_f

loca
sum  degree1 [aweight=pondn] if alien==0, detail
sum  degree1 [aweight=pondn] if alien==0, detail



matrix Rw_f=e(b)	/* coefficients of regression equation */
matrix Vregw_f=e(V)  /* var-cov matrix of regression coefficients */
/*local m_f=colsof(Rw_f)*/	/* number of regressors of regression equation */
local m_f=33	/* number of regressors of regression equation */
matrix Rwd_f=Rw_f[1,1..`m_f'-1]
local names : colnames Rwd_f
matrix Xw_f=J(1,`m_f'-1, 1)
mat Xwa_f=J(1,`m_f'-1, 1)  

tokenize `names'
local i 1			/* counter for regressors */
	while "`1'"~=""{	
		qui su `1' if alien==1 
		local mean`i'=r(mean)
		mat Xw_f[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xm */
		qui su `1'  if alien==1 
		local mean`i'=r(mean)
		mat Xwa_f[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xma */	
		local i=`i'+1	
	macro shift	
}

/*Decomposition 1*/
matrix C1=Rwd_i*diag(Xwa_i-Xwa_f)	/*Effect of diff. in average charact between /*
							*/ ivorians and aliens: Explained differences*/
matrix R1=Xwa_f*diag(Rwd_i-Rwd_f)	/* Discrimination effect: Ivoirians-aliens*/

/*Decomposition 2*/
matrix C2=Rwd_f*diag(Xwa_i-Xwa_f)     /*Effect of diff. in average charact between /*
							*/ ivorians and aliens: Explained differences*/
matrix R2=Xwa_i*diag(Rwd_i-Rwd_f)     /* Discrimination effect: Ivoirians-aliens*/

mat a=(C1\R1\C2\R2)
mat list a


/*==========================================
   Ivoirian vs Foreigner in the urban sector
===========================================*/

/*Heckman regression for ivorian in the urban sector */
heckman   lwage agey age2 /*married*/ degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
        water elect phone*/  n_mig evr_mig /*pc_use web_acc*/ /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 [aweight=pondn] if alien==0 & urban==1 ,  /*
    */ robust select (agey age2 married baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_IvAlien.txt, bdec(3) br 3aster ctitle("Ivorian_Urban") append replace

predict yhat_iu
matrix Rw_iu=e(b)	/* coefficients of regression equation */
matrix Vregw_iu=e(V)  /* var-cov matrix of regression coefficients */
/*local m_iu=colsof(Rw_iu)*/	/* number of regressors of regression equation */
local m_iu=33	/* number of regressors of regression equation */
matrix Rwd_iu=Rw_iu[1,1..`m_iu'-1]
local names : colnames Rwd_iu
matrix Xw_iu=J(1,`m_iu'-1, 1)
mat Xwa_iu=J(1,`m_iu'-1, 1)  

tokenize `names'
local i 1			/* counter for regressors */
	while "`1'"~=""{	
		qui su `1' if alien==0 & urban==1
		local mean`i'=r(mean)
		mat Xw_iu[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xm */
		qui su `1' if alien==0 & urban==1
		local mean`i'=r(mean)
		mat Xwa_iu[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xma */	
		local i=`i'+1	
	macro shift	
}


/*Heckman regression for foreigner in the urban sector */
heckman   lwage agey age2 /*married*/ degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
        water elect phone*/  n_mig evr_mig /*pc_use web_acc*/ /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 [aweight=pondn] if alien==1 & urban==1 ,  /*
    */ robust select (agey age2 married baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_IvAlien.txt, bdec(3) br 3aster ctitle("Foreigner_Urban") append replace
predict yhat_fu
matrix Rw_fu=e(b)	/* coefficients of regression equation */
matrix Vregw_fu=e(V)  /* var-cov matrix of regression coefficients */
/*local m_fu=colsof(Rw_fu)*/	/* number of regressors of regression equation */
local m_fu=33	/* number of regressors of regression equation */
matrix Rwd_fu=Rw_fu[1,1..`m_fu'-1]
local names : colnames Rwd_fu
matrix Xw_fu=J(1,`m_fu'-1, 1)
mat Xwa_fu=J(1,`m_fu'-1, 1)  

tokenize `names'
local i 1			/* counter for regressors */
	while "`1'"~=""{	
		qui su `1' if alien==1 & urban==1
		local mean`i'=r(mean)
		mat Xw_fu[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xm */
		qui su `1'  if alien==1 & urban==1
		local mean`i'=r(mean)
		mat Xwa_fu[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xma */	
		local i=`i'+1	
	macro shift	
}

/*Decomposition 1*/
matrix CU1=Rwd_iu*diag(Xwa_iu-Xwa_fu)	/*Effect of diff. in average charact between /*
							*/ ivorians and aliens n the urban sector: Explained differences*/
matrix RU1=Xwa_fu*diag(Rwd_iu-Rwd_fu)	/* Discrimination effect: Ivoirians-aliens urban sector*/

/*Decomposition 2*/
matrix CU2=Rwd_fu*diag(Xwa_iu-Xwa_fu)     /*Effect of diff. in average charact between /*
							*/ ivorians and aliens n the urban sector: Explained differences*/
matrix RU2=Xwa_iu*diag(Rwd_iu-Rwd_fu)     /* Decomposition 1: Discrimination effect: Ivoirians-aliens*/

mat b=(CU1\RU1\CU2\RU2)
mat list b

/*==========================================
   Ivoirian vs Foreigner in the rural sector
===========================================*/
recode regn5 0=1 if idmenp==1020103
/*Heckman regression for ivorian in the rural sector */
heckman  lwage agey age2 /*married*/ degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
        water elect phone*/  n_mig evr_mig /*pc_use web_acc*/ /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 [aweight=pondn] if alien==0 & urban==0 ,  /*
    */ robust select (agey age2 married baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_IvAlien.txt, bdec(3) br 3aster ctitle("Ivorian_rural") append replace

predict yhat_ir
matrix Rw_ir=e(b)	/* coefficients of regression equation */
matrix Vregw_ir=e(V)  /* var-cov matrix of regression coefficients */
/*local m_ir=colsof(Rw_ir)*/	/* number of regressors of regression equation */
local m_ir=33	/* number of regressors of regression equation */
matrix Rwd_ir=Rw_ir[1,1..`m_ir'-1]
local names : colnames Rwd_ir
matrix Xw_ir=J(1,`m_ir'-1, 1)
mat Xwa_ir=J(1,`m_ir'-1, 1)  

tokenize `names'
local i 1			/* counter for regressors */
	while "`1'"~=""{	
		qui su `1' if alien==0 & urban==0
		local mean`i'=r(mean)
		mat Xw_ir[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xw */
		qui su `1' if alien==0 & urban==0
		local mean`i'=r(mean)
		mat Xwa_ir[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xwa */	
		local i=`i'+1	
	macro shift	
}


/*Heckman regression for foreigner in the rural sector */
recode regn3 0=1 if idmenp==1020701
recode regn3 0=1 if idmenp==1061301
recode regn3 0=1 if idmenp==1060701

recode regn5 0=1 if idmenp==1051201

recode web_acc 0=1 if idmenp==1060201
recode web_acc 0=1 if idmenp==1061601
recode web_acc 0=1 if idmenp==1091801
recode web_acc 0=1 if idmenp==1110201

heckman   lwage agey age2 /*married*/ degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
        water elect phone*/  n_mig evr_mig /*pc_use web_acc*/ /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 [aweight=pondn] if alien==1 & urban==0 ,  /*
    */ robust select (agey age2 married baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_IvAlien.txt, bdec(3) br 3aster ctitle("Foreigner_rural") append replace
predict yhat_fr
matrix Rw_fr=e(b)	/* coefficients of regression equation */
matrix Vregw_fr=e(V)  /* var-cov matrix of regression coefficients */
/*local m_fr=colsof(Rw_fr)*/	/* number of regressors of regression equation */
local m_fr=33	/* number of regressors of regression equation */
matrix Rwd_fr=Rw_fr[1,1..`m_fr'-1]
local names : colnames Rwd_fr
matrix Xw_fr=J(1,`m_fr'-1, 1)
mat Xwa_fr=J(1,`m_fr'-1, 1)  

tokenize `names'
local i 1			/* counter for regressors */
	while "`1'"~=""{	
		qui su `1' if alien==1 & urban==1
		local mean`i'=r(mean)
		mat Xw_fr[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xm */
		qui su `1'  if alien==1 & urban==1
		local mean`i'=r(mean)
		mat Xwa_fr[1,`i']=`mean`i''	 /* store mean value of charact. in matrix Xma */	
		local i=`i'+1	
	macro shift	
}


/*Decomposition 1*/
matrix CR1=Rwd_ir*diag(Xwa_ir-Xwa_fr)	/*Effect of diff. in average charact between /*
							*/ ivorians and aliens n the rural sector: Explained differences*/
matrix RR1=Xwa_fr*diag(Rwd_ir-Rwd_fr)	/* Discrimination effect: Ivoirians-aliens rural sector*/

/*Decomposition 2*/
matrix CR2=Rwd_fr*diag(Xwa_ir-Xwa_fr)    /*Decomposition 2: effect of diff. in average charact between/*
					          */ ivorians and aliens in the rural sector: Explained differences */
matrix RR2=Xwa_ir*diag(Rwd_ir-Rwd_fr)     /* Decomposition 1: Discrimination effect: Ivoirians-aliens*/


mat c=(CR1\RR1\CR2\RR2)
mat list c



/*




/*====================================
decompose lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
   */ relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4  csp1 csp2 csp3 csp4 csp5 water elect /*
   */ phone n_mig evr_mig pc_use web_acc  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 /*
   */ regn10 [aweight=pondn], by(popurb) detail estimates


===============================================*


/*Heckman regression for ivorian in the rural sector */
heckman   lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
       */  water elect phone n_mig evr_mig pc_use web_acc /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 [aweight=pondn] if alien==0 & urban==0 ,  /*
    */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_IvAlien.txt, bdec(3) br 3aster ctitle("Ivorian_Rural") append replace
predict yhat_ir
matrix Rw_ir=e(b)	/* coefficients of regression equation */
matrix Vregw_ir=e(V)  /* var-cov matrix of regression coefficients */
local m_ir=colsof(Rw_ir)	/* number of regressors of regression equation */


/*Heckman regression for ivorian in the rural sector */
heckman   lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
       */  water elect phone n_mig evr_mig pc_use web_acc /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 [aweight=pondn] if alien==1 & urban==0 ,  /*
    */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_IvAlien.txt, bdec(3) br 3aster ctitle("Foreigner_Rural") append replace
predict yhat_fr
matrix Rw_fr=e(b)	/* coefficients of regression equation */
matrix Vregw_fr=e(V)  /* var-cov matrix of regression coefficients */
local m_fr=colsof(Rw_fr)	/* number of regressors of regression equation */








heckman   lwage agey age2 male married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
    */ /* relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
    */  water elect phone n_mig evr_mig urban pc_use web_acc /*
   */ regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10,  /*
   */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 /* 
   */ degree6 water elect phone n_mig evr_mig urban)

outreg using c:\gohou\civ_heck_res.txt, bdec(3) br 3aster ctitle("all wage earners") replace

/*Heckman regression for rural sector*/

heckman   lwage agey age2 male married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
              */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
              */  water elect phone n_mig evr_mig pc_use web_acc /*
          */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 if urban==0,  /*
          */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_res.txt, bdec(3) br 3aster  ctitle("Rural") append replace

/*Heckman regression for urban sector*/

heckman   lwage agey age2 male married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
         */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
        */  water elect phone n_mig evr_mig pc_use web_acc /*
     */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 if urban==1,  /*
     */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig )

outreg using c:\gohou\civ_heck_res.txt, bdec(3) br 3aster  ctitle("Urban") append replace

/*Heckman regression for male*/

heckman   lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
          */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
         */  water elect phone n_mig evr_mig urban pc_use web_acc /*
     */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 if male==1,  /*
    */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig urban)

outreg using c:\gohou\civ_heck_res2.txt, bdec(3) br 3aster  ctitle("Male") replace

/*Heckman regression for female*/

heckman   lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
       */  water elect phone n_mig evr_mig urban pc_use web_acc /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 if male==0,  /*
    */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig urban)

outreg using c:\gohou\civ_heck_res2.txt, bdec(3) br 3aster ctitle("female") append replace

heckman   lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
       */  water elect phone n_mig evr_mig urban pc_use web_acc /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 if alien==0,  /*
    */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig urban)

outreg using c:\gohou\civ_heck_res2.txt, bdec(3) br 3aster ctitle("Ivorian") append replace

heckman   lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
       */  water elect phone n_mig evr_mig urban pc_use web_acc /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 if alien==0,  /*
    */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig urban)

outreg using c:\gohou\civ_heck_res2.txt, bdec(3) br 3aster ctitle("Foreigner") append replace

heckman   lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
       */  water elect phone n_mig evr_mig urban pc_use web_acc /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 if alien==1 & urban==1,  /*
    */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig urban)

outreg using c:\gohou\civ_heck_res3.txt, bdec(3) br 3aster ctitle("Alien_Urban") replace

heckman   lwage agey age2 married degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 /*
        */  /*relig1 relig2 relig3 ethni1 ethni2 ethni3 ethni4*/  csp1 csp2 csp3 csp4 csp5 /*
       */  water elect phone n_mig evr_mig urban pc_use web_acc /*
    */  regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 if alien==1 & urban==0,  /*
    */ robust select (agey age2 baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig urban)

outreg using c:\gohou\civ_heck_res3.txt, bdec(3) br 3aster ctitle("Alien_Rural") append replace

*/

/*===================
heckman   lwage agey age2 degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 csp1 csp2 csp3 csp4 csp5 n_mig evr_mig regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10  if alien==0, select (agey age2 married baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig ) twostep mills(lambda)

regress   lwage agey age2 degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 csp1 csp2 csp3 csp4 csp5 n_mig evr_mig regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10 lambda  if alien==0
decompose, save (high)

heckman   lwage agey age2 degree2 degree3 degree4 degree5 degree6  tchool2 tchool3 csp1 csp2 csp3 csp4 csp5 n_mig evr_mig regn1 regn2 regn3 regn4 regn5 regn6 regn7 regn8 regn9 regn10  if alien==1, select (agey age2 married baby kid adult senior degree2 degree3 degree4 degree5 degree6 water elect phone n_mig evr_mig ) 

decompose, save(low)

decompose, lambda(lbda)

=================*/


log off


capture log close
exit

