/*===============================================================================

                         	  CI: Income estimation from CI 2002 survey                                         
                                        Gaston Gohou
                                         January 2004

  ================================================================================= */


cd "C:\Documents and Settings\Bachir\Desktop\Bachir\World Bank\Wodon\CIV\Cote d'Ivoire Consumption\STATA"

version 7.0
clear
capture log close
log using "civ02_inc_res.txt", replace text 
set more off
set mem 32m
set matsize 800
log off

/*Take the general HH indicators*/
use pauvre,  replace
keep grappe menord hhsize sexhead agehead csphead pchhexp hhexp _region_ _milieu_ strate pond  pauv 
rename _region_ reg
rename _milieu_ rururb
generate grappen = real(grappe)
generate menordn = real(menord)

/*Generate HH id number*/
gen idmen = grappen*100 + menordn
drop grappe menord

recode pauv .=0
label define  pauvl 1 poor 0 nopoor
label value pauv pauvl
  
encode reg, gen(regn)
encode rururb, gen(rururbn)

order idmen pond  pauv pchhexp hhexp regn rururbn  hhsize sexhead agehead csphead   regn rururbn strate reg rururb grappen menordn 
sort idmen
save civ_inc,  replace

/*================================================================================================
                                                                Adding job type for the head of HH
=================================================================================================*/
use sect02,  clear

keep grappe menord s1q2 s2q16a  s2q16b 

keep if s1q2==1

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn s1q2 s2q16a  

gen job =1
replace job=2 if s2q16b==6 | s2q16b ==7
replace job=3 if (s2q16b==8 | s2q16b ==9 | s2q16b ==10 | s2q16b ==11| s2q16b ==12 | s2q16b ==13)
/*replace job=4 if (s2q16b==14 | s2q16b ==15 | s2q16b ==16)*/
replace job=41 if s2q16b==14 
replace job=42 if s2q16b==15
replace job=43 if s2q16b ==16
/*replace job=5 if (s2q16b==17 | s2q16b ==18 | s2q16b ==19 | s2q16b ==20 | s2q16b ==21)*/
replace job=51 if s2q16b==17
replace job=52 if s2q16b==18
replace job=53 if s2q16b==19
replace job=54 if s2q16b==20
replace job=55 if s2q16b==21

replace job=6 if (s2q16b==.)
label define jobl 1 cvserc 2 prsect 3 ast_prsc 41 iboss_woe 42 iboss_we 43 aid 51 agr 52 mty 53 d_aid 54 Agr_aid 55 oth_agr 6 other
label value job jobl

sort idmen
save tmp1, replace

merge idmen using civ_inc
recode job .=6
drop _merge s2q16b 

sort idmen
save civ_inc, replace


/*================================================================================================
                                                                Adding HH  wage received from formal job
=================================================================================================*/
use sect02,  clear

keep grappe menord s1q2 s2q26a  s2q26b s2cq12a  s2cq12b 

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

rename s2q26a wage1
rename s2q26b unit1
rename s2cq12a wage2
rename s2cq12b unit2

/* annual wage*/
gen awage1=0
replace awage1=wage1*52 if unit1==1
replace awage1=wage1*12 if unit1==2
replace awage1=wage1*4 if unit1==3
replace awage1=wage1*2 if unit1==4
replace awage1=wage1 if unit1==5

gen awage2=0
replace awage2=wage2*260 if unit2==1  /*assumption: 5 days per week and 52 weeks =260 working days in a year*/
replace awage2=wage2*52 if unit2==2  
replace awage2=wage2*12 if unit2==3
replace awage2=wage2 if unit1==4

/*generate wage income per hh*/
collapse (sum) awage1 awage2, by (idmen) fast

gen wage=awage1+awage2

sort idmen
save tmp1, replace

merge idmen using civ_inc
drop _merge

sort idmen
save civ_inc, replace

/* ===================================================================================
                                                                         Income from livestock
=====================================================================================*/
use sect03a,  clear

keep grappe menord   s3aq8  s3aq12a  s3aq12b 
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

ren s3aq8  lsrev
recode lsrev .=0
ren s3aq12a  lsauto
ren s3aq12b lsunit

gen lsautcon=0
replace lsautcon=lsauto*365 if lsunit==1 /*each day*/
replace lsautcon=lsauto*52  if lsunit==2 /*every week*/
replace lsautcon=lsauto*104  if lsunit==3 /*twice a week*/
replace lsautcon=lsauto*12  if lsunit==4 /*once a month*/
replace lsautcon=lsauto*24  if lsunit==5 /*twice a month*/
replace lsautcon=lsauto*4  if lsunit==6 /*once a quarter*/
replace lsautcon=lsauto*2  if lsunit==7 /* once a semester*/
replace lsautcon=lsauto  if lsunit==8 /*once a year*/

gen ls_inc=lsrev+lsautcon

collapse (sum) ls_inc, by (idmen) fast

sort idmen
save tmp1, replace

merge idmen using civ_inc
drop _merge
sort idmen
save civ_inc, replace

/*========================================================================================
                                                       Income from hunting, fishing and honey
==========================================================================================*/
use sect03b1,  clear

keep grappe menord    s3b1q2a s3b1q2b  s3b1q4a s3b1q4b s3b1q7 s3b1q8 s3b1q9 s3b1q11a s3b1q11b s3b1q13a s3b1q13b s3b1q16a s3b1q16b
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

/*fishing income*/
ren s3b1q2a  f_rev
ren s3b1q2b f_unit
gen fish_rev =0
replace fish_rev=f_rev*260 if  f_unit ==1  /*every day, 5 days/week  and 52 wks a yr*/
replace fish_rev=f_rev*52 if  f_unit ==2  /*every week and 52 wks a yr*/
replace fish_rev=f_rev*104 if  f_unit ==3  /*twice a week*/
replace fish_rev=f_rev*12 if  f_unit ==4  /*once a month*/
replace fish_rev=f_rev*24  if  f_unit ==5  /*twice a month*/
replace fish_rev=f_rev*4 if  f_unit ==6  /*once a quarter*/

ren s3b1q4a  f_rev_a
ren s3b1q4b f_unit_a
gen fish_rev_a =0
replace fish_rev_a=f_rev_a*260 if  f_unit_a ==1  /*every day, 5 days/week  and 52 wks a yr*/
replace fish_rev_a=f_rev_a*52 if  f_unit_a ==2  /*every week and 52 wks a yr*/
replace fish_rev_a=f_rev_a*104 if  f_unit_a ==3  /*twice a week*/
replace fish_rev_a=f_rev_a*12 if  f_unit_a ==4  /*once a month*/
replace fish_rev_a=f_rev_a*24  if  f_unit_a ==5  /*twice a month*/
replace fish_rev_a=f_rev_a*4 if  f_unit_a ==6  /*once a quarter*/

gen fish_inc = fish_rev + fish_rev_a

/*Honey income*/
ren s3b1q7 honey_q_s
ren s3b1q8 honey_q_c
ren s3b1q9 honey_price

gen honey_inc=(honey_q_s +honey_q_c) * honey_price

/*Hunting income*/
ren s3b1q11a h_rev
ren s3b1q11b h_unit
gen hunt_rev =0
replace hunt_rev=h_rev*260 if  h_unit ==1  /*every day, 5 days/week  and 52 wks a yr*/
replace hunt_rev=h_rev*52 if  h_unit ==2  /*every week and 52 wks a yr*/
replace hunt_rev=h_rev*104 if  h_unit ==3  /*twice a week*/
replace hunt_rev=h_rev*12 if  h_unit ==4  /*once a month*/
replace hunt_rev=h_rev*24  if  h_unit ==5  /*twice a month*/
replace hunt_rev=h_rev*4 if  h_unit ==6  /*once a quarter*/

ren s3b1q13a  h_rev_a
ren s3b1q13b h_unit_a
gen hunt_rev_a =0
replace hunt_rev_a=h_rev_a*260 if  h_unit_a ==1  /*every day, 5 days/week  and 52 wks a yr*/
replace hunt_rev_a=h_rev_a*52 if  h_unit_a ==2  /*every week and 52 wks a yr*/
replace hunt_rev_a=h_rev_a*104 if  h_unit_a ==3  /*twice a week*/
replace hunt_rev_a=h_rev_a*12 if  h_unit_a ==4  /*once a month*/
replace hunt_rev_a=h_rev_a*24  if  h_unit_a ==5  /*twice a month*/
replace hunt_rev_a=h_rev_a*4 if  h_unit_a ==6  /*once a quarter*/

gen hunt_inc = hunt_rev + hunt_rev_a

/* Agriculture cost*/
ren s3b1q16a s_rev
ren s3b1q16b s_unit
gen staff_cost=0
replace staff_cost=s_rev*260 if  s_unit ==1  /*every day, 5 days/week  and 52 wks a yr*/
replace staff_cost=s_rev*52 if  s_unit ==2  /*every week and 52 wks a yr*/
replace staff_cost=s_rev*104 if  s_unit ==3  /*twice a week*/
replace staff_cost=s_rev*12 if  s_unit ==4  /*once a month*/
replace staff_cost=s_rev*24  if  s_unit ==5  /*twice a month*/
replace staff_cost=s_rev*4 if  s_unit ==6  /*once a quarter*/

/*gen agr_inc1=fish_inc+ honey_inc+ hunt_inc*/
gen agr_inc1=fish_inc+ honey_inc+ hunt_inc -staff_cost

collapse (sum) agr_inc1 , by (idmen) fast

sort idmen
save tmp1, replace

merge idmen using civ_inc
drop _merge

sort idmen
save civ_inc, replace

/*========================================================================================
                                                       Income from agriculture crop
==========================================================================================*/
use sect03b2,  clear

keep grappe menord    s3b2q6a s3b2q7  s3b2q8 s3b2q19 s3b2q21 s3b2q23
recode s3b2q6a .=0
recode s3b2q7 .=0
recode s3b2q8 .=0
recode s3b2q19 .=0
recode s3b2q21 .=0
recode s3b2q23 .=0

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

/*crop rev*/
ren s3b2q8 c_rev
gen c_rev2=s3b2q6a *s3b2q7 
/*crop cost*/
ren s3b2q19 cost_frt
ren s3b2q21 cost_ins
ren s3b2q23 cost_seed

/*gen agr_inc2=c_rev*/
gen agr_inc2=c_rev-cost_frt-cost_ins-cost_seed
gen agr_inc2_2=c_rev2-cost_frt-cost_ins-cost_seed

collapse (sum) agr_inc2 agr_inc2_2, by (idmen) fast

sort idmen
save tmp1, replace

merge idmen using civ_inc
drop if _merge==1
drop _merge

sort idmen
save civ_inc, replace

/*========================================================================================
                                                       Income from non agricultural firm
==========================================================================================*/
use sect04b,  clear

keep grappe menord     s4bq4   s4bq9a s4bq9b
recode s4bq9a  .=0
recode s4bq9b .=0

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

gen nagr_rev=0
replace nagr_rev=s4bq9a*260 if s4bq9b==1
replace nagr_rev=s4bq9a*52 if s4bq9b==2
replace nagr_rev=s4bq9a*12 if s4bq9b==3
replace nagr_rev=s4bq9a*3 if s4bq9b==4
replace nagr_rev=s4bq9a  if s4bq9b==5

collapse (sum) nagr_rev , by (idmen) fast
recode nagr_rev .=0
sort idmen
save tmp1, replace

merge idmen using civ_inc
drop _merge

sort idmen
save civ_inc, replace

/*========================================================================================
                                                       Other cost from entrprises
==========================================================================================*/
use sect05a,  clear

 recode s5aq1 .=0
 recode s5aq2 .=0
 recode s5aq3 .=0
 recode s5aq4 .=0
 recode s5aq5 .=0
 recode s5aq6 .=0
 recode s5aq7 .=0
 recode s5aq8 .=0
 recode s5aq9 .=0
 recode s5aq10 .=0

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

gen gas=s5aq1*12
gen elec=s5aq2*6
gen water=s5aq3*4
gen transp=s5aq4*12
gen oexp=(s5aq5*260+s5aq6*12+s5aq7)/3
gen wag_p= s5aq8
gen n_mch=s5aq10

gen oth_cost=gas+elec+water+transp+oexp+wag_p+n_mch

collapse (sum) oth_cost , by (idmen) fast
sort idmen
save tmp1, replace

merge idmen using civ_inc
drop _merge

sort idmen
save civ_inc, replace

/*========================================================================================
                                                       Loans
==========================================================================================*/
use sect05b,  clear

 recode  s5bq7 .=0
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

gen loan=s5bq7

collapse (sum) loan, by (idmen) fast
sort idmen
save tmp1, replace

merge idmen using civ_inc
drop _merge

sort idmen

save civ_inc, replace


/*========================================================================================
                                                       Income from complementary resources
==========================================================================================*/
use sect09,  clear

keep grappe menord      s9q0 s9q1a s9q1b

recode s9q1a .=0

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord  grappen menordn

gen oth_agr=s9q1a 
replace oth_agr=0 if (s9q0~=1 & s9q0~=2)
recode s9q1b .=4 if s9q0 ==1
recode s9q1b .=2 if s9q0 ==2

gen oth_wag=s9q1a
replace oth_wag=0 if (s9q0~=3 & s9q0~=4 & s9q0~=5 & s9q0~=6  & s9q0~=12)
recode s9q1b .=4 if s9q0 ==3 | s9q0 ==12
recode s9q1b .=4 if s9q0 ==4 | s9q0 ==5 | s9q0 ==6

gen rent=s9q1a
replace rent=0 if s9q0~=7
recode s9q1b .=1 if (s9q0==7 & rent<1000000)
recode s9q1b .=4 if (s9q0==7 & rent>1000000)

gen transfer=s9q1a
replace transfer=0 if  (s9q0~=8 & s9q0~=9 & s9q0~=10 & s9q0~=11)
recode s9q1b .=2 if (s9q0==8 & s9q1a<100000)
recode s9q1b .=4 if (s9q0==8 & s9q1a>100000)
recode s9q1b .=2 if (s9q0==9 | s9q0==10)
recode s9q1b .=1 if (s9q0==11)

gen saving=s9q1a
replace saving=0 if s9q0~=13
recode  s9q1b .=4 if s9q0==13

collapse (sum) oth_agr oth_wag  rent transfer saving , by (idmen) fast
sort idmen
save tmp1, replace

merge idmen using civ_inc

drop _merge
sort idmen
save civ_inc, replace


/* ===========================
 Total hh income
==============================*/
recode wage .=0
recode oth_wag .=0
recode rent  .=0
recode ls_inc .=0
recode agr_inc1 .=0
recode agr_inc2 .=0
recode oth_agr .=0
recode nagr_rev .=0
recode transfer .=0
recode saving .=0
recode loan   .=0

gen hhinc= wage+oth_wag+rent +ls_inc+agr_inc1+agr_inc2+oth_agr+nagr_rev+transfer +saving+loan       
gen hhinc2=  wage+oth_wag+rent +ls_inc+agr_inc1+agr_inc2_2+oth_agr+nagr_rev+transfer +saving+loan

/*deflatd income*/

gen dhhinc=hhinc if strate==1
replace dhhinc=hhinc/0.96 if strate==2
replace dhhinc=hhinc/0.90 if strate==3
replace dhhinc=hhinc/0.96 if strate==4
replace dhhinc=hhinc/0.78 if strate==5

gen dhhinc2=hhinc2 if strate==1
replace dhhinc2=hhinc2/0.96 if strate==2
replace dhhinc2=hhinc2/0.90 if strate==3
replace dhhinc2=hhinc2/0.96 if strate==4
replace dhhinc2=hhinc2/0.78 if strate==5
/*
svyset strata strate
svyset psu idmen
svyset pweight pond
*/
gen agr_inc=agr_inc1+agr_inc2
svymean hhinc hhinc2 hhexp wage ls_inc agr_inc agr_inc1 agr_inc2 nagr_rev loan, by(pauv)
svymean hhinc hhinc2 hhexp wage ls_inc agr_inc agr_inc1 agr_inc2 nagr_rev loan  if pauv==1
svymean hhinc hhinc2 hhexp wage ls_inc agr_inc agr_inc1 agr_inc2 nagr_rev loan  if pauv==0

local xxx "wage ls_inc agr_inc  nagr_rev loan oth_agr oth_wag  rent transfer saving"
	foreach var of local xxx {
 	gen r`var'=`var'/hhinc
}

svymean rwage rls_inc ragr_inc  rnagr_rev rloan roth_agr roth_wag  rrent rtransfer rsaving, by(pauv)
svymean rwage rls_inc ragr_inc rnagr_rev rloan roth_agr roth_wag  rrent rtransfer rsaving if pauv==1
svymean rwage rls_inc ragr_inc  rnagr_rev rloan roth_agr roth_wag  rrent rtransfer rsaving if pauv==0
svymean rwage rls_inc ragr_inc  rnagr_rev rloan roth_agr roth_wag  rrent rtransfer rsaving if job==43


*gen pondn = pond*hhsize
*svyset pweight pondn

gen pchhinc=dhhinc/hhsize
gen pchhinc2=dhhinc2/hhsize
gen pchhinc_test=pchhinc - (oth_cost/hhsize)

gen dincexp=pchhinc-pchhexp
/*gen dincexp2=pchhinc2-pchhexp*/

sum pchhinc pchhexp dincexp if pchhinc>=0, detail
sum  pchhinc pchhexp dincexp if job==1 , detail
sum pchhinc pchhexp  dincexp if job==2, detail
sum pchhinc pchhexp dincexp if job==3, detail
sum pchhinc pchhexp dincexp if job==41 & pchhinc>=0, detail
sum pchhinc pchhexp dincexp if job==42, detail
sum pchhinc pchhexp dincexp if job==43 & pchhinc>=0, detail
sum pchhinc pchhexp dincexp if job==51& pchhinc>=0, detail
sum pchhinc pchhexp dincexp if job==52, detail
sum pchhinc pchhexp dincexp if job==53, detail
sum pchhinc pchhexp dincexp if job==54 & pchhinc>=0, detail
sum pchhinc pchhexp dincexp if job==55, detail
sum pchhinc pchhexp dincexp  if job==6 & pchhinc>=0, detail


svymean pchhinc pchhexp dincexp , by(pauv) obs size
svymean pchhinc pchhexp dincexp , by(rururbn ) obs size
svymean pchhinc pchhexp dincexp , by( rururbn pauv) obs size
svymean pchhinc pchhexp dincexp , by( regn) obs size
svymean pchhinc pchhexp dincexp , by( pauv regn) obs size
svymean pchhinc pchhexp dincexp , by( rururbn regn) obs size
svymean pchhinc pchhexp dincexp , by( job) obs size
svymean pchhinc pchhexp dincexp , by( pauv job) obs size
svymean pchhinc pchhexp dincexp , by( job pauv ) obs size


corr pchhinc pchhexp
corr pchhinc pchhexp if job==1
corr pchhinc pchhexp if job==2
corr pchhinc pchhexp if job==3
corr pchhinc pchhexp if job==41
corr pchhinc pchhexp if job==42
corr pchhinc pchhexp if job==43
corr pchhinc pchhexp if job==51
corr pchhinc pchhexp if job==52
corr pchhinc pchhexp if job==53
corr pchhinc pchhexp if job==54
corr pchhinc pchhexp if job==55
corr pchhinc pchhexp if job==6

spearman pchhinc pchhexp
spearman pchhinc pchhexp if job==1
spearman pchhinc pchhexp if job==2
spearman pchhinc pchhexp if job==3
spearman pchhinc pchhexp if job==41
spearman pchhinc pchhexp if job==42
spearman pchhinc pchhexp if job==43
spearman pchhinc pchhexp if job==51
spearman pchhinc pchhexp if job==52
spearman pchhinc pchhexp if job==53
spearman pchhinc pchhexp if job==54
spearman pchhinc pchhexp if job==55
spearman pchhinc pchhexp if job==6


/* take off the extreme observation based on the difference between income and expenditure*/

/*1st case: Using the variance. The standard deviation for dincexp is 4565304 and its mean is 47701.96*/
gen varpct =0
replace varpct=1 if (dincexp >= 47701.96 - (2*4565304)  & dincexp <= 47701.96 + (2*4565304)) 

/*2nd case: take off the 1% top and bottom: 1% percentile = -1667159;   99%percentile value = 2895684*/
gen onepct =0
replace onepct=1 if (dincexp >=-1667159  & dincexp <= 2895684) 

/*3nd case: take off the 5% top and bottom:  5% percentile value= -735956; 95% percentile=700927   */
gen fivepct =0
replace fivepct=1 if (dincexp >=-735956 & dincexp <= 700927  ) 
save, replace

log on
sum pchhinc pchhexp dincexp if pchhinc>=0 & varpct==1, detail
sum pchhinc pchhexp dincexp if pchhinc>=0 & onepct==1, detail
sum pchhinc pchhexp dincexp if pchhinc>=0 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==1 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==1 & onepct==1, detail
sum pchhinc pchhexp dincexp if job==1 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==2 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==2 & onepct==1, detail
sum pchhinc pchhexp dincexp if job==2 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==3 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==3 & onepct==1, detail
sum pchhinc pchhexp dincexp if job==3 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==41  & pchhinc>=0 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==41  & pchhinc>=0  & onepct==1, detail
sum pchhinc pchhexp dincexp if job==41 & pchhinc>=0 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==42 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==42 & onepct==1, detail
sum pchhinc pchhexp dincexp if job==42 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==43  & pchhinc>=0 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==43  & pchhinc>=0  & onepct==1, detail
sum pchhinc pchhexp dincexp if job==43 & pchhinc>=0 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==51  & pchhinc>=0 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==51  & pchhinc>=0  & onepct==1, detail
sum pchhinc pchhexp dincexp if job==51  & pchhinc>=0 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==52 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==52 & onepct==1, detail
sum pchhinc pchhexp dincexp if job==52 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==53 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==53 & onepct==1, detail
sum pchhinc pchhexp dincexp if job==53 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==54  & pchhinc>=0 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==54  & pchhinc>=0  & onepct==1, detail
sum pchhinc pchhexp dincexp if job==54  & pchhinc>=0 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==55 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==55 & onepct==1, detail
sum pchhinc pchhexp dincexp if job==55 & fivepct==1, detail

sum pchhinc pchhexp dincexp if job==6   & pchhinc>=0 & varpct==1, detail
sum pchhinc pchhexp dincexp if job==6  & pchhinc>=0  & onepct==1, detail
sum pchhinc pchhexp dincexp if job==6  & pchhinc>=0 & fivepct==1, detail

/*correlation between income and expenditure*/
corr pchhinc pchhexp  
corr pchhinc pchhexp if varpct ==1
corr pchhinc pchhexp if onepct==1
corr pchhinc pchhexp if  fivepct==1


corr pchhinc pchhexp if job==1 
corr pchhinc pchhexp if job==1 & varpct ==1
corr pchhinc pchhexp if job==1 & onepct==1
corr pchhinc pchhexp if job==1 & fivepct==1

corr pchhinc pchhexp if job==2 
corr pchhinc pchhexp if job==2 & varpct ==1
corr pchhinc pchhexp if job==2 & onepct==1
corr pchhinc pchhexp if job==2 & fivepct==1

corr pchhinc pchhexp if job==3 
corr pchhinc pchhexp if job==3 & varpct ==1
corr pchhinc pchhexp if job==3 & onepct==1
corr pchhinc pchhexp if job==3 & fivepct==1

corr pchhinc pchhexp if job==41 
corr pchhinc pchhexp if job==41 & varpct ==1
corr pchhinc pchhexp if job==41 & onepct==1
corr pchhinc pchhexp if job==41 & fivepct==1

corr pchhinc pchhexp if job==42 
corr pchhinc pchhexp if job==42 & varpct ==1
corr pchhinc pchhexp if job==42 & onepct==1
corr pchhinc pchhexp if job==42 & fivepct==1

corr pchhinc pchhexp if job==43 
corr pchhinc pchhexp if job==43 & varpct ==1
corr pchhinc pchhexp if job==43 & onepct==1
corr pchhinc pchhexp if job==43 & fivepct==1

corr pchhinc pchhexp if job==51 
corr pchhinc pchhexp if job==51 & varpct ==1
corr pchhinc pchhexp if job==51 & onepct==1
corr pchhinc pchhexp if job==51 & fivepct==1

corr pchhinc pchhexp if job==52 
corr pchhinc pchhexp if job==52 & varpct ==1
corr pchhinc pchhexp if job==52 & onepct==1
corr pchhinc pchhexp if job==52 & fivepct==1

corr pchhinc pchhexp if job==53 
corr pchhinc pchhexp if job==53 & varpct ==1
corr pchhinc pchhexp if job==53 & onepct==1
corr pchhinc pchhexp if job==53 & fivepct==1

corr pchhinc pchhexp if job==54 
corr pchhinc pchhexp if job==54 & varpct ==1
corr pchhinc pchhexp if job==54 & onepct==1
corr pchhinc pchhexp if job==54 & fivepct==1

corr pchhinc pchhexp if job==55 
corr pchhinc pchhexp if job==55 & varpct ==1
corr pchhinc pchhexp if job==55 & onepct==1
corr pchhinc pchhexp if job==55 & fivepct==1

corr pchhinc pchhexp if job==6 
corr pchhinc pchhexp if job==6 & varpct ==1
corr pchhinc pchhexp if job==6 & onepct==1
corr pchhinc pchhexp if job==6 & fivepct==1


/* Spearman ratio between income and expenditure*/
spearman  pchhinc pchhexp  
spearman  pchhinc pchhexp if varpct ==1
spearman  pchhinc pchhexp if onepct==1
spearman  pchhinc pchhexp if  fivepct==1


spearman  pchhinc pchhexp if job==1 
spearman  pchhinc pchhexp if job==1 & varpct ==1
spearman  pchhinc pchhexp if job==1 & onepct==1
spearman  pchhinc pchhexp if job==1 & fivepct==1

spearman  pchhinc pchhexp if job==2 
spearman  pchhinc pchhexp if job==2 & varpct ==1
spearman  pchhinc pchhexp if job==2 & onepct==1
spearman  pchhinc pchhexp if job==2 & fivepct==1

spearman  pchhinc pchhexp if job==3 
spearman  pchhinc pchhexp if job==3 & varpct ==1
spearman  pchhinc pchhexp if job==3 & onepct==1
spearman  pchhinc pchhexp if job==3 & fivepct==1

spearman  pchhinc pchhexp if job==41 
spearman  pchhinc pchhexp if job==41 & varpct ==1
spearman  pchhinc pchhexp if job==41 & onepct==1
spearman  pchhinc pchhexp if job==41 & fivepct==1

spearman  pchhinc pchhexp if job==42 
spearman  pchhinc pchhexp if job==42 & varpct ==1
spearman  pchhinc pchhexp if job==42 & onepct==1
spearman  pchhinc pchhexp if job==42 & fivepct==1

spearman  pchhinc pchhexp if job==43 
spearman  pchhinc pchhexp if job==43 & varpct ==1
spearman  pchhinc pchhexp if job==43 & onepct==1
spearman  pchhinc pchhexp if job==43 & fivepct==1

spearman  pchhinc pchhexp if job==51 
spearman  pchhinc pchhexp if job==51 & varpct ==1
spearman  pchhinc pchhexp if job==51 & onepct==1
spearman  pchhinc pchhexp if job==51 & fivepct==1

spearman  pchhinc pchhexp if job==52 
spearman  pchhinc pchhexp if job==52 & varpct ==1
spearman  pchhinc pchhexp if job==52 & onepct==1
spearman  pchhinc pchhexp if job==52 & fivepct==1

spearman  pchhinc pchhexp if job==53 
spearman  pchhinc pchhexp if job==53 & varpct ==1
spearman  pchhinc pchhexp if job==53 & onepct==1
spearman  pchhinc pchhexp if job==53 & fivepct==1

spearman  pchhinc pchhexp if job==54 
spearman  pchhinc pchhexp if job==54 & varpct ==1
spearman  pchhinc pchhexp if job==54 & onepct==1
spearman  pchhinc pchhexp if job==54 & fivepct==1

spearman  pchhinc pchhexp if job==55 
spearman  pchhinc pchhexp if job==55 & varpct ==1
spearman  pchhinc pchhexp if job==55 & onepct==1
spearman  pchhinc pchhexp if job==55 & fivepct==1

spearman  pchhinc pchhexp if job==6 
spearman  pchhinc pchhexp if job==6 & varpct ==1
spearman  pchhinc pchhexp if job==6 & onepct==1
spearman  pchhinc pchhexp if job==6 & fivepct==1






log off


capture log close
exit

