/*===============================================================================

            			  CI: Infrastructure data 
				Energy  - Water and Sanitation - Transport - ICT                                         
                        
				                  Gaston Gohou
                                            May 2004

This program computes the infrastructure statistics of hh based on the 2002 HH survey

  ================================================================================= */

version 7.0
clear
capture log close
set more off
set mem 32m
set matsize 800

cd "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\"
log using civ02_infra_res.txt, replace text 
log off

/*Expenditure and HH characteristics*/
/* Add the HH level varrables: hh expenditure, weight, poverty statut*/

use pauvre.dta,  replace
keep grappe menord hhsize pchhexp hhexp _region_ _milieu_ strate pond  pauv 
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn

rename _region_ reg
rename _milieu_ rururb
encode reg, gen(regn)
encode rururb, gen(rururbn)
drop rururb reg menordn menord grappen grappe 

gen urban=cond(rururbn==2, 1,0)
label define urbl 1 urban 0 rural
label value urban urbl
drop rururbn

recode pauv .=0
label define  pauvl 1 poor 0 nopoor
label value pauv pauvl

gen pondn=pond*hhsize
sort pchhexp

/*===gen population quintile====*/
xtile ppquint = pchhexp [pweight=pondn], nq(5)
xtile ppquint_urb = pchhexp [pweight=pondn] if urban==1, nq(5)
xtile ppquint_rur = pchhexp [pweight=pondn] if urban==0, nq(5)


/*===gen household quintile====*/
xtile hhquint = pchhexp [pweight=pond], nq(5)
xtile hhquint_urb = pchhexp [pweight=pond] if urban==1, nq(5)
xtile hhquint_rur = pchhexp [pweight=pond] if urban==0, nq(5)

sort idmen
save civ02_infr.dta, replace


/* ============  Energy varaibles  =====================*/

use "Q:\My Documents\AfrPRSP\Survey\Civ\EP2002\Data\stata\sect07.dta",  clear
keep grappe menord s7q12 s7q13a s7q13b s7q15 s7q16a s7q16b s7q17 s7q18a s7q18b s7q19 s7q20 s7q21 s7q22 s7q23 s7q24

generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord grappen menordn 

/*Lighting sources*/
ren s7q15 light
recode light 5=4
label variable light "Main source of lighting"
label define light 1 lamp 2 "Pub-provided electricity" 3 "Priv-provided electricity"  4 other
label value light light

ren s7q16a t 
gen light_exp = 0
replace light_exp = t*52 if s7q16b==1
replace light_exp = t*12 if s7q16b==2
replace light_exp = t*6 if s7q16b==3
label variable light_exp "Annual light expenditure"
drop t

/*Main cooking fuel*/
ren s7q17 cook
recode cook 4=2 3=1 6=5 8=7 10=9 12=11
label variable light "Main cooking fuel"
label define cook 1 charcoal 2 firewood 5 "liquif. petroleum" 7 "Pub electricity"  9 "kerosen" 11 other
label value cook cook

ren s7q18a t 
gen cook_exp = 0
replace cook_exp = t*365 if s7q18b==1
replace cook_exp = t*52 if s7q18b==2
replace cook_exp = t*12 if s7q18b==3
replace cook_exp = t*8 if s7q18b==4
replace cook_exp = t*6 if s7q18b==5
label variable cook_exp "Annual cooking fuel expenditure"
drop t

/*Water and sanitation*/

/*Toilet*/
ren s7q21 toilet
label variable toilet "Toilet facility"
label define toilet 1 "connected to sewewerage" 2 "Septic tank" 3 "none"
label value toilet toilet 


/*Water*/
ren s7q12 water
label variable water "source of drinking water"
label define water 1 "Piped in dwelling" 2 "Public Tap" 3 "tanker, vendor" 4 "Tubed_piped well or borehole" 5 "Protected dug well"  6 "river" 7 "other"
label value water water

ren s7q13a t 
gen water_exp = 0
replace water_exp = t*365 if s7q13b==1
replace water_exp = t*182 if s7q13b==2
replace water_exp = t*122 if s7q13b==3
replace water_exp = t*52 if s7q13b==4
replace water_exp = t*26 if s7q13b==5
replace water_exp = t*4 if s7q13b==6
label variable water_exp "Annual Water expenditure"
drop t


/*========ICT===================*/
/*Access to phone=====*/
ren s7q23 phone
label variable phone "Owner of a phone*/

ren s7q24 phone_type
label define phone_type 1 cell_phone 2 fix 3 both
label value phone_type phone_type 

drop s7q13b s7q16b s7q18b s7q19 s7q20 s7q22


sort idmen
save tmp1.dta, replace
merge using civ02_infr.dta
drop _merge

sort idmen
save civ02_infr.dta, replace

/*====TV ownership======*/
use sect10b.dta, clear
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord grappen menordn 

keep if s10bq1a==7
keep idmen s10bq1b
ren s10bq1b tv
label variable tv "tv ownership"
label define tv 1 yes 2 no
label value tv tv 
sort idmen
save tmp.dta, replace 
merge idmen using civ02_infr.dta
drop _merge
sort idmen
save civ02_infr.dta, replace

/*====Radio ownership======*/
use sect10b.dta, clear
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord grappen menordn 

keep if s10bq1a==8
keep idmen s10bq1b
ren s10bq1b radio 
label variable radio "radio ownership"
label define radio 1 yes 2 no
label value radio radio 
sort idmen
save tmp.dta, replace 
merge idmen using civ02_infr.dta
drop _merge
sort idmen
save civ02_infr.dta, replace


/*============transport============*/

/*====Car ownership======*/
use sect10b.dta, clear
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord grappen menordn 

keep if s10bq1a==6
keep idmen s10bq1b
ren s10bq1b car
label variable car "car ownership"
label define car 1 yes 2 no
label value car car 
sort idmen
save tmp.dta, replace 
merge idmen using civ02_infr.dta
drop _merge
sort idmen
save civ02_infr.dta, replace

/*====Bicycles  ownership======*/
use sect10b.dta, clear
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord grappen menordn 

keep if s10bq1a==4
keep idmen s10bq1b
ren s10bq1b bike
label variable bike "bike ownership"
label define bike 1 yes 2 no
label value bike bike
sort idmen
save tmp.dta, replace 
merge idmen using civ02_infr.dta
drop _merge
sort idmen
save civ02_infr.dta, replace

/*====Motorcycles  ownership======*/
use sect10b.dta, clear
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord grappen menordn 

keep if s10bq1a==5
keep idmen s10bq1b
ren s10bq1b motorcycle
label variable motorcycle "Motorcycle ownership"
label define bike 1 yes 2 no
label value motorcycle motorcycle
sort idmen
save tmp.dta, replace 
merge idmen using civ02_infr.dta
drop _merge
sort idmen
save civ02_infr.dta, replace


/* Spending on transport and communication */
use sect08f.dta, clear
generate grappen = real(grappe)
generate menordn = real(menord)
gen idmen = grappen*100 + menordn
drop grappe menord grappen menordn 

#delimit; 
recode s8fq2 .=0; recode s8fq3 .=0; recode s8fq4 .=0; recode s8fq5 .=0;
recode s8fq6 .=0; recode s8fq7 .=0;
#delimit cr

gen transp_exp= s8fq2+ s8fq3 + s8fq4 + s8fq5
gen comm_exp = s8fq6 + s8fq7
collapse (sum) transp_exp comm_exp, by (idmen)

sort idmen
save tmp.dta, replace 
merge idmen using civ02_infr.dta
drop _merge
sort idmen
save civ02_infr.dta, replace

svyset strata strate
svyset psu idmen
/*svyset pweight pond
gen pondn = pond*hhsize*/
svyset pweight pondn


log on

/*========
			MAIN LIGHTING SOURCE
							========*/
/* BY urban rural (%HH)*/
svytab light  urban [pw=pond], percent column

/* BY NATIONAL QUINTILE (%HH)*/
svytab light  hhquint [pw=pond], percent  column

/*BY URBAN QUINTILE (%HH)*/
svytab light  hhquint_urb [pw=pond], percent  column

/*BY RURAL QUINTILE (%HH)*/
svytab light  hhquint_rur [pw=pond], percent  column

/*BY urban rural (%POPULATION)*/
svytab light  urban [pw=pondn], percent  column

/*BY NATIONAL QUINTILE (%POPULATION)*/
svytab light  ppquint [pw=pondn], percent  column

/*BY URBAN QUINTILE (%POPULATION)*/
svytab light  ppquint_urb [pw=pondn], percent  column

/*BY RURAL QUINTILE (%POPULATION)*/
svytab light  ppquint_rur [pw=pondn], percent  column


/*========
			MAIN COOKING FUEL USED
							========*/

/* BY urban rural (%HH)*/
svytab cook urban [pw=pond], percent  column

/* BY NATIONAL QUINTILE (%HH)*/
svytab cook hhquint [pw=pond], percent  column

/*BY URBAN QUINTILE (%HH)*/
svytab cook hhquint_urb [pw=pond], percent  column

/*BY RURAL QUINTILE (%HH)*/
svytab cook hhquint_rur [pw=pond], percent  column

/*BY urban rural (%POPULATION)*/
svytab cook urban [pw=pondn], percent  column

/*BY NATIONAL QUINTILE (%POPULATION)*/
svytab cook ppquint [pw=pondn], percent  column

/*BY URBAN QUINTILE (%POPULATION)*/
svytab cook ppquint_urb [pw=pondn], percent  column

/*BY RURAL QUINTILE (%POPULATION)*/
svytab cook ppquint_rur [pw=pondn], percent  column


/*==============
		 Spending on electricity (% of household)
									============*/
gen r_light_exp= 100*light_exp/ ( hhexp* hhsize)
/*urban  rural total */ 
sum r_light_exp
bysort urban: sum r_light_exp 

/*national quitile */ 
bysort hhquint: sum r_light_exp 

/*Urban quitile */ 
bysort hhquint_urb: sum r_light_exp 

/*Rural quitile */ 
bysort hhquint_rur: sum r_light_exp 


/*==============
		 Spending on cooking fuel (% of household)
									============*/
gen r_cook_exp= 100*cook_exp/ ( hhexp* hhsize)
/*urban  rural total */ 
sum r_cook_exp
bysort urban: sum r_cook_exp 

/*national quitile */ 
bysort hhquint: sum r_cook_exp

/*Urban quitile */ 
bysort hhquint_urb: sum r_cook_exp 

/*Rural quitile */ 
bysort hhquint_rur: sum r_cook_exp


/*========
			WATER AND SANITATION
							========*/
/*TOILET*/
/* BY urban rural (%HH)*/
svytab toilet urban [pw=pond], percent  column

/* BY NATIONAL QUINTILE (%HH)*/
svytab toilet hhquint [pw=pond], percent  column

/*BY URBAN QUINTILE (%HH)*/
svytab toilet hhquint_urb [pw=pond], percent  column

/*BY RURAL QUINTILE (%HH)*/
svytab toilet hhquint_rur [pw=pond], percent  column

/*BY urban rural (%POPULATION)*/
svytab toilet urban [pw=pondn], percent  column

/*BY NATIONAL QUINTILE (%POPULATION)*/
svytab toilet ppquint [pw=pondn], percent  column

/*BY URBAN QUINTILE (%POPULATION)*/
svytab toilet ppquint_urb [pw=pondn], percent  column

/*BY RURAL QUINTILE (%POPULATION)*/
svytab toilet ppquint_rur [pw=pondn], percent  column

/*==============
		 Spending on water (% of household)
									============*/
gen r_water_exp= 100*water_exp/ ( hhexp* hhsize)
/*urban  rural total */ 
sum r_water_exp
bysort urban: sum r_water_exp 

/*national quitile */ 
bysort hhquint: sum r_water_exp

/*Urban quitile */ 
bysort hhquint_urb: sum r_water_exp 

/*Rural quitile */ 
bysort hhquint_rur: sum r_water_exp


/*Drinking Water*/
/* BY urban rural (%HH)*/
svytab water  urban [pw=pond], percent  column

/* BY NATIONAL QUINTILE (%HH)*/
svytab water hhquint [pw=pond], percent  column

/*BY URBAN QUINTILE (%HH)*/
svytab water hhquint_urb [pw=pond], percent  column

/*BY RURAL QUINTILE (%HH)*/
svytab water hhquint_rur [pw=pond], percent  column

/*BY urban rural (%POPULATION)*/
svytab water urban [pw=pondn], percent  column

/*BY NATIONAL QUINTILE (%POPULATION)*/
svytab water ppquint [pw=pondn], percent  column

/*BY URBAN QUINTILE (%POPULATION)*/
svytab water ppquint_urb [pw=pondn], percent  column

/*BY RURAL QUINTILE (%POPULATION)*/
svytab water ppquint_rur [pw=pondn], percent  column


/*========
			TRANSPORT
							========*/

/*CAR*/
/* BY urban rural (%HH)*/
svytab car urban [pw=pond], percent  column

/* BY NATIONAL QUINTILE (%HH)*/
svytab car hhquint [pw=pond], percent  column

/*BY URBAN QUINTILE (%HH)*/
svytab car hhquint_urb [pw=pond], percent  column

/*BY RURAL QUINTILE (%HH)*/
svytab car hhquint_rur [pw=pond], percent  column

/*BY urban rural (%POPULATION)*/
svytab car urban [pw=pondn], percent  column

/*BY NATIONAL QUINTILE (%POPULATION)*/
svytab car ppquint [pw=pondn], percent  column

/*BY URBAN QUINTILE (%POPULATION)*/
svytab car ppquint_urb [pw=pondn], percent  column

/*BY RURAL QUINTILE (%POPULATION)*/
svytab car ppquint_rur [pw=pondn], percent  column


/*MOTOCYCLES*/
/* BY urban rural (%HH)*/
svytab motorcycle urban [pw=pond], percent  column

/* BY NATIONAL QUINTILE (%HH)*/
svytab motorcycle hhquint [pw=pond], percent  column

/*BY URBAN QUINTILE (%HH)*/
svytab motorcycle hhquint_urb [pw=pond], percent  column

/*BY RURAL QUINTILE (%HH)*/
svytab motorcycle hhquint_rur [pw=pond], percent  column

/*BY urban rural (%POPULATION)*/
svytab motorcycle urban [pw=pondn], percent  column

/*BY NATIONAL QUINTILE (%POPULATION)*/
svytab motorcycle ppquint [pw=pondn], percent  column

/*BY URBAN QUINTILE (%POPULATION)*/
svytab motorcycle ppquint_urb [pw=pondn], percent  column

/*BY RURAL QUINTILE (%POPULATION)*/
svytab motorcycle ppquint_rur [pw=pondn], percent  column


/*BIKES*/
/* BY urban rural (%HH)*/
svytab bike urban [pw=pond], percent  column

/* BY NATIONAL QUINTILE (%HH)*/
svytab bike hhquint [pw=pond], percent  column

/*BY URBAN QUINTILE (%HH)*/
svytab bike hhquint_urb [pw=pond], percent  column

/*BY RURAL QUINTILE (%HH)*/
svytab bike hhquint_rur [pw=pond], percent  column

/*BY urban rural (%POPULATION)*/
svytab bike urban [pw=pondn], percent  column

/*BY NATIONAL QUINTILE (%POPULATION)*/
svytab bike ppquint [pw=pondn], percent  column

/*BY URBAN QUINTILE (%POPULATION)*/
svytab bike ppquint_urb [pw=pondn], percent  column

/*BY RURAL QUINTILE (%POPULATION)*/
svytab bike ppquint_rur [pw=pondn], percent  column

/*==============
		 Spending on transport service (% of household)
									============*/
gen r_transp_exp= 100*transp_exp/ ( hhexp* hhsize)
/*urban  rural total */ 
sum r_transp_exp
bysort urban: sum r_transp_exp 

/*national quitile */ 
bysort hhquint: sum r_transp_exp

/*Urban quitile */ 
bysort hhquint_urb: sum r_transp_exp 

/*Rural quitile */ 
bysort hhquint_rur: sum r_transp_exp

/*==============
		 Spending on transport and communication (% of household)
									============*/
gen r_trcmm_exp= 100*(transp_exp+comm_exp)/( hhexp* hhsize)
/*urban  rural total */ 
sum r_trcmm_exp
bysort urban: sum r_trcmm_exp 

/*national quitile */ 
bysort hhquint: sum r_trcmm_exp

/*Urban quitile */ 
bysort hhquint_urb: sum r_trcmm_exp 

/*Rural quitile */ 
bysort hhquint_rur: sum r_trcmm_exp


/*==============
		 ICT (% of household)
									============*/

/*Access to TV*/

/*urban  rural total */ 
svytab tv urban, percent column
svytab tv hhquint, percent column
svytab tv hhquint_urb, percent column
svytab tv hhquint_rur, percent column



/*Access to radio*/
svytab radio urban, percent column
svytab radio hhquint, percent column
svytab radio hhquint_urb, percent column
svytab radio hhquint_rur, percent column



/*Access to phone*/
svytab phone urban, percent column
svytab phone hhquint, percent column
svytab phone hhquint_urb, percent column
svytab phone hhquint_rur, percent column


log off

capture log close
exit

