clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of consumption and poverty****
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"



***********************
***EDUCATIONAL LEVEL***
***********************
cap log close
log using educ.log, replace

use sect01, clear
ta s1q30
*La codification est 1/2, il y a 3 categories (avec 3 observations), donc je remets les 3 dans le 2ieme: les non eduques/*
*/groupe
recode s1q30 3=2
ta s1q30 s1q33
gen everattd = s1q30 if s1q6a >=5 /*Education for people of at least 5 years old*/
label var everattd "person has attended to either modern or tradicional (coranic) school"
ta everattd, m

*The 2 qestions below are asked to ind. attending modern school only:
g atschool= s1q35 if s1q6a >=5
label var atschool "School attendance at time of survey" 

/*Not sure at this point because there is no variable explicitly asking if the person attend 
school the scholar year of the survey. I consider the question: do you attend the same school? I suppose
variations are low*/

tab atschool, missing

gen schltyp=s1q38
label var schltyp "Type of school attending"
tab atschool schltyp


g educlev=s1q31 if s1q6a >=5

recode educlev . =1 if everattd==2 /* people who have never attended to school have "no level of education"*/
/*recode educlev  =2*/ *There is no code for the coranic level
recode educlev 1 2 3 4 5 =3
recode educlev 6 =4 /* I am assuming that people with educlev=6 are complete primary*/
recode educlev 7 8 9 10 11 12 24 25 26 27 28 29 30 31 32 33 34 35 36 37 =5 /*I assume "secondaire" and "secondaire professionnelle" are the same*/
recode educlev 13 =6 /* I am assuming that people with educlev=13 are complete secondary*/
recode educlev 14 15 16 17 18 19 20 21 22 23 =7
recode educlev 0 =8
/*recode educlev  =9
recode educlev  =99*/

tab educlev, missing
* asked only to people who have not been at a traditional school or have no level of education
* In order not to get unnecessary missings, we assume that people who have attended traditional
* school and have some adquired level of education are not illiterate

ta s1q27
/*Il y a 4 outliers : 3 pour 0, 1 pour 7; je les enleve*/
drop if s1q27==0 | s1q27==7

gen literacy = s1q27 if s1q6a >=5
label var literacy "Literacy status"
tab literacy, missing

replace literacy=1 if s1q27==.&(educlev>2&educlev~=.)
tab literacy, m
tab literacy educlev, missing
tab literacy educlev


/*gen repet=cond(s2q04>0,1,0) if s2q04~=.*/ *Check what is this variable

* Type of Education (modern vs. coranic vs. none)

gen educ_type = s1q33 /*Not sure*/

recode educ_type 1 2 3 4 =1
recode educ_type 5 6 =2
tab educ_type, missing

label define educ_type 1 "ecole. moderne" 2 "Coranic"
label values educ_type educ_type
tab educ_type, m


log close
set more on
exit
