clear _all
set mem 800m
set matsize 300
set more 1
set seed 123456789
set rmsg on
*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.

cd "C:\Documents and Settings\Bachir\Desktop\Bachir\World Bank\Wodon\CIV\Cote d'Ivoire Consumption\STATA"

use sect01, clear
count
sort hid
save, replace

use hhexp, clear
count
keep hid school internet health trcomm trschool hhexp
sort hid
merge hid using sect01
ta _mer
assert _mer==3
keep if _merg==3
drop _merg
compress
count
sort hid
save education, replace



use pauvre, clear
count
keep hid pond region milieu _region_ _milieu_ povline pauv pchhexp strate deflat hhsize 

sort hid
merge hid using education
ta _mer
assert _mer==3
keep if _merg==3
drop _merg
compress
count
sort hid
save education, replace


cap log close
log using education.log, replace

keep hid indid s1q2 s1q3 s1q6a s1q35 s1q42 s1q46 s1q48 s1q52 s1q62 s1q63-s1q74 s1q76 ///
school internet health trcomm trschool hhexp ///
pond region milieu _region_ _milieu_ povline pauv pchhexp strate deflat hhsize

*Individual weights
bys hid: g double weight = pond / hhsize

*Generating quintile groups
cap drop percapexp
g percapexp= pchhexp if  (pchhexp>0 &  pchhexp<=5000000)
su percapexp
replace percapexp=r(mean) if percapexp==.
su percapexp [aw=weig]
cap drop rich
xtile rich=percapexp , nq(5)
lab var rich "Wealth Groups"
ta rich [aw=weig]



bys indid: g double sex = s1q3
ta sex

bys indid: g double agey = s1q6a
count if agey < 18
count if agey>5 & agey < 18
su agey


*Boys
bys indid: g double boy = cond(agey>5&agey<18 & sex==1, 1, 0)
count if boy==1
bys hid: egen double boys = sum(boy)                                      /*Number of boys in age to go to school in the HH*/
su boy boys

bys indid: g double boy_scho = cond(s1q35==1, 1, 0) if boy==1
count if boy_scho==1
bys hid: egen double boys_scho = sum(boy_scho)                           /*Number of boys actually at school in the HH*/
su boy_scho boys_scho

*Girls
bys indid: g double girl = cond(agey>5&agey<18 & sex==2, 1, 0)
count if girl==1
bys hid: egen double girls = sum(girl)                                      /*Number of girls in age to go to school in the HH*/
su girl girls

bys indid: g double girl_scho = cond(s1q35==1, 1, 0) if girl==1
count if girl_scho==1
bys hid: egen double girls_scho = sum(girl_scho)                           /*Number of girls actually at school in the HH*/
su girl_scho girls_scho

*All children
bys indid: g double child = cond(agey>5&agey<18, 1, 0)
count if child==1
bys hid: egen double childs = sum(child)                                      /*Number of children in age to go to school in the HH*/
su child childs

bys indid: g double child_scho = cond(s1q35==1, 1, 0) if child==1
count if child_scho==1
bys hid: egen double childs_scho = sum(child_scho)                           /*Number of children actually at school in the HH*/
su child_scho childs_scho





*Reset all the children that have been declared as not in school but that their parents claim
*expenditures for schooling as actually at school.

replace child_scho=1 if (s1q63>0&s1q63<.)| (s1q64>0&s1q64<.)|(s1q65>0&s1q65<.)| ///
(s1q66>0&s1q66<.)|(s1q67>0&s1q67<.)|(s1q68>0&s1q68<.)|(s1q69>0&s1q69<.)|(s1q70>0&s1q70<.) ///
|(s1q71>0&s1q71<.)|(s1q72>0&s1q72<.)|(s1q73>0&s1q73<.)|(s1q74>0&s1q74<.)|(s1q76>0&s1q76<.)

count if child_scho==1

sort indid

keep if (agey>5 & agey<18) & child_scho==1          /*keeping only the scholarized children for tabulations*/
count

replace s1q35=2 if s1q35==.                       /*Setting the missings as not at school*/



*Creating the variable for all the children actually at school and replace those claimed as not in school but that have
*expenditures as actually in school.

bysort indid: g double class_eleves = cond(s1q35==1, 1, 0)
replace class_eleves=1 if (s1q63>0&s1q63<.)| (s1q64>0&s1q64<.)|(s1q65>0&s1q65<.)| ///
(s1q66>0&s1q66<.)|(s1q67>0&s1q67<.)|(s1q68>0&s1q68<.)|(s1q69>0&s1q69<.)|(s1q70>0&s1q70<.) ///
|(s1q71>0&s1q71<.)|(s1q72>0&s1q72<.)|(s1q73>0&s1q73<.)|(s1q74>0&s1q74<.)|(s1q76>0&s1q76<.)

assert child_scho == class_eleves
replace s1q48=1 if class_eleves==1 & s1q48==.  /*Putting the scholarized that have not declared their degree as in primary school*/

ta rich class_eleves [aw=wei]


bysort indid: g double class_eleves_boys = class_eleves if (sex==1)
replace class_eleves_boys =. if class_eleves_boys == 0
tab rich class_eleves  if sex==1 [aw=wei]

bysort indid: g double class_eleves_girls = class_eleves if (sex==2)
replace class_eleves_girls =. if class_eleves_girls == 0
tab rich class_eleves  if sex==2 [aw=wei]


assert class_eleves_girls==. if class_eleves_boys==1

bysort indid: g double class_eleves_urban = class_eleves if ( milieu==1)
replace class_eleves_urban =. if class_eleves_urban == 0
ta rich class_eleves_urban [aw=wei]
tab rich class_eleves  if mil==1 [aw=wei]



bysort indid: g double class_eleves_rural = class_eleves  if ( milieu==2)
replace class_eleves_rural =. if class_eleves_rural == 0
ta rich class_eleves_rural [aw=wei]
tab rich class_eleves  if mil==2 [aw=wei]


assert class_eleves_urban==. if class_eleves_rural==1


bysort indid: g double class_prescho = s1q48==0
replace class_prescho =. if class_prescho == 0
ta rich class_prescho [aw=wei]



bysort indid: g double class_prescho_boys = s1q48==0 if sex==1
replace class_prescho_boys =. if class_prescho_boys == 0
ta rich class_prescho_boys [aw=wei]

bysort indid: g double class_prescho_girls = s1q48==0 if sex==2
replace class_prescho_girls =. if class_prescho_girls == 0
ta rich class_prescho_girls [aw=wei]

bysort indid: g double class_prescho_urban = s1q48==0 if milieu==1  
replace class_prescho_urban =. if class_prescho_urban == 0  
ta rich class_prescho_urban [aw=wei]
          
bysort indid: g double class_prescho_rural = s1q48==0 if milieu==2
replace class_prescho_rural =. if class_prescho_rural == 0
ta rich class_prescho_rural [aw=wei]

bysort indid: g double class_prim = ( s1q48>0 & s1q48 <7)
replace class_prim =. if class_prim == 0
ta rich class_prim [aw=wei]

bysort indid: g double class_prim_boys  = ( s1q48>0 & s1q48 <7) if sex==1
replace class_prim_boys  =. if class_prim_boys  == 0
ta rich class_prim_boys  [aw=wei]

bysort indid: g double class_prim_girls  = ( s1q48>0 & s1q48 <7) if sex==2
replace class_prim_girls  =. if class_prim_girls  == 0
ta rich class_prim_girls  [aw=wei]

bysort indid: g double class_prim_urban = ( s1q48>0 & s1q48 <7) if milieu==1
replace class_prim_urban =. if class_prim_urban == 0
ta rich class_prim_urban [aw=wei]

bysort indid: g double class_prim_rural = ( s1q48>0 & s1q48 <7) if milieu==2
replace class_prim_rural =. if class_prim_rural == 0
ta rich class_prim_rural [aw=wei]

bysort indid: g double class_sec = ( s1q48>6 & s1q48 < 14)
replace class_sec =. if class_sec == 0
ta rich class_sec [aw=wei]

bysort indid: g double class_sec_boys  =  ( s1q48>6 & s1q48 < 14)  if sex==1
replace class_sec_boys  =. if class_sec_boys  == 0
ta rich class_sec_boys  [aw=wei]

bysort indid: g double class_sec_girls  = ( s1q48>6 & s1q48 < 14)  if sex==2
replace class_sec_girls  =. if class_sec_girls  == 0
ta rich class_sec_girls  [aw=wei]

bysort indid: g double class_sec_urban = ( s1q48>6 & s1q48 < 14) if milieu==1
replace class_sec_urban =. if class_sec_urban == 0
ta rich class_sec_urban [aw=wei]

bysort indid: g double class_sec_rural = ( s1q48>6 & s1q48 < 14) if milieu==2
replace class_sec_rural =. if class_sec_rural == 0
ta rich class_sec_rural [aw=wei]

bysort indid: g double class_postsec = ( s1q48 >13 & s1q48 <16)
replace class_postsec =. if class_postsec == 0
ta rich class_postsec [aw=wei]

bysort indid: g double class_postsec_boys  = ( s1q48 >13 & s1q48 <16)  if sex==1
replace class_postsec_boys  =. if class_postsec_boys  == 0
ta rich class_postsec_boys  [aw=wei]

bysort indid: g double class_postsec_girls  = ( s1q48 >13 & s1q48 <16) if sex==2
replace class_postsec_girls  =. if class_postsec_girls  == 0
ta rich class_postsec_girls  [aw=wei]

bysort indid: g double class_postsec_urban = ( s1q48 >13 & s1q48 <16) if milieu==1
replace class_postsec_urban =. if class_postsec_urban == 0
ta rich class_postsec_urban [aw=wei]

bysort indid: g double class_postsec_rural = ( s1q48 >13 & s1q48 <16) if milieu==2
replace class_postsec_rural =. if class_postsec_rural == 0
ta rich class_postsec_rural [aw=wei]

bysort indid: g double class_sup = ( s1q48>15 & s1q48 < 24)
replace class_sup =. if class_sup == 0
ta rich class_sup [aw=wei]

bysort indid: g double class_sup_boys  = ( s1q48>15 & s1q48 < 24)  if sex==1
replace class_sup_boys  =. if class_sup_boys  == 0
ta rich class_sup_boys  [aw=wei]

bysort indid: g double class_sup_girls  = ( s1q48>15 & s1q48 < 24) if sex==2
replace class_sup_girls  =. if class_sup_girls  == 0
ta rich class_sup_girls  [aw=wei]

bysort indid: g double class_sup_urban = ( s1q48>15 & s1q48 < 24) if milieu==1
replace class_sup_urban =. if class_sup_urban == 0
ta rich class_sup_urban [aw=wei]

bysort indid: g double class_sup_rural = ( s1q48>15 & s1q48 < 24) if milieu==2
replace class_sup_rural =. if class_sup_rural == 0
ta rich class_sup_rural [aw=wei]

bysort indid: g double class_techprof = ( s1q48>23 & s1q48<40)
replace class_techprof =. if class_techprof == 0
ta rich class_techprof [aw=wei]

bysort indid: g double class_techprof_boys  = ( s1q48>23 & s1q48<40)  if sex==1
replace class_techprof_boys  =. if class_techprof_boys  == 0
ta rich class_techprof_boys  [aw=wei]

bysort indid: g double class_techprof_girls  = ( s1q48>23 & s1q48<40) if sex==2
replace class_techprof_girls  =. if class_techprof_girls  == 0
ta rich class_techprof_girls  [aw=wei]

bysort indid: g double class_techprof_urban = ( s1q48>23 & s1q48<40) if milieu==1
replace class_techprof_urban =. if class_techprof_urban == 0
ta rich class_techprof_urban [aw=wei]

bysort indid: g double class_techprof_rural = ( s1q48>23 & s1q48<40) if milieu==2
replace class_techprof_rural =. if class_techprof_rural == 0
ta rich class_techprof_rural [aw=wei]




*Number of students per household, by sex, residence and education level


bys hid: egen double eleves = sum(class_eleves)  
ta eleves [aw=wei]
table rich [aw=wei], c(mean eleves ) row col f(%9.2g)
bysort hid: egen double eleves_boys = sum(class_eleves_boys)  if class_eleves_boys==1
ta eleves_boys [aw=wei]
table rich [aw=wei], c(mean eleves_boys ) row col f(%9.2g)
bysort hid: egen double eleves_girls = sum(class_eleves_girls)    if class_eleves_girls==1
ta eleves_girls [aw=wei]
table rich [aw=wei], c(mean eleves_girls ) row col f(%9.2g)
bysort hid: egen double eleves_urban = sum(class_eleves_urban)  if class_eleves_urban==1 
ta eleves_urban [aw=wei]
table rich [aw=wei], c(mean eleves_urban ) row col f(%9.2g)
bysort hid: egen double eleves_rural = sum(class_eleves_rural)  if class_eleves_rural==1
ta eleves_rural [aw=wei]
table rich [aw=wei], c(mean eleves_rural ) row col f(%9.2g)
bysort hid: egen double prescho = sum(class_prescho)   if class_prescho==1       /*Number of preschools children in the HH */
ta prescho [aw=wei]
table rich [aw=wei], c(mean prescho ) row col f(%9.2g)
bysort hid: egen double prescho_boys = sum(class_prescho_boys)     if class_prescho_boys==1
ta prescho_boys [aw=wei]
table rich [aw=wei], c(mean prescho_boys ) row col f(%9.2g)
bysort hid: egen double prescho_girls = sum(class_prescho_girls)    if class_prescho_girls==1 
ta prescho_girls [aw=wei]
table rich [aw=wei], c(mean prescho_girls ) row col f(%9.2g)
bysort hid: egen double prescho_urban = sum(class_prescho_urban )     if class_prescho_urban==1
ta prescho_urban [aw=wei]
table rich [aw=wei], c(mean prescho_urban ) row col f(%9.2g)
bysort hid: egen double prescho_rural = sum(class_prescho_rural )   if class_prescho_rural==1  
ta prescho_rural [aw=wei]
table rich [aw=wei], c(mean prescho_rural ) row col f(%9.2g)
bysort hid: egen double prim = sum(class_prim)    if class_prim          /*Number of primary children in the HH */
ta prim [aw=wei]
table rich [aw=wei], c(mean prim ) row col f(%9.2g)
bysort hid: egen double prim_boys = sum(class_prim_boys)   if class_prim_boys==1     
ta prim_boys [aw=wei]
table rich [aw=wei], c(mean prim_boys ) row col f(%9.2g)
bysort hid: egen double prim_girls = sum(class_prim_girls)     if class_prim_girls==1   
ta prim_girls [aw=wei]
table rich [aw=wei], c(mean prim_girls ) row col f(%9.2g)
bysort hid: egen double prim_urban = sum(class_prim_urban )   if class_prim_urban==1     
ta prim_urban [aw=wei]
table rich [aw=wei], c(mean prim_urban ) row col f(%9.2g)
bysort hid: egen double prim_rural = sum(class_prim_rural )  if class_prim_rural==1      
ta prim_rural [aw=wei]
table rich [aw=wei], c(mean prim_rural ) row col f(%9.2g)
bysort hid: egen double sec = sum(class_sec)   if class_sec==1             /*Number of secondary children in the HH */
ta sec [aw=wei]
table rich [aw=wei], c(mean sec ) row col f(%9.2g)
bysort hid: egen double sec_boys = sum(class_sec_boys)    if class_sec_boys==1    
ta sec_boys [aw=wei]
table rich [aw=wei], c(mean sec_boys ) row col f(%9.2g)
bysort hid: egen double sec_girls = sum(class_sec_girls)    if class_sec_girls==1    
ta sec_girls [aw=wei]
table rich [aw=wei], c(mean sec_girls ) row col f(%9.2g)
bysort hid: egen double sec_urban = sum(class_sec_urban )   if class_sec_urban ==1     
ta sec_urban [aw=wei]
table rich [aw=wei], c(mean sec_urban ) row col f(%9.2g)
bysort hid: egen double sec_rural = sum(class_sec_rural )   if class_sec_rural    
ta sec_rural [aw=wei]
table rich [aw=wei], c(mean sec_rural ) row col f(%9.2g)
bysort hid: egen double postsec = sum(class_postsec)  if class_postsec==1         /*Number of postsecondary children in the HH */
ta postsec [aw=wei]
table rich [aw=wei], c(mean postsec ) row col f(%9.2g)
bysort hid: egen double postsec_boys = sum(class_postsec_boys)   if class_postsec_boys==1
ta postsec_boys [aw=wei]
table rich [aw=wei], c(mean postsec_boys ) row col f(%9.2g)
bysort hid: egen double postsec_girls = sum(class_postsec_girls)   if class_postsec_girls==1
ta postsec_girls [aw=wei]
table rich [aw=wei], c(mean postsec_girls ) row col f(%9.2g)
bysort hid: egen double postsec_urban = sum(class_postsec_urban ) if class_postsec_urban==1  
ta postsec_urban [aw=wei]
table rich [aw=wei], c(mean postsec_urban ) row col f(%9.2g)
bysort hid: egen double postsec_rural = sum(class_postsec_rural ) if class_postsec_rural==1  
ta postsec_rural [aw=wei]
table rich [aw=wei], c(mean postsec_rural ) row col f(%9.2g)
bysort hid: egen double sup = sum(class_sup)   if class_sup==1                /*Number of tertiary children in the HH */
ta sup [aw=wei]
table rich [aw=wei], c(mean sup ) row col f(%9.2g)
bysort hid: egen double sup_boys = sum(class_sup_boys)   if class_sup_boys==1
ta sup_boys [aw=wei]
table rich [aw=wei], c(mean sup_boys ) row col f(%9.2g)
bysort hid: egen double sup_girls = sum(class_sup_girls) if class_sup_girls==1 
ta sup_girls [aw=wei]
table rich [aw=wei], c(mean sup_girls ) row col f(%9.2g)
bysort hid: egen double sup_urban = sum(class_sup_urban )   if class_sup_urban==1
ta sup_urban [aw=wei]
table rich [aw=wei], c(mean sup_urban ) row col f(%9.2g)
bysort hid: egen double sup_rural = sum(class_sup_rural ) if class_sup_rural==1 
ta sup_rural [aw=wei]
table rich [aw=wei], c(mean sup_rural ) row col f(%9.2g)
bysort hid: egen double techprof = sum(class_techprof)          if class_techprof==1      /*Number of technical/professionals children in the HH */
ta techprof [aw=wei]
table rich [aw=wei], c(mean techprof ) row col f(%9.2g)
bysort hid: egen double techprof_boys = sum(class_techprof_boys)   if class_techprof_boys==1   
ta techprof_boys [aw=wei]
table rich [aw=wei], c(mean techprof_boys ) row col f(%9.2g)
bysort hid: egen double techprof_girls = sum(class_techprof_girls)   if class_techprof_girls==1   
ta techprof_girls [aw=wei]
table rich [aw=wei], c(mean techprof_girls ) row col f(%9.2g)
bysort hid: egen double techprof_urban = sum(class_techprof_urban )  if class_techprof_urban==1   
ta techprof_urban [aw=wei]
table rich [aw=wei], c(mean techprof_urban ) row col f(%9.2g)
bysort hid: egen double techprof_rural = sum(class_techprof_rural ) if class_techprof_rural==1     
ta techprof_rural [aw=wei]
table rich [aw=wei], c(mean techprof_rural ) row col f(%9.2g)
             



*Few quick checks: Verifying the totals
bys hid: egen maxbo=max(eleves_boys)
replace maxbo = 0 if maxbo==.
bys hid: egen maxgi =max(eleves_girls)
replace maxgi = 0 if maxgi==.
bys hid: g tot1 = maxbo + maxgi 
assert tot1 == eleves

bys hid: egen maxu=max(eleves_ur)
replace maxu = 0 if maxu==.
bys hid: egen maxr =max(eleves_ru)
replace maxr = 0 if maxr==.
bys hid: g tot2 = maxu + maxr 
assert tot2 == eleves


bys hid: egen maxpre =max(prescho)
replace maxpre = 0 if maxpre ==.
bys hid: egen maxpri =max(prim)
replace maxpri = 0 if maxpri ==.
bys hid: egen maxsec =max(sec)
replace maxsec = 0 if maxsec ==.
bys hid: egen maxpo =max(postsec)
replace maxpo = 0 if maxpo ==.
bys hid: egen maxsu =max(sup)
replace maxsu = 0 if maxsu ==.
bys hid: egen maxte =max(techprof)
replace maxte = 0 if maxte ==.
bys hid: g tot3 = maxpre + maxpri + maxsec + maxpo + maxsu + maxte 
assert tot3 == eleves

drop tot1 tot2 tot3 maxbo maxgi maxu maxr maxpre maxpri maxsec maxpo maxsu maxte 




*Total education expenditures
sort indid
egen double toteduc1 = rsum(s1q63-s1q74)
egen double toteduc2 = rsum(toteduc1 s1q76)
egen double inscription = rsum(s1q63 s1q64)
egen double scolarite = rsum(s1q65)
egen double fournitures = rsum(s1q66 s1q67) 
egen double uniformes = rsum(s1q68)
egen double transport = rsum(s1q69)
egen double autres_educ_dep = rsum(s1q70 s1q71 s1q72 s1q73 s1q74)
egen double bourses = rsum(s1q76)


*Per capita education expenditures

bys hid: g double inscription_eleves = inscription/eleves
su inscription_eleves [aw=wei]
table rich [aw=wei], c(mean inscription_eleves ) row col f(%9.2g)

bys hid: g double inscription_prescho = inscription/prescho
su inscription_prescho [aw=wei]
table rich [aw=wei], c(mean inscription_prescho ) row col f(%9.2g)

bys hid: g double inscription_prim = inscription /prim 
su inscription_prim [aw=wei]
table rich [aw=wei], c(mean inscription_prim ) row col f(%9.2g)

bys hid: g double inscription_sec = inscription/sec 
su inscription_sec [aw=wei]
table rich [aw=wei], c(mean inscription_sec ) row col f(%9.2g)

bys hid: g double inscription_postsec = inscription/postsec 
su inscription_postsec [aw=wei]
table rich [aw=wei], c(mean inscription_postsec ) row col f(%9.2g)

bys hid: g double inscription_sup = inscription/sup 
su inscription_sup [aw=wei]
table rich [aw=wei], c(mean inscription_sup ) row col f(%9.2g)

bys hid: g double inscription_techprof = inscription/techprof 
su inscription_techprof [aw=wei]
table rich [aw=wei], c(mean inscription_techprof ) row col f(%9.2g)

bys hid: g double inscription_eleves_boys = inscription/eleves_boys
su inscription_eleves_boys [aw=wei]
table rich [aw=wei], c(mean inscription_eleves_boys ) row col f(%9.2g)

bys hid: g double inscription_prescho_boys = inscription/prescho_boys
su inscription_prescho_boys [aw=wei]
table rich [aw=wei], c(mean inscription_prescho_boys ) row col f(%9.2g)

bys hid: g double inscription_prim_boys = inscription /prim_boys
su inscription_prim_boys [aw=wei]
table rich [aw=wei], c(mean inscription_prim_boys ) row col f(%9.2g)

bys hid: g double inscription_sec_boys = inscription/sec_boys 
su inscription_sec_boys [aw=wei]
table rich [aw=wei], c(mean inscription_sec_boys ) row col f(%9.2g)

bys hid: g double inscription_postsec_boys = inscription/postsec_boys 
su inscription_postsec_boys [aw=wei]
table rich [aw=wei], c(mean inscription_postsec_boys ) row col f(%9.2g)

bys hid: g double inscription_sup_boys = inscription/sup_boys
su inscription_sup_boys [aw=wei]
table rich [aw=wei], c(mean inscription_sup_boys ) row col f(%9.2g)

bys hid: g double inscription_techprof_boys = inscription/techprof_boys 
su inscription_techprof_boys [aw=wei]
table rich [aw=wei], c(mean inscription_techprof_boys ) row col f(%9.2g)

bys hid: g double inscription_eleves_girls = inscription/eleves_girls 
su inscription_eleves_girls [aw=wei]
table rich [aw=wei], c(mean inscription_eleves_girls ) row col f(%9.2g)

bys hid: g double inscription_prescho_girls = inscription/prescho_girls 
su inscription_prescho_girls [aw=wei]
table rich [aw=wei], c(mean inscription_prescho_girls ) row col f(%9.2g)

bys hid: g double inscription_prim_girls = inscription /prim_girls 
su inscription_prim_girls [aw=wei]
table rich [aw=wei], c(mean inscription_prim_girls ) row col f(%9.2g)

bys hid: g double inscription_sec_girls = inscription/sec_girls 
su inscription_sec_girls [aw=wei]
table rich [aw=wei], c(mean inscription_sec_girls ) row col f(%9.2g)

bys hid: g double inscription_postsec_girls = inscription/postsec_girls 
su inscription_postsec_girls [aw=wei]
table rich [aw=wei], c(mean inscription_postsec_girls ) row col f(%9.2g)

bys hid: g double inscription_sup_girls = inscription/sup_girls 
su inscription_sup_girls [aw=wei]
table rich [aw=wei], c(mean inscription_sup_girls ) row col f(%9.2g)

bys hid: g double inscription_techprof_girls = inscription/techprof_girls 
su inscription_techprof_girls [aw=wei]
table rich [aw=wei], c(mean inscription_techprof_girls ) row col f(%9.2g)

bys hid: g double inscription_eleves_urban = inscription/eleves_urban 
su inscription_eleves_urban [aw=wei]
table rich [aw=wei], c(mean inscription_eleves_urban ) row col f(%9.2g)

bys hid: g double inscription_prescho_urban = inscription/prescho_urban 
su inscription_prescho_urban [aw=wei]
table rich [aw=wei], c(mean inscription_prescho_urban ) row col f(%9.2g)

bys hid: g double inscription_prim_urban = inscription /prim_urban 
su inscription_prim_urban [aw=wei]
table rich [aw=wei], c(mean inscription_prim_urban ) row col f(%9.2g)

bys hid: g double inscription_sec_urban = inscription/sec_urban 
su inscription_sec_urban [aw=wei]
table rich [aw=wei], c(mean inscription_sec_urban ) row col f(%9.2g)

bys hid: g double inscription_postsec_urban = inscription/postsec_urban 
su inscription_postsec_urban [aw=wei]
table rich [aw=wei], c(mean inscription_postsec_urban ) row col f(%9.2g)

bys hid: g double inscription_sup_urban = inscription/sup_urban 
su inscription_sup_urban [aw=wei]
table rich [aw=wei], c(mean inscription_sup_urban ) row col f(%9.2g)

bys hid: g double inscription_techprof_urban = inscription/techprof_urban 
su inscription_techprof_urban [aw=wei]
table rich [aw=wei], c(mean inscription_techprof_urban ) row col f(%9.2g)

bys hid: g double inscription_eleves_rural = inscription/eleves_rural 
su inscription_eleves_rural [aw=wei]
table rich [aw=wei], c(mean inscription_eleves_rural ) row col f(%9.2g)

bys hid: g double inscription_prescho_rural = inscription/prescho_rural 
su inscription_prescho_rural [aw=wei]
table rich [aw=wei], c(mean inscription_prescho_rural ) row col f(%9.2g)

bys hid: g double inscription_prim_rural = inscription /prim_rural 
su inscription_prim_rural [aw=wei]
table rich [aw=wei], c(mean inscription_prim_rural ) row col f(%9.2g)

bys hid: g double inscription_sec_rural = inscription/sec_rural 
su inscription_sec_rural [aw=wei]
table rich [aw=wei], c(mean inscription_sec_rural ) row col f(%9.2g)

bys hid: g double inscription_postsec_rural = inscription/postsec_rural 
su inscription_postsec_rural [aw=wei]
table rich [aw=wei], c(mean inscription_postsec_rural ) row col f(%9.2g)

bys hid: g double inscription_sup_rural = inscription/sup_rural 
su inscription_sup_rural [aw=wei]
table rich [aw=wei], c(mean inscription_sup_rural ) row col f(%9.2g)

bys hid: g double inscription_techprof_rural = inscription/techprof_rural 
su inscription_techprof_rural [aw=wei]
table rich [aw=wei], c(mean inscription_techprof_rural ) row col f(%9.2g)


bys hid: g double scolarite_eleves = scolarite/eleves
su scolarite_eleves [aw=wei]
table rich [aw=wei], c(mean scolarite_eleves ) row col f(%9.2g)

bys hid: g double scolarite_prescho = scolarite/prescho
su scolarite_prescho [aw=wei]
table rich [aw=wei], c(mean scolarite_prescho ) row col f(%9.2g)

bys hid: g double scolarite_prim = scolarite/prim 
su scolarite_prim [aw=wei]
table rich [aw=wei], c(mean scolarite_prim ) row col f(%9.2g)

bys hid: g double scolarite_sec = scolarite/sec 
su scolarite_sec [aw=wei]
table rich [aw=wei], c(mean scolarite_sec ) row col f(%9.2g)

bys hid: g double scolarite_postsec = scolarite/postsec 
su scolarite_postsec [aw=wei]
table rich [aw=wei], c(mean scolarite_postsec ) row col f(%9.2g)

bys hid: g double scolarite_sup = scolarite/sup 
su scolarite_sup [aw=wei]
table rich [aw=wei], c(mean scolarite_sup ) row col f(%9.2g)

bys hid: g double scolarite_techprof = scolarite/techprof 
su scolarite_techprof [aw=wei]
table rich [aw=wei], c(mean scolarite_techprof ) row col f(%9.2g)

bys hid: g double scolarite_eleves_boys = scolarite/eleves_boys
su scolarite_eleves_boys [aw=wei]
table rich [aw=wei], c(mean scolarite_eleves_boys ) row col f(%9.2g)

bys hid: g double scolarite_prescho_boys = scolarite/prescho_boys
su scolarite_prescho_boys [aw=wei]
table rich [aw=wei], c(mean scolarite_prescho_boys ) row col f(%9.2g)

bys hid: g double scolarite_prim_boys = scolarite/prim_boys
su scolarite_prim_boys [aw=wei]
table rich [aw=wei], c(mean scolarite_prim_boys ) row col f(%9.2g)

bys hid: g double scolarite_sec_boys = scolarite/sec_boys 
su scolarite_sec_boys [aw=wei]
table rich [aw=wei], c(mean scolarite_sec_boys ) row col f(%9.2g)

bys hid: g double scolarite_postsec_boys = scolarite/postsec_boys 
su scolarite_postsec_boys [aw=wei]
table rich [aw=wei], c(mean scolarite_postsec_boys ) row col f(%9.2g)

bys hid: g double scolarite_sup_boys = scolarite/sup_boys
su scolarite_sup_boys [aw=wei]
table rich [aw=wei], c(mean scolarite_sup_boys ) row col f(%9.2g)

bys hid: g double scolarite_techprof_boys = scolarite/techprof_boys 
su scolarite_techprof_boys [aw=wei]
table rich [aw=wei], c(mean scolarite_techprof_boys ) row col f(%9.2g)

bys hid: g double scolarite_eleves_girls = scolarite/eleves_girls 
su scolarite_eleves_girls [aw=wei]
table rich [aw=wei], c(mean scolarite_eleves_girls ) row col f(%9.2g)

bys hid: g double scolarite_prescho_girls = scolarite/prescho_girls 
su scolarite_prescho_girls [aw=wei]
table rich [aw=wei], c(mean scolarite_prescho_girls ) row col f(%9.2g)

bys hid: g double scolarite_prim_girls = scolarite/prim_girls 
su scolarite_prim_girls [aw=wei]
table rich [aw=wei], c(mean scolarite_prim_girls ) row col f(%9.2g)

bys hid: g double scolarite_sec_girls = scolarite/sec_girls 
su scolarite_sec_girls [aw=wei]
table rich [aw=wei], c(mean scolarite_sec_girls ) row col f(%9.2g)

bys hid: g double scolarite_postsec_girls = scolarite/postsec_girls 
su scolarite_postsec_girls [aw=wei]
table rich [aw=wei], c(mean scolarite_postsec_girls ) row col f(%9.2g)

bys hid: g double scolarite_sup_girls = scolarite/sup_girls 
su scolarite_sup_girls [aw=wei]
table rich [aw=wei], c(mean scolarite_sup_girls ) row col f(%9.2g)

bys hid: g double scolarite_techprof_girls = scolarite/techprof_girls 
su scolarite_techprof_girls [aw=wei]
table rich [aw=wei], c(mean scolarite_techprof_girls ) row col f(%9.2g)

bys hid: g double scolarite_eleves_urban = scolarite/eleves_urban 
su scolarite_eleves_urban [aw=wei]
table rich [aw=wei], c(mean scolarite_eleves_urban ) row col f(%9.2g)

bys hid: g double scolarite_prescho_urban = scolarite/prescho_urban 
su scolarite_prescho_urban [aw=wei]
table rich [aw=wei], c(mean scolarite_prescho_urban ) row col f(%9.2g)

bys hid: g double scolarite_prim_urban = scolarite /prim_urban 
su scolarite_prim_urban [aw=wei]
table rich [aw=wei], c(mean scolarite_prim_urban ) row col f(%9.2g)

bys hid: g double scolarite_sec_urban = scolarite/sec_urban 
su scolarite_sec_urban [aw=wei]
table rich [aw=wei], c(mean scolarite_sec_urban ) row col f(%9.2g)

bys hid: g double scolarite_postsec_urban = scolarite/postsec_urban 
su scolarite_postsec_urban [aw=wei]
table rich [aw=wei], c(mean scolarite_postsec_urban ) row col f(%9.2g)

bys hid: g double scolarite_sup_urban = scolarite/sup_urban 
su scolarite_sup_urban [aw=wei]
table rich [aw=wei], c(mean scolarite_sup_urban ) row col f(%9.2g)

bys hid: g double scolarite_techprof_urban = scolarite/techprof_urban 
su scolarite_techprof_urban [aw=wei]
table rich [aw=wei], c(mean scolarite_techprof_urban ) row col f(%9.2g)

bys hid: g double scolarite_eleves_rural = scolarite/eleves_rural 
su scolarite_eleves_rural [aw=wei]
table rich [aw=wei], c(mean scolarite_eleves_rural ) row col f(%9.2g)

bys hid: g double scolarite_prescho_rural = scolarite/prescho_rural 
su scolarite_prescho_rural [aw=wei]
table rich [aw=wei], c(mean scolarite_prescho_rural ) row col f(%9.2g)

bys hid: g double scolarite_prim_rural = scolarite /prim_rural 
su scolarite_prim_rural [aw=wei]
table rich [aw=wei], c(mean scolarite_prim_rural ) row col f(%9.2g)

bys hid: g double scolarite_sec_rural = scolarite/sec_rural 
su scolarite_sec_rural [aw=wei]
table rich [aw=wei], c(mean scolarite_sec_rural ) row col f(%9.2g)

bys hid: g double scolarite_postsec_rural = scolarite/postsec_rural 
su scolarite_postsec_rural [aw=wei]
table rich [aw=wei], c(mean scolarite_postsec_rural ) row col f(%9.2g)

bys hid: g double scolarite_sup_rural = scolarite/sup_rural 
su scolarite_sup_rural [aw=wei]
table rich [aw=wei], c(mean scolarite_sup_rural ) row col f(%9.2g)

bys hid: g double scolarite_techprof_rural = scolarite/techprof_rural 
su scolarite_techprof_rural [aw=wei]
table rich [aw=wei], c(mean scolarite_techprof_rural ) row col f(%9.2g)


bys hid: g double fournitures_eleves = fournitures/eleves
su fournitures_eleves [aw=wei]
table rich [aw=wei], c(mean fournitures_eleves ) row col f(%9.2g)

bys hid: g double fournitures_prescho = fournitures/prescho
su fournitures_prescho [aw=wei]
table rich [aw=wei], c(mean fournitures_prescho ) row col f(%9.2g)

bys hid: g double fournitures_prim = fournitures/prim 
su fournitures_prim [aw=wei]
table rich [aw=wei], c(mean fournitures_prim ) row col f(%9.2g)

bys hid: g double fournitures_sec = fournitures/sec 
su fournitures_sec [aw=wei]
table rich [aw=wei], c(mean fournitures_sec ) row col f(%9.2g)

bys hid: g double fournitures_postsec = fournitures/postsec 
su fournitures_postsec [aw=wei]
table rich [aw=wei], c(mean fournitures_postsec ) row col f(%9.2g)

bys hid: g double fournitures_sup = fournitures/sup 
su fournitures_sup [aw=wei]
table rich [aw=wei], c(mean fournitures_sup ) row col f(%9.2g)

bys hid: g double fournitures_techprof = fournitures/techprof
su fournitures_techprof [aw=wei]
table rich [aw=wei], c(mean fournitures_techprof ) row col f(%9.2g)

bys hid: g double fournitures_eleves_boys = fournitures/eleves_boys
su fournitures_eleves_boys [aw=wei]
table rich [aw=wei], c(mean fournitures_eleves_boys ) row col f(%9.2g)

bys hid: g double fournitures_prescho_boys = fournitures/prescho_boys
su fournitures_prescho_boys [aw=wei]
table rich [aw=wei], c(mean fournitures_prescho_boys ) row col f(%9.2g)

bys hid: g double fournitures_prim_boys = fournitures/prim_boys
su fournitures_prim_boys [aw=wei]
table rich [aw=wei], c(mean fournitures_prim_boys ) row col f(%9.2g)

bys hid: g double fournitures_sec_boys = fournitures/sec_boys 
su fournitures_sec_boys [aw=wei]
table rich [aw=wei], c(mean fournitures_sec_boys ) row col f(%9.2g)

bys hid: g double fournitures_postsec_boys = fournitures/postsec_boys 
su fournitures_postsec_boys [aw=wei]
table rich [aw=wei], c(mean fournitures_postsec_boys ) row col f(%9.2g)

bys hid: g double fournitures_sup_boys = fournitures/sup_boys
su fournitures_sup_boys [aw=wei]
table rich [aw=wei], c(mean fournitures_sup_boys ) row col f(%9.2g)

bys hid: g double fournitures_techprof_boys = fournitures/techprof_boys 
su fournitures_techprof_boys [aw=wei]
table rich [aw=wei], c(mean fournitures_techprof_boys ) row col f(%9.2g)

bys hid: g double fournitures_eleves_girls = fournitures/eleves_girls 
su fournitures_eleves_girls [aw=wei]
table rich [aw=wei], c(mean fournitures_eleves_girls ) row col f(%9.2g)

bys hid: g double fournitures_prescho_girls = fournitures/prescho_girls 
su fournitures_prescho_girls [aw=wei]
table rich [aw=wei], c(mean fournitures_prescho_girls ) row col f(%9.2g)

bys hid: g double fournitures_prim_girls = fournitures/prim_girls 
su fournitures_prim_girls [aw=wei]
table rich [aw=wei], c(mean fournitures_prim_girls ) row col f(%9.2g)

bys hid: g double fournitures_sec_girls = fournitures/sec_girls 
su fournitures_sec_girls [aw=wei]
table rich [aw=wei], c(mean fournitures_sec_girls ) row col f(%9.2g)

bys hid: g double fournitures_postsec_girls = fournitures/postsec_girls 
su fournitures_postsec_girls [aw=wei]
table rich [aw=wei], c(mean fournitures_postsec_girls ) row col f(%9.2g)

bys hid: g double fournitures_sup_girls = fournitures/sup_girls 
su fournitures_sup_girls [aw=wei]
table rich [aw=wei], c(mean fournitures_sup_girls ) row col f(%9.2g)

bys hid: g double fournitures_techprof_girls = fournitures/techprof_girls 
su fournitures_techprof_girls [aw=wei]
table rich [aw=wei], c(mean fournitures_techprof_girls ) row col f(%9.2g)

bys hid: g double fournitures_eleves_urban = fournitures/eleves_urban 
su fournitures_eleves_urban [aw=wei]
table rich [aw=wei], c(mean fournitures_eleves_urban ) row col f(%9.2g)

bys hid: g double fournitures_prescho_urban = fournitures/prescho_urban 
su fournitures_prescho_urban [aw=wei]
table rich [aw=wei], c(mean fournitures_prescho_urban ) row col f(%9.2g)

bys hid: g double fournitures_prim_urban = fournitures /prim_urban 
su fournitures_prim_urban [aw=wei]
table rich [aw=wei], c(mean fournitures_prim_urban ) row col f(%9.2g)

bys hid: g double fournitures_sec_urban = fournitures/sec_urban 
su fournitures_sec_urban [aw=wei]
table rich [aw=wei], c(mean fournitures_sec_urban ) row col f(%9.2g)

bys hid: g double fournitures_postsec_urban = fournitures/postsec_urban 
su fournitures_postsec_urban [aw=wei]
table rich [aw=wei], c(mean fournitures_postsec_urban ) row col f(%9.2g)

bys hid: g double fournitures_sup_urban = fournitures/sup_urban 
su fournitures_sup_urban [aw=wei]
table rich [aw=wei], c(mean fournitures_sup_urban ) row col f(%9.2g)

bys hid: g double fournitures_techprof_urban = fournitures/techprof_urban 
su fournitures_techprof_urban [aw=wei]
table rich [aw=wei], c(mean fournitures_techprof_urban ) row col f(%9.2g)

bys hid: g double fournitures_eleves_rural = fournitures/eleves_rural 
su fournitures_eleves_rural [aw=wei]
table rich [aw=wei], c(mean fournitures_eleves_rural ) row col f(%9.2g)

bys hid: g double fournitures_prescho_rural = fournitures/prescho_rural 
su fournitures_prescho_rural [aw=wei]
table rich [aw=wei], c(mean fournitures_prescho_rural ) row col f(%9.2g)

bys hid: g double fournitures_prim_rural = fournitures /prim_rural 
su fournitures_prim_rural [aw=wei]
table rich [aw=wei], c(mean fournitures_prim_rural ) row col f(%9.2g)

bys hid: g double fournitures_sec_rural = fournitures/sec_rural 
su fournitures_sec_rural [aw=wei]
table rich [aw=wei], c(mean fournitures_sec_rural ) row col f(%9.2g)

bys hid: g double fournitures_postsec_rural = fournitures/postsec_rural 
su fournitures_postsec_rural [aw=wei]
table rich [aw=wei], c(mean fournitures_postsec_rural ) row col f(%9.2g)

bys hid: g double fournitures_sup_rural = fournitures/sup_rural 
su fournitures_sup_rural [aw=wei]
table rich [aw=wei], c(mean fournitures_sup_rural ) row col f(%9.2g)

bys hid: g double fournitures_techprof_rural = fournitures/techprof_rural 
su fournitures_techprof_rural [aw=wei]
table rich [aw=wei], c(mean fournitures_techprof_rural ) row col f(%9.2g)


bys hid: g double uniformes_eleves = uniformes/eleves
su uniformes_eleves [aw=wei]
table rich [aw=wei], c(mean uniformes_eleves ) row col f(%9.2g)

bys hid: g double uniformes_prescho = uniformes/prescho
su uniformes_prescho [aw=wei]
table rich [aw=wei], c(mean uniformes_prescho ) row col f(%9.2g)

bys hid: g double uniformes_prim = uniformes/prim 
su uniformes_prim [aw=wei]
table rich [aw=wei], c(mean uniformes_prim ) row col f(%9.2g)

bys hid: g double uniformes_sec = uniformes/sec 
su uniformes_sec [aw=wei]
table rich [aw=wei], c(mean uniformes_sec ) row col f(%9.2g)

bys hid: g double uniformes_postsec = uniformes/postsec 
su uniformes_postsec [aw=wei]
table rich [aw=wei], c(mean uniformes_postsec ) row col f(%9.2g)

bys hid: g double uniformes_sup = uniformes/sup 
su uniformes_sup [aw=wei]
table rich [aw=wei], c(mean uniformes_sup ) row col f(%9.2g)

bys hid: g double uniformes_techprof = uniformes/techprof 
su uniformes_techprof [aw=wei]
table rich [aw=wei], c(mean uniformes_techprof ) row col f(%9.2g)

bys hid: g double uniformes_eleves_boys = uniformes/eleves_boys
su uniformes_eleves_boys [aw=wei]
table rich [aw=wei], c(mean uniformes_eleves_boys ) row col f(%9.2g)

bys hid: g double uniformes_prescho_boys = uniformes/prescho_boys
su uniformes_prescho_boys [aw=wei]
table rich [aw=wei], c(mean uniformes_prescho_boys ) row col f(%9.2g)

bys hid: g double uniformes_prim_boys = uniformes/prim_boys
su uniformes_prim_boys [aw=wei]
table rich [aw=wei], c(mean uniformes_prim_boys ) row col f(%9.2g)

bys hid: g double uniformes_sec_boys = uniformes/sec_boys 
su uniformes_sec_boys [aw=wei]
table rich [aw=wei], c(mean uniformes_sec_boys ) row col f(%9.2g)

bys hid: g double uniformes_postsec_boys = uniformes/postsec_boys 
su uniformes_postsec_boys [aw=wei]
table rich [aw=wei], c(mean uniformes_postsec_boys ) row col f(%9.2g)

bys hid: g double uniformes_sup_boys = uniformes/sup_boys
su uniformes_sup_boys [aw=wei]
table rich [aw=wei], c(mean uniformes_sup_boys ) row col f(%9.2g)

bys hid: g double uniformes_techprof_boys = uniformes/techprof_boys 
su uniformes_techprof_boys [aw=wei]
table rich [aw=wei], c(mean uniformes_techprof_boys ) row col f(%9.2g)

bys hid: g double uniformes_eleves_girls = uniformes/eleves_girls 
su uniformes_eleves_girls [aw=wei]
table rich [aw=wei], c(mean uniformes_eleves_girls ) row col f(%9.2g)

bys hid: g double uniformes_prescho_girls = uniformes/prescho_girls 
su uniformes_prescho_girls [aw=wei]
table rich [aw=wei], c(mean uniformes_prescho_girls ) row col f(%9.2g)

bys hid: g double uniformes_prim_girls = uniformes/prim_girls 
su uniformes_prim_girls [aw=wei]
table rich [aw=wei], c(mean uniformes_prim_girls ) row col f(%9.2g)

bys hid: g double uniformes_sec_girls = uniformes/sec_girls 
su uniformes_sec_girls [aw=wei]
table rich [aw=wei], c(mean uniformes_sec_girls ) row col f(%9.2g)

bys hid: g double uniformes_postsec_girls = uniformes/postsec_girls 
su uniformes_postsec_girls [aw=wei]
table rich [aw=wei], c(mean uniformes_postsec_girls ) row col f(%9.2g)

bys hid: g double uniformes_sup_girls = uniformes/sup_girls 
su uniformes_sup_girls [aw=wei]
table rich [aw=wei], c(mean uniformes_sup_girls ) row col f(%9.2g)

bys hid: g double uniformes_techprof_girls = uniformes/techprof_girls 
su uniformes_techprof_girls [aw=wei]
table rich [aw=wei], c(mean uniformes_techprof_girls ) row col f(%9.2g)

bys hid: g double uniformes_eleves_urban = uniformes/eleves_urban 
su uniformes_eleves_urban [aw=wei]
table rich [aw=wei], c(mean uniformes_eleves_urban ) row col f(%9.2g)

bys hid: g double uniformes_prescho_urban = uniformes/prescho_urban 
su uniformes_prescho_urban [aw=wei]
table rich [aw=wei], c(mean uniformes_prescho_urban ) row col f(%9.2g)

bys hid: g double uniformes_prim_urban = uniformes /prim_urban 
su uniformes_prim_urban [aw=wei]
table rich [aw=wei], c(mean uniformes_prim_urban ) row col f(%9.2g)

bys hid: g double uniformes_sec_urban = uniformes/sec_urban 
su uniformes_sec_urban [aw=wei]
table rich [aw=wei], c(mean uniformes_sec_urban ) row col f(%9.2g)

bys hid: g double uniformes_postsec_urban = uniformes/postsec_urban 
su uniformes_postsec_urban [aw=wei]
table rich [aw=wei], c(mean uniformes_postsec_urban ) row col f(%9.2g)

bys hid: g double uniformes_sup_urban = uniformes/sup_urban 
su uniformes_sup_urban [aw=wei]
table rich [aw=wei], c(mean uniformes_sup_urban ) row col f(%9.2g)

bys hid: g double uniformes_techprof_urban = uniformes/techprof_urban 
su uniformes_techprof_urban [aw=wei]
table rich [aw=wei], c(mean uniformes_techprof_urban ) row col f(%9.2g)

bys hid: g double uniformes_eleves_rural = uniformes/eleves_rural 
su uniformes_eleves_rural [aw=wei]
table rich [aw=wei], c(mean uniformes_eleves_rural ) row col f(%9.2g)

bys hid: g double uniformes_prescho_rural = uniformes/prescho_rural 
su uniformes_prescho_rural [aw=wei]
table rich [aw=wei], c(mean uniformes_prescho_rural ) row col f(%9.2g)

bys hid: g double uniformes_prim_rural = uniformes /prim_rural 
su uniformes_prim_rural [aw=wei]
table rich [aw=wei], c(mean uniformes_prim_rural ) row col f(%9.2g)

bys hid: g double uniformes_sec_rural = uniformes/sec_rural 
su uniformes_sec_rural [aw=wei]
table rich [aw=wei], c(mean uniformes_sec_rural ) row col f(%9.2g)

bys hid: g double uniformes_postsec_rural = uniformes/postsec_rural 
su uniformes_postsec_rural [aw=wei]
table rich [aw=wei], c(mean uniformes_postsec_rural ) row col f(%9.2g)

bys hid: g double uniformes_sup_rural = uniformes/sup_rural 
su uniformes_sup_rural [aw=wei]
table rich [aw=wei], c(mean uniformes_sup_rural ) row col f(%9.2g)

bys hid: g double uniformes_techprof_rural = uniformes/techprof_rural 
su uniformes_techprof_rural [aw=wei]
table rich [aw=wei], c(mean uniformes_techprof_rural ) row col f(%9.2g)


bys hid: g double transport_eleves = transport/eleves
su transport_eleves [aw=wei]
table rich [aw=wei], c(mean transport_eleves ) row col f(%9.2g)

bys hid: g double transport_prescho = transport/prescho
su transport_prescho [aw=wei]
table rich [aw=wei], c(mean transport_prescho ) row col f(%9.2g)

bys hid: g double transport_prim = transport/prim 
su transport_prim [aw=wei]
table rich [aw=wei], c(mean transport_prim ) row col f(%9.2g)

bys hid: g double transport_sec = transport/sec 
su transport_sec [aw=wei]
table rich [aw=wei], c(mean transport_sec ) row col f(%9.2g)

bys hid: g double transport_postsec = transport/postsec 
su transport_postsec [aw=wei]
table rich [aw=wei], c(mean transport_postsec ) row col f(%9.2g)

bys hid: g double transport_sup = transport/sup 
su transport_sup [aw=wei]
table rich [aw=wei], c(mean transport_sup ) row col f(%9.2g)

bys hid: g double transport_techprof = transport/techprof 
su transport_techprof [aw=wei]
table rich [aw=wei], c(mean transport_techprof ) row col f(%9.2g)

bys hid: g double transport_eleves_boys = transport/eleves_boys
su transport_eleves_boys [aw=wei]
table rich [aw=wei], c(mean transport_eleves_boys ) row col f(%9.2g)

bys hid: g double transport_prescho_boys = transport/prescho_boys
su transport_prescho_boys [aw=wei]
table rich [aw=wei], c(mean transport_prescho_boys ) row col f(%9.2g)

bys hid: g double transport_prim_boys = transport/prim_boys
su transport_prim_boys [aw=wei]
table rich [aw=wei], c(mean transport_prim_boys ) row col f(%9.2g)

bys hid: g double transport_sec_boys = transport/sec_boys 
su transport_sec_boys [aw=wei]
table rich [aw=wei], c(mean transport_sec_boys ) row col f(%9.2g)

bys hid: g double transport_postsec_boys = transport/postsec_boys 
su transport_postsec_boys [aw=wei]
table rich [aw=wei], c(mean transport_postsec_boys ) row col f(%9.2g)

bys hid: g double transport_sup_boys = transport/sup_boys
su transport_sup_boys [aw=wei]
table rich [aw=wei], c(mean transport_sup_boys ) row col f(%9.2g)

bys hid: g double transport_techprof_boys = transport/techprof_boys 
su transport_techprof_boys [aw=wei]
table rich [aw=wei], c(mean transport_techprof_boys ) row col f(%9.2g)

bys hid: g double transport_eleves_girls = transport/eleves_girls 
su transport_eleves_girls [aw=wei]
table rich [aw=wei], c(mean transport_eleves_girls ) row col f(%9.2g)

bys hid: g double transport_prescho_girls = transport/prescho_girls 
su transport_prescho_girls [aw=wei]
table rich [aw=wei], c(mean transport_prescho_girls ) row col f(%9.2g)

bys hid: g double transport_prim_girls = transport/prim_girls 
su transport_prim_girls [aw=wei]
table rich [aw=wei], c(mean transport_prim_girls ) row col f(%9.2g)

bys hid: g double transport_sec_girls = transport/sec_girls 
su transport_sec_girls [aw=wei]
table rich [aw=wei], c(mean transport_sec_girls ) row col f(%9.2g)

bys hid: g double transport_postsec_girls = transport/postsec_girls 
su transport_postsec_girls [aw=wei]
table rich [aw=wei], c(mean transport_postsec_girls ) row col f(%9.2g)

bys hid: g double transport_sup_girls = transport/sup_girls 
su transport_sup_girls [aw=wei]
table rich [aw=wei], c(mean transport_sup_girls ) row col f(%9.2g)

bys hid: g double transport_techprof_girls = transport/techprof_girls 
su transport_techprof_girls [aw=wei]
table rich [aw=wei], c(mean transport_techprof_girls ) row col f(%9.2g)

bys hid: g double transport_eleves_urban = transport/eleves_urban 
su transport_eleves_urban [aw=wei]
table rich [aw=wei], c(mean transport_eleves_urban ) row col f(%9.2g)

bys hid: g double transport_prescho_urban = transport/prescho_urban 
su transport_prescho_urban [aw=wei]
table rich [aw=wei], c(mean transport_prescho_urban ) row col f(%9.2g)

bys hid: g double transport_prim_urban = transport /prim_urban 
su transport_prim_urban [aw=wei]
table rich [aw=wei], c(mean transport_prim_urban ) row col f(%9.2g)

bys hid: g double transport_sec_urban = transport/sec_urban 
su transport_sec_urban [aw=wei]
table rich [aw=wei], c(mean transport_sec_urban ) row col f(%9.2g)

bys hid: g double transport_postsec_urban = transport/postsec_urban 
su transport_postsec_urban [aw=wei]
table rich [aw=wei], c(mean transport_postsec_urban ) row col f(%9.2g)

bys hid: g double transport_sup_urban = transport/sup_urban 
su transport_sup_urban [aw=wei]
table rich [aw=wei], c(mean transport_sup_urban ) row col f(%9.2g)

bys hid: g double transport_techprof_urban = transport/techprof_urban 
su transport_techprof_urban [aw=wei]
table rich [aw=wei], c(mean transport_techprof_urban ) row col f(%9.2g)

bys hid: g double transport_eleves_rural = transport/eleves_rural 
su transport_eleves_rural [aw=wei]
table rich [aw=wei], c(mean transport_eleves_rural ) row col f(%9.2g)

bys hid: g double transport_prescho_rural = transport/prescho_rural 
su transport_prescho_rural [aw=wei]
table rich [aw=wei], c(mean transport_prescho_rural ) row col f(%9.2g)

bys hid: g double transport_prim_rural = transport /prim_rural 
su transport_prim_rural [aw=wei]
table rich [aw=wei], c(mean transport_prim_rural ) row col f(%9.2g)

bys hid: g double transport_sec_rural = transport/sec_rural 
su transport_sec_rural [aw=wei]
table rich [aw=wei], c(mean transport_sec_rural ) row col f(%9.2g)

bys hid: g double transport_postsec_rural = transport/postsec_rural 
su transport_postsec_rural [aw=wei]
table rich [aw=wei], c(mean transport_postsec_rural ) row col f(%9.2g)

bys hid: g double transport_sup_rural = transport/sup_rural 
su transport_sup_rural [aw=wei]
table rich [aw=wei], c(mean transport_sup_rural ) row col f(%9.2g)

bys hid: g double transport_techprof_rural = transport/techprof_rural 
su transport_techprof_rural [aw=wei]
table rich [aw=wei], c(mean transport_techprof_rural ) row col f(%9.2g)


bys hid: g double autres_educ_dep_eleves = autres_educ_dep/eleves
su autres_educ_dep_eleves [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_eleves ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prescho = autres_educ_dep/prescho
su autres_educ_dep_prescho [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prescho ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prim = autres_educ_dep/prim 
su autres_educ_dep_prim [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prim ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sec = autres_educ_dep/sec 
su autres_educ_dep_sec [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sec ) row col f(%9.2g)

bys hid: g double autres_educ_dep_postsec = autres_educ_dep/postsec 
su autres_educ_dep_postsec [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_postsec ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sup = autres_educ_dep/sup 
su autres_educ_dep_sup [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sup ) row col f(%9.2g)

bys hid: g double autres_educ_dep_techprof = autres_educ_dep/techprof 
su autres_educ_dep_techprof [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_techprof ) row col f(%9.2g)

bys hid: g double autres_educ_dep_eleves_boys = autres_educ_dep/eleves_boys
su autres_educ_dep_eleves_boys [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_eleves_boys ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prescho_boys = autres_educ_dep/prescho_boys
su autres_educ_dep_prescho_boys [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prescho_boys ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prim_boys = autres_educ_dep/prim_boys
su autres_educ_dep_prim_boys [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prim_boys ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sec_boys = autres_educ_dep/sec_boys 
su autres_educ_dep_sec_boys [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sec_boys ) row col f(%9.2g)

bys hid: g double autres_educ_dep_postsec_boys = autres_educ_dep/postsec_boys 
su autres_educ_dep_postsec_boys [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_postsec_boys ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sup_boys = autres_educ_dep/sup_boys
su autres_educ_dep_sup_boys [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sup_boys ) row col f(%9.2g)

bys hid: g double autres_educ_dep_techprof_boys = autres_educ_dep/techprof_boys 
su autres_educ_dep_techprof_boys [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_techprof_boys ) row col f(%9.2g)

bys hid: g double autres_educ_dep_eleves_girls = autres_educ_dep/eleves_girls 
su autres_educ_dep_eleves_girls [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_eleves_girls ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prescho_girls = autres_educ_dep/prescho_girls 
su autres_educ_dep_prescho_girls [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prescho_girls ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prim_girls = autres_educ_dep/prim_girls 
su autres_educ_dep_prim_girls [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prim_girls ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sec_girls = autres_educ_dep/sec_girls 
su autres_educ_dep_sec_girls [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sec_girls ) row col f(%9.2g)

bys hid: g double autres_educ_dep_postsec_girls = autres_educ_dep/postsec_girls 
su autres_educ_dep_postsec_girls [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_postsec_girls ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sup_girls = autres_educ_dep/sup_girls 
su autres_educ_dep_sup_girls [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sup_girls ) row col f(%9.2g)

bys hid: g double autres_educ_dep_techprof_girls = autres_educ_dep/techprof_girls 
su autres_educ_dep_techprof_girls [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_techprof_girls ) row col f(%9.2g)

bys hid: g double autres_educ_dep_eleves_urban = autres_educ_dep/eleves_urban 
su autres_educ_dep_eleves_urban [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_eleves_urban ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prescho_urban = autres_educ_dep/prescho_urban 
su autres_educ_dep_prescho_urban [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prescho_urban ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prim_urban = autres_educ_dep /prim_urban 
su autres_educ_dep_prim_urban [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prim_urban ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sec_urban = autres_educ_dep/sec_urban 
su autres_educ_dep_sec_urban [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sec_urban ) row col f(%9.2g)

bys hid: g double autres_educ_dep_postsec_urban = autres_educ_dep/postsec_urban 
su autres_educ_dep_postsec_urban [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_postsec_urban ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sup_urban = autres_educ_dep/sup_urban 
su autres_educ_dep_sup_urban [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sup_urban ) row col f(%9.2g)

bys hid: g double autres_educ_dep_techprof_urban = autres_educ_dep/techprof_urban 
su autres_educ_dep_techprof_urban [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_techprof_urban ) row col f(%9.2g)

bys hid: g double autres_educ_dep_eleves_rural = autres_educ_dep/eleves_rural 
su autres_educ_dep_eleves_rural [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_eleves_rural ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prescho_rural = autres_educ_dep/prescho_rural 
su autres_educ_dep_prescho_rural [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prescho_rural ) row col f(%9.2g)

bys hid: g double autres_educ_dep_prim_rural = autres_educ_dep /prim_rural 
su autres_educ_dep_prim_rural [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_prim_rural ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sec_rural = autres_educ_dep/sec_rural 
su autres_educ_dep_sec_rural [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sec_rural ) row col f(%9.2g)

bys hid: g double autres_educ_dep_postsec_rural = autres_educ_dep/postsec_rural 
su autres_educ_dep_postsec_rural [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_postsec_rural ) row col f(%9.2g)

bys hid: g double autres_educ_dep_sup_rural = autres_educ_dep/sup_rural 
su autres_educ_dep_sup_rural [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_sup_rural ) row col f(%9.2g)

bys hid: g double autres_educ_dep_techprof_rural = autres_educ_dep/techprof_rural 
su autres_educ_dep_techprof_rural [aw=wei]
table rich [aw=wei], c(mean autres_educ_dep_techprof_rural ) row col f(%9.2g)


bys hid: g double bourses_eleves = bourses/eleves
su bourses_eleves [aw=wei]
table rich [aw=wei], c(mean bourses_eleves ) row col f(%9.2g)

bys hid: g double bourses_prescho = bourses/prescho
su bourses_prescho [aw=wei]
table rich [aw=wei], c(mean bourses_prescho ) row col f(%9.2g)

bys hid: g double bourses_prim = bourses/prim 
su bourses_prim [aw=wei]
table rich [aw=wei], c(mean bourses_prim ) row col f(%9.2g)

bys hid: g double bourses_sec = bourses/sec 
su bourses_sec [aw=wei]
table rich [aw=wei], c(mean bourses_sec ) row col f(%9.2g)

bys hid: g double bourses_postsec = bourses/postsec 
su bourses_postsec [aw=wei]
table rich [aw=wei], c(mean bourses_postsec ) row col f(%9.2g)

bys hid: g double bourses_sup = bourses/sup 
su bourses_sup [aw=wei]
table rich [aw=wei], c(mean bourses_sup ) row col f(%9.2g)

bys hid: g double bourses_techprof = bourses/techprof 
su bourses_techprof [aw=wei]
table rich [aw=wei], c(mean bourses_techprof ) row col f(%9.2g)

bys hid: g double bourses_eleves_boys = bourses/eleves_boys
su bourses_eleves_boys [aw=wei]
table rich [aw=wei], c(mean bourses_eleves_boys ) row col f(%9.2g)

bys hid: g double bourses_prescho_boys = bourses/prescho_boys
su bourses_prescho_boys [aw=wei]
table rich [aw=wei], c(mean bourses_prescho_boys ) row col f(%9.2g)

bys hid: g double bourses_prim_boys = bourses/prim_boys
su bourses_prim_boys [aw=wei]
table rich [aw=wei], c(mean bourses_prim_boys ) row col f(%9.2g)

bys hid: g double bourses_sec_boys = bourses/sec_boys 
su bourses_sec_boys [aw=wei]
table rich [aw=wei], c(mean bourses_sec_boys ) row col f(%9.2g)

bys hid: g double bourses_postsec_boys = bourses/postsec_boys 
su bourses_postsec_boys [aw=wei]
table rich [aw=wei], c(mean bourses_postsec_boys ) row col f(%9.2g)

bys hid: g double bourses_sup_boys = bourses/sup_boys
su bourses_sup_boys [aw=wei]
table rich [aw=wei], c(mean bourses_sup_boys ) row col f(%9.2g)

bys hid: g double bourses_techprof_boys = bourses/techprof_boys 
su bourses_techprof_boys [aw=wei]
table rich [aw=wei], c(mean bourses_techprof_boys ) row col f(%9.2g)

bys hid: g double bourses_eleves_girls = bourses/eleves_girls 
su bourses_eleves_girls [aw=wei]
table rich [aw=wei], c(mean bourses_eleves_girls ) row col f(%9.2g)

bys hid: g double bourses_prescho_girls = bourses/prescho_girls 
su bourses_prescho_girls [aw=wei]
table rich [aw=wei], c(mean bourses_prescho_girls ) row col f(%9.2g)

bys hid: g double bourses_prim_girls = bourses/prim_girls 
su bourses_prim_girls [aw=wei]
table rich [aw=wei], c(mean bourses_prim_girls ) row col f(%9.2g)

bys hid: g double bourses_sec_girls = bourses/sec_girls 
su bourses_sec_girls [aw=wei]
table rich [aw=wei], c(mean bourses_sec_girls ) row col f(%9.2g)

bys hid: g double bourses_postsec_girls = bourses/postsec_girls 
su bourses_postsec_girls [aw=wei]
table rich [aw=wei], c(mean bourses_postsec_girls ) row col f(%9.2g)

bys hid: g double bourses_sup_girls = bourses/sup_girls 
su bourses_sup_girls [aw=wei]
table rich [aw=wei], c(mean bourses_sup_girls ) row col f(%9.2g)

bys hid: g double bourses_techprof_girls = bourses/techprof_girls 
su bourses_techprof_girls [aw=wei]
table rich [aw=wei], c(mean bourses_techprof_girls ) row col f(%9.2g)

bys hid: g double bourses_eleves_urban = bourses/eleves_urban 
su bourses_eleves_urban [aw=wei]
table rich [aw=wei], c(mean bourses_eleves_urban ) row col f(%9.2g)

bys hid: g double bourses_prescho_urban = bourses/prescho_urban 
su bourses_prescho_urban [aw=wei]
table rich [aw=wei], c(mean bourses_prescho_urban ) row col f(%9.2g)

bys hid: g double bourses_prim_urban = bourses /prim_urban 
su bourses_prim_urban [aw=wei]
table rich [aw=wei], c(mean bourses_prim_urban ) row col f(%9.2g)

bys hid: g double bourses_sec_urban = bourses/sec_urban 
su bourses_sec_urban [aw=wei]
table rich [aw=wei], c(mean bourses_sec_urban ) row col f(%9.2g)

bys hid: g double bourses_postsec_urban = bourses/postsec_urban 
su bourses_postsec_urban [aw=wei]
table rich [aw=wei], c(mean bourses_postsec_urban ) row col f(%9.2g)

bys hid: g double bourses_sup_urban = bourses/sup_urban 
su bourses_sup_urban [aw=wei]
table rich [aw=wei], c(mean bourses_sup_urban ) row col f(%9.2g)

bys hid: g double bourses_techprof_urban = bourses/techprof_urban 
su bourses_techprof_urban [aw=wei]
table rich [aw=wei], c(mean bourses_techprof_urban ) row col f(%9.2g)

bys hid: g double bourses_eleves_rural = bourses/eleves_rural 
su bourses_eleves_rural [aw=wei]
table rich [aw=wei], c(mean bourses_eleves_rural ) row col f(%9.2g)

bys hid: g double bourses_prescho_rural = bourses/prescho_rural 
su bourses_prescho_rural [aw=wei]
table rich [aw=wei], c(mean bourses_prescho_rural ) row col f(%9.2g)

bys hid: g double bourses_prim_rural = bourses /prim_rural 
su bourses_prim_rural [aw=wei]
table rich [aw=wei], c(mean bourses_prim_rural ) row col f(%9.2g)

bys hid: g double bourses_sec_rural = bourses/sec_rural 
su bourses_sec_rural [aw=wei]
table rich [aw=wei], c(mean bourses_sec_rural ) row col f(%9.2g)

bys hid: g double bourses_postsec_rural = bourses/postsec_rural 
su bourses_postsec_rural [aw=wei]
table rich [aw=wei], c(mean bourses_postsec_rural ) row col f(%9.2g)

bys hid: g double bourses_sup_rural = bourses/sup_rural 
su bourses_sup_rural [aw=wei]
table rich [aw=wei], c(mean bourses_sup_rural ) row col f(%9.2g)

bys hid: g double bourses_techprof_rural = bourses/techprof_rural 
su bourses_techprof_rural [aw=wei]
table rich [aw=wei], c(mean bourses_techprof_rural ) row col f(%9.2g)


bys hid: g double toteduc1_eleves = toteduc1/eleves
su toteduc1_eleves [aw=wei]
table rich [aw=wei], c(mean toteduc1_eleves ) row col f(%9.2g)

bys hid: g double toteduc1_prescho = toteduc1/prescho
su toteduc1_prescho [aw=wei]
table rich [aw=wei], c(mean toteduc1_prescho ) row col f(%9.2g)

bys hid: g double toteduc1_prim = toteduc1/prim 
su toteduc1_prim [aw=wei]
table rich [aw=wei], c(mean toteduc1_prim ) row col f(%9.2g)

bys hid: g double toteduc1_sec = toteduc1/sec 
su toteduc1_sec [aw=wei]
table rich [aw=wei], c(mean toteduc1_sec ) row col f(%9.2g)

bys hid: g double toteduc1_postsec = toteduc1/postsec 
su toteduc1_postsec [aw=wei]
table rich [aw=wei], c(mean toteduc1_postsec ) row col f(%9.2g)

bys hid: g double toteduc1_sup = toteduc1/sup 
su toteduc1_sup [aw=wei]
table rich [aw=wei], c(mean toteduc1_sup ) row col f(%9.2g)

bys hid: g double toteduc1_techprof = toteduc1/techprof 
su toteduc1_techprof [aw=wei]
table rich [aw=wei], c(mean toteduc1_techprof ) row col f(%9.2g)

bys hid: g double toteduc1_eleves_boys = toteduc1/eleves_boys
su toteduc1_eleves_boys [aw=wei]
table rich [aw=wei], c(mean toteduc1_eleves_boys ) row col f(%9.2g)

bys hid: g double toteduc1_prescho_boys = toteduc1/prescho_boys
su toteduc1_prescho_boys [aw=wei]
table rich [aw=wei], c(mean toteduc1_prescho_boys ) row col f(%9.2g)

bys hid: g double toteduc1_prim_boys = toteduc1/prim_boys
su toteduc1_prim_boys [aw=wei]
table rich [aw=wei], c(mean toteduc1_prim_boys ) row col f(%9.2g)

bys hid: g double toteduc1_sec_boys = toteduc1/sec_boys 
su toteduc1_sec_boys [aw=wei]
table rich [aw=wei], c(mean toteduc1_sec_boys ) row col f(%9.2g)

bys hid: g double toteduc1_postsec_boys = toteduc1/postsec_boys 
su toteduc1_postsec_boys [aw=wei]
table rich [aw=wei], c(mean toteduc1_postsec_boys ) row col f(%9.2g)

bys hid: g double toteduc1_sup_boys = toteduc1/sup_boys
su toteduc1_sup_boys [aw=wei]
table rich [aw=wei], c(mean toteduc1_sup_boys ) row col f(%9.2g)

bys hid: g double toteduc1_techprof_boys = toteduc1/techprof_boys 
su toteduc1_techprof_boys [aw=wei]
table rich [aw=wei], c(mean toteduc1_techprof_boys ) row col f(%9.2g)

bys hid: g double toteduc1_eleves_girls = toteduc1/eleves_girls 
su toteduc1_eleves_girls [aw=wei]
table rich [aw=wei], c(mean toteduc1_eleves_girls ) row col f(%9.2g)

bys hid: g double toteduc1_prescho_girls = toteduc1/prescho_girls 
su toteduc1_prescho_girls [aw=wei]
table rich [aw=wei], c(mean toteduc1_prescho_girls ) row col f(%9.2g)

bys hid: g double toteduc1_prim_girls = toteduc1/prim_girls 
su toteduc1_prim_girls [aw=wei]
table rich [aw=wei], c(mean toteduc1_prim_girls ) row col f(%9.2g)

bys hid: g double toteduc1_sec_girls = toteduc1/sec_girls 
su toteduc1_sec_girls [aw=wei]
table rich [aw=wei], c(mean toteduc1_sec_girls ) row col f(%9.2g)

bys hid: g double toteduc1_postsec_girls = toteduc1/postsec_girls 
su toteduc1_postsec_girls [aw=wei]
table rich [aw=wei], c(mean toteduc1_postsec_girls ) row col f(%9.2g)

bys hid: g double toteduc1_sup_girls = toteduc1/sup_girls 
su toteduc1_sup_girls [aw=wei]
table rich [aw=wei], c(mean toteduc1_sup_girls ) row col f(%9.2g)

bys hid: g double toteduc1_techprof_girls = toteduc1/techprof_girls 
su toteduc1_techprof_girls [aw=wei]
table rich [aw=wei], c(mean toteduc1_techprof_girls ) row col f(%9.2g)

bys hid: g double toteduc1_eleves_urban = toteduc1/eleves_urban 
su toteduc1_eleves_urban [aw=wei]
table rich [aw=wei], c(mean toteduc1_eleves_urban ) row col f(%9.2g)

bys hid: g double toteduc1_prescho_urban = toteduc1/prescho_urban 
su toteduc1_prescho_urban [aw=wei]
table rich [aw=wei], c(mean toteduc1_prescho_urban ) row col f(%9.2g)

bys hid: g double toteduc1_prim_urban = toteduc1 /prim_urban 
su toteduc1_prim_urban [aw=wei]
table rich [aw=wei], c(mean toteduc1_prim_urban ) row col f(%9.2g)

bys hid: g double toteduc1_sec_urban = toteduc1/sec_urban 
su toteduc1_sec_urban [aw=wei]
table rich [aw=wei], c(mean toteduc1_sec_urban ) row col f(%9.2g)

bys hid: g double toteduc1_postsec_urban = toteduc1/postsec_urban 
su toteduc1_postsec_urban [aw=wei]
table rich [aw=wei], c(mean toteduc1_postsec_urban ) row col f(%9.2g)

bys hid: g double toteduc1_sup_urban = toteduc1/sup_urban 
su toteduc1_sup_urban [aw=wei]
table rich [aw=wei], c(mean toteduc1_sup_urban ) row col f(%9.2g)

bys hid: g double toteduc1_techprof_urban = toteduc1/techprof_urban 
su toteduc1_techprof_urban [aw=wei]
table rich [aw=wei], c(mean toteduc1_techprof_urban ) row col f(%9.2g)

bys hid: g double toteduc1_eleves_rural = toteduc1/eleves_rural 
su toteduc1_eleves_rural [aw=wei]
table rich [aw=wei], c(mean toteduc1_eleves_rural ) row col f(%9.2g)

bys hid: g double toteduc1_prescho_rural = toteduc1/prescho_rural 
su toteduc1_prescho_rural [aw=wei]
table rich [aw=wei], c(mean toteduc1_prescho_rural ) row col f(%9.2g)

bys hid: g double toteduc1_prim_rural = toteduc1 /prim_rural 
su toteduc1_prim_rural [aw=wei]
table rich [aw=wei], c(mean toteduc1_prim_rural ) row col f(%9.2g)

bys hid: g double toteduc1_sec_rural = toteduc1/sec_rural 
su toteduc1_sec_rural [aw=wei]
table rich [aw=wei], c(mean toteduc1_sec_rural ) row col f(%9.2g)

bys hid: g double toteduc1_postsec_rural = toteduc1/postsec_rural 
su toteduc1_postsec_rural [aw=wei]
table rich [aw=wei], c(mean toteduc1_postsec_rural ) row col f(%9.2g)

bys hid: g double toteduc1_sup_rural = toteduc1/sup_rural 
su toteduc1_sup_rural [aw=wei]
table rich [aw=wei], c(mean toteduc1_sup_rural ) row col f(%9.2g)

bys hid: g double toteduc1_techprof_rural = toteduc1/techprof_rural 
su toteduc1_techprof_rural [aw=wei]
table rich [aw=wei], c(mean toteduc1_techprof_rural ) row col f(%9.2g)


bys hid: g double toteduc2_eleves = toteduc2/eleves
su toteduc2_eleves [aw=wei]
table rich [aw=wei], c(mean toteduc2_eleves ) row col f(%9.2g)

bys hid: g double toteduc2_prescho = toteduc2/prescho
su toteduc2_prescho [aw=wei]
table rich [aw=wei], c(mean toteduc2_prescho ) row col f(%9.2g)

bys hid: g double toteduc2_prim = toteduc2/prim 
su toteduc2_prim [aw=wei]
table rich [aw=wei], c(mean toteduc2_prim ) row col f(%9.2g)

bys hid: g double toteduc2_sec = toteduc2/sec 
su toteduc2_sec [aw=wei]
table rich [aw=wei], c(mean toteduc2_sec ) row col f(%9.2g)

bys hid: g double toteduc2_postsec = toteduc2/postsec 
su toteduc2_postsec [aw=wei]
table rich [aw=wei], c(mean toteduc2_postsec ) row col f(%9.2g)

bys hid: g double toteduc2_sup = toteduc2/sup 
su toteduc2_sup [aw=wei]
table rich [aw=wei], c(mean toteduc2_sup ) row col f(%9.2g)

bys hid: g double toteduc2_techprof = toteduc2/techprof 
su toteduc2_techprof [aw=wei]
table rich [aw=wei], c(mean toteduc2_techprof ) row col f(%9.2g)

bys hid: g double toteduc2_eleves_boys = toteduc2/eleves_boys
su toteduc2_eleves_boys [aw=wei]
table rich [aw=wei], c(mean toteduc2_eleves_boys ) row col f(%9.2g)

bys hid: g double toteduc2_prescho_boys = toteduc2/prescho_boys
su toteduc2_prescho_boys [aw=wei]
table rich [aw=wei], c(mean toteduc2_prescho_boys ) row col f(%9.2g)

bys hid: g double toteduc2_prim_boys = toteduc2/prim_boys
su toteduc2_prim_boys [aw=wei]
table rich [aw=wei], c(mean toteduc2_prim_boys ) row col f(%9.2g)

bys hid: g double toteduc2_sec_boys = toteduc2/sec_boys 
su toteduc2_sec_boys [aw=wei]
table rich [aw=wei], c(mean toteduc2_sec_boys ) row col f(%9.2g)

bys hid: g double toteduc2_postsec_boys = toteduc2/postsec_boys 
su toteduc2_postsec_boys [aw=wei]
table rich [aw=wei], c(mean toteduc2_postsec_boys ) row col f(%9.2g)

bys hid: g double toteduc2_sup_boys = toteduc2/sup_boys
su toteduc2_sup_boys [aw=wei]
table rich [aw=wei], c(mean toteduc2_sup_boys ) row col f(%9.2g)

bys hid: g double toteduc2_techprof_boys = toteduc2/techprof_boys 
su toteduc2_techprof_boys [aw=wei]
table rich [aw=wei], c(mean toteduc2_techprof_boys ) row col f(%9.2g)

bys hid: g double toteduc2_eleves_girls = toteduc2/eleves_girls 
su toteduc2_eleves_girls [aw=wei]
table rich [aw=wei], c(mean toteduc2_eleves_girls ) row col f(%9.2g)

bys hid: g double toteduc2_prescho_girls = toteduc2/prescho_girls 
su toteduc2_prescho_girls [aw=wei]
table rich [aw=wei], c(mean toteduc2_prescho_girls ) row col f(%9.2g)

bys hid: g double toteduc2_prim_girls = toteduc2/prim_girls 
su toteduc2_prim_girls [aw=wei]
table rich [aw=wei], c(mean toteduc2_prim_girls ) row col f(%9.2g)

bys hid: g double toteduc2_sec_girls = toteduc2/sec_girls 
su toteduc2_sec_girls [aw=wei]
table rich [aw=wei], c(mean toteduc2_sec_girls ) row col f(%9.2g)

bys hid: g double toteduc2_postsec_girls = toteduc2/postsec_girls 
su toteduc2_postsec_girls [aw=wei]
table rich [aw=wei], c(mean toteduc2_postsec_girls ) row col f(%9.2g)

bys hid: g double toteduc2_sup_girls = toteduc2/sup_girls 
su toteduc2_sup_girls [aw=wei]
table rich [aw=wei], c(mean toteduc2_sup_girls ) row col f(%9.2g)

bys hid: g double toteduc2_techprof_girls = toteduc2/techprof_girls 
su toteduc2_techprof_girls [aw=wei]
table rich [aw=wei], c(mean toteduc2_techprof_girls ) row col f(%9.2g)

bys hid: g double toteduc2_eleves_urban = toteduc2/eleves_urban 
su toteduc2_eleves_urban [aw=wei]
table rich [aw=wei], c(mean toteduc2_eleves_urban ) row col f(%9.2g)

bys hid: g double toteduc2_prescho_urban = toteduc2/prescho_urban 
su toteduc2_prescho_urban [aw=wei]
table rich [aw=wei], c(mean toteduc2_prescho_urban ) row col f(%9.2g)

bys hid: g double toteduc2_prim_urban = toteduc2 /prim_urban 
su toteduc2_prim_urban [aw=wei]
table rich [aw=wei], c(mean toteduc2_prim_urban ) row col f(%9.2g)

bys hid: g double toteduc2_sec_urban = toteduc2/sec_urban 
su toteduc2_sec_urban [aw=wei]
table rich [aw=wei], c(mean toteduc2_sec_urban ) row col f(%9.2g)

bys hid: g double toteduc2_postsec_urban = toteduc2/postsec_urban 
su toteduc2_postsec_urban [aw=wei]
table rich [aw=wei], c(mean toteduc2_postsec_urban ) row col f(%9.2g)

bys hid: g double toteduc2_sup_urban = toteduc2/sup_urban 
su toteduc2_sup_urban [aw=wei]
table rich [aw=wei], c(mean toteduc2_sup_urban ) row col f(%9.2g)

bys hid: g double toteduc2_techprof_urban = toteduc2/techprof_urban 
su toteduc2_techprof_urban [aw=wei]
table rich [aw=wei], c(mean toteduc2_techprof_urban ) row col f(%9.2g)

bys hid: g double toteduc2_eleves_rural = toteduc2/eleves_rural 
su toteduc2_eleves_rural [aw=wei]
table rich [aw=wei], c(mean toteduc2_eleves_rural ) row col f(%9.2g)

bys hid: g double toteduc2_prescho_rural = toteduc2/prescho_rural 
su toteduc2_prescho_rural [aw=wei]
table rich [aw=wei], c(mean toteduc2_prescho_rural ) row col f(%9.2g)

bys hid: g double toteduc2_prim_rural = toteduc2 /prim_rural 
su toteduc2_prim_rural [aw=wei]
table rich [aw=wei], c(mean toteduc2_prim_rural ) row col f(%9.2g)

bys hid: g double toteduc2_sec_rural = toteduc2/sec_rural 
su toteduc2_sec_rural [aw=wei]
table rich [aw=wei], c(mean toteduc2_sec_rural ) row col f(%9.2g)

bys hid: g double toteduc2_postsec_rural = toteduc2/postsec_rural 
su toteduc2_postsec_rural [aw=wei]
table rich [aw=wei], c(mean toteduc2_postsec_rural ) row col f(%9.2g)

bys hid: g double toteduc2_sup_rural = toteduc2/sup_rural 
su toteduc2_sup_rural [aw=wei]
table rich [aw=wei], c(mean toteduc2_sup_rural ) row col f(%9.2g)

bys hid: g double toteduc2_techprof_rural = toteduc2/techprof_rural 
su toteduc2_techprof_rural [aw=wei]
table rich [aw=wei], c(mean toteduc2_techprof_rural ) row col f(%9.2g)










sort hid
su  inscription [aw=wei]
bys rich: su  inscription [aw=wei]

sort hid
su  scolarite [aw=wei]
bys rich: su  scolarite [aw=wei]

sort hid
su  fournitures [aw=wei]
bys rich: su  fournitures [aw=wei]

sort hid
su  uniformes [aw=wei]
bys rich: su  uniformes [aw=wei]

sort hid
su  transport [aw=wei]
bys rich: su  transport [aw=wei]


sort hid
su  autres_educ_dep [aw=wei]
bys rich: su  autres_educ_dep [aw=wei]

sort hid
su  bourses [aw=wei]
bys rich: su  bourses [aw=wei]

sort hid
su  toteduc1 [aw=wei]
bys rich: su  toteduc1 [aw=wei]

sort hid
su  toteduc2 [aw=wei]
bys rich: su  toteduc2 [aw=wei]




#delim;
su class_* prescho* prim* sec* postsec* sup* techprof* inscription* scolarite* 
fournitures* uniformes* transport* autres_educ_dep* bourses* toteduc1* toteduc2* 
[aw=weig];
#delim cr

sort hid
save educ_exp, replace






*drop if eleves==0



collapse (sum) inscription* scolarite*  fournitures* uniformes* transport* autres_educ_dep* bourses* toteduc1* toteduc2* ///
(mean) eleves* prescho* prim* sec* postsec* sup* techprof* rich pond weight hhsize ///
(max) class_* (min) sexmale=sex milur=milieu (max) sexfem=sex milru=milieu [w=pond], by(hid)
sort hid
save educ_exp2, replace

cap log close
log using "Eductables2.log", replace
sum  [aw=weig], d
#delim;
global educ "inscription inscription_eleves inscription_prescho inscription_prim 
inscription_sec inscription_postsec inscription_sup inscription_techprof 
inscription_eleves_boys inscription_prescho_boys inscription_prim_boys 
inscription_sec_boys inscription_postsec_boys inscription_sup_boys 
inscription_techprof_boys inscription_eleves_girls inscription_prescho_girls 
inscription_prim_girls inscription_sec_girls inscription_postsec_girls 
inscription_sup_girls inscription_techprof_girls inscription_eleves_urban 
inscription_prescho_urban inscription_prim_urban inscription_sec_urban 
inscription_postsec_urban inscription_sup_urban inscription_techprof_urban 
inscription_eleves_rural inscription_prescho_rural inscription_prim_rural 
inscription_sec_rural inscription_postsec_rural inscription_sup_rural 
inscription_techprof_rural scolarite scolarite_eleves scolarite_prescho 
scolarite_prim scolarite_sec scolarite_postsec scolarite_sup scolarite_techprof 
scolarite_eleves_boys scolarite_prescho_boys scolarite_prim_boys scolarite_sec_boys 
scolarite_postsec_boys  scolarite_sup_boys scolarite_techprof_boys 
scolarite_eleves_girls scolarite_prescho_girls scolarite_prim_girls scolarite_sec_girls 
scolarite_postsec_girls scolarite_sup_girls scolarite_techprof_girls 
scolarite_eleves_urban scolarite_prescho_urban scolarite_prim_urban 
scolarite_sec_urban scolarite_postsec_urban scolarite_sup_urban 
scolarite_techprof_urban scolarite_eleves_rural scolarite_prescho_rural 
scolarite_prim_rural scolarite_sec_rural scolarite_postsec_rural scolarite_sup_rural 
scolarite_techprof_rural fournitures fournitures_eleves fournitures_prescho fournitures_prim 
fournitures_sec fournitures_postsec fournitures_sup fournitures_techprof fournitures_eleves_boys 
fournitures_prescho_boys fournitures_prim_boys fournitures_sec_boys fournitures_postsec_boys 
fournitures_sup_boys fournitures_techprof_boys fournitures_eleves_girls fournitures_prescho_girls 
fournitures_prim_girls fournitures_sec_girls fournitures_postsec_girls fournitures_sup_girls 
fournitures_techprof_girls fournitures_eleves_urban fournitures_prescho_urban fournitures_prim_urban 
fournitures_sec_urban fournitures_postsec_urban fournitures_sup_urban fournitures_techprof_urban 
fournitures_eleves_rural fournitures_prescho_rural fournitures_prim_rural fournitures_sec_rural 
fournitures_postsec_rural fournitures_sup_rural fournitures_techprof_rural uniformes uniformes_eleves 
uniformes_prescho uniformes_prim uniformes_sec uniformes_postsec uniformes_sup uniformes_techprof 
uniformes_eleves_boys uniformes_prescho_boys uniformes_prim_boys uniformes_sec_boys uniformes_postsec_boys 
uniformes_sup_boys uniformes_techprof_boys uniformes_eleves_girls uniformes_prescho_girls uniformes_prim_girls 
uniformes_sec_girls uniformes_postsec_girls uniformes_sup_girls uniformes_techprof_girls uniformes_eleves_urban 
uniformes_prescho_urban uniformes_prim_urban uniformes_sec_urban uniformes_postsec_urban uniformes_sup_urban 
uniformes_techprof_urban uniformes_eleves_rural uniformes_prescho_rural uniformes_prim_rural uniformes_sec_rural 
uniformes_postsec_rural uniformes_sup_rural uniformes_techprof_rural transport transport_eleves transport_prescho 
transport_prim transport_sec transport_postsec transport_sup transport_techprof transport_eleves_boys 
transport_prescho_boys transport_prim_boys transport_sec_boys transport_postsec_boys transport_sup_boys 
transport_techprof_boys transport_eleves_girls transport_prescho_girls transport_prim_girls transport_sec_girls 
transport_postsec_girls transport_sup_girls transport_techprof_girls transport_eleves_urban transport_prescho_urban 
transport_prim_urban transport_sec_urban transport_postsec_urban transport_sup_urban transport_techprof_urban 
transport_eleves_rural transport_prescho_rural transport_prim_rural transport_sec_rural transport_postsec_rural 
transport_sup_rural transport_techprof_rural autres_educ_dep autres_educ_dep_eleves autres_educ_dep_prescho 
autres_educ_dep_prim autres_educ_dep_sec autres_educ_dep_postsec autres_educ_dep_sup autres_educ_dep_techprof 
autres_educ_dep_eleves_boys autres_educ_dep_prescho_boys autres_educ_dep_prim_boys autres_educ_dep_sec_boys 
autres_educ_dep_postsec_boys autres_educ_dep_sup_boys autres_educ_dep_techprof_boys autres_educ_dep_eleves_girls 
autres_educ_dep_prescho_girls autres_educ_dep_prim_girls autres_educ_dep_sec_girls autres_educ_dep_postsec_girls 
autres_educ_dep_sup_girls autres_educ_dep_techprof_girls autres_educ_dep_eleves_urban autres_educ_dep_prescho_urban 
autres_educ_dep_prim_urban autres_educ_dep_sec_urban autres_educ_dep_postsec_urban autres_educ_dep_sup_urban 
autres_educ_dep_techprof_urban autres_educ_dep_eleves_rural autres_educ_dep_prescho_rural autres_educ_dep_prim_rural 
autres_educ_dep_sec_rural autres_educ_dep_postsec_rural autres_educ_dep_sup_rural autres_educ_dep_techprof_rural 
bourses bourses_eleves bourses_prescho bourses_prim bourses_sec bourses_postsec bourses_sup bourses_techprof 
bourses_eleves_boys bourses_prescho_boys bourses_prim_boys bourses_sec_boys bourses_postsec_boys bourses_sup_boys 
bourses_techprof_boys bourses_eleves_girls bourses_prescho_girls bourses_prim_girls bourses_sec_girls 
bourses_postsec_girls bourses_sup_girls bourses_techprof_girls bourses_eleves_urban bourses_prescho_urban 
bourses_prim_urban bourses_sec_urban bourses_postsec_urban bourses_sup_urban bourses_techprof_urban bourses_eleves_rural 
bourses_prescho_rural bourses_prim_rural bourses_sec_rural bourses_postsec_rural bourses_sup_rural bourses_techprof_rural 
toteduc1 toteduc1_eleves toteduc1_prescho toteduc1_prim toteduc1_sec toteduc1_postsec toteduc1_sup toteduc1_techprof 
toteduc1_eleves_boys toteduc1_prescho_boys toteduc1_prim_boys toteduc1_sec_boys toteduc1_postsec_boys toteduc1_sup_boys 
toteduc1_techprof_boys toteduc1_eleves_girls toteduc1_prescho_girls toteduc1_prim_girls toteduc1_sec_girls 
toteduc1_postsec_girls toteduc1_sup_girls toteduc1_techprof_girls toteduc1_eleves_urban toteduc1_prescho_urban 
toteduc1_prim_urban toteduc1_sec_urban toteduc1_postsec_urban toteduc1_sup_urban toteduc1_techprof_urban 
toteduc1_eleves_rural toteduc1_prescho_rural toteduc1_prim_rural toteduc1_sec_rural toteduc1_postsec_rural 
toteduc1_sup_rural toteduc1_techprof_rural toteduc2 toteduc2_eleves toteduc2_prescho toteduc2_prim toteduc2_sec 
toteduc2_postsec toteduc2_sup toteduc2_techprof toteduc2_eleves_boys toteduc2_prescho_boys toteduc2_prim_boys 
toteduc2_sec_boys toteduc2_postsec_boys toteduc2_sup_boys toteduc2_techprof_boys toteduc2_eleves_girls 
toteduc2_prescho_girls toteduc2_prim_girls toteduc2_sec_girls toteduc2_postsec_girls toteduc2_sup_girls 
toteduc2_techprof_girls toteduc2_eleves_urban toteduc2_prescho_urban toteduc2_prim_urban toteduc2_sec_urban 
toteduc2_postsec_urban toteduc2_sup_urban toteduc2_techprof_urban toteduc2_eleves_rural toteduc2_prescho_rural 
toteduc2_prim_rural toteduc2_sec_rural toteduc2_postsec_rural toteduc2_sup_rural toteduc2_techprof_rural

 ";
global educ2 "eleves eleves_boys eleves_girls eleves_urban eleves_rural prescho prescho_boys prescho_girls prescho_urban 
prescho_rural prim prim_boys prim_girls prim_urban prim_rural sec sec_boys sec_girls sec_urban sec_rural postsec 
postsec_boys postsec_girls postsec_urban postsec_rural sup sup_boys sup_girls sup_urban sup_rural techprof techprof_boys 
techprof_girls techprof_urban techprof_rural";

#delimit cr
foreach i of global educ2 {
  di "Table of wealth groups by mean of `i'"
  table rich [aw=pond], col row c(mean `i') f(%9.2g)
}
foreach i of global educ2 {
  di "Table of wealth groups by sum of `i'"
  table rich [aw=pond], col row c(sum `i') f(%9.2g)
}

cap log close



