clear _all
set mem 800m
set matsize 300
set more 1
set seed 123456789
set rmsg on
*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.

cd "C:\Documents and Settings\Bachir\Desktop\Bachir\World Bank\Wodon\CIV\Cote d'Ivoire Consumption\STATA"

use sect01, clear
count
sort hid
save, replace

use hhexp, clear
count
keep hid school internet health trcomm trschool hhexp
sort hid
merge hid using sect01
ta _mer
assert _mer==3
keep if _merg==3
drop _merg
compress
count
sort hid
save education, replace



use pauvre, clear
count
keep hid pond region milieu _region_ _milieu_ povline pauv pchhexp strate deflat hhsize 

sort hid
merge hid using education
ta _mer
assert _mer==3
keep if _merg==3
drop _merg
compress
count
sort hid
save education, replace


cap log close
log using education.log, replace

keep hid indid s1q2 s1q3 s1q6a s1q35 s1q42 s1q46 s1q48 s1q52 s1q62 s1q63-s1q74 s1q76 ///
school internet health trcomm trschool hhexp ///
pond region milieu _region_ _milieu_ povline pauv pchhexp strate deflat hhsize

*Individual weights
bys hid: g double weight = pond / hhsize

*Generating quintile groups
cap drop percapexp
g percapexp= pchhexp if  (pchhexp>0 &  pchhexp<=5000000)
su percapexp
replace percapexp=r(mean) if percapexp==.
su percapexp [aw=weig]
cap drop rich
xtile rich=percapexp , nq(5)
lab var rich "Wealth Groups"
ta rich [aw=weig]



bys indid: g double sex = s1q3
ta sex

bys indid: g double agey = s1q6a
count if agey < 18
count if agey>5 & agey < 18
su agey
*Boys
bys indid: g double boy = cond(agey>5&agey<18 & sex==1, 1, 0)
count if boy==1
bys hid: egen double boys = sum(boy)                                      /*Number of boys in age to go to school in the HH*/
su boy boys

bys indid: g double boy_scho = cond(s1q35==1, 1, 0) if boy==1
count if boy_scho==1
bys hid: egen double boys_scho = sum(boy_scho)                           /*Number of boys actually at school in the HH*/
su boy_scho boys_scho

*Girls
bys indid: g double girl = cond(agey>5&agey<18 & sex==2, 1, 0)
count if girl==1
bys hid: egen double girls = sum(girl)                                      /*Number of girls in age to go to school in the HH*/
su girl girls

bys indid: g double girl_scho = cond(s1q35==1, 1, 0) if girl==1
count if girl_scho==1
bys hid: egen double girls_scho = sum(girl_scho)                           /*Number of girls actually at school in the HH*/
su girl_scho girls_scho

*All children
bys indid: g double child = cond(agey>5&agey<18, 1, 0)
count if child==1
bys hid: egen double childs = sum(child)                                      /*Number of children in age to go to school in the HH*/
su child childs
bys indid: g double child_scho = cond(s1q35==1, 1, 0) if child==1
count if child_scho==1
bys hid: egen double childs_scho = sum(child_scho)                           /*Number of children actually at school in the HH*/
su child_scho childs_scho


sort indid

keep if (agey>5 & agey<18) & child_scho==1          /*keeping only the scholarized children for tabulations*/
count

replace s1q35=2 if s1q35==.                       /*Setting the missings as not at school*/



*Creating the variable for all the children actually at school and replace those claimed as not in school but that have
*expenditures as actually in school.

bysort indid: g double class_eleves = cond(s1q35==1, 1, 0)
replace class_eleves=1 if (s1q63>0&s1q63<.)| (s1q64>0&s1q64<.)|(s1q65>0&s1q65<.)| ///
(s1q66>0&s1q66<.)|(s1q67>0&s1q67<.)|(s1q68>0&s1q68<.)|(s1q69>0&s1q69<.)|(s1q70>0&s1q70<.) ///
|(s1q71>0&s1q71<.)|(s1q72>0&s1q72<.)|(s1q73>0&s1q73<.)|(s1q74>0&s1q74<.)|(s1q76>0&s1q76<.)


replace s1q48=1 if class_eleves==1 & s1q48==.  /*Putting the scholarized that have not declared their degree as in primary school*/


bysort indid: g double class_eleves_boys = class_eleves if (sex==1)
replace class_eleves_boys =. if class_eleves_boys == 0
tab rich class_eleves  if sex==1 [aw=wei]

bysort indid: g double class_eleves_girls = class_eleves if (sex==2)
replace class_eleves_girls =. if class_eleves_girls == 0
tab rich class_eleves  if sex==2 [aw=wei]


assert class_eleves_girls==. if class_eleves_boys==1

bysort indid: g double class_eleves_urban = class_eleves if ( milieu==1)
replace class_eleves_urban =. if class_eleves_urban == 0
ta rich class_eleves_urban [aw=wei]
tab rich class_eleves  if mil==1 [aw=wei]



bysort indid: g double class_eleves_rural = class_eleves  if ( milieu==2)
replace class_eleves_rural =. if class_eleves_rural == 0
ta rich class_eleves_rural [aw=wei]
tab rich class_eleves  if mil==2 [aw=wei]


assert class_eleves_urban==. if class_eleves_rural==1


bysort indid: g double class_prescho = s1q48==0
replace class_prescho =. if class_prescho == 0
ta rich class_prescho [aw=wei]



bysort indid: g double class_prescho_boys = s1q48==0 if sex==1
replace class_prescho_boys =. if class_prescho_boys == 0
ta rich class_prescho_boys [aw=wei]

bysort indid: g double class_prescho_girls = s1q48==0 if sex==2
replace class_prescho_girls =. if class_prescho_girls == 0
ta rich class_prescho_girls [aw=wei]

bysort indid: g double class_prescho_urban = s1q48==0 if milieu==1  
replace class_prescho_urban =. if class_prescho_urban == 0  
ta rich class_prescho_urban [aw=wei]
          
bysort indid: g double class_prescho_rural = s1q48==0 if milieu==2
replace class_prescho_rural =. if class_prescho_rural == 0
ta rich class_prescho_rural [aw=wei]

bysort indid: g double class_prim = ( s1q48>0 & s1q48 <7)
replace class_prim =. if class_prim == 0
ta rich class_prim [aw=wei]

bysort indid: g double class_prim_boys  = ( s1q48>0 & s1q48 <7) if sex==1
replace class_prim_boys  =. if class_prim_boys  == 0
ta rich class_prim_boys  [aw=wei]

bysort indid: g double class_prim_girls  = ( s1q48>0 & s1q48 <7) if sex==2
replace class_prim_girls  =. if class_prim_girls  == 0
ta rich class_prim_girls  [aw=wei]

bysort indid: g double class_prim_urban = ( s1q48>0 & s1q48 <7) if milieu==1
replace class_prim_urban =. if class_prim_urban == 0
ta rich class_prim_urban [aw=wei]

bysort indid: g double class_prim_rural = ( s1q48>0 & s1q48 <7) if milieu==2
replace class_prim_rural =. if class_prim_rural == 0
ta rich class_prim_rural [aw=wei]

bysort indid: g double class_sec = ( s1q48>6 & s1q48 < 16)
replace class_sec =. if class_sec == 0
ta rich class_sec [aw=wei]

bysort indid: g double class_sec_boys  =  ( s1q48>6 & s1q48 < 16)  if sex==1
replace class_sec_boys  =. if class_sec_boys  == 0
ta rich class_sec_boys  [aw=wei]

bysort indid: g double class_sec_girls  = ( s1q48>6 & s1q48 < 16)  if sex==2
replace class_sec_girls  =. if class_sec_girls  == 0
ta rich class_sec_girls  [aw=wei]

bysort indid: g double class_sec_urban = ( s1q48>6 & s1q48 < 16) if milieu==1
replace class_sec_urban =. if class_sec_urban == 0
ta rich class_sec_urban [aw=wei]

bysort indid: g double class_sec_rural = ( s1q48>6 & s1q48 < 16) if milieu==2
replace class_sec_rural =. if class_sec_rural == 0
ta rich class_sec_rural [aw=wei]



bysort indid: g double class_sup = ( s1q48>15 & s1q48 < 24)
replace class_sup =. if class_sup == 0
ta rich class_sup [aw=wei]

bysort indid: g double class_sup_boys  = ( s1q48>15 & s1q48 < 24)  if sex==1
replace class_sup_boys  =. if class_sup_boys  == 0
ta rich class_sup_boys  [aw=wei]

bysort indid: g double class_sup_girls  = ( s1q48>15 & s1q48 < 24) if sex==2
replace class_sup_girls  =. if class_sup_girls  == 0
ta rich class_sup_girls  [aw=wei]

bysort indid: g double class_sup_urban = ( s1q48>15 & s1q48 < 24) if milieu==1
replace class_sup_urban =. if class_sup_urban == 0
ta rich class_sup_urban [aw=wei]

bysort indid: g double class_sup_rural = ( s1q48>15 & s1q48 < 24) if milieu==2
replace class_sup_rural =. if class_sup_rural == 0
ta rich class_sup_rural [aw=wei]

bysort indid: g double class_techprof = ( s1q48>23 & s1q48<40)
replace class_techprof =. if class_techprof == 0
ta rich class_techprof [aw=wei]

bysort indid: g double class_techprof_boys  = ( s1q48>23 & s1q48<40)  if sex==1
replace class_techprof_boys  =. if class_techprof_boys  == 0
ta rich class_techprof_boys  [aw=wei]

bysort indid: g double class_techprof_girls  = ( s1q48>23 & s1q48<40) if sex==2
replace class_techprof_girls  =. if class_techprof_girls  == 0
ta rich class_techprof_girls  [aw=wei]

bysort indid: g double class_techprof_urban = ( s1q48>23 & s1q48<40) if milieu==1
replace class_techprof_urban =. if class_techprof_urban == 0
ta rich class_techprof_urban [aw=wei]

bysort indid: g double class_techprof_rural = ( s1q48>23 & s1q48<40) if milieu==2
replace class_techprof_rural =. if class_techprof_rural == 0
ta rich class_techprof_rural [aw=wei]


*Number of students per household, by sex, residence and education level


bys hid: egen double eleves = sum(class_eleves)  
ta eleves [aw=wei]
table rich [aw=wei], c(mean eleves ) row col f(%9.2g)
bysort hid: egen double eleves_boys = sum(class_eleves_boys)  if class_eleves_boys==1
ta eleves_boys [aw=wei]
table rich [aw=wei], c(mean eleves_boys ) row col f(%9.2g)
bysort hid: egen double eleves_girls = sum(class_eleves_girls)    if class_eleves_girls==1
ta eleves_girls [aw=wei]
table rich [aw=wei], c(mean eleves_girls ) row col f(%9.2g)
bysort hid: egen double eleves_urban = sum(class_eleves_urban)  if class_eleves_urban==1 
ta eleves_urban [aw=wei]
table rich [aw=wei], c(mean eleves_urban ) row col f(%9.2g)
bysort hid: egen double eleves_rural = sum(class_eleves_rural)  if class_eleves_rural==1
ta eleves_rural [aw=wei]
table rich [aw=wei], c(mean eleves_rural ) row col f(%9.2g)


bysort hid: egen double prescho = sum(class_prescho)   if class_prescho==1       /*Number of preschools children in the HH */
ta prescho [aw=wei]
table rich [aw=wei], c(mean prescho ) row col f(%9.2g)
bysort hid: egen double prescho_boys = sum(class_prescho_boys)     if class_prescho_boys==1
ta prescho_boys [aw=wei]
table rich [aw=wei], c(mean prescho_boys ) row col f(%9.2g)
bysort hid: egen double prescho_girls = sum(class_prescho_girls)    if class_prescho_girls==1 
ta prescho_girls [aw=wei]
table rich [aw=wei], c(mean prescho_girls ) row col f(%9.2g)
bysort hid: egen double prescho_urban = sum(class_prescho_urban )     if class_prescho_urban==1
ta prescho_urban [aw=wei]
table rich [aw=wei], c(mean prescho_urban ) row col f(%9.2g)
bysort hid: egen double prescho_rural = sum(class_prescho_rural )   if class_prescho_rural==1  
ta prescho_rural [aw=wei]
table rich [aw=wei], c(mean prescho_rural ) row col f(%9.2g)


bysort hid: egen double prim = sum(class_prim)    if class_prim          /*Number of primary children in the HH */
ta prim [aw=wei]
table rich [aw=wei], c(mean prim ) row col f(%9.2g)
bysort hid: egen double prim_boys = sum(class_prim_boys)   if class_prim_boys==1     
ta prim_boys [aw=wei]
table rich [aw=wei], c(mean prim_boys ) row col f(%9.2g)
bysort hid: egen double prim_girls = sum(class_prim_girls)     if class_prim_girls==1   
ta prim_girls [aw=wei]
table rich [aw=wei], c(mean prim_girls ) row col f(%9.2g)
bysort hid: egen double prim_urban = sum(class_prim_urban )   if class_prim_urban==1     
ta prim_urban [aw=wei]
table rich [aw=wei], c(mean prim_urban ) row col f(%9.2g)
bysort hid: egen double prim_rural = sum(class_prim_rural )  if class_prim_rural==1      
ta prim_rural [aw=wei]


table rich [aw=wei], c(mean prim_rural ) row col f(%9.2g)
bysort hid: egen double sec = sum(class_sec)   if class_sec==1             /*Number of secondary children in the HH */
ta sec [aw=wei]
table rich [aw=wei], c(mean sec ) row col f(%9.2g)
bysort hid: egen double sec_boys = sum(class_sec_boys)    if class_sec_boys==1    
ta sec_boys [aw=wei]
table rich [aw=wei], c(mean sec_boys ) row col f(%9.2g)
bysort hid: egen double sec_girls = sum(class_sec_girls)    if class_sec_girls==1    
ta sec_girls [aw=wei]
table rich [aw=wei], c(mean sec_girls ) row col f(%9.2g)
bysort hid: egen double sec_urban = sum(class_sec_urban )   if class_sec_urban ==1     
ta sec_urban [aw=wei]
table rich [aw=wei], c(mean sec_urban ) row col f(%9.2g)
bysort hid: egen double sec_rural = sum(class_sec_rural )   if class_sec_rural    
ta sec_rural [aw=wei]
table rich [aw=wei], c(mean sec_rural ) row col f(%9.2g)


bysort hid: egen double sup = sum(class_sup)   if class_sup==1                /*Number of tertiary children in the HH */
ta sup [aw=wei]
table rich [aw=wei], c(mean sup ) row col f(%9.2g)
bysort hid: egen double sup_boys = sum(class_sup_boys)   if class_sup_boys==1
ta sup_boys [aw=wei]
table rich [aw=wei], c(mean sup_boys ) row col f(%9.2g)
bysort hid: egen double sup_girls = sum(class_sup_girls) if class_sup_girls==1 
ta sup_girls [aw=wei]
table rich [aw=wei], c(mean sup_girls ) row col f(%9.2g)
bysort hid: egen double sup_urban = sum(class_sup_urban )   if class_sup_urban==1
ta sup_urban [aw=wei]
table rich [aw=wei], c(mean sup_urban ) row col f(%9.2g)
bysort hid: egen double sup_rural = sum(class_sup_rural ) if class_sup_rural==1 
ta sup_rural [aw=wei]
table rich [aw=wei], c(mean sup_rural ) row col f(%9.2g)
bysort hid: egen double techprof = sum(class_techprof)          if class_techprof==1      /*Number of technical/professionals children in the HH */
ta techprof [aw=wei]
table rich [aw=wei], c(mean techprof ) row col f(%9.2g)
bysort hid: egen double techprof_boys = sum(class_techprof_boys)   if class_techprof_boys==1   
ta techprof_boys [aw=wei]
table rich [aw=wei], c(mean techprof_boys ) row col f(%9.2g)
bysort hid: egen double techprof_girls = sum(class_techprof_girls)   if class_techprof_girls==1   
ta techprof_girls [aw=wei]
table rich [aw=wei], c(mean techprof_girls ) row col f(%9.2g)
bysort hid: egen double techprof_urban = sum(class_techprof_urban )  if class_techprof_urban==1   
ta techprof_urban [aw=wei]
table rich [aw=wei], c(mean techprof_urban ) row col f(%9.2g)
bysort hid: egen double techprof_rural = sum(class_techprof_rural ) if class_techprof_rural==1     
ta techprof_rural [aw=wei]
table rich [aw=wei], c(mean techprof_rural ) row col f(%9.2g)
             



*Few quick checks: Verifying the totals
bys hid: egen double maxbo=max(eleves_boys)
replace maxbo = 0 if maxbo==.
bys hid: egen double maxgi =max(eleves_girls)
replace maxgi = 0 if maxgi==.
bys hid: g tot1 = maxbo + maxgi 
assert tot1 == eleves

bys hid: egen double maxu=max(eleves_ur)
replace maxu = 0 if maxu==.
bys hid: egen double maxr =max(eleves_ru)
replace maxr = 0 if maxr==.
bys hid: g tot2 = maxu + maxr 
assert tot2 == eleves


bys hid: egen double maxpre =max(prescho)
replace maxpre = 0 if maxpre ==.
bys hid: egen double maxpri =max(prim)
replace maxpri = 0 if maxpri ==.
bys hid: egen double maxsec =max(sec)
replace maxsec = 0 if maxsec ==.
bys hid: egen double maxsu =max(sup)
replace maxsu = 0 if maxsu ==.
bys hid: egen double maxte =max(techprof)
replace maxte = 0 if maxte ==.
bys hid: g tot3 = maxpre + maxpri + maxsec + maxsu + maxte 
assert tot3 == eleves

drop tot1 tot2 tot3 maxbo maxgi maxu maxr maxpre maxpri maxsec maxsu maxte 




*Total education expenditures per child
sort indid
egen double toteduc1 = rsum(s1q63-s1q74)
egen double toteduc2 = rsum(toteduc1 s1q76)
egen double inscription = rsum(s1q63 s1q64)
egen double scolarite = rsum(s1q65)
egen double fournitures = rsum(s1q66 s1q67) 
egen double uniformes = rsum(s1q68)
egen double transport = rsum(s1q69)
egen double autres_educ_dep = rsum(s1q70 s1q71 s1q72 s1q73 s1q74)
egen double bourses = rsum(s1q76)


*Total education expenditures per HH
bys hid: egen double inscrip = sum(inscription)
bys hid: egen double scol = sum(scolarite)
bys hid: egen double fourn= sum( fournitures)
bys hid: egen double unif= sum( uniformes)
bys hid: egen double transp= sum( transport)
bys hid: egen double autdepedu= sum( autres_educ_dep)
bys hid: egen double bours= sum( bourses)
bys hid: egen double edu1= sum( toteduc1)
bys hid: egen double edu2= sum( toteduc2)

*Total education expenditures per student
bys hid: gen double inscrip_eleves = inscrip / eleves
bys hid: gen double scol_eleves = scol / eleves
bys hid: gen double fourn_eleves = fourn / eleves
bys hid: gen double unif_eleves = unif / eleves
bys hid: gen double transp_eleves = transp / eleves
bys hid: gen double autdepedu_eleves = autdepedu / eleves
bys hid: gen double bours_eleves = bours / eleves
bys hid: gen double edu1_eleves = edu1 / eleves 
bys hid: gen double edu2_eleves = edu2 / eleves


*Total education expenditures by level, sex and area


*Inscription
bys hid: egen double inscrip_prescho = sum(inscription) if class_prescho==1
bys hid: gen double inscr_child_prescho = inscrip_prescho/prescho
replace inscr_child_prescho = 0 if prescho == 0 

bys hid: egen double inscrip_prim = sum(inscription) if class_prim ==1
bys hid: gen double inscr_child_prim = inscrip_prim /prim 
replace inscr_child_prim = 0 if prim == 0

bys hid: egen double inscrip_sec = sum(inscription) if class_sec ==1
bys hid: gen double inscr_child_sec = inscrip_sec /sec 
replace inscr_child_sec = 0 if sec == 0


bys hid: egen double inscrip_sup = sum(inscription) if class_sup ==1
bys hid: gen double inscr_child_sup = inscrip_sup /sup 
replace inscr_child_sup = 0 if sup == 0 

bys hid: egen double inscrip_techprof = sum(inscription) if class_techprof ==1
bys hid: gen double inscr_child_techprof = inscrip_techprof /techprof 
replace inscr_child_techprof = 0 if techprof == 0 

bys hid: egen double inscrip_boys = sum(inscription) if boy ==1
bys hid: gen double inscr_child_boys = inscrip_boys /boys 
replace inscr_child_boys = 0 if boys == 0 

bys hid: egen double inscrip_girls = sum(inscription) if girl ==1
bys hid: gen double inscr_child_girls = inscrip_girls /girls 
replace inscr_child_girls = 0 if girls == 0 

bys hid: egen double inscrip_urban = sum(inscription) if milieu ==1
bys hid: gen double inscr_child_urban = inscrip_urban /eleves_urban  
replace inscr_child_urban = 0 if eleves_urban == 0 

bys hid: egen double inscrip_rural = sum(inscription) if milieu ==2
bys hid: gen double inscr_child_rural = inscrip_rural /eleves_rural
replace inscr_child_rural = 0 if eleves_rural == 0 


*Scolarite
bys hid: egen double scol_prescho = sum(scolarite) if class_prescho==1
bys hid: gen double scol_child_prescho = scol_prescho/prescho
replace scol_child_prescho = 0 if prescho == 0 

bys hid: egen double scol_prim = sum(scolarite) if class_prim ==1
bys hid: gen double scol_child_prim = scol_prim /prim 
replace scol_child_prim = 0 if prim == 0

bys hid: egen double scol_sec = sum(scolarite) if class_sec ==1
bys hid: gen double scol_child_sec = scol_sec /sec 
replace scol_child_sec = 0 if sec == 0


bys hid: egen double scol_sup = sum(scolarite) if class_sup ==1
bys hid: gen double scol_child_sup = scol_sup /sup 
replace scol_child_sup = 0 if sup == 0 

bys hid: egen double scol_techprof = sum(scolarite) if class_techprof ==1
bys hid: gen double scol_child_techprof = scol_techprof /techprof 
replace scol_child_techprof = 0 if techprof == 0 

bys hid: egen double scol_boys = sum(scolarite) if boy ==1
bys hid: gen double scol_child_boys = scol_boys /boys 
replace scol_child_boys = 0 if boys == 0 

bys hid: egen double scol_girls = sum(scolarite) if girl ==1
bys hid: gen double scol_child_girls = scol_girls /girls 
replace scol_child_girls = 0 if girls == 0 

bys hid: egen double scol_urban = sum(scolarite) if milieu ==1
bys hid: gen double scol_child_urban = scol_urban /eleves_urban  
replace scol_child_urban = 0 if eleves_urban == 0 

bys hid: egen double scol_rural = sum(scolarite) if milieu ==2
bys hid: gen double scol_child_rural = scol_girls /eleves_rural
replace scol_child_rural = 0 if eleves_rural == 0 


*Fournitures
bys hid: egen double fourn_prescho = sum(fournitures) if class_prescho==1
bys hid: gen double fourn_child_prescho = fourn_prescho/prescho
replace fourn_child_prescho = 0 if prescho == 0 

bys hid: egen double fourn_prim = sum(fournitures) if class_prim ==1
bys hid: gen double fourn_child_prim = fourn_prim /prim 
replace fourn_child_prim = 0 if prim == 0

bys hid: egen double fourn_sec = sum(fournitures) if class_sec ==1
bys hid: gen double fourn_child_sec = fourn_sec /sec 
replace fourn_child_sec = 0 if sec == 0


bys hid: egen double fourn_sup = sum(fournitures) if class_sup ==1
bys hid: gen double fourn_child_sup = fourn_sup /sup 
replace fourn_child_sup = 0 if sup == 0 

bys hid: egen double fourn_techprof = sum(fournitures) if class_techprof ==1
bys hid: gen double fourn_child_techprof = fourn_techprof /techprof 
replace fourn_child_techprof = 0 if techprof == 0 

bys hid: egen double fourn_boys = sum(fournitures) if boy ==1
bys hid: gen double fourn_child_boys = fourn_boys /boys 
replace fourn_child_boys = 0 if boys == 0 

bys hid: egen double fourn_girls = sum(fournitures) if girl ==1
bys hid: gen double fourn_child_girls = fourn_girls /girls 
replace fourn_child_girls = 0 if girls == 0 

bys hid: egen double fourn_urban = sum(fournitures) if milieu ==1
bys hid: gen double fourn_child_urban = fourn_urban /eleves_urban  
replace fourn_child_urban = 0 if eleves_urban == 0 

bys hid: egen double fourn_rural = sum(fournitures) if milieu ==2
bys hid: gen double fourn_child_rural = fourn_girls /eleves_rural
replace fourn_child_rural = 0 if eleves_rural == 0 



*Uniformes
bys hid: egen double unif_prescho = sum(uniformes) if class_prescho==1
bys hid: gen double unif_child_prescho = unif_prescho/prescho
replace unif_child_prescho = 0 if prescho == 0 

bys hid: egen double unif_prim = sum(uniformes) if class_prim ==1
bys hid: gen double unif_child_prim = unif_prim /prim 
replace unif_child_prim = 0 if prim == 0

bys hid: egen double unif_sec = sum(uniformes) if class_sec ==1
bys hid: gen double unif_child_sec = unif_sec /sec 
replace unif_child_sec = 0 if sec == 0


bys hid: egen double unif_sup = sum(uniformes) if class_sup ==1
bys hid: gen double unif_child_sup = unif_sup /sup 
replace unif_child_sup = 0 if sup == 0 

bys hid: egen double unif_techprof = sum(uniformes) if class_techprof ==1
bys hid: gen double unif_child_techprof = unif_techprof /techprof 
replace unif_child_techprof = 0 if techprof == 0 

bys hid: egen double unif_boys = sum(uniformes) if boy ==1
bys hid: gen double unif_child_boys = unif_boys /boys 
replace unif_child_boys = 0 if boys == 0 

bys hid: egen double unif_girls = sum(uniformes) if girl ==1
bys hid: gen double unif_child_girls = unif_girls /girls 
replace unif_child_girls = 0 if girls == 0 

bys hid: egen double unif_urban = sum(uniformes) if milieu ==1
bys hid: gen double unif_child_urban = unif_urban /eleves_urban  
replace unif_child_urban = 0 if eleves_urban == 0 

bys hid: egen double unif_rural = sum(uniformes) if milieu ==2
bys hid: gen double unif_child_rural = unif_girls /eleves_rural
replace unif_child_rural = 0 if eleves_rural == 0 


*Transport
bys hid: egen double transp_prescho = sum(transport) if class_prescho==1
bys hid: gen double transp_child_prescho = transp_prescho/prescho
replace transp_child_prescho = 0 if prescho == 0 

bys hid: egen double transp_prim = sum(transport) if class_prim ==1
bys hid: gen double transp_child_prim = transp_prim /prim 
replace transp_child_prim = 0 if prim == 0

bys hid: egen double transp_sec = sum(transport) if class_sec ==1
bys hid: gen double transp_child_sec = transp_sec /sec 
replace transp_child_sec = 0 if sec == 0


bys hid: egen double transp_sup = sum(transport) if class_sup ==1
bys hid: gen double transp_child_sup = transp_sup /sup 
replace transp_child_sup = 0 if sup == 0 

bys hid: egen double transp_techprof = sum(transport) if class_techprof ==1
bys hid: gen double transp_child_techprof = transp_techprof /techprof 
replace transp_child_techprof = 0 if techprof == 0 

bys hid: egen double transp_boys = sum(transport) if boy ==1
bys hid: gen double transp_child_boys = transp_boys /boys 
replace transp_child_boys = 0 if boys == 0 

bys hid: egen double transp_girls = sum(transport) if girl ==1
bys hid: gen double transp_child_girls = transp_girls /girls 
replace transp_child_girls = 0 if girls == 0 

bys hid: egen double transp_urban = sum(transport) if milieu ==1
bys hid: gen double transp_child_urban = transp_urban /eleves_urban  
replace transp_child_urban = 0 if eleves_urban == 0 

bys hid: egen double transp_rural = sum(transport) if milieu ==2
bys hid: gen double transp_child_rural = transp_girls /eleves_rural
replace transp_child_rural = 0 if eleves_rural == 0 


*Autres Depenses d'Education
bys hid: egen double autdep_prescho = sum(autres_educ_dep) if class_prescho==1
bys hid: gen double autdep_child_prescho = autdep_prescho/prescho
replace autdep_child_prescho = 0 if prescho == 0 

bys hid: egen double autdep_prim = sum(autres_educ_dep) if class_prim ==1
bys hid: gen double autdep_child_prim = autdep_prim /prim 
replace autdep_child_prim = 0 if prim == 0

bys hid: egen double autdep_sec = sum(autres_educ_dep) if class_sec ==1
bys hid: gen double autdep_child_sec = autdep_sec /sec 
replace autdep_child_sec = 0 if sec == 0


bys hid: egen double autdep_sup = sum(autres_educ_dep) if class_sup ==1
bys hid: gen double autdep_child_sup = autdep_sup /sup 
replace autdep_child_sup = 0 if sup == 0 

bys hid: egen double autdep_techprof = sum(autres_educ_dep) if class_techprof ==1
bys hid: gen double autdep_child_techprof = autdep_techprof /techprof 
replace autdep_child_techprof = 0 if techprof == 0 

bys hid: egen double autdep_boys = sum(autres_educ_dep) if boy ==1
bys hid: gen double autdep_child_boys = autdep_boys /boys 
replace autdep_child_boys = 0 if boys == 0 

bys hid: egen double autdep_girls = sum(autres_educ_dep) if girl ==1
bys hid: gen double autdep_child_girls = autdep_girls /girls 
replace autdep_child_girls = 0 if girls == 0 

bys hid: egen double autdep_urban = sum(autres_educ_dep) if milieu ==1
bys hid: gen double autdep_child_urban = autdep_urban /eleves_urban  
replace autdep_child_urban = 0 if eleves_urban == 0 

bys hid: egen double autdep_rural = sum(autres_educ_dep) if milieu ==2
bys hid: gen double autdep_child_rural = autdep_girls /eleves_rural
replace autdep_child_rural = 0 if eleves_rural == 0 


*Bourses
bys hid: egen double bour_prescho = sum(bourses) if class_prescho==1
bys hid: gen double bour_child_prescho = bour_prescho/prescho
replace bour_child_prescho = 0 if prescho == 0 

bys hid: egen double bour_prim = sum(bourses) if class_prim ==1
bys hid: gen double bour_child_prim = bour_prim /prim 
replace bour_child_prim = 0 if prim == 0

bys hid: egen double bour_sec = sum(bourses) if class_sec ==1
bys hid: gen double bour_child_sec = bour_sec /sec 
replace bour_child_sec = 0 if sec == 0

bys hid: egen double bour_sup = sum(bourses) if class_sup ==1
bys hid: gen double bour_child_sup = bour_sup /sup 
replace bour_child_sup = 0 if sup == 0 

bys hid: egen double bour_techprof = sum(bourses) if class_techprof ==1
bys hid: gen double bour_child_techprof = bour_techprof /techprof 
replace bour_child_techprof = 0 if techprof == 0 

bys hid: egen double bour_boys = sum(bourses) if boy ==1
bys hid: gen double bour_child_boys = bour_boys /boys 
replace bour_child_boys = 0 if boys == 0 

bys hid: egen double bour_girls = sum(bourses) if girl ==1
bys hid: gen double bour_child_girls = bour_girls /girls 
replace bour_child_girls = 0 if girls == 0 

bys hid: egen double bour_urban = sum(bourses) if milieu ==1
bys hid: gen double bour_child_urban = bour_urban /eleves_urban  
replace bour_child_urban = 0 if eleves_urban == 0 

bys hid: egen double bour_rural = sum(bourses) if milieu ==2
bys hid: gen double bour_child_rural = bour_girls /eleves_rural
replace bour_child_rural = 0 if eleves_rural == 0 



*Total 1 (hors bourses)
bys hid: egen double tot1_prescho = sum(toteduc1) if class_prescho==1
bys hid: gen double tot1_child_prescho = tot1_prescho/prescho
replace tot1_child_prescho = 0 if prescho == 0 

bys hid: egen double tot1_prim = sum(toteduc1) if class_prim ==1
bys hid: gen double tot1_child_prim = tot1_prim /prim 
replace tot1_child_prim = 0 if prim == 0

bys hid: egen double tot1_sec = sum(toteduc1) if class_sec ==1
bys hid: gen double tot1_child_sec = tot1_sec /sec 
replace tot1_child_sec = 0 if sec == 0


bys hid: egen double tot1_sup = sum(toteduc1) if class_sup ==1
bys hid: gen double tot1_child_sup = tot1_sup /sup 
replace tot1_child_sup = 0 if sup == 0 

bys hid: egen double tot1_techprof = sum(toteduc1) if class_techprof ==1
bys hid: gen double tot1_child_techprof = tot1_techprof /techprof 
replace tot1_child_techprof = 0 if techprof == 0 

bys hid: egen double tot1_boys = sum(toteduc1) if boy ==1
bys hid: gen double tot1_child_boys = tot1_boys /boys 
replace tot1_child_boys = 0 if boys == 0 

bys hid: egen double tot1_girls = sum(toteduc1) if girl ==1
bys hid: gen double tot1_child_girls = tot1_girls /girls 
replace tot1_child_girls = 0 if girls == 0 

bys hid: egen double tot1_urban = sum(toteduc1) if milieu ==1
bys hid: gen double tot1_child_urban = tot1_urban /eleves_urban  
replace tot1_child_urban = 0 if eleves_urban == 0 

bys hid: egen double tot1_rural = sum(toteduc1) if milieu ==2
bys hid: gen double tot1_child_rural = tot1_girls /eleves_rural
replace tot1_child_rural = 0 if eleves_rural == 0 


*Total 2 (avec bourses)
bys hid: egen double tot2_prescho = sum(toteduc2) if class_prescho==1
bys hid: gen double tot2_child_prescho = tot2_prescho/prescho
replace tot2_child_prescho = 0 if prescho == 0 

bys hid: egen double tot2_prim = sum(toteduc2) if class_prim ==1
bys hid: gen double tot2_child_prim = tot2_prim /prim 
replace tot2_child_prim = 0 if prim == 0

bys hid: egen double tot2_sec = sum(toteduc2) if class_sec ==1
bys hid: gen double tot2_child_sec = tot2_sec /sec 
replace tot2_child_sec = 0 if sec == 0


bys hid: egen double tot2_sup = sum(toteduc2) if class_sup ==1
bys hid: gen double tot2_child_sup = tot2_sup /sup 
replace tot2_child_sup = 0 if sup == 0 

bys hid: egen double tot2_techprof = sum(toteduc2) if class_techprof ==1
bys hid: gen double tot2_child_techprof = tot2_techprof /techprof 
replace tot2_child_techprof = 0 if techprof == 0 

bys hid: egen double tot2_boys = sum(toteduc2) if boy ==1
bys hid: gen double tot2_child_boys = tot2_boys /boys 
replace tot2_child_boys = 0 if boys == 0 

bys hid: egen double tot2_girls = sum(toteduc2) if girl ==1
bys hid: gen double tot2_child_girls = tot2_girls /girls 
replace tot2_child_girls = 0 if girls == 0 

bys hid: egen double tot2_urban = sum(toteduc2) if milieu ==1
bys hid: gen double tot2_child_urban = tot2_urban /eleves_urban  
replace tot2_child_urban = 0 if eleves_urban == 0 

bys hid: egen double tot2_rural = sum(toteduc2) if milieu ==2
bys hid: gen double tot2_child_rural = tot2_girls /eleves_rural
replace tot2_child_rural = 0 if eleves_rural == 0 


collapse (mean) ins* sco*  four* uni* tran* aut* bou* tot1* toteduc1* tot2* toteduc2* edu1* edu2* ///
eleves* prescho* prim* sec* sup* techprof* rich pond weight hhsize ///
class_* (min) sexmale=sex milur=milieu (max) sexfem=sex milru=milieu [w=pond], by(hid)
sort hid
save educ_exp2, replace


#delim;
global vars "inscrip inscrip_eleves inscr_child_prescho inscr_child_prim inscr_child_sec 
inscr_child_sup inscr_child_techprof inscr_child_boys 
inscr_child_girls inscr_child_urban inscr_child_rural scol scol_eleves 
scol_child_prescho scol_child_prim scol_child_sec scol_child_sup 
scol_child_techprof scol_child_boys scol_child_girls scol_child_urban scol_child_rural 
fourn fourn_eleves fourn_child_prescho fourn_child_prim fourn_child_sec  
fourn_child_sup fourn_child_techprof fourn_child_boys fourn_child_girls fourn_child_urban 
fourn_child_rural unif unif_eleves unif_child_prescho unif_child_prim unif_child_sec 
unif_child_sup unif_child_techprof unif_child_boys unif_child_girls 
unif_child_urban unif_child_rural transp transp_eleves transp_child_prescho transp_child_prim 
transp_child_sec transp_child_sup transp_child_techprof transp_child_boys 
transp_child_girls transp_child_urban transp_child_rural autdepedu autdepedu_eleves 
autdep_child_prescho autdep_child_prim autdep_child_sec autdep_child_sup 
autdep_child_techprof autdep_child_boys autdep_child_girls autdep_child_urban autdep_child_rural 
bours bours_eleves bour_child_prescho bour_child_prim bour_child_sec bour_child_sup 
bour_child_techprof bour_child_boys bour_child_girls bour_child_urban bour_child_rural tot1_child_prescho 
tot1_child_prim tot1_child_sec tot1_child_sup tot1_child_techprof tot1_child_boys 
tot1_child_girls tot1_child_urban tot1_child_rural tot2_child_prescho tot2_child_prim tot2_child_sec 
tot2_child_sup tot2_child_techprof tot2_child_boys tot2_child_girls tot2_child_urban 
tot2_child_rural
edu1 edu1_eleves edu2 edu2_eleves
inscrip_prescho inscrip_prim inscrip_sec inscrip_sup inscrip_techprof inscrip_boys 
inscrip_girls inscrip_urban inscrip_rural scol_prescho scol_prim scol_sec scol_sup 
scol_techprof scol_boys scol_girls scol_urban scol_rural fourn_prescho fourn_prim fourn_sec 
fourn_sup fourn_techprof fourn_boys fourn_girls fourn_urban fourn_rural unif_prescho unif_prim 
unif_sec unif_sup unif_techprof unif_boys unif_girls unif_urban unif_rural transp_eleves 
transp_prim transp_sec transp_sup transp_techprof transp_boys transp_girls transp_urban 
transp_rural autdep_prescho autdep_prim autdep_sec autdep_sup autdep_techprof autdep_boys 
autdep_girls autdep_urban autdep_rural bour_prescho bour_prim bour_sec bour_sup bour_techprof 
bour_boys bour_girls bour_urban bour_rural tot1_prescho tot1_prim tot1_sec tot1_sup tot1_techprof 
tot1_boys tot1_girls tot1_urban tot1_rural tot2_prescho tot2_prim tot2_sec tot2_sup tot2_techprof 
tot2_boys tot2_girls tot2_urban tot2_rural
";
#delim cr


cap log close
log using "Eductables2.log", replace

foreach i of global vars {
  di "Table of wealth groups by mean of `i'"
  table rich [aw=pond], col row c(mean `i') f(%9.2g)
}


cap log close
set more on
set rmsg off
exit
