clear _all
set mem 800m
set matsize 300
set more 1
set seed 123456789
set rmsg on
*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.

cd "C:\Documents and Settings\Bachir\Desktop\Bachir\World Bank\Wodon\CIV\Cote d'Ivoire Consumption\STATA"

use sect01, clear
count
sort hid
save, replace

use hhexp, clear
count
keep hid school internet health trcomm trschool hhexp
sort hid
merge hid using sect01
ta _mer
assert _mer==3
keep if _merg==3
drop _merg
compress
count
sort hid
save education, replace



use pauvre, clear
count
keep hid pond region milieu _region_ _milieu_ povline pauv pchhexp strate deflat hhsize 

sort hid
merge hid using education
ta _mer
assert _mer==3
keep if _merg==3
drop _merg
compress
count
sort hid
save education, replace


cap log close
log using education.log, replace

keep hid indid s1q2 s1q3 s1q6a s1q35 s1q42 s1q46 s1q48 s1q52 s1q62 s1q63-s1q74 s1q76 ///
school internet health trcomm trschool hhexp ///
pond region milieu _region_ _milieu_ povline pauv pchhexp strate deflat hhsize

*Individual weights
bys hid: g double weight = pond / hhsize

*Generating quintile groups
cap drop percapexp
g percapexp= pchhexp if  (pchhexp>0 &  pchhexp<=5000000)
su percapexp
replace percapexp=r(mean) if percapexp==.
su percapexp [aw=weig]
cap drop rich
xtile rich=percapexp , nq(5)
lab var rich "Wealth Groups"
ta rich [aw=weig]



bys indid: g double sex = s1q3
ta sex

bys indid: g double agey = s1q6a
count if agey < 18
count if agey>5 & agey < 18
su agey
*Boys
bys indid: g double boy = cond(agey>5&agey<18 & sex==1, 1, 0)
count if boy==1
bys hid: egen double boys = sum(boy)                                      /*Number of boys in age to go to school in the HH*/
su boy boys

bys indid: g double boy_scho = cond(s1q35==1, 1, 0) if boy==1
count if boy_scho==1
bys hid: egen double boys_scho = sum(boy_scho)                           /*Number of boys actually at school in the HH*/
su boy_scho boys_scho

*Girls
bys indid: g double girl = cond(agey>5&agey<18 & sex==2, 1, 0)
count if girl==1
bys hid: egen double girls = sum(girl)                                      /*Number of girls in age to go to school in the HH*/
su girl girls

bys indid: g double girl_scho = cond(s1q35==1, 1, 0) if girl==1
count if girl_scho==1
bys hid: egen double girls_scho = sum(girl_scho)                           /*Number of girls actually at school in the HH*/
su girl_scho girls_scho

*All children
bys indid: g double child = cond(agey>5&agey<18, 1, 0)
count if child==1
bys hid: egen double childs = sum(child)                                      /*Number of children in age to go to school in the HH*/
su child childs
bys indid: g double child_scho = cond(s1q35==1, 1, 0) if child==1
count if child_scho==1
bys hid: egen double childs_scho = sum(child_scho)                           /*Number of children actually at school in the HH*/
su child_scho childs_scho


sort indid

keep if (agey>5 & agey<18) & child_scho==1          /*keeping only the scholarized children for tabulations*/
count

replace s1q35=2 if s1q35==.                       /*Setting the missings as not at school*/



*Creating the variable for all the children actually at school and replace those claimed as not in school but that have
*expenditures as actually in school.

bysort indid: g double class_eleves = cond(s1q35==1, 1, 0)
replace class_eleves = 1 if (s1q63>=0&s1q63<.)| (s1q64>=0&s1q64<.)|(s1q65>=0&s1q65<.)| ///
(s1q66>=0&s1q66<.)|(s1q67>=0&s1q67<.)|(s1q68>=0&s1q68<.)|(s1q69>=0&s1q69<.)|(s1q70>=0&s1q70<.) ///
|(s1q71>=0&s1q71<.)|(s1q72>=0&s1q72<.)|(s1q73>=0&s1q73<.)|(s1q74>=0&s1q74<.)|(s1q76>=0&s1q76<.)


replace s1q48=1 if class_eleves==1 & s1q48==.  /*Putting the scholarized that have not declared their degree as in primary school*/


bysort indid: g double class_eleves_boys = class_eleves if (sex==1)
replace class_eleves_boys =. if class_eleves_boys == 0
tab rich class_eleves  if sex==1 [aw=wei]

bysort indid: g double class_eleves_girls = class_eleves if (sex==2)
replace class_eleves_girls =. if class_eleves_girls == 0
tab rich class_eleves  if sex==2 [aw=wei]


assert class_eleves_girls==. if class_eleves_boys==1

bysort indid: g double class_eleves_urban = class_eleves if ( milieu==1)
replace class_eleves_urban =. if class_eleves_urban == 0
ta rich class_eleves_urban [aw=wei]
tab rich class_eleves  if mil==1 [aw=wei]



bysort indid: g double class_eleves_rural = class_eleves  if ( milieu==2)
replace class_eleves_rural =. if class_eleves_rural == 0
ta rich class_eleves_rural [aw=wei]
tab rich class_eleves  if mil==2 [aw=wei]


assert class_eleves_urban==. if class_eleves_rural==1


bysort indid: g double class_prescho = s1q48==0
replace class_prescho =. if class_prescho == 0
ta rich class_prescho [aw=wei]



bysort indid: g double class_prescho_boys = s1q48==0 if sex==1
replace class_prescho_boys =. if class_prescho_boys == 0
ta rich class_prescho_boys [aw=wei]

bysort indid: g double class_prescho_girls = s1q48==0 if sex==2
replace class_prescho_girls =. if class_prescho_girls == 0
ta rich class_prescho_girls [aw=wei]

bysort indid: g double class_prescho_urban = s1q48==0 if milieu==1  
replace class_prescho_urban =. if class_prescho_urban == 0  
ta rich class_prescho_urban [aw=wei]
          
bysort indid: g double class_prescho_rural = s1q48==0 if milieu==2
replace class_prescho_rural =. if class_prescho_rural == 0
ta rich class_prescho_rural [aw=wei]

bysort indid: g double class_prim = ( s1q48>0 & s1q48 <7)
replace class_prim =. if class_prim == 0
ta rich class_prim [aw=wei]

bysort indid: g double class_prim_boys  = ( s1q48>0 & s1q48 <7) if sex==1
replace class_prim_boys  =. if class_prim_boys  == 0
ta rich class_prim_boys  [aw=wei]

bysort indid: g double class_prim_girls  = ( s1q48>0 & s1q48 <7) if sex==2
replace class_prim_girls  =. if class_prim_girls  == 0
ta rich class_prim_girls  [aw=wei]

bysort indid: g double class_prim_urban = ( s1q48>0 & s1q48 <7) if milieu==1
replace class_prim_urban =. if class_prim_urban == 0
ta rich class_prim_urban [aw=wei]

bysort indid: g double class_prim_rural = ( s1q48>0 & s1q48 <7) if milieu==2
replace class_prim_rural =. if class_prim_rural == 0
ta rich class_prim_rural [aw=wei]

bysort indid: g double class_sec = ( s1q48>6 & s1q48 < 16)
replace class_sec =. if class_sec == 0
ta rich class_sec [aw=wei]

bysort indid: g double class_sec_boys  =  ( s1q48>6 & s1q48 < 16)  if sex==1
replace class_sec_boys  =. if class_sec_boys  == 0
ta rich class_sec_boys  [aw=wei]

bysort indid: g double class_sec_girls  = ( s1q48>6 & s1q48 < 16)  if sex==2
replace class_sec_girls  =. if class_sec_girls  == 0
ta rich class_sec_girls  [aw=wei]

bysort indid: g double class_sec_urban = ( s1q48>6 & s1q48 < 16) if milieu==1
replace class_sec_urban =. if class_sec_urban == 0
ta rich class_sec_urban [aw=wei]

bysort indid: g double class_sec_rural = ( s1q48>6 & s1q48 < 16) if milieu==2
replace class_sec_rural =. if class_sec_rural == 0
ta rich class_sec_rural [aw=wei]



bysort indid: g double class_sup = ( s1q48>15 & s1q48 < 24)
replace class_sup =. if class_sup == 0
ta rich class_sup [aw=wei]

bysort indid: g double class_sup_boys  = ( s1q48>15 & s1q48 < 24)  if sex==1
replace class_sup_boys  =. if class_sup_boys  == 0
ta rich class_sup_boys  [aw=wei]

bysort indid: g double class_sup_girls  = ( s1q48>15 & s1q48 < 24) if sex==2
replace class_sup_girls  =. if class_sup_girls  == 0
ta rich class_sup_girls  [aw=wei]

bysort indid: g double class_sup_urban = ( s1q48>15 & s1q48 < 24) if milieu==1
replace class_sup_urban =. if class_sup_urban == 0
ta rich class_sup_urban [aw=wei]

bysort indid: g double class_sup_rural = ( s1q48>15 & s1q48 < 24) if milieu==2
replace class_sup_rural =. if class_sup_rural == 0
ta rich class_sup_rural [aw=wei]

bysort indid: g double class_techprof = ( s1q48>23 & s1q48<40)
replace class_techprof =. if class_techprof == 0
ta rich class_techprof [aw=wei]

bysort indid: g double class_techprof_boys  = ( s1q48>23 & s1q48<40)  if sex==1
replace class_techprof_boys  =. if class_techprof_boys  == 0
ta rich class_techprof_boys  [aw=wei]

bysort indid: g double class_techprof_girls  = ( s1q48>23 & s1q48<40) if sex==2
replace class_techprof_girls  =. if class_techprof_girls  == 0
ta rich class_techprof_girls  [aw=wei]

bysort indid: g double class_techprof_urban = ( s1q48>23 & s1q48<40) if milieu==1
replace class_techprof_urban =. if class_techprof_urban == 0
ta rich class_techprof_urban [aw=wei]

bysort indid: g double class_techprof_rural = ( s1q48>23 & s1q48<40) if milieu==2
replace class_techprof_rural =. if class_techprof_rural == 0
ta rich class_techprof_rural [aw=wei]


*Number of students per household, by sex, residence and education level


bys hid: egen double eleves = sum(class_eleves)  
ta eleves [aw=wei]
table rich [aw=wei], c(mean eleves ) row col f(%9.2g)
bysort hid: egen double eleves_boys = sum(class_eleves_boys)  if class_eleves_boys==1
ta eleves_boys [aw=wei]
table rich [aw=wei], c(mean eleves_boys ) row col f(%9.2g)
bysort hid: egen double eleves_girls = sum(class_eleves_girls)    if class_eleves_girls==1
ta eleves_girls [aw=wei]
table rich [aw=wei], c(mean eleves_girls ) row col f(%9.2g)
bysort hid: egen double eleves_urban = sum(class_eleves_urban)  if class_eleves_urban==1 
ta eleves_urban [aw=wei]
table rich [aw=wei], c(mean eleves_urban ) row col f(%9.2g)
bysort hid: egen double eleves_rural = sum(class_eleves_rural)  if class_eleves_rural==1
ta eleves_rural [aw=wei]
table rich [aw=wei], c(mean eleves_rural ) row col f(%9.2g)


bysort hid: egen double prescho = sum(class_prescho)   if class_prescho==1       /*Number of preschools children in the HH */
ta prescho [aw=wei]
table rich [aw=wei], c(mean prescho ) row col f(%9.2g)
bysort hid: egen double prescho_boys = sum(class_prescho_boys)     if class_prescho_boys==1
ta prescho_boys [aw=wei]
table rich [aw=wei], c(mean prescho_boys ) row col f(%9.2g)
bysort hid: egen double prescho_girls = sum(class_prescho_girls)    if class_prescho_girls==1 
ta prescho_girls [aw=wei]
table rich [aw=wei], c(mean prescho_girls ) row col f(%9.2g)
bysort hid: egen double prescho_urban = sum(class_prescho_urban )     if class_prescho_urban==1
ta prescho_urban [aw=wei]
table rich [aw=wei], c(mean prescho_urban ) row col f(%9.2g)
bysort hid: egen double prescho_rural = sum(class_prescho_rural )   if class_prescho_rural==1  
ta prescho_rural [aw=wei]
table rich [aw=wei], c(mean prescho_rural ) row col f(%9.2g)


bysort hid: egen double prim = sum(class_prim)    if class_prim          /*Number of primary children in the HH */
ta prim [aw=wei]
table rich [aw=wei], c(mean prim ) row col f(%9.2g)
bysort hid: egen double prim_boys = sum(class_prim_boys)   if class_prim_boys==1     
ta prim_boys [aw=wei]
table rich [aw=wei], c(mean prim_boys ) row col f(%9.2g)
bysort hid: egen double prim_girls = sum(class_prim_girls)     if class_prim_girls==1   
ta prim_girls [aw=wei]
table rich [aw=wei], c(mean prim_girls ) row col f(%9.2g)
bysort hid: egen double prim_urban = sum(class_prim_urban )   if class_prim_urban==1     
ta prim_urban [aw=wei]
table rich [aw=wei], c(mean prim_urban ) row col f(%9.2g)
bysort hid: egen double prim_rural = sum(class_prim_rural )  if class_prim_rural==1      
ta prim_rural [aw=wei]


table rich [aw=wei], c(mean prim_rural ) row col f(%9.2g)
bysort hid: egen double sec = sum(class_sec)   if class_sec==1             /*Number of secondary children in the HH */
ta sec [aw=wei]
table rich [aw=wei], c(mean sec ) row col f(%9.2g)
bysort hid: egen double sec_boys = sum(class_sec_boys)    if class_sec_boys==1    
ta sec_boys [aw=wei]
table rich [aw=wei], c(mean sec_boys ) row col f(%9.2g)
bysort hid: egen double sec_girls = sum(class_sec_girls)    if class_sec_girls==1    
ta sec_girls [aw=wei]
table rich [aw=wei], c(mean sec_girls ) row col f(%9.2g)
bysort hid: egen double sec_urban = sum(class_sec_urban )   if class_sec_urban ==1     
ta sec_urban [aw=wei]
table rich [aw=wei], c(mean sec_urban ) row col f(%9.2g)
bysort hid: egen double sec_rural = sum(class_sec_rural )   if class_sec_rural    
ta sec_rural [aw=wei]
table rich [aw=wei], c(mean sec_rural ) row col f(%9.2g)


bysort hid: egen double sup = sum(class_sup)   if class_sup==1                /*Number of tertiary children in the HH */
ta sup [aw=wei]
table rich [aw=wei], c(mean sup ) row col f(%9.2g)
bysort hid: egen double sup_boys = sum(class_sup_boys)   if class_sup_boys==1
ta sup_boys [aw=wei]
table rich [aw=wei], c(mean sup_boys ) row col f(%9.2g)
bysort hid: egen double sup_girls = sum(class_sup_girls) if class_sup_girls==1 
ta sup_girls [aw=wei]
table rich [aw=wei], c(mean sup_girls ) row col f(%9.2g)
bysort hid: egen double sup_urban = sum(class_sup_urban )   if class_sup_urban==1
ta sup_urban [aw=wei]
table rich [aw=wei], c(mean sup_urban ) row col f(%9.2g)
bysort hid: egen double sup_rural = sum(class_sup_rural ) if class_sup_rural==1 
ta sup_rural [aw=wei]
table rich [aw=wei], c(mean sup_rural ) row col f(%9.2g)
bysort hid: egen double techprof = sum(class_techprof)          if class_techprof==1      /*Number of technical/professionals children in the HH */
ta techprof [aw=wei]
table rich [aw=wei], c(mean techprof ) row col f(%9.2g)
bysort hid: egen double techprof_boys = sum(class_techprof_boys)   if class_techprof_boys==1   
ta techprof_boys [aw=wei]
table rich [aw=wei], c(mean techprof_boys ) row col f(%9.2g)
bysort hid: egen double techprof_girls = sum(class_techprof_girls)   if class_techprof_girls==1   
ta techprof_girls [aw=wei]
table rich [aw=wei], c(mean techprof_girls ) row col f(%9.2g)
bysort hid: egen double techprof_urban = sum(class_techprof_urban )  if class_techprof_urban==1   
ta techprof_urban [aw=wei]
table rich [aw=wei], c(mean techprof_urban ) row col f(%9.2g)
bysort hid: egen double techprof_rural = sum(class_techprof_rural ) if class_techprof_rural==1     
ta techprof_rural [aw=wei]
table rich [aw=wei], c(mean techprof_rural ) row col f(%9.2g)
             



*Few quick checks: Verifying the totals
bys hid: egen double maxbo=max(eleves_boys)
replace maxbo = 0 if maxbo==.
bys hid: egen double maxgi =max(eleves_girls)
replace maxgi = 0 if maxgi==.
bys hid: g tot1 = maxbo + maxgi 
assert tot1 == eleves

bys hid: egen double maxu=max(eleves_ur)
replace maxu = 0 if maxu==.
bys hid: egen double maxr =max(eleves_ru)
replace maxr = 0 if maxr==.
bys hid: g tot2 = maxu + maxr 
assert tot2 == eleves


bys hid: egen double maxpre =max(prescho)
replace maxpre = 0 if maxpre ==.
bys hid: egen double maxpri =max(prim)
replace maxpri = 0 if maxpri ==.
bys hid: egen double maxsec =max(sec)
replace maxsec = 0 if maxsec ==.
bys hid: egen double maxsu =max(sup)
replace maxsu = 0 if maxsu ==.
bys hid: egen double maxte =max(techprof)
replace maxte = 0 if maxte ==.
bys hid: g tot3 = maxpre + maxpri + maxsec + maxsu + maxte 
assert tot3 == eleves

drop tot1 tot2 tot3 maxbo maxgi maxu maxr maxpre maxpri maxsec maxsu maxte 




*Total education expenditures per child
sort indid
egen double toteduc1 = rsum(s1q63-s1q74)
egen double toteduc2 = rsum(toteduc1 s1q76)
egen double inscription = rsum(s1q63 s1q64)
egen double scolarite = rsum(s1q65)
egen double fournitures = rsum(s1q66 s1q67) 
egen double uniformes = rsum(s1q68)
egen double transport = rsum(s1q69)
egen double autres_educ_dep = rsum(s1q70 s1q71 s1q72 s1q73 s1q74)
egen double bourses = rsum(s1q76)


#delim;

keep  milieu region pond pauv hid school trschool hhexp percapexp weight rich 
sex boy boys boy_scho boys_scho girl girls girl_scho girls_scho child childs 
child_scho childs_scho class_eleves class_prescho class_prim class_sec class_sup 
class_techprof eleves eleves_boys eleves_girls toteduc1 toteduc2 inscription 
scolarite fournitures uniformes transport autres_educ_dep bourses
prescho prim sec sup techprof ;


collapse (mean) ins* sco*  four* uni* tran* aut* bou* toteduc1* toteduc2*  ///
eleves* prescho prim sec sup techprof rich pond weight hhsize region ///
class_* (min) sexmale=sex milur=milieu (max) sexfem=sex milru=milieu [w=pond], by(hid);
sort hid;
save educ_exp2, replace;
#delim cr
