clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of consumption and poverty****
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"

***************
***EMPLOYMENT***
***************

cap log close
log using emploi.log, replace

use sect02, clear
* Generate Employment Variables:

*1) SEARCH (for the past 7 days)
* =====================================================================================================
* This question only reflects people searching today, but who have not worked for the past 12 months, 
* but want to work !
* =====================================================================================================

* Find those who are not in the L.F.


gen lf=cond(s2q9~=.,0,1) if s2q4~=.

lab var lf "Labor force"

gen search=1 if s2q11==1 & (lf~=.)  /* At this point, I have a problem: the question refers to a serach of 
job during the last 4 WEEKS not the last 7 days*/
tab search

* 1 means "search during the past week!"

*2) EMPL 
gen empl=1 /*if s2q14==1|s2q14==3|s2q14==4|s2q14==16*/ /* I cannot retrieve the codes*/
replace empl=2 if emp==.&s2q14~=.
tab empl
tab s2q14


*3) HOURS OF WORK 

* ======================================================================================================
* Must be hours spent in main and secundary occupations (during a week) according to standarized file's def.
* Information to construct this variable comes from question asked to everybody "utlilisation de temps". 
* We will use the average hours that the person spent during the past 7 days in his/her main occupation
* (hours normally spent are not available).  
* Also note, that hours worked a week should be computed by multiplying the usual number of days a that 
* a person spends in main ocuppation during a week times the number of hours a person spends
* in the mian occupation a day 
* Also, I'll give a value of 99 to poeple who report having worked more than 80 hours a week
* =======================================================================================================

* Hours of work for people with just one occupation
gen hourwrk = (s2q17) if empl~=.&lf~=.  

/*I prefer to use s2q17 instead of s2q6a . The hours of work are 
labelled in hours , not in days*/
* ======================================================================================================

* ======================================================================================================
* Hours of work for people with 2+ occupations:
* The survey doesn't ask how many days individuals work in other (paid) occupation. Only ask how many hours per day.
* We will assume that the days an individual works in other occupations are the same they work in their primary 
* occupation.
* ======================================================================================================
replace hourwrk=(s2q17)+(s2cq8) if (empl~=.&s2cq1==1)&lf~=.
recode hourwrk 0=.

replace hourwrk=99 if (hourwrk>79&hourwrk~=.)
sum hourwrk

* 4) LABINC "Monthly Labor Income"

* ==========================================================================================
* Not complatible with standarized files (LABINC should be Yearly Labor Income)
* wage and then divide by the hours normally worked on a week in order to get the wage rate!
* ==========================================================================================

* WORKERS WITH ONE JOB ONLY

* Monthly monetary wage 

gen double(labinc)=0 if empl~=.&lf~=.
replace s2q26=0 if s2q26==.&empl~=.&lf~=.


replace labinc = s2q26 if labinc~=.

*replace labinc = 0 if labinc==.
*sum labinc



* Status: temporary and Permanent (only asked to workers if 0<s2q16<=13 ) /*I have some doubt in the codification since I don't know if "metayer, 
aide familial, manoeuvre agricole, apprenti, autres" can be included in independant workers. I consider the actual status
s2q16b not the status at entry s2q16a*/

gen permanent = s2q24
recode permanent 1=0 2=1 3=0 /* "Saisonier" is not permanent */
tab permanent




*5) OCCUPAT
gen occupat=9 if lf~=.

/*employed*/ replace occupat=1 if empl~=.
/*unemployed*/ replace occupat=2 if (search==1|s2q12==12|s2q12==14|s2q12==15)
* unemployed : somebody who is searching for a job or is not searching but wants to work
/*homemaker*/ replace occupat=3 if s2q16==19&(labinc==0|hourwrk<=7|hourwrk==.)


* ==========================================================================================
* I am assuming that homemakers are those who declare to be "aide familial", who don't report a salary or
* who work less than 7 hours a week ! (not compatible with standarizes files...). If "aide familial" earns salary
* and works more than 7 hous a week, is considered employed 
* ==========================================================================================

/*Retired*/ replace occupat=4 if lf==0&s2q12==5
/*Student*/ replace occupat=5 if lf==0&s2q12==6
/*Dependent */ replace occupat=6 if lf==0&s2q12==1|s2q12==2|s2q12==10
* Dependents: invalid, house wifes

tab occupat

tab labinc if occupat==1
sort occupat
by occupat: sum labinc






/*
*6) STATOCC (main occupation - only if OCCUPAT==1 - not perfectly compatible with the standarized files)
gen statocc=9 if empl~=.

* Gov. wage employee (public administration or establishment)
replace statocc=1 if s4q12==1|s4q12==2

* Formal, wage employed (includes private firms, ONGs and International Organizations)
replace statocc=2 if s4q12==3|s4q12==7|s4q12==5

* Informal Sector (includes unpaid family workers, family business, and cooperatives ) 
replace statocc=3 if s4q12==4|s4q12==10|s4q12==6

* Self Employed or independent 
replace statocc=4 if s4q12==8|s4q12==9

* =====================================================================================================
* Is there a way to distinguish employers from independent workers ?
* ======================================================================================================*/















* Generate Employment Variables:

*1) SEARCH (for the past 7 days)
* =====================================================================================================
* This question only reflects people searching today, but who have not worked for the past 12 months, 
* but want to work !
* =====================================================================================================

* Find those who are not in the L.F.

gen lf=cond(s4q09>5&s4q09~=.,0,1) if s4q02~=.

gen search=1 if s4q07==1 & (lf~=.)
tab search

gen seach_tr=1 if search==1

* 1 means "search during the past week!"

*2) EMPL 
gen empl=1 if s4q10==1|s4q10==3|s4q10==4|s4q10==16
replace empl=2 if emp==.&s4q10~=.
tab empl
tab s4q10
