
clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of consumption and poverty****
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"



cap log close
log using feel_poor.log, replace

* OTHER VARIABLES - PERCEPTION OF POVERTY

*I don't have variable on this item; however, there is a question
*about if they have difficulties to purchase food, health care, etc.
*This could be used to derive an indirect perception of poverty.

use sect11a, clear

cap log close
log using pov_feel_poor.log, replace
count
/*gen feel_poor=cond(s11aq6==1, 1, 0)
tab feel_poor */

drop if s11aq2==.
drop if s11aq6==.
keep if s11aq7 > 4 /*Keeping long term problems (> 1 year) */
collapse (sum) s11aq6 , by(hid)
ta s11aq6, m
recode s11aq6 1 2 3 4 5=0 
recode s11aq6 6 7 8 9 10=1
ta s11aq6, m
ren s11aq6 feel_poor 

/*encode grappe, gen(grap)
encode menord, gen(menor)
g hid=(grap*100)+menor
drop grap menor
cap drop indid
sort hid
by hid: g n=_n
g indid=(hid*100)+n
drop n*/

sort hid 
save feel_poor, replace

use ind6, clear
sort hid
save, replace

use feel_poor, replace

merge hid using ind6
tab _merge






*cap drop _expand
*dups hid indid, drop

keep grappe menord hid- num_srs2
count
sort hid indid


save feel_poor.dta, replace





/*Variables for head_head*/




#delimit;
/* --------------------------- */
/* Head of household variables */
/* --------------------------- */;

cap log close;
log using head_feel_poor.log, replace;

count if relat == 1;

preserve;
keep if relat == 1;
count;

sort hid;
cap drop _expand;
dups hid, drop;
sort hid;

* gender of head of household: male;
by hid: gen h_mal = cond( sex == 1, 1, 0 ) ;
lab var h_mal "Male-headed household";

* gender of head of household: female and divorced/seperated, or never married;
by hid: gen h_fem = cond( sex == 2, 1, 0 ) ;
lab var h_fem "Female-headed household";

* female-headed households that are non-polygamous;
by hid: gen h_npf = cond( sex == 2 & ( marstat ~= 3 ), 1, 0 ) if ( marstat ~= . );
lab var h_npf "Female head not polygamous";

* polygamous hh, female-headed;
by hid: gen h_pf = cond( sex == 2 & marstat == 3, 1, 0 ) if ( marstat ~= . );
lab var h_pf "female-headed polygamous household";

* assumes that separated => no income from absent spouse;
by hid: gen h_nsp = cond( marstat == 1 | marstat == 4 | marstat == 5, 1, 0 ) if ( marstat ~= . );
lab var h_nsp "Head of household is single";

* Note: agey not allowed to be missing;
by hid: gen h_agey = agey ;
lab var h_agey "Age of head";

by hid: gen h_agey_c = cond( h_agey < 99, h_agey, . ) ;
lab var h_agey_c "Age of Head, no 99 allowed";

by hid: gen int h_agey2 = ((h_agey)^2) ;
lab var h_agey2 "Square of age of household Head";

by hid: gen int h_agey2_c = ((h_agey_c)^2);
lab var h_agey2_c "Square of no-99 age of household head";

by hid: gen int feel_poor_h = cond(feel_poor==1,1,0) if feel_poor~=.;
lab var feel_poor_h "Household head feels poor";



************************************ Health status of the head*****************************************************;
sort hid;
by hid: g int h_hand=1 if handicap==1;
replace h_hand=0 if h_hand==.;

************************************ Religion of the head**********************************************************;
sort hid;
by hid: g int h_christ=1 if religion==1; /*Head Christian*/;
replace h_christ=0 if h_christ==.;
by hid: g int h_musl=1 if religion==2; /*Head Muslem*/;
replace h_musl=0 if h_musl==.;
by hid: g int h_anim=1 if religion==3; /*Head Animist*/;
replace h_anim=0 if h_anim==.;

************************************ Ethnicity of the head**********************************************************;
sort hid;
by hid: g int h_akan=1    if ethnie==1; /*Head akan*/;
replace h_akan=0 if h_akan==.;
by hid: g int h_krou=1    if ethnie==2; /*Head Krou*/;
replace h_krou=0 if h_krou==.;
by hid: g int h_manden=1  if ethnie==3; /*Head Mande North*/;
replace h_manden=0 if h_manden==.;
by hid: g int h_mandes=1  if ethnie==4; /*Head mande South*/;
replace h_mandes=0 if h_mandes==.;
by hid: g int h_volta=1   if ethnie==5; /*Head voltaic*/;
replace h_volta=0 if h_volta==.;
by hid: g int h_etr=1     if ethnie==9; /*Head Stranger*/;
replace h_etr=0 if h_etr==.;


************************************ employment variables**********************************************************;


/*by hid: gen h_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . );
lab var h_ilf "Head of household in labor force"*/;

by hid: gen h_nilf = cond( nilf==1, 1, 0 );
lab var h_nilf "Head of household not in labor force";

by hid: gen int h_hrs = hourwrk if ( empl == 1 );
lab var h_hrs "Head's hours worked per week";

* could be amended to be those who are employed ;
by hid: gen h_em = cond( empl == 1, 1, 0 ) if ( empl ~= . );   
/*Here I take empl instead of occupat to take into account, those who have a job but have not worked last 7 days*/;
lab var h_em "Head of household is employed";

* could be amended to be those who are unemployed (search==1 and/or want to work) 
/*But I choose to drop the search condition*/;
by hid: gen h_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . );
lab var h_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;



/*
by hid: gen h_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_pub "Head is public sector wage employee";
by hid: gen h_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );

lab var h_pvt "Head is private sector wage employee";
*by hid: gen h_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
*lab var h_emp "Head is an employer";
by hid: gen h_inf = cond(occupat==1 & statocc==3,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_inf "Head works in informal sector";
by hid: gen h_self = cond(occupat==1 & statocc==4,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_self "Head is self employed";
tab h_self;
by hid: gen h_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var h_ag "Head is engaged in an agricultural activity";
tab h_ag;
*/



sort hid;

by hid: g h_ag=cond(industry==1, 1, 0) if ( empl == 1 & empl~=.) ;
lab var h_ag "Head is engaged in an agricultural activity";
tab h_ag;

by hid: g h_man=cond(industry==2, 1, 0) if ( empl == 1 & empl~=.) ;
lab var h_man "Head is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab h_man;

by hid: g h_com=cond(industry==3, 1, 0) if ( empl == 1 & empl~=.) ;
lab var h_com "Head is engaged in Utilities/commerce activities";
tab h_com;

by hid: g h_adm=cond(industry==4, 1, 0) if ( empl == 1 & empl~=.) ;
lab var h_adm "Head is engaged in Banking/financial services/Professional/Public administration activities";
tab h_adm;


* first test variable: head should have one employment category or be unemployed;
*egen heademp = rsum(h_unem h_ag h_mfg h_mine h_cnst h_util h_comm h_bank h_prof h_pbad h_tspt h_othr) if (relat == 1);

*egen heademp = rsum(h_unem h_pub h_pvt h_inf h_self) if (relat == 1);

egen heademp = rsum(h_unem h_ag h_com h_adm h_man) if (relat == 1);

* must deal with known problems from definition of unemployed;

replace h_unem  = 0 if   heademp == 2;
replace heademp = 1 if   heademp == 2;
assert heademp <= 1 if ( heademp ~= . );
drop heademp;

*by hid: gen h_job = cond( h_ag == 1   | h_mfg == 1  | h_mine == 1 | h_cnst == 1 | h_util == 1 | 
                          h_comm == 1 | h_bank == 1 | h_prof == 1 | h_pbad == 1 | h_tspt == 1 | 
                          h_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );


/*by hid: gen h_job =  cond( h_pub == 1   | h_pvt == 1  | h_inf == 1 | h_self == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .)*/;

by hid: gen h_job =  cond( h_ag == 1   | h_com == 1  | h_man == 1 | h_adm == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .);
lab var h_job "Head has a job";


* check that the head has a job, is unemployed, or is not in the labor force;
tempvar hjob_test;
* must deal with known problems from definition of unemployment;
replace h_unem = 0 if h_job  == 1;
replace h_nilf = 0 if h_unem == 1;
replace h_nilf = 0 if h_job  == 1;

gen int hjob_test = h_job + h_unem + h_nilf ;
assert hjob_test <= 1 if ( hjob_test ~= . );
tab hjob_test;

by hid: gen h_nojb = cond( h_unem == 1 | h_nilf == 1, 1, 0 ) if ( occupat ~= .);
lab var h_nojb "Head unemployed or NILF";


********************************************education variables**********************************************;

by hid: gen h_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ne "Head has no education";

by hid: gen h_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ke "Head has koranic education";

by hid: gen h_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pnc "Head incomplete primary";

by hid: gen h_pc  = cond( educlev == 4, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pc "Head completed primary";

by hid: gen h_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_snc "Head incomplete secondary";

by hid: gen h_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_sc "Head completed secondary";

by hid: gen h_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ts "Head has tertiary";

by hid: gen h_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ps "Head preschool only";

by hid: gen h_ue  = cond( educlev == 9 | educlev == 99 | educlev == ., 1, 0 );
lab var h_ue "Head unstated/unknown education";

by hid: gen h_sct = cond(educlev == 5|educlev==6 | educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_sct "Head has at least imcomplete, completed secondary or tertiary education";

/*by hid: gen h_st  = cond(educlev>=5 & educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_st "Head has at least some secondary education"*/;

by hid: gen h_prim = cond(educlev==3|educlev==4|educlev==8,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_prim "Head has at least some prescholl or primary education";

by hid: gen h_noeduc=cond(educlev==1, 1, 0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_noeduc "Head has no education or has preschool";



tempvar test_h_ed1;
egen test_h_ed1 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps );
lab var test_h_ed1 "Test that head has some level of education if educlev ~= .";
assert test_h_ed1 == 1 if ( educlev < 9 & educlev ~= . );

tempvar test_h_ed3;
egen test_h_ed3 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps h_ue );
lab var test_h_ed1 "Test that head has education information or missing";
assert test_h_ed3 <= 1;

tempvar test_h_ed2;
egen test_h_ed2 = rsum( h_sct h_sct h_prim );
lab var test_h_ed2 "Test of head's educlev for lumping education";
assert test_h_ed2 <= 2 if ( test_h_ed2 ~= . );

by hid: gen h_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var h_lit "Head is literate";

by hid: gen h_occup= occupat;
*by hid: gen h_industry= industry;
by hid: gen h_statoc= statoc;

********************************************Migration variables**********************************************;

by hid: gen mig_h = cond(mig == 1, 1, 0) if mig~=.;
lab var mig_h "Head is a Migrant";

sort hid;

******************************************* Land Variables **************************************************;
bysort hid: gen byte land = cond(ownland == 1, 1, 0 ) if ( ownland ~= . );
lab var land "Head owns land";

replace landsize = 0 if ownland == 2;
rename landsize landsz ;
*recast double landsz;
lab var landsz " land (ha) owned by household";  

by hid: gen float landsz2 = (landsz^2);
lab var landsz2 "Square of land (ha) owned by household";

* if no observations, regression won't run;
qui sum landsz;
if ( `r(N)' == 0 ) {;
	replace landsz  = 0;
	replace landsz2 = 0;
	};

count;

sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

sort hid;

save head_feel_poor, replace;

/****************************************** Remmitances Variables *******************************************;

*label define yesno 1 "Yes" 2 "No", add;

label value s9bq06 s9bq06;
label value s9bq01 yesno;

rename s9bq01 get_remit;
rename s9bq06 source_remit  ;

tab get_remit;
tab get_remit poor, row col;
tab source_remit;
tab source_remit poor, row col;

gen remit_value=s9bq09+s9bq10+s9bq11;
* If one is missing, all are missings. If one is non-missing, all are non-missing!;

gen missing_rem=cond(remit_value==.,1,0);
tab missing_rem*/;









/* ---------------- */
/* Spouse variables */
/* ---------------- */;

restore;

count;

cap log close;
log using spouse_feel_poor.log, replace;
gen sp=1 if relat==2;
recode sp .=0;
egen nbsp=sum(sp), by(hid);
tab nbsp;
preserve;
keep if relat==1;
tab nbsp;
restore;
drop nbsp;

bysort hid: egen smaxage = max(agey) if relat == 2;
keep if relat==2 & agey == smaxage;

sort hid;
cap drop _expand;
dups hid, drop;
sort hid;

count;

sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;
*============
* Controlling for the possibility of 2 spouses with same age and education,
* then keep the one with the lowest indid
* ===========;

gen realed=educlev;
*recode realed 1=0 8=1 9=. 99=.;
bysort hid: egen smaxeduc = max(realed) if realed~=.;
keep if (realed == smaxeduc) | realed==.;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

bysort hid: egen sminindi = min(indid);
keep if indid == sminindi;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

count;

* note: agey cannot be missing;
by hid: gen s_agey = agey;
lab var s_agey "Age of spouse";

by hid: gen s_agey_c = cond( agey < 99, agey, . );
lab var s_agey_c "Spouse's age corrected for 99";

by hid: gen int s_agey2 = ((s_agey)^2);
lab var s_agey2 "Square of age of Spouse";

by hid: gen int s_agey2_c = ((s_agey_c)^2);
lab var s_agey2_c "Square of age of spouse corrected for 99";

************************************ Health status of the spouse*****************************************************;
sort hid;
by hid: g int s_hand=1 if handicap==1;
replace s_hand=0 if s_hand==.;

************************************ Religion of the head**********************************************************;
sort hid;
by hid: g int s_christ=1 if religion==1 /*Spouse Christian*/;
replace s_christ=0 if s_christ==.;
by hid: g int s_musl=1 if religion==2 /*Spouse Muslem*/;
replace s_musl=0 if s_musl==.;
by hid: g int s_anim=1 if religion==3 /*Spouse Animist*/;
replace s_anim=0 if s_anim==.;

************************************ Ethnicity of the head**********************************************************;
sort hid;
by hid: g int s_akan=1    if ethnie==1 /*Spouse akan*/;
replace s_akan=0 if s_akan==.;
by hid: g int s_krou=1    if ethnie==2 /*Spouse Krou*/;
replace s_krou=0 if s_krou==.;
by hid: g int s_manden=1  if ethnie==3 /*Spouse Mande North*/;
replace s_manden=0 if s_manden==.;
by hid: g int s_mandes=1  if ethnie==4 /*Spouse mande South*/;
replace s_mandes=0 if s_mandes==.;
by hid: g int s_volta=1   if ethnie==5 /*Spouse voltaic*/;
replace s_volta=0 if s_volta==.;
by hid: g int s_etr=1     if ethnie==9 /*Spouse Stranger*/;
replace s_etr=0 if s_etr==.;



***************************************** employment variables**************************************************;
/*by hid: gen s_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . );
lab var s_ilf "Head of household in labor force"*/;

by hid: gen s_nilf = cond( nilf==1, 1, 0 );
lab var s_nilf "Head of household not in labor force";

by hid: gen int s_hrs = hourwrk if ( empl == 1 );
lab var s_hrs "Head's hours worked per week";

* could be amended to be those who are employed ;
by hid: gen s_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )   ;
/*Here I take empl instead of occupat to take into account, those who have a job but have not worked last 7 days*/;
lab var s_em "Head of household is employed";

* could be amended to be those who are unemployed (search==1 and/or want to work) /*But I choose to drop the search condition*/;
by hid: gen s_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . );
lab var s_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;



/*
by hid: gen s_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_pub "Head is public sector wage employee";
by hid: gen s_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );

lab var s_pvt "Head is private sector wage employee";
*by hid: gen s_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
*lab var s_emp "Head is an employer";
by hid: gen s_inf = cond(occupat==1 & statocc==3,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_inf "Head works in informal sector";
by hid: gen s_self = cond(occupat==1 & statocc==4,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_self "Head is self employed";
tab s_self;
by hid: gen s_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var s_ag "Head is engaged in an agricultural activity";
tab s_ag;
*/



sort hid;

by hid: g s_ag=cond(industry==1, 1, 0) if ( empl == 1 & empl~=.) ;
lab var s_ag "Head is engaged in an agricultural activity";
tab s_ag;

by hid: g s_man=cond(industry==2, 1, 0) if ( empl == 1 & empl~=.) ;
lab var s_man "Head is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab s_man;

by hid: g s_com=cond(industry==3, 1, 0) if ( empl == 1 & empl~=.) ;
lab var s_com "Head is engaged in Utilities/commerce activities";
tab s_com;

by hid: g s_adm=cond(industry==4, 1, 0) if ( empl == 1 & empl~=.) ;
lab var s_adm "Head is engaged in Banking/financial services/Professional/Public administration activities";
tab s_adm;




/*by hid: gen int s_hrs = hourwrk;
lab var s_hrs "Spouse hours worked per week";

by hid: gen s_ag = cond( empl == 1, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var s_ag "Spouse is engaged in an agricultural activity"*/;

*by hid: gen s_job = cond( s_ag   == 1 | s_mfg  == 1 | s_mine == 1 | s_cnst == 1 | s_util == 1 | 
			       s_comm == 1 | s_bank == 1 | s_prof == 1 | s_pbad == 1 | s_tspt == 1 | 
			       s_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );




/*by hid: gen s_job =  cond( s_pub == 1   | s_pvt == 1  | s_inf == 1 | s_self == 1 , 1, 0 ) 
			        if ( occupat ~= . /*& industry ~= .*/ )*/;


by hid: gen s_job =  cond( s_ag == 1   | s_com == 1  | s_adm == 1 | s_man == 1 , 1, 0 ) 
			        if ( occupat ~= . /*& industry ~= .*/ );
lab var s_job "Spouse has a job";

* check that the spouse has a job, is unemployed, or is not in the labor force;
tempvar sjob_test;
replace s_unem = 0 if s_job == 1;
replace s_nilf = 0 if s_unem == 1;
replace s_nilf = 0 if s_job == 1;
gen int sjob_test = s_job + s_unem + s_nilf;
assert sjob_test <= 1 if ( sjob_test ~= . );
tab sjob_test;

by hid: gen s_nojb = cond( s_nilf == 1 | s_unem == 1, 1, 0 ) if ( occupat ~= .);
lab var s_nojb "Spouse has no job";

* education variables;

by hid: gen s_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_ne "Spouse has no education";

by hid: gen s_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ke "Spouse has koranic education";

by hid: gen s_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pnc "Spouse incomplete primary";

by hid: gen s_pc  = cond( educlev == 4, 1, 0 ) /* if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pc "Spouse completed primary";

by hid: gen s_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_snc "Spouse incomplete secondary";

by hid: gen s_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_sc "Spouse completed secondary";

by hid: gen s_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ts "Spouse tertiary";

by hid: gen s_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ps "Spouse preschool only";

by hid: gen s_ue  = cond( educlev == 9 | educlev == 99 | educlev==., 1, 0 );
lab var s_ue "Spouse unstated education";

by hid: gen s_sct = cond(educlev==5|educlev==6|educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_sct "Spouse has imcomplete , completed secondary or tertiary education";

by hid: gen s_st  = cond(educlev>=5&educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_st "Spouse has at least some secondary education";

by hid: gen s_prim = cond(educlev==3|educlev==4|educlev==8,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_prim "Spouse has some level of primary schooling";

by hid: gen s_noeduc = cond(educlev==1,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_noeduc "Spouse has no education or has preschool";


tempvar test_s_ed1;
egen test_s_ed1 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps );
lab var test_s_ed1 "Test that spouse has some level of education if educlev ~= .";
assert test_s_ed1 <= 1 if ( educlev < 9 & educlev ~= . );

tempvar test_s_ed3;
egen test_s_ed3 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps s_ue );
lab var test_s_ed1 "Test that spouse has education information or missing";
assert test_s_ed3 <= 1;

tempvar test_s_ed2;
egen test_s_ed2 = rsum( s_sct s_st s_prim );
lab var test_s_ed2 "Test of spouse's educlev for lumping education";
assert test_s_ed2 <= 2 if ( test_s_ed2 ~= . );

by hid: gen s_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var s_lit "Spouse is literate";

sort hid;
tab relat;
by hid: gen s_occup= occupat;
*by hid: gen s_industry= industry;
by hid: gen s_statoc= statoc;
g s_relat=relat ;
sort hid;
save spouse_feel_poor, replace;



cap log close;
log using head-spouse_feel_poor.log, replace;

use head_feel_poor, clear;
sort  hid;
merge hid using spouse_feel_poor;
tab _merge ;

/* this ensures that all obs have a head of household*/;
assert _merge ~= 2;

di "MUST SET SPOUSE OBS TO ZERO; HE/SHE HAS NO SPOUSE";

sort hid;
by hid: replace s_christ=0 if (_merge==1);
by hid: replace s_anim=0 if   (_merge==1);
by hid: replace s_musl=0 if   (_merge==1);
by hid: replace s_hand=0 if   (_merge==1);
by hid: replace s_akan=0 if   (_merge==1);
by hid: replace s_krou=0 if   (_merge==1);
by hid: replace s_manden=0 if (_merge==1);
by hid: replace s_mandes=0 if (_merge==1);
by hid: replace s_volta=0 if  (_merge==1);
by hid: replace s_etr=0 if    (_merge==1);

sort hid;
by hid: replace s_agey    = 0 if ( _merge == 1 );
by hid: replace s_agey_c  = 0 if ( _merge  == 1 );
by hid: replace s_agey2   = 0 if ( _merge  == 1 );
by hid: replace s_agey2_c = 0 if ( _merge  == 1 );
by hid: replace s_nilf    = 0 if ( _merge  == 1 );

* employment variables;
by hid: replace s_ag     = 0 if ( _merge  == 1 );
by hid: replace s_adm     = 0 if ( _merge  == 1 );
by hid: replace s_com    = 0 if ( _merge  == 1 );
by hid: replace s_man     = 0 if ( _merge  == 1 );
by hid: replace s_job     = 0 if ( _merge  == 1 );

* could be amended to be those unemployed;
by hid: replace s_unem    = 0 if ( _merge  == 1 );
*by hid: replace s_ag      = 0 if ( _merge  == 1 );

/*
by hid: replace s_merge fg     = 0 if ( _merge  == 1 );
by hid: replace s_merge ine    = 0 if ( _merge  == 1 );
by hid: replace s_cnst    = 0 if ( _merge  == 1 );
by hid: replace s_util    = 0 if ( _merge  == 1 );
by hid: replace s_comm    = 0 if ( _merge  == 1 );
by hid: replace s_bank    = 0 if ( _merge  == 1 );
by hid: replace s_prof    = 0 if ( _merge  == 1 );
by hid: replace s_pbad    = 0 if ( _merge  == 1 );
by hid: replace s_tspt    = 0 if ( _merge  == 1 );
by hid: replace s_othr    = 0 if ( _merge  == 1 );
*/;

* lumping variables;
/*
by hid: replace s_bppa    = 0 if ( _merge  == 1 );
*by hid: replace s_merge guc    = 0 if ( _merge  == 1 );
by hid: replace s_nojb    = 0 if ( _merge  == 1 );
by hid: replace s_svcs    = 0 if ( _merge  == 1 );
by hid: replace s_wemp    = 0 if ( _merge  == 1 );
by hid: replace s_ind    = 0 if ( _merge  == 1 );
*/;

* education variables;

by hid: replace s_ne      = 0 if ( _merge  == 1 );
by hid: replace s_ke      = 0 if ( _merge  == 1 );
by hid: replace s_pnc     = 0 if ( _merge  == 1 );
by hid: replace s_pc      = 0 if ( _merge  == 1 );
by hid: replace s_snc     = 0 if ( _merge  == 1 );
by hid: replace s_sc      = 0 if ( _merge  == 1 );
by hid: replace s_ts      = 0 if ( _merge  == 1 );
by hid: replace s_ps      = 0 if ( _merge  == 1 );
by hid: replace s_ue      = 0 if ( _merge  == 1 );
by hid: replace s_sct     = 0 if ( _merge  == 1 );
by hid: replace s_st      = 0 if ( _merge  == 1 );
by hid: replace s_prim    = 0 if ( _merge  == 1 );
by hid: replace s_lit     = 0 if ( _merge  == 1 );
*by hid: replace s_self     = 0 if ( _merge  == 1 );

* other
by hid: replace s_hrs      = 0 if ( _merge  == 1 );
by hid: replace s_occup    = 0 if ( _merge  == 1 );
*by hid: replace s_industry = 0 if ( _merge  == 1 );
by hid: replace s_statoc   = 0 if ( _merge  == 1 );
by hid: replace s_relat    = 0 if ( _merge  == 1 );

* a few quick checks;
assert relat   == 1 if _merge  == 1;
assert s_relat == 2 if _merge  == 3;
gen h_sgl=_merge ==1;

**test***;

*drop help;

*gen help= s_nojb +s_svcs+ s_pbad+ s_othr+s_ag+h_sgl;

*tab help;

* cleanup;

drop _merge ;

ta geocode2, m;
sort hid;

save head-spouse_feel_poor, replace;





/* Still using a rough measure of total consumption */;

/* ------------- */
/* poverty lines */
/* ------------- */;

cap log close;

log using reg00_feel_poor.log,replace;

use hhexp, clear;
drop  homecons house hinvest hutil school internet health trcomm trschool clothing dgoods remitt  hygine entmnt domest inkind;
sort hid ;
save hhexp1, replace;

use head-spouse_feel_poor, clear;
sort hid;

merge hid using hhexp1;

ta geocode2;
sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

ta _merge;
drop _merge;

save final_feel_poor, replace;

count;


use final_feel_poor, clear; 

tab geocode2, m;

#delimit cr

g rururb=milieu

g wta=pond
drop  _region_ _milieu_

gen byte rural = cond( rururb == 1, 1, 0 )
lab var rural "dummy for rural areas"

gen byte urban = 1 - rural
*gen urban = cond( rururb == 2, 1, 0)
lab var urban "dummy for urban areas"
recode literacy 2=1 3=2 
save, replace








/* ------------------------------- */
/* generate the dependent variable */
/* ------------------------------- */

gen     pl = povline 
lab var pl "Poverty line"

tab2 rururb pl, m
g double total_pc=pchhexp

sum hhexp total_pc

bysort rururb hid: gen double ln_wm_pl = ln( total_pc / pl )
lab var ln_wm_pl "ln(welfare measure)"

# delimit ;
tab nspouse;
tab h_sgl;
tab h_nsp;
cap drop geo1 ge02 geo3 geo4 geo5;
ta geocode2, m;
destring geocode2, replace;
ta geocode2;


*tab strate, gen(geo);
tab strate rururb;
recast double hhsize;
gen double(weight)=wta*hhsize;
sum weight wta hhsize;

* Note we should use h_sgl (not h_nsp) because it correspond to the same number of houses with zero spouses. ;

rename poor poor_old;
gen poor=cond(total_pc<pl,1,0) if (total_pc~=.&pl~=.) ;
compare poor poor_old;
ren landsz lander  /*It seems there is a bug in stata7 concerning this name; I replace landsz by lander*/;
#delimit cr
ta geocode1, m
ta geocode1 rururb
ta geocode1, gen(geo)
save, replace








/* --------------------------------------------------------------------------- */
/* REGRESSIONS                                                                 */
/* --------------------------------------------------------------------------- */

* clean up all variables


#delimit;

bysort urban: sum
      total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr      
	s_unem s_nilf s_ag s_com s_adm s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*;

bysort urban: sum
      total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr
	s_unem s_nilf s_ag s_com s_adm s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
 	if poor==1;

bysort urban: sum
      total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr
	s_unem s_nilf s_ag s_com s_adm s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
 if poor==0;




/*bysort urban: sum
       total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr  
	s_unem s_nilf s_ag s_com s_adm s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
	if feel_poor==1;

bysort urban: sum
      total_pc num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 num_srs num_srs2 num_adp num_adp2 agedep agedp2
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_st h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	h_unem h_nilf h_ag h_com h_adm h_man
	s_prim s_st s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr     
	s_unem s_nilf s_ag s_com s_adm s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo*
	if feel_poor==0

*/;


/* REGRESSIONS CORRECTING FOR AGE == 99 */;



* DO SOME POVERTY CALCULATIONS - For my Dirty Consumption Aggregate;
poverty total_pc [aw=weight], l(183450) all;
poverty total_pc [aw=weight] if urban==1, l(183450) all;
poverty total_pc [aw=weight] if rural==1, l(183450) all;




/* NATIONAL*/;
reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] ;
outreg using reg.xls, ctitle(national) bdec(3) br 3aster replace;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100)*/ ;




/* URBAN */;
reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] if rururb==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr      
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight] if rururb==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] ", reps(100) */;




/* RURAL */;
reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[w=weight] if rururb==2;
outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "reg ln_wm_pl 
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 /*num_srs num_srs2  */
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr   
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [w=weight] if rururb==2" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] 
_se[geo4] _se[geo5] ", reps(100) */;





**********************************************************************************************
PERCEPTION OF POVERTY vs. POVERTY -- DETERMINANTS
**********************************************************************************************;



*sum poor feel_poor;
tab poor [aw=weight];
*tab feel_poor_h [aw=weight];
sort urban;
by urban: tab poor;
*by urban: tab feel_poor_h;


*** NATIONAL ****;
dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr   
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] ;
outreg using reg.xls, ctitle(national) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr    
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100) */;



*** URBAN ****;
dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr  
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if urban==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr     
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if urban==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100) */;




***** RURAL *******; 
dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr     
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if rural==1;

outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob1;
sum prob1;
drop prob;
/*set seed 123456789;
bs  "dprobit poor
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr  
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if rural==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] 
", reps(100)*/ ; 



********FEEL POOR *********;


* NATIONAL;
dprobit feel_poor_h
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2   
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr 
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight];
outreg using reg.xls, ctitle(national)  bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit feel_poor_h
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr     
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight]" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _b[geo2] _b[geo3] _b[geo4] _b[geo5] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] _se[geo2] _se[geo3]
_se[geo4] _se[geo5] ", reps(100)*/ ;



* URBAN;
dprobit feel_poor_h
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2 
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if urban==1;
outreg using reg.xls, ctitle(urban) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit feel_poor_h
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2   
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr       
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if urban==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100) */;



* RURAL;
dprobit feel_poor_h
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_em h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr     
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17
	[aw=weight] if rural==1;
outreg using reg.xls, ctitle(rural) bdec(3) br 3aster append;
predict prob;
sum prob;
drop prob;
/*set seed 123456789;
bs  "dprobit feel_poor_h
      num_bab num_bab2 num_kid num_kid2 num_ads num_ads2  
	/*h_fem h_nsp*/ h_agey_c h_agey2_c s_agey_c s_agey2_c 
	h_prim h_sct h_lit
        h_hand
        h_anim h_musl
        h_krou h_manden h_mandes h_volta h_etr
	/*h_unem h_nilf*/ h_com h_ag h_man
	s_prim s_sct s_lit 
        s_hand
        s_anim s_musl
        s_krou s_manden s_mandes s_volta s_etr    
	/*s_em s_nilf*/ s_com s_ag s_man
	land lander landsz2 
	mig_h
	lomwater  lomelec
	geo2-geo17 [aw=weight] if rural==1" 
"_b[num_bab] _b[num_bab2] _b[num_kid] _b[num_kid2] _b[num_ads] _b[num_ads2] _b[num_srs] _b[num_srs2] _b[num_adp]
_b[num_adp2] _b[h_fem] _b[h_nsp] _b[h_agey_c] _b[h_agey2_c] _b[s_agey_c] _b[s_agey2_c] _b[h_prim] _b[h_st] _b[h_lit]
_b[s_prim] _b[s_st] _b[h_unem] _b[h_nilf] _b[h_pub] _b[h_pvt] _b[h_self] _b[h_ag] _b[s_unem] _b[s_nilf] _b[s_pub]
_b[s_pvt]  _b[s_self] _b[s_ag] _b[lander] _b[landsz2] _b[mig_h] _se[num_bab] 
_se[num_bab2] _se[num_kid] _se[num_kid2] _se[num_ads] _se[num_ads2] _se[num_srs] _se[num_srs2] _se[num_adp]
_se[num_adp2] _se[h_fem] _se[h_nsp] _se[h_agey_c] _se[h_agey2_c] _se[s_agey_c] _se[s_agey2_c] _se[h_prim] _se[h_st]
_se[h_lit] _se[s_prim] _se[s_st] _se[h_unem] _se[h_nilf] _se[h_pub] _se[h_pvt] _se[h_self] _se[h_ag] _se[s_unem]
_se[s_nilf] _se[s_pub] _se[s_pvt] _se[s_self] _se[s_ag] _se[lander] _se[landsz2] _se[mig_h] ", reps(100)*/;



#delimit cr



/*
use temp, clear
d
codebook
su*/

set more on 
log close
exit


