clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and tabulate objective and subjective poverty*******************
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"

cap log close
log using fpoor.log, replace

*First , merging the datasets so that I can have an identification for head

use sect01, clear
keep grappe menord hid indid s1q4
compress
sort grappe menord hid indid
save relat, replace

use sect11a, clear
sort grappe menord hid indid
merge grappe menord hid indid using relat
ta _m, m
drop _m
sort grappe menord hid
save relat, replace


use pauvre, clear
sort hid
by hid: replace pauv=0 if pauv==.
sort grappe menord hid
merge grappe menord hid using relat
ta _merge, m
drop _merge
save relat, replace
sort hid indid s11aq2

/*dups hid indid, drop
count*/

g weight=pond*hhsize

recode s11aq6 2=0 if s11aq6~=.
cap drop feel_poor
g feel_poor=cond(s11aq6==1, 1, 0) if s11aq6~=.
ta feel_poor, m
ta feel_poor [aw=weight], m
ta feel_poor pauv
ta feel_poor pauv [aw=weight]
drop feel_poor

g pb_alim=cond(s11aq2==1 & s11aq6==1, 1, 0)
ta pb_alim [aw=weight], m
g pb_loy=cond(s11aq2==2 & s11aq6==1, 1, 0)
ta pb_loy [aw=weight], m
g pb_sant=cond(s11aq2==3 & s11aq6==1, 1, 0)
ta pb_sant [aw=weight], m
g pb_scho=cond(s11aq2==4 & s11aq6==1, 1, 0)
ta pb_scho [aw=weight], m
g pb_eau=cond(s11aq2==5 & s11aq6==1, 1, 0)
ta pb_eau [aw=weight], m
g pb_elec=cond(s11aq2==6 & s11aq6==1, 1, 0)
ta pb_elec [aw=weight], m
g pb_transp=cond(s11aq2==7 & s11aq6==1, 1, 0)
ta pb_transp [aw=weight], m
g pb_entr=cond(s11aq2==8 & s11aq6==1, 1, 0)
ta pb_entr [aw=weight], m
g pb_hab=cond(s11aq2==9 & s11aq6==1, 1, 0)
ta pb_hab [aw=weight], m
g pb_equip=cond(s11aq2==10 & s11aq6==1, 1, 0)
ta pb_equip [aw=weight], m



/*First doing the analysis at individual level by making a PCF analysis*/



sort hid indid s11aq2

tab1 pb_alim pb_loy pb_sant pb_scho pb_eau pb_elec pb_transp pb_entr pb_hab pb_equip
su pb_alim pb_loy pb_sant pb_scho pb_eau pb_elec pb_transp pb_entr pb_hab pb_equip

global pbe "pb_alim pb_loy pb_sant pb_scho pb_eau pb_elec pb_transp pb_entr pb_hab pb_equip"

factor $pbe [aw=weight] , pcf factors(5) 
greigen
score pbe
su pbe
ret list
replace pbe=pbe-r(min)
su pbe
sort pbe
cap drop pbes1 
g pbes1=sum(pbe )
qui replace pbes1=pbes1/pbes1[_N]
su pbes1
sort pbes1
cap drop feel_poor
g feel_poor=cond(pbes1> .616, 1, 0) if pbes1~=.
ta feel_poor, m
ta feel_poor [aw=weight], m
ta feel_poor pauv, m
ta feel_poor pauv [aw=weight], m    /*Doesn't seem good, so do for the head*/


sort pbe
centile pbe, centile(20 40 60 80)
egen rank1 =rank(pbe), unique
su rank1
ret list

/*Second doing the analysis at individual level by taking only 2 or 3 pbs*/

g pbalimsant2=cond(pb_alim==1 & pb_sant==1, 1, 0) /*Two pbs*/
ta pbalimsant2, m
ta pbalimsant2 [aw=weight], m
g pbalimsant3=cond(pb_alim==1 & pb_sant==1 & pb_hab==1, 1, 0) /*Three pbs*/
ta pbalimsant3, m
ta pbalimsant3 [aw=weight], m

cap drop feel_p1
sort hid
by hid: g feel_p1=cond(pbalimsant2==1, 1, 0)
ta feel_p1 , m
ta feel_p1 [aw=weight], m
ta feel_p1 pauv
ta feel_p1 pauv [aw=weight] 

cap drop feel_p2
by hid: g feel_p2=cond(pbalimsant3==1, 1, 0)
ta feel_p2 , m
ta feel_p2 [aw=weight], m
ta feel_p2 pauv
ta feel_p2 pauv [aw=weight] 


drop pbalimsant2 pbalimsant3 feel_p1 feel_p2

g pbalimsant2=cond(pb_alim==1 | pb_sant==1, 1, 0) /*Two pbs*/
ta pbalimsant2, m
ta pbalimsant2 [aw=weight], m
g pbalimsant3=cond(pb_alim==1 | pb_sant==1 | pb_hab==1, 1, 0) /*Three pbs*/
ta pbalimsant3, m
ta pbalimsant3 [aw=weight], m

cap drop feel_p1
sort hid
by hid: g feel_p1=cond(pbalimsant2==1, 1, 0)
ta feel_p1 , m
ta feel_p1 [aw=weight], m
ta feel_p1 pauv
ta feel_p1 pauv [aw=weight] 

cap drop feel_p2
by hid: g feel_p2=cond(pbalimsant3==1, 1, 0)
ta feel_p2 , m
ta feel_p2 [aw=weight], m
ta feel_p2 pauv
ta feel_p2 pauv [aw=weight] 








/*Second, doing the analysis at the household level: I keep the heads*/

preserve

ta s1q4, m
sort hid indid s11aq2
keep if s1q4==1     /*Keeping the heads */
count
recode s11aq6 2=0 if s11aq6~=.
g pb_alimh=cond(s11aq2==1 & s11aq6==1, 1, 0)
ta pb_alimh [aw=weight], m
g pb_loyh=cond(s11aq2==2 & s11aq6==1, 1, 0)
ta pb_loyh [aw=weight], m
g pb_santh=cond(s11aq2==3 & s11aq6==1, 1, 0)
ta pb_santh [aw=weight], m
g pb_schoh=cond(s11aq2==4 & s11aq6==1, 1, 0)
ta pb_schoh [aw=weight], m
g pb_eauh=cond(s11aq2==5 & s11aq6==1, 1, 0)
ta pb_eauh [aw=weight], m
g pb_elech=cond(s11aq2==6 & s11aq6==1, 1, 0)
ta pb_elech [aw=weight], m
g pb_transph=cond(s11aq2==7 & s11aq6==1, 1, 0)
ta pb_transph [aw=weight], m
g pb_entrh=cond(s11aq2==8 & s11aq6==1, 1, 0)
ta pb_entrh [aw=weight], m
g pb_habh=cond(s11aq2==9 & s11aq6==1, 1, 0)
ta pb_habh [aw=weight], m
g pb_equiph=cond(s11aq2==10 & s11aq6==1, 1, 0)
ta pb_equiph [aw=weight], m


sort hid indid s11aq2

tab1 pb_alimh pb_loyh pb_santh pb_schoh pb_eauh pb_elech pb_transph pb_entrh pb_habh pb_equiph
su pb_alimh pb_loyh pb_santh pb_schoh pb_eauh pb_elech pb_transph pb_entrh pb_habh pb_equiph

global pbeh "pb_alimh pb_loyh pb_santh pb_schoh pb_eauh pb_elech pb_transph pb_entrh pb_habh pb_equiph"
factor $pbeh [aw=weight] , pcf factors(5) 
greigen
score pbeh
su pbeh
ret list
replace pbeh=pbeh-r(min)
su pbeh
sort pbeh
cap drop pbehs1 
g pbehs1=sum(pbeh )
qui replace pbehs1=pbehs1/pbehs1[_N]
su pbehs1
sort pbehs1
cap drop feel_poorh
g feel_poorh=cond(pbehs1> .616, 1, 0) if pbehs1~=.
ta feel_poorh [aw=weight], m
ta feel_poorh pauv , m
ta feel_poorh pauv [aw=weight], m    /*Doesn't seem good too */


sort pbeh
centile pbeh, centile(20 40 60 80)
egen rankh1 =rank(pbeh), unique
su rankh1
ret list

/*Second doing the analysis for the heads by taking only 2 or 3 pbs*/

g pbalimsanth2=cond(pb_alimh==1 & pb_santh==1, 1, 0) /*Two pbs*/
ta pbalimsanth2 , m
ta pbalimsanth2 [aw=weight] , m
g pbalimsanth3=cond(pb_alimh==1 & pb_santh==1 & pb_habh==1, 1, 0) /*Three pbs*/
ta pbalimsanth3, m
ta pbalimsanth3 [aw=weight] , m

cap drop feel_ph1
sort hid
by hid: g feel_ph1=cond(pbalimsanth2==1, 1, 0)
ta feel_ph1 [aw=weight] , m
ta feel_ph1 pauv, m
ta feel_ph1 pauv [aw=weight] , m

cap drop feel_ph2
by hid: g feel_ph2=cond(pbalimsanth3==1, 1, 0)
ta feel_ph2 [aw=weight] , m
ta feel_ph2 pauv
ta feel_ph2 pauv [aw=weight] 


drop pbalimsanth2 pbalimsanth3 feel_ph1 feel_ph2

g pbalimsanth2=cond(pb_alimh==1 | pb_santh==1, 1, 0) /*Two pbs*/
ta pbalimsanth2, m
ta pbalimsanth2 [aw=weight] , m
g pbalimsanth3=cond(pb_alimh==1 | pb_santh==1 | pb_habh==1, 1, 0) /*Three pbs*/
ta pbalimsanth3, m
ta pbalimsanth3 [aw=weight] , m

cap drop feel_ph1
sort hid
by hid: g feel_ph1=cond(pbalimsanth2==1, 1, 0)
ta feel_ph1 [aw=weight] , m
ta feel_ph1 pauv
ta feel_ph1 pauv [aw=weight] 

cap drop feel_ph2
by hid: g feel_ph2=cond(pbalimsanth3==1, 1, 0)
ta feel_ph2 [aw=weight] , m
ta feel_ph2 pauv
ta feel_ph2 pauv [aw=weight] 


restore


log close
exit

