clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of consumption and poverty****
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"

#delimit;

use head, clear;

merge grappe menord hid indid  using spouse;

tab _merge ;

* this ensures that all obs have a head of household;
assert _merge ~= 2;

di "MUST SET SPOUSE OBS TO ZERO; HE/SHE HAS NO SPOUSE";

sort hid;

by hid: replace s_agey    = 0 if ( _merge == 1 );
by hid: replace s_agey_c  = 0 if ( _merge  == 1 );
by hid: replace s_agey2   = 0 if ( _merge  == 1 );
by hid: replace s_agey2_c = 0 if ( _merge  == 1 );
by hid: replace s_nilf    = 0 if ( _merge  == 1 );

* employment variables;
by hid: replace s_pub     = 0 if ( _merge  == 1 );
by hid: replace s_pvt     = 0 if ( _merge  == 1 );
by hid: replace s_self    = 0 if ( _merge  == 1 );
by hid: replace s_inf     = 0 if ( _merge  == 1 );
by hid: replace s_job     = 0 if ( _merge  == 1 );

* could be amended to be those unemployed;
by hid: replace s_unem    = 0 if ( _merge  == 1 );
by hid: replace s_ag      = 0 if ( _merge  == 1 );

/*
by hid: replace s_merge fg     = 0 if ( _merge  == 1 );
by hid: replace s_merge ine    = 0 if ( _merge  == 1 );
by hid: replace s_cnst    = 0 if ( _merge  == 1 );
by hid: replace s_util    = 0 if ( _merge  == 1 );
by hid: replace s_comm    = 0 if ( _merge  == 1 );
by hid: replace s_bank    = 0 if ( _merge  == 1 );
by hid: replace s_prof    = 0 if ( _merge  == 1 );
by hid: replace s_pbad    = 0 if ( _merge  == 1 );
by hid: replace s_tspt    = 0 if ( _merge  == 1 );
by hid: replace s_othr    = 0 if ( _merge  == 1 );
*/;

* lumping variables;
/*
by hid: replace s_bppa    = 0 if ( _merge  == 1 );
*by hid: replace s_merge guc    = 0 if ( _merge  == 1 );
by hid: replace s_nojb    = 0 if ( _merge  == 1 );
by hid: replace s_svcs    = 0 if ( _merge  == 1 );
by hid: replace s_wemp    = 0 if ( _merge  == 1 );
by hid: replace s_ind    = 0 if ( _merge  == 1 );
*/;

* education variables;

by hid: replace s_ne      = 0 if ( _merge  == 1 );
by hid: replace s_ke      = 0 if ( _merge  == 1 );
by hid: replace s_pnc     = 0 if ( _merge  == 1 );
by hid: replace s_pc      = 0 if ( _merge  == 1 );
by hid: replace s_snc     = 0 if ( _merge  == 1 );
by hid: replace s_sc      = 0 if ( _merge  == 1 );
by hid: replace s_ts      = 0 if ( _merge  == 1 );
by hid: replace s_ps      = 0 if ( _merge  == 1 );
by hid: replace s_ue      = 0 if ( _merge  == 1 );
by hid: replace s_sct     = 0 if ( _merge  == 1 );
by hid: replace s_st      = 0 if ( _merge  == 1 );
by hid: replace s_prim    = 0 if ( _merge  == 1 );
by hid: replace s_lit     = 0 if ( _merge  == 1 );
by hid: replace s_self     = 0 if ( _merge  == 1 );

* other
by hid: replace s_hrs      = 0 if ( _merge  == 1 );
by hid: replace s_occup    = 0 if ( _merge  == 1 );
*by hid: replace s_industry = 0 if ( _merge  == 1 );
by hid: replace s_statoc   = 0 if ( _merge  == 1 );
by hid: replace s_relat    = 0 if ( _merge  == 1 );

* a few quick checks;
assert relat   == 1 if _merge  == 1;
assert s_relat == 2 if _merge  == 3;
gen h_sgl=_merge ==1;

**test***;

*drop help;

*gen help= s_nojb +s_svcs+ s_pbad+ s_othr+s_ag+h_sgl;

*tab help;

* cleanup;

drop _merge ;
sort hid;

save head-spouse, replace;
#delimit cr


