clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of consumption and poverty****
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"

cap log close
log using head.log, replace


use temp, clear

#delimit;


/* --------------------------- */
/* Head of household variables */
/* --------------------------- */;

count if relat == 1;

keep if relat == 1;
sort hid;
* gender of head of household: female and divorced/seperated, or never married;
by hid: gen h_fem = cond( sex == 2, 1, 0 ) ;
lab var h_fem "female-headed household";

* female-headed households that are non-polygamous;
by hid: gen h_npf = cond( sex == 2 & ( marstat ~= 3 ), 1, 0 ) if ( marstat ~= . );
lab var h_npf "Female head not polygamous";
	
* polygamous hh, female-headed;
by hid: gen h_pf = cond( sex == 2 & marstat == 3, 1, 0 ) if ( marstat ~= . );
lab var h_pf "female-headed polygamous household";

* assumes that separated => no income from absent spouse;
by hid: gen h_nsp = cond( marstat == 1 | marstat == 4 | marstat == 5, 1, 0 ) if ( marstat ~= . );
lab var h_nsp "Head of household is single";

* Note: agey not allowed to be missing;
by hid: gen h_agey = agey ;
lab var h_agey "Age of head";

by hid: gen h_agey_c = cond( h_agey < 99, h_agey, . ) ;
lab var h_agey_c "Age of Head, no 99 allowed";

by hid: gen int h_agey2 = ((h_agey)^2) ;
lab var h_agey2 "Square of age of household Head";

by hid: gen int h_agey2_c = ((h_agey_c)^2);
lab var h_agey2_c "Square of no-99 age of household head";

/*by hid: gen int feel_poor_h = cond(feel_poor==1,1,0) if feel_poor~=.;
lab var feel_poor_h "Household head feels poor"*/;


************************************ employment variables**********************************************************;

by hid: gen h_nilf = cond( occupat > 2, 1, 0 ) if ( occupat ~= . );
lab var h_nilf "Head of household not in labor force";

by hid: gen int h_hrs = hourwrk if ( occupat == 1 );
lab var h_hrs "Head's  hours worked per week";

* could be amended to be those who are unemployed (search==1 and/or want to work);
by hid: gen h_unem = cond( occupat == 2, 1, 0 ) if ( occupat ~= . );
lab var h_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;

by hid: gen h_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var h_pub "Head is public sector wage employee";
by hid: gen h_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var h_pvt "Head is private sector wage employee";
*by hid: gen h_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( occupat ~= . & statocc ~= . );
*lab var h_emp "Head is an employer";
by hid: gen h_inf = cond(occupat==1 & statocc==3,1,0 ) if (occupat ~= . & statocc ~= .);
lab var h_inf "Head works in informal sector";
by hid: gen h_self = cond(occupat==1 & statocc==4,1,0 ) if (occupat ~= . & statocc ~= .);
lab var h_self "Head is self employed";
tab h_self;
by hid: gen h_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var h_ag "Head is engaged in an agricultural activity";
tab h_ag;

/*INDUSTRY - need to include : See Rwanda*/;

* first test variable: head should have one employment category or be unemployed;
*egen heademp = rsum(h_unem h_ag h_mfg h_mine h_cnst h_util h_comm h_bank h_prof h_pbad h_tspt h_othr) if (relat == 1);

egen heademp = rsum(h_unem h_pub h_pvt h_inf h_self) if (relat == 1);
* must deal with known problems from definition of unemployed;

replace h_unem  = 0 if   heademp == 2;
* replace heademp = 1 if   heademp == 2;
assert heademp <= 1 if ( heademp ~= . );
drop heademp;

*by hid: gen h_job = cond( h_ag == 1   | h_mfg == 1  | h_mine == 1 | h_cnst == 1 | h_util == 1 | 
                          h_comm == 1 | h_bank == 1 | h_prof == 1 | h_pbad == 1 | h_tspt == 1 | 
                          h_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );
by hid: gen h_job =  cond( h_pub == 1   | h_pvt == 1  | h_inf == 1 | h_self == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .);
lab var h_job "Head has a job";


* check that the head has a job, is unemployed, or is not in the labor force;
tempvar hjob_test;
* must deal with known problems from definition of unemployment;
replace h_unem = 0 if h_job  == 1;
replace h_nilf = 0 if h_unem == 1;
replace h_nilf = 0 if h_job  == 1;

gen int hjob_test = h_job + h_unem + h_nilf ;
assert hjob_test <= 1 if ( hjob_test ~= . );
tab hjob_test;

by hid: gen h_nojb = cond( h_unem == 1 | h_nilf == 1, 1, 0 ) if ( occupat ~= .);
lab var h_nojb "Head unemployed or NILF";


********************************************education variables**********************************************;

by hid: gen h_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ne "Head has no education";

by hid: gen h_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ke "Head has koranic education";

by hid: gen h_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pnc "Head incomplete primary";

by hid: gen h_pc  = cond( educlev == 4, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pc "Head completed primary";

by hid: gen h_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_snc "Head incomplete secondary";

by hid: gen h_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_sc "Head completed secondary";

by hid: gen h_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ts "Head has tertiary";

by hid: gen h_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ps "Head preschool only";

by hid: gen h_ue  = cond( educlev == 9 | educlev == 99 | educlev == ., 1, 0 );
lab var h_ue "Head unstated/unknown education";

by hid: gen h_sct = cond(educlev==6 | educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_sct "Head has completed secondary or tertiary education";

by hid: gen h_st  = cond(educlev>=5 & educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_st "Head has at least some secondary education";

by hid: gen h_prim = cond(educlev==3|educlev==4,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_prim "Head has at least some primary education";

tempvar test_h_ed1;
egen test_h_ed1 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps );
lab var test_h_ed1 "Test that head has some level of education if educlev ~= .";
assert test_h_ed1 == 1 if ( educlev < 9 & educlev ~= . );

tempvar test_h_ed3;
egen test_h_ed3 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps h_ue );
lab var test_h_ed1 "Test that head has education information or missing";
assert test_h_ed3 <= 1;

tempvar test_h_ed2;
egen test_h_ed2 = rsum( h_sct h_st h_prim );
lab var test_h_ed2 "Test of head's educlev for lumping education";
assert test_h_ed2 <= 2 if ( test_h_ed2 ~= . );

by hid: gen h_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var h_lit "Head is literate";

by hid: gen h_occup= occupat;
*by hid: gen h_industry= industry;
by hid: gen h_statoc= statoc;

********************************************Migration variables**********************************************;

by hid: gen mig_h = cond(mig == 1, 1, 0) if mig~=.;
lab var mig_h "Head is a Migrant";

sort hid;

/******************************************* Land Variables **************************************************;
bysort hid: gen byte land = cond(ownland == 1, 1, 0 ) if ( ownland ~= . );
lab var land "Head owns land";

replace landsize = 0 if ownland == 2;
rename landsize landsz;
recast float landsz;
lab var landsz " land (ha) owned by household";

by hid: gen float landsz2 = (landsz^2);
lab var landsz2 "Square of land (ha) owned by household";

* if no observations, regression won't run;
qui sum landsz;
if ( `r(N)' == 0 ) {;
	replace landsz  = 0;
	replace landsz2 = 0;
	};

replace landirr=0 if landirr==.;
sort hid;

****************************************** Remmitances Variables *******************************************;

*label define yesno 1 "Yes" 2 "No", add;

label value s9bq06 s9bq06;
label value s9bq01 yesno;

rename s9bq01 get_remit;
rename s9bq06 source_remit  ;

tab get_remit;
tab get_remit poor, row col;
tab source_remit;
tab source_remit poor, row col;

gen remit_value=s9bq09+s9bq10+s9bq11;
* If one is missing, all are missings. If one is non-missing, all are non-missing!;

gen missing_rem=cond(remit_value==.,1,0);
tab missing_rem;

sort grappe menord hid indid ;

save head, replace;

#delimit cr

log close
