#delimit;

/* --------------------------- */
/* Head of household variables */
/* --------------------------- */;


cap drop h_*;
cap drop s_*;


count if relat == 1;


*cap drop _expand
*dups hid indid, drop
sort hid;

* gender of head of household: male;
by hid: gen h_mal = cond( sex == 1, 1, 0 ) if relat == 1;
lab var h_mal "Male-headed household";

* gender of head of household: female and divorced/seperated, or never married;
by hid: gen h_fem = cond( sex == 2, 1, 0 )  if relat == 1;
lab var h_fem "Female-headed household";

* female-headed households that are non-polygamous;
by hid: gen h_npf = cond( sex == 2 & ( marstat ~= 3 ), 1, 0 ) if ( marstat ~= . ) &  relat == 1;
lab var h_npf "Female head not polygamous";

* polygamous hh, female-headed;
by hid: gen h_pf = cond( sex == 2 & marstat == 3, 1, 0 ) if ( marstat ~= . ) &  relat == 1;
lab var h_pf "female-headed polygamous household";

* assumes that separated => no income from absent spouse;
by hid: gen h_nsp = cond( marstat == 1 | marstat == 4 | marstat == 5, 1, 0 ) if ( marstat ~= . ) &  relat == 1;
lab var h_nsp "Head of household is single";

* Note: agey not allowed to be missing;
by hid: gen h_agey =agey if relat == 1  ;
replace h_agey=0 if h_agey==.;
lab var h_agey "Age of head";

by hid: gen h_agey_c = cond( h_agey < 99, h_agey, . )  if relat == 1;
lab var h_agey_c "Age of Head, no 99 allowed";

by hid: gen int h_agey2 = ((h_agey)^2);
lab var h_agey2 "Square of age of household Head";




by hid: gen int h_agey2_c = ((h_agey_c)^2) if relat == 1;
lab var h_agey2_c "Square of no-99 age of household head";



************************************ Health status of the head*****************************************************;
sort hid;
by hid: g int h_hand=1 if handicap==1 &  relat == 1;
replace h_hand=0 if h_hand==.;

************************************ Religion of the head**********************************************************;
sort hid;
by hid: g int h_christ=1 if religion==1 &  relat == 1; /*Head Christian*/;
replace h_christ=0 if h_christ==.;
by hid: g int h_musl=1 if religion==2  & relat == 1; /*Head Muslem*/;
replace h_musl=0 if h_musl==.;
by hid: g int h_anim=1 if religion==3 &  relat == 1; /*Head Animist*/;
replace h_anim=0 if h_anim==.;

************************************ Ethnicity of the head**********************************************************;
sort hid;
by hid: g int h_akan=1    if ethnie==1 &  relat == 1; /*Head akan*/;
replace h_akan=0 if h_akan==.;
by hid: g int h_krou=1    if ethnie==2 &  relat == 1; /*Head Krou*/;
replace h_krou=0 if h_krou==.;
by hid: g int h_manden=1  if ethnie==3 &  relat == 1; /*Head Mande North*/;
replace h_manden=0 if h_manden==.;
by hid: g int h_mandes=1  if ethnie==4 &  relat == 1; /*Head mande South*/;
replace h_mandes=0 if h_mandes==.;
by hid: g int h_mande=cond(h_manden==1|h_mandes==1, 1, 0)   /*Mande*/ ;
by hid: g int h_volta=1   if ethnie==5 &  relat == 1; /*Head voltaic*/;
replace h_volta=0 if h_volta==.;
by hid: g int h_etr=1     if ethnie==9 &  relat == 1; /*Head Stranger*/;
replace h_etr=0 if h_etr==.;


************************************ employment variables**********************************************************;

/*by hid: gen h_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . );
lab var h_ilf "Head of household in labor force"*/;

by hid: gen h_nilf = cond( nilf==1, 1, 0 ) if relat == 1;
lab var h_nilf "Head of household not in labor force";

by hid: gen int h_hrs = hourwrk if ( empl == 1 ) &  relat == 1;
lab var h_hrs "Head's hours worked per week";

* could be amended to be those who are employed ;





by hid: gen h_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )   &  relat == 1;
 /*Here I take empl instead of occupat to take into account, those who have a job but have not worked last 7 days*/;
lab var h_em "Head of household is employed";

* could be amended to be those who are unemployed (search==1 and/or want to work) /*But I choose to drop the search condition*/;
by hid: gen h_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . ) &  relat == 1;
lab var h_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;



/*
by hid: gen h_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_pub "Head is public sector wage employee";
by hid: gen h_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );

lab var h_pvt "Head is private sector wage employee";
*by hid: gen h_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
*lab var h_emp "Head is an employer";
by hid: gen h_inf = cond(occupat==1 & statocc==3,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_inf "Head works in informal sector";
by hid: gen h_self = cond(occupat==1 & statocc==4,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var h_self "Head is self employed";
tab h_self;
by hid: gen h_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var h_ag "Head is engaged in an agricultural activity";
tab h_ag;
*/




sort hid;

by hid: g h_ag=cond(industry==1| s2q16b==17|s2q16b==18|s2q16b==20, 1, 0) if ( empl == 1)  &  relat == 1;
lab var h_ag "Head is engaged in an agricultural activity";
tab h_ag, m;
recode h_ag .=0;

by hid: g h_man=cond(industry==2| s2q16b==11|s2q16b==12|s2q16b==13, 1, 0) if ( empl == 1)  &  relat == 1;
lab var h_man "Head is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab h_man, m;
recode h_man .=0;

by hid: g h_com=cond(industry==3|(s2q16b==14| s2q16b==15| s2q16b==16), 1, 0) if ( empl == 1 )  &  relat == 1;
lab var h_com "Head is engaged in Utilities/commerce activities";
tab h_com, m;
recode h_com .=0;

by hid: g h_adm=cond(industry==4 | (s2q16b>=1 & s2q16b<=10), 1, 0) if ( empl == 1 )  &  relat == 1;
lab var h_adm "Head is engaged in Banking/financial services/Professional/Public administration activities";
tab h_adm, m;
recode h_adm .=0;

by hid: g h_other=cond(industry>4| (s2q16b==19|s2q16b==21), 1, 0) if ( empl == 1 )  &  relat == 1;
lab var h_other "Head is engaged in Other activities";
tab h_other, m;
recode h_other .=0;






* first test variable: head should have one employment category or be unemployed;
*egen heademp = rsum(h_unem h_ag h_mfg h_mine h_cnst h_util h_comm h_bank h_prof h_pbad h_tspt h_othr) if (relat == 1);

*egen heademp = rsum(h_unem h_pub h_pvt h_inf h_self) if (relat == 1);

cap drop heademp;
egen heademp = rsum(h_unem h_ag h_com h_adm h_man) if (relat == 1);


ta heademp, m;

/* must deal with known problems from definition of unemployed;

replace h_unem  = 0 if   heademp == 2;
replace heademp = 1 if   heademp == 2;
*assert heademp <= 1 if ( heademp ~= . );
drop heademp;

*by hid: gen h_job = cond( h_ag == 1   | h_mfg == 1  | h_mine == 1 | h_cnst == 1 | h_util == 1 | 
                          h_comm == 1 | h_bank == 1 | h_prof == 1 | h_pbad == 1 | h_tspt == 1 | 
                          h_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );


/*by hid: gen h_job =  cond( h_pub == 1   | h_pvt == 1  | h_inf == 1 | h_self == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .)*/;

by hid: gen h_job =  cond( h_ag == 1   | h_com == 1  | h_man == 1 | h_adm == 1 , 1, 0 ) 
			        if ( occupat ~= . & statocc ~= .);
lab var h_job "Head has a job";


* check that the head has a job, is unemployed, or is not in the labor force;
tempvar hjob_test;
* must deal with known problems from definition of unemployment;
replace h_unem = 0 if h_job  == 1;
replace h_nilf = 0 if h_unem == 1;
replace h_nilf = 0 if h_job  == 1;

gen int hjob_test = h_job + h_unem + h_nilf ;
*assert hjob_test <= 1 if ( hjob_test ~= . );
tab hjob_test;

by hid: gen h_nojb = cond( h_unem == 1 | h_nilf == 1, 1, 0 ) if ( occupat ~= .);
lab var h_nojb "Head unemployed or NILF";


*/



********************************************education variables**********************************************;

by hid: gen h_ne  = cond( relat == 1 & educlev == 1, 1, 0 )  ;/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ne "Head has no education";

by hid: gen h_ke  = cond( relat == 1 &  educlev == 2, 1, 0 );/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ke "Head has koranic education";

by hid: gen h_pnc = cond( relat == 1 &  educlev == 3, 1, 0 );/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pnc "Head incomplete primary";

by hid: gen h_pc  = cond( relat == 1 &  educlev == 4, 1, 0 );/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_pc "Head completed primary";

by hid: gen h_snc = cond( relat == 1 &  educlev == 5, 1, 0 );/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_snc "Head incomplete secondary";

by hid: gen h_sc  = cond( relat == 1 &  educlev == 6, 1, 0 );/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_sc "Head completed secondary";

by hid: gen h_ts  = cond( relat == 1 &  educlev == 7, 1, 0 );/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ts "Head has tertiary";

by hid: gen h_ps  = cond( relat == 1 &  educlev == 8, 1, 0 );/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var h_ps "Head preschool only";

by hid: gen h_ue  = cond( relat == 1 &  educlev == 9 | educlev == 99 | educlev == ., 1, 0 );
lab var h_ue "Head unstated/unknown education";

by hid: gen h_sct = cond( relat == 1 & educlev == 5|educlev==6 | educlev==7,1,0) ; /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_sct "Head has at least imcomplete, completed secondary or tertiary education";

/*by hid: gen h_st  = cond( relat == 1 & educlev>=5 & educlev<=7,1,0);/*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_st "Head has at least some secondary education"*/;

by hid: gen h_prim = cond( relat == 1 & educlev==3|educlev==4|educlev==8,1,0);/*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_prim "Head has at least some prescholl or primary education";

by hid: gen h_noeduc=cond( relat == 1 & educlev==1, 1, 0);/*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var h_noeduc "Head has no education or has preschool";


/*
tempvar test_h_ed1;
egen test_h_ed1 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps );
lab var test_h_ed1 "Test that head has some level of education if educlev ~= .";
*assert test_h_ed1 == 1 if ( educlev < 9 & educlev ~= . );

tempvar test_h_ed3;
egen test_h_ed3 = rsum( h_ne h_ke h_pnc h_pc h_snc h_sc h_ts h_ps h_ue );
lab var test_h_ed1 "Test that head has education information or missing";
*assert test_h_ed3 <= 1;

tempvar test_h_ed2;
egen test_h_ed2 = rsum( h_sct h_sct h_prim );
lab var test_h_ed2 "Test of head's educlev for lumping education";
*assert test_h_ed2 <= 2 if ( test_h_ed2 ~= . );
*/

by hid: gen h_lit = cond( relat == 1 & literacy == 1, 1, 0 );
lab var h_lit "Head is literate";

by hid: gen h_occup= occupat if relat == 1;
*by hid: gen h_industry= industry if relat == 1;
by hid: gen h_statoc= statoc if relat == 1;

********************************************Migration variables**********************************************;
cap drop t_mig_h ;
by hid: g t_mig_h =cond( relat == 1 & t_mig==1, 1, 0) if t_mig~=.;
lab var t_mig_h "Head is a Long Term Migrant";
cap drop l_mig_h ;
by hid: gen l_mig_h = cond( relat == 1 & l_mig == 1, 1, 0) if l_mig~=.;
lab var l_mig_h "Head is a Long Term Migrant";

sort hid;

******************************************* Land Variables **************************************************;
cap drop land ;
bysort hid: gen byte land = cond(ownland == 1, 1, 0 ) if ( ownland ~= . ) ;
lab var land "Head owns land";
cap drop landsize;
gen landsize=s3b1q15a+s3b1q15b;
replace landsize = 0 if ownland == 2;
cap drop landsz;
rename landsize landsz ;
*recast double landsz;
lab var landsz " land (ha) owned by household";  

cap drop landsz2 ;
by hid: gen float landsz2 = (landsz^2);
lab var landsz2 "Square of land (ha) owned by household";

* if no observations, regression won't run;
qui sum landsz;
if ( `r(N)' == 0 ) {;
	replace landsz  = 0;
	replace landsz2 = 0;
	};

count;

sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;
compress;
sort hid;

*save, replace;

/****************************************** Remmitances Variables *******************************************;

*label define yesno 1 "Yes" 2 "No", add;

label value s9bq06 s9bq06;
label value s9bq01 yesno;

rename s9bq01 get_remit;
rename s9bq06 source_remit  ;

tab get_remit;
tab get_remit poor, row col;
tab source_remit;
tab source_remit poor, row col;

gen remit_value=s9bq09+s9bq10+s9bq11;
* If one is missing, all are missings. If one is non-missing, all are non-missing!;

gen missing_rem=cond(remit_value==.,1,0);
tab missing_rem*/;












/* ---------------- */
/* Spouse variables */
/* ---------------- */;


count;

cap drop sp;
gen sp=1 if relat==2;
recode sp .=0;
cap drop nbsp;
egen nbsp=sum(sp), by(hid);
tab nbsp;
/*
preserve;
keep if relat==1;
tab nbsp;
restore;
drop nbsp;
*/;
cap drop smaxage;
bysort hid: egen smaxage = max(agey) if relat == 2;
drop if (relat==2 & agey < smaxage);

count;

sort hid;
by hid: g count=_n;
ta count;
drop if count>1;
drop count;

cap drop nbsp;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;
*============
* Controlling for the possibility of 2 spouses with same age and education,
* then keep the one with the lowest indid
* ===========;

cap drop realed;

gen realed=educlev;
*recode realed 1=0 8=1 9=. 99=.;
cap drop smaxeduc;
bysort hid: egen smaxeduc = max(realed) if realed~=.;
drop if (relat==2 & realed < smaxeduc) | realed==.;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

cap drop sminindi;
bysort hid: egen sminindi = min(indid);
drop if (relat==2 & indid > sminindi);
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

count;

* note: agey cannot be missing;
by hid: gen s_agey =agey if relat==2 ;
replace s_agey=0 if s_agey==.;
lab var s_agey "Age of spouse";

by hid: gen s_agey_c = cond( agey < 99, agey, . ) if relat==2;
lab var s_agey_c "Spouse's age corrected for 99";

by hid: gen int s_agey2 = ((s_agey)^2);
lab var s_agey2 "Square of age of Spouse";

by hid: gen int s_agey2_c = ((s_agey_c)^2) if relat==2;
lab var s_agey2_c "Square of age of spouse corrected for 99";

************************************ Health status of the spouse*****************************************************;
sort hid;
by hid: g int s_hand=1 if handicap==1 & relat==2;
replace s_hand=0 if s_hand==.;

************************************ Religion of the head**********************************************************;
sort hid;
by hid: g int s_christ=1 if religion==1 &  relat==2; /*Spouse Christian*/;
replace s_christ=0 if s_christ==.;
by hid: g int s_musl=1 if religion==2 &  relat==2; /*Spouse Muslem*/;
replace s_musl=0 if s_musl==.;
by hid: g int s_anim=1 if religion==3 &  relat==2; /*Spouse Animist*/;
replace s_anim=0 if s_anim==.;

************************************ Ethnicity of the head**********************************************************;
sort hid;
by hid: g int s_akan=1    if ethnie==1 &  relat==2; /*Spouse akan*/;
replace s_akan=0 if s_akan==.;
by hid: g int s_krou=1    if ethnie==2 &  relat==2; /*Spouse Krou*/;
replace s_krou=0 if s_krou==.;
by hid: g int s_manden=1  if ethnie==3 &  relat==2; /*Spouse Mande North*/;
replace s_manden=0 if s_manden==.;
by hid: g int s_mandes=1  if ethnie==4 &  relat==2; /*Spouse mande South*/;
replace s_mandes=0 if s_mandes==.;
by hid: g int s_mande=cond(s_manden==1|s_mandes==1, 1, 0)   /*Mande*/ ;
by hid: g int s_volta=1   if ethnie==5 &  relat==2; /*Spouse voltaic*/;
replace s_volta=0 if s_volta==.;
by hid: g int s_etr=1     if ethnie==9 &  relat==2; /*Spouse Stranger*/;
replace s_etr=0 if s_etr==.;









***************************************** employment variables**************************************************;
/*by hid: gen s_ilf = cond( lf==1, 1, 0 ) if ( lf ~= . ) &  relat==2;
lab var s_ilf "Head of household in labor force"*/;

by hid: gen s_nilf = cond( nilf==1, 1, 0 ) &  relat==2;
lab var s_nilf "Head of household not in labor force";

by hid: gen int s_hrs = hourwrk if ( empl == 1 ) &  relat==2;
lab var s_hrs "Head's hours worked per week";

* could be amended to be those who are employed ;
by hid: gen s_em = cond( empl == 1, 1, 0 ) if ( empl ~= . )   &  relat==2 ;
/*Here I take empl instead of occupat to take into account, those who have a job but have not worked last 7 days*/;
lab var s_em "Head of household is employed";

* could be amended to be those who are unemployed (search==1 and/or want to work) /*But I choose to drop the search condition*/;
by hid: gen s_unem = cond( unempl== 1, 1, 0 ) if ( unempl ~= . ) &  relat==2;
lab var s_unem "Head of household is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;



/*
by hid: gen s_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_pub "Head is public sector wage employee";
by hid: gen s_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );

lab var s_pvt "Head is private sector wage employee";
*by hid: gen s_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
*lab var s_emp "Head is an employer";
by hid: gen s_inf = cond(occupat==1 & statocc==3,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_inf "Head works in informal sector";
by hid: gen s_self = cond(occupat==1 & statocc==4,1,0 ) if ( empl == 1 ) & ( occupat ~= . & statocc ~= . );
lab var s_self "Head is self employed";
tab s_self;
by hid: gen s_ag = cond( empl == 1, 1, 0 ) if (occupat ~= . & statocc ~= . );
lab var s_ag "Head is engaged in an agricultural activity";
tab s_ag;
*/



sort hid;

by hid: g s_ag=cond(industry==1| s2q16b==17|s2q16b==18|s2q16b==20, 1, 0) if ( empl == 1)  &  relat==2;
lab var s_ag "Head is engaged in an agricultural activity";
tab s_ag, m;
recode s_ag .=0;

by hid: g s_man=cond(industry==2| s2q16b==11|s2q16b==12|s2q16b==13, 1, 0) if ( empl == 1)  &  relat==2;
lab var s_man "Spouse is engaged in Manufacturing/Mining and quarrying/construction/transport/other activities";
tab s_man, m;
recode s_man .=0;

by hid: g s_com=cond(industry==3|(s2q16b==14| s2q16b==15| s2q16b==16), 1, 0) if ( empl == 1 )  &  relat==2;
lab var s_com "Spouse is engaged in Utilities/commerce activities";
tab s_com, m;
recode s_com .=0;

by hid: g s_adm=cond(industry==4 | (s2q16b>=1 & s2q16b<=10), 1, 0) if ( empl == 1 )  &  relat==2;
lab var s_adm "Spouse is engaged in Banking/financial services/Professional/Public administration activities";
tab s_adm, m;
recode s_adm .=0;

by hid: g s_other=cond(industry>4| (s2q16b==19|s2q16b==21), 1, 0) if ( empl == 1 )  &  relat==2;
lab var s_other "Spouse is engaged in Other activities";
tab s_other, m;
recode s_other .=0;


/*
by hid: gen int s_hrs = hourwrk;
lab var s_hrs "Spouse hours worked per week";

by hid: gen s_ag = cond( empl == 1, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var s_ag "Spouse is engaged in an agricultural activity"*/;


*by hid: gen s_job = cond( s_ag   == 1 | s_mfg  == 1 | s_mine == 1 | s_cnst == 1 | s_util == 1 | 
			       s_comm == 1 | s_bank == 1 | s_prof == 1 | s_pbad == 1 | s_tspt == 1 | 
			       s_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );




/*by hid: gen s_job =  cond( s_pub == 1   | s_pvt == 1  | s_inf == 1 | s_self == 1 , 1, 0 ) 
			        if ( occupat ~= . /*& industry ~= .*/ )*/;

cap drop s_job;
by hid: gen s_job =  cond( s_ag == 1   | s_com == 1  | s_adm == 1 | s_man == 1 , 1, 0 ) 
			        if ( occupat ~= . /*& industry ~= .*/ );
lab var s_job "Spouse has a job";

* check that the spouse has a job, is unemployed, or is not in the labor force;
tempvar sjob_test;
replace s_unem = 0 if s_job == 1;
replace s_nilf = 0 if s_unem == 1;
replace s_nilf = 0 if s_job == 1;
cap drop sjob_test ;
gen int sjob_test = s_job + s_unem + s_nilf;
*assert sjob_test <= 1 if ( sjob_test ~= . );
tab sjob_test;

cap drop s_nojb ;
by hid: gen s_nojb = cond( s_nilf == 1 | s_unem == 1, 1, 0 ) if ( occupat ~= .);
lab var s_nojb "Spouse has no job";






* education variables;

by hid: gen s_ne  = cond( relat == 2 &  educlev == 1, 1, 0 ); /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_ne "Spouse has no education";

by hid: gen s_ke  = cond( relat == 2 &   educlev == 2, 1, 0 ) ;/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ke "Spouse has koranic education";

by hid: gen s_pnc = cond( relat == 2 &   educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pnc "Spouse incomplete primary";

by hid: gen s_pc  = cond( relat == 2 &   educlev == 4, 1, 0 )  ;/* if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pc "Spouse completed primary";

by hid: gen s_snc = cond( relat == 2 &   educlev == 5, 1, 0 ) ;/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_snc "Spouse incomplete secondary";

by hid: gen s_sc  = cond(  relat == 2 &  educlev == 6, 1, 0 ) ;/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_sc "Spouse completed secondary";

by hid: gen s_ts  = cond(  relat == 2 &  educlev == 7, 1, 0 )  ;/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ts "Spouse tertiary";

by hid: gen s_ps  = cond( relat == 2 &   educlev == 8, 1, 0 ) ;/*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ps "Spouse preschool only";

by hid: gen s_ue  = cond( relat == 2 &   educlev == 9 | educlev == 99 | educlev==., 1, 0 );
lab var s_ue "Spouse unstated education";

by hid: gen s_sct = cond( relat == 2 &  educlev==5|educlev==6|educlev==7,1,0)  ;/*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_sct "Spouse has imcomplete , completed secondary or tertiary education";

by hid: gen s_st  = cond( relat == 2 &  educlev>=5&educlev<=7,1,0)  ;/*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_st "Spouse has at least some secondary education";

by hid: gen s_prim = cond( relat == 2 &  educlev==3|educlev==4|educlev==8,1,0) ;/*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_prim "Spouse has some level of primary schooling";

by hid: gen s_noeduc = cond( relat == 2 &  educlev==1,1,0)  ;/*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_noeduc "Spouse has no education or has preschool";

/*
tempvar test_s_ed1;
egen test_s_ed1 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps );
lab var test_s_ed1 "Test that spouse has some level of education if educlev ~= .";
*assert test_s_ed1 <= 1 if ( educlev < 9 & educlev ~= . );

tempvar test_s_ed3;
egen test_s_ed3 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps s_ue );
lab var test_s_ed1 "Test that spouse has education information or missing";
*assert test_s_ed3 <= 1;

tempvar test_s_ed2;
egen test_s_ed2 = rsum( s_sct s_st s_prim );
lab var test_s_ed2 "Test of spouse's educlev for lumping education";
*assert test_s_ed2 <= 2 if ( test_s_ed2 ~= . );
*/

by hid: gen s_lit = cond( literacy == 1, 1, 0 );
lab var s_lit "Spouse is literate";

********************************************Migration variables**********************************************;
cap drop t_mig_s ;
by hid: g t_mig_s=cond( relat == 2 &  t_mig==1, 1, 0) if t_mig~=. ;
lab var t_mig_s "Spouse is a Long Term Migrant";
cap drop l_mig_s ;
by hid: gen l_mig_s = cond( relat == 2 &  l_mig == 1, 1, 0) if l_mig~=. ;
lab var l_mig_s "Spouse is a Long Term Migrant";

sort hid;
tab relat;
by hid: gen s_occup= occupat if relat==2;
*by hid: gen s_industry= industry if relat==2;
by hid: gen s_statoc= statoc if relat==2;
g s_relat=relat if relat==2;
compress;
sort hid;

save, replace;

#delimit cr