clear
set mem 100m
set matsize 300
set more 1

*! Author: Amadou Bassirou DIALLO
*AFTP, The World Bank, Washington
*CERDI, University of Auvergne.


*******************************************************************
***This file takes the new Cote d'Ivoire Household Survey (2002)***
***and and analyses the determinants of consumption and poverty****
*******************************************************************

cd "O:\QWodon\Bachir DIALLO\Employment_Consumption_Poverty\Other surveys\Donnes\STATA"

cap log close
log using spouse.log, replace

use temp, clear

#delimit;

/* ---------------- */
/* Spouse variables */
/* ---------------- */;


gen sp=1 if relat==2;
recode sp .=0;
egen nbsp=sum(sp), by(hid);
tab nbsp;
preserve;
keep if relat==1;
tab nbsp;
restore;
drop nbsp;

bysort hid: egen smaxage = max(agey) if relat == 2;
keep if relat == 2 & agey == smaxage;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

*============
* Controlling for the possibility of 2 spauses with same age and education,
* then keep the one with the lowest indid
* ===========;

gen realed=educlev;
*recode realed 1=0 8=1 9=. 99=.;
bysort hid: egen smaxeduc = max(realed) if realed~=.;
keep if (realed == smaxeduc) | realed==.;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

bysort hid: egen sminindi = min(indid);
keep if indid == sminindi;
egen nbsp=sum(sp), by(hid);
tab nbsp;
drop nbsp;

count;

* note: agey cannot be missing;
by hid: gen s_agey = agey;
lab var s_agey "Age of spouse";

by hid: gen s_agey_c = cond( agey < 99, agey, . );
lab var s_agey_c "Spouse's age corrected for 99";

by hid: gen int s_agey2 = ((s_agey)^2);
lab var s_agey2 "Square of age of Spouse";

by hid: gen int s_agey2_c = ((s_agey_c)^2);
lab var s_agey2_c "Square of age of spouse corrected for 99";


***************************************** employment variables**************************************************;
by hid: gen s_nilf = cond( occupat > 2, 1, 0 ) if ( occupat ~= . );
lab var s_nilf "Spouse not in labor force";

* could be amended to be those unemployed;
by hid: gen s_unem = cond( occupat == 2, 1, 0 ) if ( occupat ~= .);
lab var s_unem "Spouse is unemployed";

*replace industry=0 if occupat>1 & occupat~=.;
replace statocc=0 if occupat>1 & occupat~=.;

by hid: gen s_pub = cond( occupat == 1 & statocc == 1, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var s_pub "Spouse is public sector wage employee";

by hid: gen s_pvt = cond( occupat == 1 & statocc == 2, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var s_pvt "Spouse is private sector wage employee";

*by hid: gen s_emp = cond( occupat == 1 & statocc == 5, 1, 0 ) if ( occupat ~= . & statocc ~= . );
*lab var s_emp "Spouse is an employer";

by hid: gen s_inf = cond( occupat == 1 & (statocc == 3 | statocc==6 | statocc==9), 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var s_inf "Spouse works in informal sector";

by hid: gen s_self = cond(occupat==1 & statocc==4,1,0 ) if (occupat ~= . & statocc ~= .);
lab var s_self "Spouse is self employed";

by hid: gen int s_hrs = hourwrk;
lab var s_hrs "Spouse hours worked per week";

by hid: gen s_ag = cond( empl == 1, 1, 0 ) if ( occupat ~= . & statocc ~= . );
lab var s_ag "Spouse is engaged in an agricultural activity";


/*INDUSTRY: NEED TO INCORPORATE: SEE RWANDA*/;

*by hid: gen s_job = cond( s_ag   == 1 | s_mfg  == 1 | s_mine == 1 | s_cnst == 1 | s_util == 1 | 
			       s_comm == 1 | s_bank == 1 | s_prof == 1 | s_pbad == 1 | s_tspt == 1 | 
			       s_othr == 1, 1, 0 ) if ( occupat ~= . & industry ~= . );
by hid: gen s_job =  cond( s_pub == 1   | s_pvt == 1  | s_inf == 1 | s_self == 1 , 1, 0 ) 
			        if ( occupat ~= . /*& industry ~= .*/ );
lab var s_job "Spouse has a job";

* check that the spouse has a job, is unemployed, or is not in the labor force;
tempvar sjob_test;
replace s_unem = 0 if s_job == 1;
replace s_nilf = 0 if s_unem == 1;
replace s_nilf = 0 if s_job == 1;
gen int sjob_test = s_job + s_unem + s_nilf;
assert sjob_test <= 1 if ( sjob_test ~= . );
tab sjob_test;

by hid: gen s_nojb = cond( s_nilf == 1 | s_unem == 1, 1, 0 ) if ( occupat ~= .);
lab var s_nojb "Spouse has no job";

* education variables;

by hid: gen s_ne  = cond( educlev == 1, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_ne "Spouse has no education";

by hid: gen s_ke  = cond( educlev == 2, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ke "Spouse has koranic education";

by hid: gen s_pnc = cond( educlev == 3, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pnc "Spouse incomplete primary";

by hid: gen s_pc  = cond( educlev == 4, 1, 0 ) /* if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_pc "Spouse completed primary";

by hid: gen s_snc = cond( educlev == 5, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_snc "Spouse incomplete secondary";

by hid: gen s_sc  = cond( educlev == 6, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_sc "Spouse completed secondary";

by hid: gen s_ts  = cond( educlev == 7, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ts "Spouse tertiary";

by hid: gen s_ps  = cond( educlev == 8, 1, 0 ) /*if ( educlev ~= . & educlev ~= 9 & educlev ~= 99 )*/;
lab var s_ps "Spouse preschool only";

by hid: gen s_ue  = cond( educlev == 9 | educlev == 99 | educlev==., 1, 0 );
lab var s_ue "Spouse unstated education";

by hid: gen s_sct = cond(educlev==6|educlev==7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_sct "Spouse has completed secondary or tertiary education";

by hid: gen s_st  = cond(educlev>=5&educlev<=7,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_st "Spouse has at least some secondary education";

by hid: gen s_prim = cond(educlev==3|educlev==4,1,0) /*if (educlev ~= . & educlev ~= 9 & educlev ~= 99)*/;
lab var s_prim "Spouse has some level of primary schooling";

tempvar test_s_ed1;
egen test_s_ed1 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps );
lab var test_s_ed1 "Test that spouse has some level of education if educlev ~= .";
assert test_s_ed1 <= 1 if ( educlev < 9 & educlev ~= . );

tempvar test_s_ed3;
egen test_s_ed3 = rsum( s_ne s_ke s_pnc s_pc s_snc s_sc s_ts s_ps s_ue );
lab var test_s_ed1 "Test that spouse has education information or missing";
assert test_s_ed3 <= 1;

tempvar test_s_ed2;
egen test_s_ed2 = rsum( s_sct s_st s_prim );
lab var test_s_ed2 "Test of spouse's educlev for lumping education";
assert test_s_ed2 <= 2 if ( test_s_ed2 ~= . );

by hid: gen s_lit = cond( literacy == 1, 1, 0 ) if ( literacy ~= . );
lab var s_lit "Spouse is literate";

sort hid;
tab relat;
by hid: gen s_occup= occupat;
*by hid: gen s_industry= industry;
by hid: gen s_statoc= statoc;
g s_relat=relat ;
sort grappe menord hid indid ;

save spouse, replace;

#delimit cr
log close